package org.jboss.errai.bus.client.framework;

import java.io.InputStream;
import java.lang.annotation.Annotation;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.Set;
import java.util.function.Predicate;
import javax.enterprise.event.Event;
import org.dashbuilder.dataprovider.DataSetProviderType;
import org.dashbuilder.dataset.DataSet;
import org.dashbuilder.dataset.DataSetLookup;
import org.dashbuilder.dataset.DataSetMetadata;
import org.dashbuilder.dataset.backend.EditDataSetDef;
import org.dashbuilder.dataset.def.DataSetDef;
import org.dashbuilder.dataset.service.DataSetDefServices;
import org.dashbuilder.dataset.service.DataSetDefVfsServices;
import org.dashbuilder.dataset.service.DataSetExportServices;
import org.dashbuilder.dataset.service.DataSetLookupServices;
import org.dashbuilder.dataset.service.SQLProviderServices;
import org.dashbuilder.displayer.DisplayerSettings;
import org.dashbuilder.navigation.NavTree;
import org.dashbuilder.navigation.layout.LayoutTemplateContext;
import org.dashbuilder.navigation.layout.LayoutTemplateInfo;
import org.dashbuilder.navigation.service.NavigationServices;
import org.dashbuilder.navigation.service.PerspectivePluginServices;
import org.dashbuilder.renderer.RendererSettings;
import org.dashbuilder.renderer.service.RendererSettingsService;
import org.dashbuilder.transfer.DataTransferServices;
import org.drools.scenariosimulation.api.model.AuditLog;
import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
import org.drools.scenariosimulation.api.model.ScenarioSimulationModel.Type;
import org.drools.scenariosimulation.api.model.Simulation;
import org.drools.scenariosimulation.api.model.SimulationDescriptor;
import org.drools.workbench.models.datamodel.rule.RuleModel;
import org.drools.workbench.models.guided.dtable.shared.conversion.ConversionResult;
import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
import org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree;
import org.drools.workbench.models.guided.scorecard.shared.ScoreCardModel;
import org.drools.workbench.models.guided.template.shared.TemplateModel;
import org.drools.workbench.models.testscenarios.shared.Scenario;
import org.drools.workbench.screens.drltext.model.DrlModelContent;
import org.drools.workbench.screens.drltext.service.DRLTextEditorService;
import org.drools.workbench.screens.dsltext.model.DSLTextEditorContent;
import org.drools.workbench.screens.dsltext.service.DSLTextEditorService;
import org.drools.workbench.screens.dtablexls.service.DecisionTableXLSContent;
import org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService;
import org.drools.workbench.screens.enums.model.EnumModelContent;
import org.drools.workbench.screens.enums.service.EnumService;
import org.drools.workbench.screens.globals.model.GlobalsEditorContent;
import org.drools.workbench.screens.globals.model.GlobalsModel;
import org.drools.workbench.screens.globals.service.GlobalsEditorService;
import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphContent;
import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphModel;
import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService;
import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService;
import org.drools.workbench.screens.guided.dtable.shared.XLSConversionResult;
import org.drools.workbench.screens.guided.dtree.model.GuidedDecisionTreeEditorContent;
import org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService;
import org.drools.workbench.screens.guided.rule.model.GuidedEditorContent;
import org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService;
import org.drools.workbench.screens.guided.scorecard.model.ScoreCardModelContent;
import org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService;
import org.drools.workbench.screens.guided.template.model.GuidedTemplateEditorContent;
import org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService;
import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModelContent;
import org.drools.workbench.screens.scenariosimulation.model.SimulationRunResult;
import org.drools.workbench.screens.scenariosimulation.model.typedescriptor.FactModelTuple;
import org.drools.workbench.screens.scenariosimulation.service.DMNTypeService;
import org.drools.workbench.screens.scenariosimulation.service.ImportExportService;
import org.drools.workbench.screens.scenariosimulation.service.ImportExportType;
import org.drools.workbench.screens.scenariosimulation.service.RunnerReportService;
import org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService;
import org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSContent;
import org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService;
import org.drools.workbench.screens.testscenario.model.TestScenarioModelContent;
import org.drools.workbench.screens.testscenario.model.TestScenarioResult;
import org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService;
import org.drools.workbench.screens.workitems.model.WorkItemDefinitionElements;
import org.drools.workbench.screens.workitems.model.WorkItemsModelContent;
import org.drools.workbench.screens.workitems.service.WorkItemsEditorService;
import org.guvnor.ala.ui.model.PipelineExecutionTraceKey;
import org.guvnor.ala.ui.model.PipelineKey;
import org.guvnor.ala.ui.model.Provider;
import org.guvnor.ala.ui.model.ProviderConfiguration;
import org.guvnor.ala.ui.model.ProviderKey;
import org.guvnor.ala.ui.model.ProviderType;
import org.guvnor.ala.ui.model.ProviderTypeKey;
import org.guvnor.ala.ui.model.ProvidersInfo;
import org.guvnor.ala.ui.model.RuntimeKey;
import org.guvnor.ala.ui.model.RuntimeListItem;
import org.guvnor.ala.ui.model.RuntimesInfo;
import org.guvnor.ala.ui.openshift.model.DefaultSettings;
import org.guvnor.ala.ui.openshift.model.TemplateDescriptorModel;
import org.guvnor.ala.ui.openshift.service.OpenShiftClientService;
import org.guvnor.ala.ui.service.ProviderService;
import org.guvnor.ala.ui.service.ProviderTypeService;
import org.guvnor.ala.ui.service.ProvisioningScreensService;
import org.guvnor.ala.ui.service.ProvisioningValidationService;
import org.guvnor.ala.ui.service.RuntimeService;
import org.guvnor.ala.ui.service.SourceService;
import org.guvnor.common.services.project.builder.model.BuildResults;
import org.guvnor.common.services.project.builder.model.IncrementalBuildResults;
import org.guvnor.common.services.project.builder.service.BuildService;
import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
import org.guvnor.common.services.project.model.GAV;
import org.guvnor.common.services.project.model.MavenRepositoryMetadata;
import org.guvnor.common.services.project.model.Module;
import org.guvnor.common.services.project.model.ModuleRepositories;
import org.guvnor.common.services.project.model.POM;
import org.guvnor.common.services.project.model.Package;
import org.guvnor.common.services.project.model.ProjectImports;
import org.guvnor.common.services.project.model.WorkspaceProject;
import org.guvnor.common.services.project.security.ProjectPermissionsService;
import org.guvnor.common.services.project.service.DeploymentMode;
import org.guvnor.common.services.project.service.ModuleRepositoriesService;
import org.guvnor.common.services.project.service.ModuleRepositoryResolver;
import org.guvnor.common.services.project.service.ModuleService;
import org.guvnor.common.services.project.service.POMService;
import org.guvnor.common.services.project.service.WorkspaceProjectSearchService;
import org.guvnor.common.services.project.service.WorkspaceProjectService;
import org.guvnor.common.services.shared.config.AppConfigService;
import org.guvnor.common.services.shared.config.ResourceConfigService;
import org.guvnor.common.services.shared.metadata.MetadataService;
import org.guvnor.common.services.shared.metadata.model.Metadata;
import org.guvnor.common.services.shared.test.TestRunnerService;
import org.guvnor.m2repo.model.JarListPageRequest;
import org.guvnor.m2repo.service.M2RepoService;
import org.guvnor.structure.navigator.FileNavigatorService;
import org.guvnor.structure.navigator.NavigatorContent;
import org.guvnor.structure.organizationalunit.OrganizationalUnit;
import org.guvnor.structure.organizationalunit.OrganizationalUnitSearchService;
import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
import org.guvnor.structure.organizationalunit.config.BranchPermissions;
import org.guvnor.structure.repositories.Branch;
import org.guvnor.structure.repositories.Repository;
import org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations;
import org.guvnor.structure.repositories.RepositoryInfo;
import org.guvnor.structure.repositories.RepositorySearchService;
import org.guvnor.structure.repositories.RepositoryService;
import org.guvnor.structure.repositories.RepositoryServiceEditor;
import org.guvnor.structure.repositories.changerequest.ChangeRequestService;
import org.guvnor.structure.repositories.changerequest.portable.ChangeRequest;
import org.guvnor.structure.repositories.changerequest.portable.ChangeRequestCountSummary;
import org.guvnor.structure.repositories.changerequest.portable.PaginatedChangeRequestCommentList;
import org.guvnor.structure.repositories.changerequest.portable.PaginatedChangeRequestList;
import org.jboss.errai.bus.client.api.base.MessageBuilder;
import org.jboss.errai.bus.client.api.builder.RemoteCallSendable;
import org.jboss.errai.bus.client.api.messaging.MessageBus;
import org.jboss.errai.common.client.api.ErrorCallback;
import org.jboss.errai.common.client.api.RemoteCallback;
import org.jboss.errai.common.client.api.interceptor.InterceptedCall;
import org.jboss.errai.common.client.api.interceptor.RemoteCallContext;
import org.jboss.errai.common.client.framework.CallContextStatus;
import org.jboss.errai.common.client.framework.ProxyProvider;
import org.jboss.errai.common.client.framework.RemoteServiceProxyFactory;
import org.jboss.errai.common.client.util.AsyncBeanFactory;
import org.jboss.errai.common.client.util.CreationalCallback;
import org.jboss.errai.security.client.local.interceptors.AuthenticationServiceInterceptor;
import org.jboss.errai.security.shared.api.Group;
import org.jboss.errai.security.shared.api.Role;
import org.jboss.errai.security.shared.api.identity.User;
import org.jboss.errai.security.shared.service.AuthenticationService;
import org.jboss.errai.security.shared.service.NonCachingUserService;
import org.jbpm.designer.service.DesignerAssetService;
import org.jbpm.designer.service.DesignerContent;
import org.jbpm.workbench.common.model.QueryFilter;
import org.jbpm.workbench.common.service.GenericServiceEntryPoint;
import org.jbpm.workbench.es.model.ExecutionErrorSummary;
import org.jbpm.workbench.es.model.RequestDetails;
import org.jbpm.workbench.es.service.ExecutorService;
import org.jbpm.workbench.forms.display.FormRenderingSettings;
import org.jbpm.workbench.forms.display.service.KieWorkbenchFormsEntryPoint;
import org.jbpm.workbench.forms.service.shared.FormServiceEntryPoint;
import org.jbpm.workbench.ht.model.TaskAssignmentSummary;
import org.jbpm.workbench.ht.model.TaskSummary;
import org.jbpm.workbench.ht.service.TaskService;
import org.jbpm.workbench.pr.model.ProcessDefinitionKey;
import org.jbpm.workbench.pr.model.ProcessInstanceDiagramSummary;
import org.jbpm.workbench.pr.model.ProcessInstanceKey;
import org.jbpm.workbench.pr.model.ProcessInstanceSummary;
import org.jbpm.workbench.pr.model.ProcessSummary;
import org.jbpm.workbench.pr.model.TimerInstanceSummary;
import org.jbpm.workbench.pr.model.WorkItemSummary;
import org.jbpm.workbench.pr.service.ProcessDocumentsService;
import org.jbpm.workbench.pr.service.ProcessImageService;
import org.jbpm.workbench.pr.service.ProcessRuntimeDataService;
import org.jbpm.workbench.pr.service.ProcessService;
import org.jbpm.workbench.pr.service.ProcessVariablesService;
import org.jbpm.workbench.wi.casemgmt.service.CaseProjectService;
import org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningService;
import org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings;
import org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningStatus;
import org.jbpm.workbench.wi.dd.model.DeploymentDescriptorModel;
import org.jbpm.workbench.wi.dd.service.DDEditorService;
import org.jbpm.workbench.wi.workitems.model.ServiceTasksConfiguration;
import org.jbpm.workbench.wi.workitems.service.ServiceTaskService;
import org.kie.server.api.model.ReleaseId;
import org.kie.server.controller.api.model.runtime.ServerInstanceKey;
import org.kie.server.controller.api.model.spec.Capability;
import org.kie.server.controller.api.model.spec.ContainerConfig;
import org.kie.server.controller.api.model.spec.ContainerSpec;
import org.kie.server.controller.api.model.spec.ContainerSpecKey;
import org.kie.server.controller.api.model.spec.ServerTemplate;
import org.kie.server.controller.api.model.spec.ServerTemplateKeyList;
import org.kie.server.controller.api.model.spec.ServerTemplateList;
import org.kie.soup.project.datamodel.imports.Imports;
import org.kie.workbench.common.dmn.api.editors.included.DMNIncludedModelsService;
import org.kie.workbench.common.dmn.api.editors.types.DMNParseService;
import org.kie.workbench.common.dmn.api.editors.types.DMNValidationService;
import org.kie.workbench.common.dmn.api.editors.types.RangeValue;
import org.kie.workbench.common.dmn.api.editors.types.TimeZoneService;
import org.kie.workbench.common.forms.data.modeller.model.DataObjectFormModel;
import org.kie.workbench.common.forms.data.modeller.service.shared.ModelFinderService;
import org.kie.workbench.common.forms.dynamic.model.config.SelectorData;
import org.kie.workbench.common.forms.dynamic.service.shared.BackendSelectorDataProviderService;
import org.kie.workbench.common.forms.dynamic.service.shared.FormRenderingContext;
import org.kie.workbench.common.forms.editor.model.FormModelerContent;
import org.kie.workbench.common.forms.editor.service.shared.FormEditorService;
import org.kie.workbench.common.forms.editor.service.shared.ModuleFormFinderService;
import org.kie.workbench.common.forms.jbpm.model.authoring.JBPMProcessModel;
import org.kie.workbench.common.forms.jbpm.service.shared.BPMFinderService;
import org.kie.workbench.common.forms.jbpm.service.shared.documents.DocumentUploadChunk;
import org.kie.workbench.common.forms.jbpm.service.shared.documents.DocumentUploadResponse;
import org.kie.workbench.common.forms.jbpm.service.shared.documents.UploadedDocumentService;
import org.kie.workbench.common.forms.model.FormDefinition;
import org.kie.workbench.common.forms.model.FormModel;
import org.kie.workbench.common.profile.api.preferences.ProfileService;
import org.kie.workbench.common.screens.datamodeller.model.EditorModelContent;
import org.kie.workbench.common.screens.datamodeller.model.GenerationResult;
import org.kie.workbench.common.screens.datamodeller.model.TypeInfoResult;
import org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorEditorContent;
import org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorModel;
import org.kie.workbench.common.screens.datamodeller.service.DataModelerService;
import org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorEditorService;
import org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService;
import org.kie.workbench.common.screens.datamodeller.validation.DataObjectValidationService;
import org.kie.workbench.common.screens.datasource.management.metadata.DatabaseMetadata;
import org.kie.workbench.common.screens.datasource.management.metadata.DatabaseMetadata.TableType;
import org.kie.workbench.common.screens.datasource.management.model.DataSourceDef;
import org.kie.workbench.common.screens.datasource.management.model.DataSourceDefEditorContent;
import org.kie.workbench.common.screens.datasource.management.model.DataSourceDeploymentInfo;
import org.kie.workbench.common.screens.datasource.management.model.DriverDef;
import org.kie.workbench.common.screens.datasource.management.model.DriverDefEditorContent;
import org.kie.workbench.common.screens.datasource.management.model.DriverDefInfo;
import org.kie.workbench.common.screens.datasource.management.model.DriverDeploymentInfo;
import org.kie.workbench.common.screens.datasource.management.model.TestResult;
import org.kie.workbench.common.screens.datasource.management.service.DataManagementService;
import org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService;
import org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService;
import org.kie.workbench.common.screens.datasource.management.service.DataSourceRuntimeManagerClientService;
import org.kie.workbench.common.screens.datasource.management.service.DatabaseMetadataService;
import org.kie.workbench.common.screens.datasource.management.service.DefExplorerQuery;
import org.kie.workbench.common.screens.datasource.management.service.DefExplorerQueryResult;
import org.kie.workbench.common.screens.datasource.management.service.DefExplorerQueryService;
import org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService;
import org.kie.workbench.common.screens.defaulteditor.service.DefaultEditorContent;
import org.kie.workbench.common.screens.defaulteditor.service.DefaultEditorService;
import org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit;
import org.kie.workbench.common.screens.examples.model.ExampleRepository;
import org.kie.workbench.common.screens.examples.model.ExamplesMetaData;
import org.kie.workbench.common.screens.examples.model.ImportProject;
import org.kie.workbench.common.screens.examples.service.ExamplesService;
import org.kie.workbench.common.screens.examples.service.ProjectImportService;
import org.kie.workbench.common.screens.explorer.model.FolderItem;
import org.kie.workbench.common.screens.explorer.model.FolderListing;
import org.kie.workbench.common.screens.explorer.model.ProjectExplorerContent;
import org.kie.workbench.common.screens.explorer.service.ActiveOptions;
import org.kie.workbench.common.screens.explorer.service.ExplorerService;
import org.kie.workbench.common.screens.explorer.service.ProjectExplorerContentQuery;
import org.kie.workbench.common.screens.library.api.AssetQueryResult;
import org.kie.workbench.common.screens.library.api.LibraryInfo;
import org.kie.workbench.common.screens.library.api.LibraryService;
import org.kie.workbench.common.screens.library.api.OrganizationalUnitRepositoryInfo;
import org.kie.workbench.common.screens.library.api.ProjectAssetsQuery;
import org.kie.workbench.common.screens.projecteditor.model.ProjectScreenModel;
import org.kie.workbench.common.screens.projecteditor.service.PomEditorService;
import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
import org.kie.workbench.common.screens.server.management.model.ContainerSpecData;
import org.kie.workbench.common.screens.server.management.service.RuleCapabilitiesService;
import org.kie.workbench.common.screens.server.management.service.RuntimeManagementService;
import org.kie.workbench.common.screens.server.management.service.SpecManagementService;
import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleIncrementalPayload;
import org.kie.workbench.common.services.datamodel.service.IncrementalDataModelService;
import org.kie.workbench.common.services.datamodeller.core.DataModel;
import org.kie.workbench.common.services.datamodeller.core.DataObject;
import org.kie.workbench.common.services.datamodeller.core.ElementType;
import org.kie.workbench.common.services.datamodeller.core.JavaClass;
import org.kie.workbench.common.services.datamodeller.core.ObjectProperty;
import org.kie.workbench.common.services.datamodeller.driver.model.AnnotationDefinitionRequest;
import org.kie.workbench.common.services.datamodeller.driver.model.AnnotationDefinitionResponse;
import org.kie.workbench.common.services.datamodeller.driver.model.AnnotationParseRequest;
import org.kie.workbench.common.services.datamodeller.driver.model.AnnotationParseResponse;
import org.kie.workbench.common.services.datamodeller.driver.model.AnnotationSourceRequest;
import org.kie.workbench.common.services.datamodeller.driver.model.AnnotationSourceResponse;
import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRequest;
import org.kie.workbench.common.services.refactoring.service.AssetsUsageService;
import org.kie.workbench.common.services.refactoring.service.PartType;
import org.kie.workbench.common.services.refactoring.service.RefactoringQueryService;
import org.kie.workbench.common.services.refactoring.service.ResourceType;
import org.kie.workbench.common.services.refactoring.service.ScoreCardServiceLoader;
import org.kie.workbench.common.services.refactoring.service.impact.QueryOperationRequest;
import org.kie.workbench.common.services.shared.dependencies.DependencyService;
import org.kie.workbench.common.services.shared.dependencies.EnhancedDependencies;
import org.kie.workbench.common.services.shared.enums.EnumDropdownService;
import org.kie.workbench.common.services.shared.kmodule.KModuleModel;
import org.kie.workbench.common.services.shared.kmodule.KModuleService;
import org.kie.workbench.common.services.shared.project.KieModule;
import org.kie.workbench.common.services.shared.project.KieModuleService;
import org.kie.workbench.common.services.shared.project.ProjectImportsContent;
import org.kie.workbench.common.services.shared.project.ProjectImportsService;
import org.kie.workbench.common.services.shared.rulename.RuleNamesService;
import org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService;
import org.kie.workbench.common.services.shared.whitelist.WhiteList;
import org.kie.workbench.common.stunner.bpmn.forms.conditions.Condition;
import org.kie.workbench.common.stunner.bpmn.forms.conditions.ConditionEditorService;
import org.kie.workbench.common.stunner.bpmn.forms.conditions.GenerateConditionResult;
import org.kie.workbench.common.stunner.bpmn.forms.conditions.ParseConditionResult;
import org.kie.workbench.common.stunner.bpmn.forms.conditions.TypeMetadataQuery;
import org.kie.workbench.common.stunner.bpmn.forms.conditions.TypeMetadataQueryResult;
import org.kie.workbench.common.stunner.bpmn.integration.service.IntegrationService;
import org.kie.workbench.common.stunner.bpmn.integration.service.MigrateRequest;
import org.kie.workbench.common.stunner.bpmn.integration.service.MigrateResult;
import org.kie.workbench.common.stunner.bpmn.project.service.BPMNDiagramService;
import org.kie.workbench.common.stunner.bpmn.project.service.DataTypesService;
import org.kie.workbench.common.stunner.bpmn.service.ProjectType;
import org.kie.workbench.common.stunner.bpmn.workitem.service.WorkItemDefinitionLookupService;
import org.kie.workbench.common.stunner.cm.project.service.CaseManagementSwitchViewService;
import org.kie.workbench.common.stunner.core.diagram.Diagram;
import org.kie.workbench.common.stunner.core.graph.Element;
import org.kie.workbench.common.stunner.core.lookup.LookupManager.LookupResponse;
import org.kie.workbench.common.stunner.core.lookup.diagram.DiagramLookupRequest;
import org.kie.workbench.common.stunner.core.marshaller.MarshallingRequest.Mode;
import org.kie.workbench.common.stunner.core.marshaller.MarshallingResponse;
import org.kie.workbench.common.stunner.core.registry.factory.FactoryRegistry;
import org.kie.workbench.common.stunner.core.service.DiagramLookupService;
import org.kie.workbench.common.stunner.core.service.DiagramService;
import org.kie.workbench.common.stunner.core.service.FactoryService;
import org.kie.workbench.common.stunner.forms.service.FormGenerationService;
import org.kie.workbench.common.stunner.kogito.api.service.KogitoDiagramService;
import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
import org.kie.workbench.common.stunner.project.diagram.ProjectMetadata;
import org.kie.workbench.common.stunner.project.diagram.editor.ProjectDiagramResource;
import org.kie.workbench.common.stunner.project.service.ProjectDiagramLookupService;
import org.kie.workbench.common.stunner.project.service.ProjectDiagramResourceService;
import org.kie.workbench.common.stunner.project.service.ProjectDiagramService;
import org.kie.workbench.common.stunner.project.service.ProjectValidationService;
import org.optaplanner.workbench.screens.domaineditor.service.ComparatorDefinitionService;
import org.optaplanner.workbench.screens.guidedrule.model.ScoreInformation;
import org.optaplanner.workbench.screens.guidedrule.service.ScoreHolderService;
import org.optaplanner.workbench.screens.solver.model.SolverConfigModel;
import org.optaplanner.workbench.screens.solver.model.SolverModelContent;
import org.optaplanner.workbench.screens.solver.service.SolverEditorService;
import org.uberfire.backend.authz.AuthorizationService;
import org.uberfire.backend.plugin.RuntimePluginService;
import org.uberfire.backend.vfs.DirectoryStream;
import org.uberfire.backend.vfs.DirectoryStream.Filter;
import org.uberfire.backend.vfs.Path;
import org.uberfire.backend.vfs.VFSLockService;
import org.uberfire.backend.vfs.VFSService;
import org.uberfire.backend.vfs.impl.LockInfo;
import org.uberfire.backend.vfs.impl.LockResult;
import org.uberfire.backend.vfs.impl.VFSCacheInterceptor;
import org.uberfire.experimental.service.backend.BackendExperimentalFeatureDefRegistry;
import org.uberfire.experimental.service.backend.BackendExperimentalFeaturesRegistryService;
import org.uberfire.experimental.service.backend.ExperimentalFeaturesSession;
import org.uberfire.experimental.service.definition.ExperimentalFeatureDefinition;
import org.uberfire.experimental.service.editor.EditableExperimentalFeature;
import org.uberfire.experimental.service.editor.FeaturesEditorService;
import org.uberfire.ext.apps.api.AppsPersistenceAPI;
import org.uberfire.ext.apps.api.Directory;
import org.uberfire.ext.editor.commons.file.DefaultMetadata;
import org.uberfire.ext.editor.commons.service.CopyService;
import org.uberfire.ext.editor.commons.service.DeleteService;
import org.uberfire.ext.editor.commons.service.RenameService;
import org.uberfire.ext.editor.commons.service.ValidationService;
import org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService;
import org.uberfire.ext.editor.commons.version.VersionService;
import org.uberfire.ext.layout.editor.api.LayoutServices;
import org.uberfire.ext.layout.editor.api.PerspectiveServices;
import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate.Style;
import org.uberfire.ext.plugin.model.DynamicMenu;
import org.uberfire.ext.plugin.model.LayoutEditorModel;
import org.uberfire.ext.plugin.model.Media;
import org.uberfire.ext.plugin.model.Plugin;
import org.uberfire.ext.plugin.model.PluginContent;
import org.uberfire.ext.plugin.model.PluginType;
import org.uberfire.ext.plugin.service.PluginServices;
import org.uberfire.ext.properties.editor.model.PropertyEditorCategory;
import org.uberfire.ext.properties.editor.service.BeanPropertyEditorBuilderService;
import org.uberfire.ext.security.management.api.AbstractEntityManager.SearchRequest;
import org.uberfire.ext.security.management.api.AbstractEntityManager.SearchResponse;
import org.uberfire.ext.security.management.api.GroupManagerSettings;
import org.uberfire.ext.security.management.api.RoleManagerSettings;
import org.uberfire.ext.security.management.api.UserManagerSettings;
import org.uberfire.ext.security.management.api.service.GroupManagerService;
import org.uberfire.ext.security.management.api.service.RoleManagerService;
import org.uberfire.ext.security.management.api.service.UserManagerService;
import org.uberfire.ext.services.shared.preferences.UserPreference;
import org.uberfire.ext.services.shared.preferences.UserPreferencesService;
import org.uberfire.ext.services.shared.preferences.UserPreferencesType;
import org.uberfire.java.nio.base.version.VersionRecord;
import org.uberfire.mvp.Command;
import org.uberfire.mvp.ParameterizedCommand;
import org.uberfire.mvp.PlaceRequest;
import org.uberfire.paging.PageResponse;
import org.uberfire.preferences.shared.PreferenceScope;
import org.uberfire.preferences.shared.PreferenceScopeResolver;
import org.uberfire.preferences.shared.PreferenceStorage;
import org.uberfire.preferences.shared.PreferenceStore;
import org.uberfire.preferences.shared.bean.BasePreferencePortable;
import org.uberfire.preferences.shared.bean.PreferenceBeanServerStore;
import org.uberfire.preferences.shared.bean.PreferenceHierarchyElement;
import org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo;
import org.uberfire.preferences.shared.impl.PreferenceScopedValue;
import org.uberfire.security.authz.AuthorizationPolicy;
import org.uberfire.spaces.Space;
import org.uberfire.ssh.service.shared.editor.PortableSSHPublicKey;
import org.uberfire.ssh.service.shared.editor.SSHKeyEditorService;
import org.uberfire.workbench.model.PerspectiveDefinition;
import org.uberfire.workbench.model.SplashScreenFilter;
import org.uberfire.workbench.services.WorkbenchServices;

public class RpcProxyLoaderImpl implements RpcProxyLoader { public void loadProxies(final MessageBus bus) {
    class org_kie_workbench_common_dmn_api_editors_types_DMNParseServiceImpl extends AbstractRpcProxy implements DMNParseService { public List parseFEELList(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.types.DMNParseService").endpoint("parseFEELList:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_types_DMNParseServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public RangeValue parseRangeValue(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.types.DMNParseService").endpoint("parseRangeValue:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(RangeValue.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_types_DMNParseServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DMNParseService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_dmn_api_editors_types_DMNParseServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_project_service_ProjectDiagramLookupServiceImpl extends AbstractRpcProxy implements ProjectDiagramLookupService { public LookupResponse lookup(final DiagramLookupRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramLookupService").endpoint("lookup:org.kie.workbench.common.stunner.core.lookup.diagram.DiagramLookupRequest:", qualifiers, new Object[] { a0 }).respondTo(LookupResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramLookupServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectDiagramLookupService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_project_service_ProjectDiagramLookupServiceImpl();
      }
    });
    class org_optaplanner_workbench_screens_guidedrule_service_ScoreHolderServiceImpl extends AbstractRpcProxy implements ScoreHolderService { public ScoreInformation getProjectScoreInformation(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.guidedrule.service.ScoreHolderService").endpoint("getProjectScoreInformation:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ScoreInformation.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_guidedrule_service_ScoreHolderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ScoreHolderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_optaplanner_workbench_screens_guidedrule_service_ScoreHolderServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_enums_EnumDropdownServiceImpl extends AbstractRpcProxy implements EnumDropdownService { public String[] loadDropDownExpression(final Path a0, final String[] a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.enums.EnumDropdownService").endpoint("loadDropDownExpression:org.uberfire.backend.vfs.Path:java.lang.String[]:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(String[].class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_enums_EnumDropdownServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(EnumDropdownService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_enums_EnumDropdownServiceImpl();
      }
    });
    class org_kie_workbench_common_services_refactoring_service_ScoreCardServiceLoaderImpl extends AbstractRpcProxy implements ScoreCardServiceLoader { public Set find(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.ScoreCardServiceLoader").endpoint("find:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_ScoreCardServiceLoaderImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ScoreCardServiceLoader.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_refactoring_service_ScoreCardServiceLoaderImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DataManagementServiceImpl extends AbstractRpcProxy implements DataManagementService { public DisplayerSettings getDisplayerSettings(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataManagementService").endpoint("getDisplayerSettings:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(DisplayerSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataManagementService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DataManagementServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl extends AbstractRpcProxy implements ProjectImportsService { public ProjectImportsContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.ProjectImportsService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ProjectImportsContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void saveProjectImports(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.ProjectImportsService").endpoint("saveProjectImports:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl.this.sendRequest(bus, sendable);
      }

      public ProjectImports load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.ProjectImportsService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ProjectImports.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final ProjectImports a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.ProjectImportsService").endpoint("save:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.ProjectImports:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final ProjectImports a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.ProjectImportsService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.guvnor.common.services.project.model.ProjectImports:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.ProjectImportsService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectImportsService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_project_ProjectImportsServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_server_management_service_RuntimeManagementServiceImpl extends AbstractRpcProxy implements RuntimeManagementService { public Collection getContainersByServerInstance(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.RuntimeManagementService").endpoint("getContainersByServerInstance:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_RuntimeManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ContainerSpecData getContainersByContainerSpec(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.RuntimeManagementService").endpoint("getContainersByContainerSpec:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(ContainerSpecData.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_RuntimeManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RuntimeManagementService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_server_management_service_RuntimeManagementServiceImpl();
      }
    });
    class org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl extends AbstractRpcProxy implements GuidedDecisionTableEditorService { public GuidedDecisionTableEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedDecisionTableEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PackageDataModelOracleBaselinePayload loadDataModel(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("loadDataModel:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(PackageDataModelOracleBaselinePayload.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndUpdateGraphEntries(final Path a0, final GuidedDecisionTable52 a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("saveAndUpdateGraphEntries:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public XLSConversionResult convert(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("convert:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(XLSConversionResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final GuidedDecisionTable52 a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final GuidedDecisionTable52 a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final GuidedDecisionTable52 a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GuidedDecisionTable52 load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedDecisionTable52.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final GuidedDecisionTable52 a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final GuidedDecisionTable52 a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedDecisionTableEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableEditorServiceImpl();
      }
    });
    class org_uberfire_workbench_services_WorkbenchServicesImpl extends AbstractRpcProxy implements WorkbenchServices { public void save(final String a0, final PerspectiveDefinition a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("save:java.lang.String:org.uberfire.workbench.model.PerspectiveDefinition:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
      }

      public void save(final SplashScreenFilter a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("save:org.uberfire.workbench.model.SplashScreenFilter:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
      }

      public Set loadPerspectives() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("loadPerspectives:", qualifiers, new Object[] { }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PerspectiveDefinition loadPerspective(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("loadPerspective:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(PerspectiveDefinition.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void removePerspectiveState(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("removePerspectiveState:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
      }

      public void removePerspectiveStates() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("removePerspectiveStates:", qualifiers, new Object[] { }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
      }

      public SplashScreenFilter loadSplashScreenFilter(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("loadSplashScreenFilter:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(SplashScreenFilter.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map loadDefaultEditorsMap() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("loadDefaultEditorsMap:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void saveDefaultEditors(final Map a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("saveDefaultEditors:java.util.Map:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
      }

      public boolean isWorkbenchOnCluster() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.workbench.services.WorkbenchServices").endpoint("isWorkbenchOnCluster:", qualifiers, new Object[] { }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_workbench_services_WorkbenchServicesImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(WorkbenchServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_workbench_services_WorkbenchServicesImpl();
      }
    });
    class org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl extends AbstractRpcProxy implements RefactoringQueryService { public int queryHitCount(final RefactoringPageRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.RefactoringQueryService").endpoint("queryHitCount:org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRequest:", qualifiers, new Object[] { a0 }).respondTo(Integer.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl.this.sendRequest(bus, sendable);
        return 0;
      }

      public PageResponse query(final RefactoringPageRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.RefactoringQueryService").endpoint("query:org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRequest:", qualifiers, new Object[] { a0 }).respondTo(PageResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List query(final String a0, final Set a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.RefactoringQueryService").endpoint("query:java.lang.String:java.util.Set:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PageResponse queryToPageResponse(final QueryOperationRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.RefactoringQueryService").endpoint("queryToPageResponse:org.kie.workbench.common.services.refactoring.service.impact.QueryOperationRequest:", qualifiers, new Object[] { a0 }).respondTo(PageResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List queryToList(final QueryOperationRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.RefactoringQueryService").endpoint("queryToList:org.kie.workbench.common.services.refactoring.service.impact.QueryOperationRequest:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RefactoringQueryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_refactoring_service_RefactoringQueryServiceImpl();
      }
    });
    class org_dashbuilder_navigation_service_NavigationServicesImpl extends AbstractRpcProxy implements NavigationServices { public NavTree loadNavTree() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.NavigationServices").endpoint("loadNavTree:", qualifiers, new Object[] { }).respondTo(NavTree.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_NavigationServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void saveNavTree(final NavTree a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.NavigationServices").endpoint("saveNavTree:org.dashbuilder.navigation.NavTree:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_NavigationServicesImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(NavigationServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_navigation_service_NavigationServicesImpl();
      }
    });
    class org_uberfire_ext_editor_commons_version_VersionServiceImpl extends AbstractRpcProxy implements VersionService { public List getVersions(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.version.VersionService").endpoint("getVersions:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_version_VersionServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path getPathToPreviousVersion(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.version.VersionService").endpoint("getPathToPreviousVersion:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_version_VersionServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path restore(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.version.VersionService").endpoint("restore:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_version_VersionServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(VersionService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_editor_commons_version_VersionServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl extends AbstractRpcProxy implements DriverDefEditorService { public DriverDefEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DriverDefEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final DriverDefEditorContent a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.datasource.management.model.DriverDefEditorContent:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final DriverDef a0, final Module a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService").endpoint("create:org.kie.workbench.common.screens.datasource.management.model.DriverDef:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createGlobal(final DriverDef a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService").endpoint("createGlobal:org.kie.workbench.common.screens.datasource.management.model.DriverDef:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public List validate(final DriverDef a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DriverDefEditorService").endpoint("validate:org.kie.workbench.common.screens.datasource.management.model.DriverDef:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DriverDefEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DriverDefEditorServiceImpl();
      }
    });
    class org_dashbuilder_dataset_service_DataSetExportServicesImpl extends AbstractRpcProxy implements DataSetExportServices { public Path exportDataSetCSV(final DataSetLookup a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetExportServices").endpoint("exportDataSetCSV:org.dashbuilder.dataset.DataSetLookup:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetExportServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path exportDataSetCSV(final DataSet a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetExportServices").endpoint("exportDataSetCSV:org.dashbuilder.dataset.DataSet:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetExportServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path exportDataSetExcel(final DataSetLookup a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetExportServices").endpoint("exportDataSetExcel:org.dashbuilder.dataset.DataSetLookup:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetExportServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path exportDataSetExcel(final DataSet a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetExportServices").endpoint("exportDataSetExcel:org.dashbuilder.dataset.DataSet:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetExportServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSetExportServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_dataset_service_DataSetExportServicesImpl();
      }
    });
    class org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl extends AbstractRpcProxy implements ProjectScreenService { public ProjectScreenModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ProjectScreenModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void save(final Path a0, final ProjectScreenModel a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.projecteditor.model.ProjectScreenModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl.this.sendRequest(bus, sendable);
      }

      public WorkspaceProject save(final Path a0, final ProjectScreenModel a1, final String a2, final DeploymentMode a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.projecteditor.model.ProjectScreenModel:java.lang.String:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final WorkspaceProject a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService").endpoint("delete:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl.this.sendRequest(bus, sendable);
      }

      public void copy(final WorkspaceProject a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService").endpoint("copy:org.guvnor.common.services.project.model.WorkspaceProject:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl.this.sendRequest(bus, sendable);
      }

      public void reImport(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService").endpoint("reImport:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectScreenService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_projecteditor_service_ProjectScreenServiceImpl();
      }
    });
    class org_uberfire_ssh_service_shared_editor_SSHKeyEditorServiceImpl extends AbstractRpcProxy implements SSHKeyEditorService { public Collection getUserKeys() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ssh.service.shared.editor.SSHKeyEditorService").endpoint("getUserKeys:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ssh_service_shared_editor_SSHKeyEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void deleteKey(final PortableSSHPublicKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ssh.service.shared.editor.SSHKeyEditorService").endpoint("deleteKey:org.uberfire.ssh.service.shared.editor.PortableSSHPublicKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ssh_service_shared_editor_SSHKeyEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public void addKey(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ssh.service.shared.editor.SSHKeyEditorService").endpoint("addKey:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ssh_service_shared_editor_SSHKeyEditorServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(SSHKeyEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ssh_service_shared_editor_SSHKeyEditorServiceImpl();
      }
    });
    class org_uberfire_ext_properties_editor_service_BeanPropertyEditorBuilderServiceImpl extends AbstractRpcProxy implements BeanPropertyEditorBuilderService { public PropertyEditorCategory extract(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.properties.editor.service.BeanPropertyEditorBuilderService").endpoint("extract:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(PropertyEditorCategory.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_properties_editor_service_BeanPropertyEditorBuilderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PropertyEditorCategory extract(final String a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.properties.editor.service.BeanPropertyEditorBuilderService").endpoint("extract:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(PropertyEditorCategory.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_properties_editor_service_BeanPropertyEditorBuilderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BeanPropertyEditorBuilderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_properties_editor_service_BeanPropertyEditorBuilderServiceImpl();
      }
    });
    class org_guvnor_common_services_shared_config_AppConfigServiceImpl extends AbstractRpcProxy implements AppConfigService { public Map loadPreferences() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.config.AppConfigService").endpoint("loadPreferences:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_config_AppConfigServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public long getTimestamp() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.config.AppConfigService").endpoint("getTimestamp:", qualifiers, new Object[] { }).respondTo(Long.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_config_AppConfigServiceImpl.this.sendRequest(bus, sendable);
        return 0L;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(AppConfigService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_shared_config_AppConfigServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_integration_service_IntegrationServiceImpl extends AbstractRpcProxy implements IntegrationService { public MigrateResult migrateDiagram(final MigrateRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.integration.service.IntegrationService").endpoint("migrateDiagram:org.kie.workbench.common.stunner.bpmn.integration.service.MigrateRequest:", qualifiers, new Object[] { a0 }).respondTo(MigrateResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_integration_service_IntegrationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public MarshallingResponse getDiagramByPath(final Path a0, final Mode a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.integration.service.IntegrationService").endpoint("getDiagramByPath:org.uberfire.backend.vfs.Path:org.kie.workbench.common.stunner.core.marshaller.MarshallingRequest.Mode:", qualifiers, new Object[] { a0, a1 }).respondTo(MarshallingResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_integration_service_IntegrationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(IntegrationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_bpmn_integration_service_IntegrationServiceImpl();
      }
    });
    class org_uberfire_ext_plugin_service_PluginServicesImpl extends AbstractRpcProxy implements PluginServices { public String getMediaServletURI() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("getMediaServletURI:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listRuntimePlugins() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("listRuntimePlugins:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listPluginRuntimePlugins(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("listPluginRuntimePlugins:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listPlugins() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("listPlugins:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listPlugins(final PluginType a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("listPlugins:org.uberfire.ext.plugin.model.PluginType:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Plugin createNewPlugin(final String a0, final PluginType a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("createNewPlugin:java.lang.String:org.uberfire.ext.plugin.model.PluginType:", qualifiers, new Object[] { a0, a1 }).respondTo(Plugin.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PluginContent getPluginContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("getPluginContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(PluginContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void deleteMedia(final Media a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("deleteMedia:org.uberfire.ext.plugin.model.Media:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
      }

      public DynamicMenu getDynamicMenuContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("getDynamicMenuContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DynamicMenu.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Plugin a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("save:org.uberfire.ext.plugin.model.Plugin:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutEditorModel getLayoutEditor(final Path a0, final PluginType a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("getLayoutEditor:org.uberfire.backend.vfs.Path:org.uberfire.ext.plugin.model.PluginType:", qualifiers, new Object[] { a0, a1 }).respondTo(LayoutEditorModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveMenu(final DynamicMenu a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("saveMenu:org.uberfire.ext.plugin.model.DynamicMenu:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveLayout(final LayoutEditorModel a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("saveLayout:org.uberfire.ext.plugin.model.LayoutEditorModel:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listDynamicMenus() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("listDynamicMenus:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listLayoutEditor(final PluginType a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("listLayoutEditor:org.uberfire.ext.plugin.model.PluginType:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final DefaultMetadata a2, final Plugin a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.ext.editor.commons.file.DefaultMetadata:org.uberfire.ext.plugin.model.Plugin:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final Plugin a1, final DefaultMetadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.plugin.service.PluginServices").endpoint("save:org.uberfire.backend.vfs.Path:org.uberfire.ext.plugin.model.Plugin:org.uberfire.ext.editor.commons.file.DefaultMetadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_plugin_service_PluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PluginServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_plugin_service_PluginServicesImpl();
      }
    });
    class org_jbpm_workbench_es_service_ExecutorServiceImpl extends AbstractRpcProxy implements ExecutorService { public RequestDetails getRequestDetails(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.es.service.ExecutorService").endpoint("getRequestDetails:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(RequestDetails.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_es_service_ExecutorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Long scheduleRequest(final String a0, final String a1, final Date a2, final Map a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.es.service.ExecutorService").endpoint("scheduleRequest:java.lang.String:java.lang.String:java.util.Date:java.util.Map:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Long.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_es_service_ExecutorServiceImpl.this.sendRequest(bus, sendable);
        return 0L;
      }

      public void cancelRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.es.service.ExecutorService").endpoint("cancelRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_es_service_ExecutorServiceImpl.this.sendRequest(bus, sendable);
      }

      public void requeueRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.es.service.ExecutorService").endpoint("requeueRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_es_service_ExecutorServiceImpl.this.sendRequest(bus, sendable);
      }

      public void acknowledgeError(final String a0, final String a1, final String[] a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.es.service.ExecutorService").endpoint("acknowledgeError:java.lang.String:java.lang.String:java.lang.String[]:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_es_service_ExecutorServiceImpl.this.sendRequest(bus, sendable);
      }

      public ExecutionErrorSummary getError(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.es.service.ExecutorService").endpoint("getError:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(ExecutionErrorSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_es_service_ExecutorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ExecutorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_es_service_ExecutorServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl extends AbstractRpcProxy implements SpecManagementService { public void saveContainerSpec(final String a0, final ContainerSpec a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("saveContainerSpec:java.lang.String:org.kie.server.controller.api.model.spec.ContainerSpec:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void saveServerTemplate(final ServerTemplate a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("saveServerTemplate:org.kie.server.controller.api.model.spec.ServerTemplate:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public ServerTemplate getServerTemplate(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("getServerTemplate:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(ServerTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void deleteServerInstance(final ServerInstanceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("deleteServerInstance:org.kie.server.controller.api.model.runtime.ServerInstanceKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public ServerTemplateKeyList listServerTemplateKeys() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("listServerTemplateKeys:", qualifiers, new Object[] { }).respondTo(ServerTemplateKeyList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ServerTemplateList listServerTemplates() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("listServerTemplates:", qualifiers, new Object[] { }).respondTo(ServerTemplateList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void deleteContainerSpec(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("deleteContainerSpec:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deleteServerTemplate(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("deleteServerTemplate:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void copyServerTemplate(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("copyServerTemplate:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateContainerConfig(final String a0, final String a1, final Capability a2, final ContainerConfig a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("updateContainerConfig:java.lang.String:java.lang.String:org.kie.server.controller.api.model.spec.Capability:org.kie.server.controller.api.model.spec.ContainerConfig:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateContainerSpec(final String a0, final ContainerSpec a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("updateContainerSpec:java.lang.String:org.kie.server.controller.api.model.spec.ContainerSpec:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateContainerSpec(final String a0, final String a1, final ContainerSpec a2, final boolean a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("updateContainerSpec:java.lang.String:java.lang.String:org.kie.server.controller.api.model.spec.ContainerSpec:boolean:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void startContainer(final ContainerSpecKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("startContainer:org.kie.server.controller.api.model.spec.ContainerSpecKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void stopContainer(final ContainerSpecKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("stopContainer:org.kie.server.controller.api.model.spec.ContainerSpecKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void activateContainer(final ContainerSpecKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("activateContainer:org.kie.server.controller.api.model.spec.ContainerSpecKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deactivateContainer(final ContainerSpecKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("deactivateContainer:org.kie.server.controller.api.model.spec.ContainerSpecKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
      }

      public boolean isContainerIdValid(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("isContainerIdValid:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public String validContainerId(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("validContainerId:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isNewServerTemplateIdValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.SpecManagementService").endpoint("isNewServerTemplateIdValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(SpecManagementService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_server_management_service_SpecManagementServiceImpl();
      }
    });
    class org_guvnor_ala_ui_service_ProvisioningValidationServiceImpl extends AbstractRpcProxy implements ProvisioningValidationService { public boolean isValidContainerName(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProvisioningValidationService").endpoint("isValidContainerName:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProvisioningValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProvisioningValidationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_service_ProvisioningValidationServiceImpl();
      }
    });
    class org_jboss_errai_security_shared_service_AuthenticationServiceImpl extends AbstractRpcProxy implements AuthenticationService { public User login(final String a0, final String a1) {
        try {
          final CallContextStatus status = new CallContextStatus(AuthenticationServiceInterceptor.class);
          final RemoteCallContext callContext = new RemoteCallContext() {
            public String getMethodName() {
              return "login";
            }
            public Class getReturnType() {
              return User.class;
            }
            public Annotation[] getAnnotations() {
              return new Annotation[] { };
            }
            public Annotation[] getTypeAnnotations() {
              return new Annotation[] { };
            }
            public Object proceed() {
              status.proceed();
              if (status.getNextInterceptor() == null) {
                RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jboss.errai.security.shared.service.AuthenticationService").endpoint("login:java.lang.String:java.lang.String:", qualifiers, getParameters()).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
                org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.sendRequest(bus, sendable);
              } else if (status.getNextInterceptor() == AuthenticationServiceInterceptor.class) {
                final RemoteCallContext ctx = this;
                final CreationalCallback icc = new CreationalCallback() {
                  public void callback(final Object beanInstance) {
                    status.setProceeding(false);
                    ((AuthenticationServiceInterceptor) beanInstance).aroundInvoke(ctx);
                    if ((!status.isProceeding()) && (AuthenticationServiceInterceptor.class == status.getNextInterceptor())) {
                      remoteCallback.callback(ctx.getResult());
                    }
                  }
                };
                org.jboss.errai.ioc.client.container.IOC.getAsyncBeanManager().lookupBeans(AuthenticationServiceInterceptor.class).iterator().next().getInstance(icc);
              }
              return null;
            }
            public void proceed(final RemoteCallback interceptorCallback) {
              final RemoteCallback providedCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.remoteCallback;
              remoteCallback = new RemoteCallback() {
                public void callback(Object response) {
                  RemoteCallback intCallback = interceptorCallback;
                  setResult(response);
                  intCallback.callback(getResult());
                  providedCallback.callback(getResult());
                }
              };
              proceed();
            }
            public void proceed(RemoteCallback interceptorCallback, final ErrorCallback interceptorErrorCallback) {
              final ErrorCallback providedErrorCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.errorCallback;
              errorCallback = new ErrorCallback() {
                public boolean error(Object message, Throwable throwable) {
                  interceptorErrorCallback.error(message, throwable);
                  if (getResult() != null) {
                    remoteCallback.callback(getResult());
                    return false;
                  } else if (providedErrorCallback != null) {
                    return providedErrorCallback.error(message, throwable);
                  }
                  return true;
                }
              };
              proceed(interceptorCallback);
            }
          };
          callContext.setParameters(new Object[] { a0, a1 });
          callContext.proceed();
        } catch (Throwable throwable) {
          if (errorCallback != null) {
            if (errorCallback.error(null, throwable)) {
              invokeDefaultErrorHandlers(throwable);
            }
          } else {
            invokeDefaultErrorHandlers(throwable);
          }
        }
        return null;
      }

      public boolean isLoggedIn() {
        try {
          final CallContextStatus status = new CallContextStatus(AuthenticationServiceInterceptor.class);
          final RemoteCallContext callContext = new RemoteCallContext() {
            public String getMethodName() {
              return "isLoggedIn";
            }
            public Class getReturnType() {
              return boolean.class;
            }
            public Annotation[] getAnnotations() {
              return new Annotation[] { };
            }
            public Annotation[] getTypeAnnotations() {
              return new Annotation[] { };
            }
            public Object proceed() {
              status.proceed();
              if (status.getNextInterceptor() == null) {
                RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jboss.errai.security.shared.service.AuthenticationService").endpoint("isLoggedIn:", qualifiers, getParameters()).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
                org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.sendRequest(bus, sendable);
              } else if (status.getNextInterceptor() == AuthenticationServiceInterceptor.class) {
                final RemoteCallContext ctx = this;
                final CreationalCallback icc = new CreationalCallback() {
                  public void callback(final Object beanInstance) {
                    status.setProceeding(false);
                    ((AuthenticationServiceInterceptor) beanInstance).aroundInvoke(ctx);
                    if ((!status.isProceeding()) && (AuthenticationServiceInterceptor.class == status.getNextInterceptor())) {
                      remoteCallback.callback(ctx.getResult());
                    }
                  }
                };
                org.jboss.errai.ioc.client.container.IOC.getAsyncBeanManager().lookupBeans(AuthenticationServiceInterceptor.class).iterator().next().getInstance(icc);
              }
              return null;
            }
            public void proceed(final RemoteCallback interceptorCallback) {
              final RemoteCallback providedCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.remoteCallback;
              remoteCallback = new RemoteCallback() {
                public void callback(Object response) {
                  RemoteCallback intCallback = interceptorCallback;
                  setResult(response);
                  intCallback.callback(getResult());
                  providedCallback.callback(getResult());
                }
              };
              proceed();
            }
            public void proceed(RemoteCallback interceptorCallback, final ErrorCallback interceptorErrorCallback) {
              final ErrorCallback providedErrorCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.errorCallback;
              errorCallback = new ErrorCallback() {
                public boolean error(Object message, Throwable throwable) {
                  interceptorErrorCallback.error(message, throwable);
                  if (getResult() != null) {
                    remoteCallback.callback(getResult());
                    return false;
                  } else if (providedErrorCallback != null) {
                    return providedErrorCallback.error(message, throwable);
                  }
                  return true;
                }
              };
              proceed(interceptorCallback);
            }
          };
          callContext.setParameters(new Object[] { });
          callContext.proceed();
        } catch (Throwable throwable) {
          if (errorCallback != null) {
            if (errorCallback.error(null, throwable)) {
              invokeDefaultErrorHandlers(throwable);
            }
          } else {
            invokeDefaultErrorHandlers(throwable);
          }
        }
        return false;
      }

      public void logout() {
        try {
          final CallContextStatus status = new CallContextStatus(AuthenticationServiceInterceptor.class);
          final RemoteCallContext callContext = new RemoteCallContext() {
            public String getMethodName() {
              return "logout";
            }
            public Class getReturnType() {
              return void.class;
            }
            public Annotation[] getAnnotations() {
              return new Annotation[] { };
            }
            public Annotation[] getTypeAnnotations() {
              return new Annotation[] { };
            }
            public Object proceed() {
              status.proceed();
              if (status.getNextInterceptor() == null) {
                RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jboss.errai.security.shared.service.AuthenticationService").endpoint("logout:", qualifiers, getParameters()).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
                org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.sendRequest(bus, sendable);
              } else if (status.getNextInterceptor() == AuthenticationServiceInterceptor.class) {
                final RemoteCallContext ctx = this;
                final CreationalCallback icc = new CreationalCallback() {
                  public void callback(final Object beanInstance) {
                    status.setProceeding(false);
                    ((AuthenticationServiceInterceptor) beanInstance).aroundInvoke(ctx);
                    if ((!status.isProceeding()) && (AuthenticationServiceInterceptor.class == status.getNextInterceptor())) {
                      remoteCallback.callback(ctx.getResult());
                    }
                  }
                };
                org.jboss.errai.ioc.client.container.IOC.getAsyncBeanManager().lookupBeans(AuthenticationServiceInterceptor.class).iterator().next().getInstance(icc);
              }
              return null;
            }
            public void proceed(final RemoteCallback interceptorCallback) {
              final RemoteCallback providedCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.remoteCallback;
              remoteCallback = new RemoteCallback() {
                public void callback(Object response) {
                  RemoteCallback intCallback = interceptorCallback;
                  setResult(response);
                  intCallback.callback(getResult());
                  providedCallback.callback(getResult());
                }
              };
              proceed();
            }
            public void proceed(RemoteCallback interceptorCallback, final ErrorCallback interceptorErrorCallback) {
              final ErrorCallback providedErrorCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.errorCallback;
              errorCallback = new ErrorCallback() {
                public boolean error(Object message, Throwable throwable) {
                  interceptorErrorCallback.error(message, throwable);
                  if (getResult() != null) {
                    remoteCallback.callback(getResult());
                    return false;
                  } else if (providedErrorCallback != null) {
                    return providedErrorCallback.error(message, throwable);
                  }
                  return true;
                }
              };
              proceed(interceptorCallback);
            }
          };
          callContext.setParameters(new Object[] { });
          callContext.proceed();
        } catch (Throwable throwable) {
          if (errorCallback != null) {
            if (errorCallback.error(null, throwable)) {
              invokeDefaultErrorHandlers(throwable);
            }
          } else {
            invokeDefaultErrorHandlers(throwable);
          }
        }
      }

      public User getUser() {
        try {
          final CallContextStatus status = new CallContextStatus(AuthenticationServiceInterceptor.class);
          final RemoteCallContext callContext = new RemoteCallContext() {
            public String getMethodName() {
              return "getUser";
            }
            public Class getReturnType() {
              return User.class;
            }
            public Annotation[] getAnnotations() {
              return new Annotation[] { };
            }
            public Annotation[] getTypeAnnotations() {
              return new Annotation[] { };
            }
            public Object proceed() {
              status.proceed();
              if (status.getNextInterceptor() == null) {
                RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jboss.errai.security.shared.service.AuthenticationService").endpoint("getUser:", qualifiers, getParameters()).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
                org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.sendRequest(bus, sendable);
              } else if (status.getNextInterceptor() == AuthenticationServiceInterceptor.class) {
                final RemoteCallContext ctx = this;
                final CreationalCallback icc = new CreationalCallback() {
                  public void callback(final Object beanInstance) {
                    status.setProceeding(false);
                    ((AuthenticationServiceInterceptor) beanInstance).aroundInvoke(ctx);
                    if ((!status.isProceeding()) && (AuthenticationServiceInterceptor.class == status.getNextInterceptor())) {
                      remoteCallback.callback(ctx.getResult());
                    }
                  }
                };
                org.jboss.errai.ioc.client.container.IOC.getAsyncBeanManager().lookupBeans(AuthenticationServiceInterceptor.class).iterator().next().getInstance(icc);
              }
              return null;
            }
            public void proceed(final RemoteCallback interceptorCallback) {
              final RemoteCallback providedCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.remoteCallback;
              remoteCallback = new RemoteCallback() {
                public void callback(Object response) {
                  RemoteCallback intCallback = interceptorCallback;
                  setResult(response);
                  intCallback.callback(getResult());
                  providedCallback.callback(getResult());
                }
              };
              proceed();
            }
            public void proceed(RemoteCallback interceptorCallback, final ErrorCallback interceptorErrorCallback) {
              final ErrorCallback providedErrorCallback = org_jboss_errai_security_shared_service_AuthenticationServiceImpl.this.errorCallback;
              errorCallback = new ErrorCallback() {
                public boolean error(Object message, Throwable throwable) {
                  interceptorErrorCallback.error(message, throwable);
                  if (getResult() != null) {
                    remoteCallback.callback(getResult());
                    return false;
                  } else if (providedErrorCallback != null) {
                    return providedErrorCallback.error(message, throwable);
                  }
                  return true;
                }
              };
              proceed(interceptorCallback);
            }
          };
          callContext.setParameters(new Object[] { });
          callContext.proceed();
        } catch (Throwable throwable) {
          if (errorCallback != null) {
            if (errorCallback.error(null, throwable)) {
              invokeDefaultErrorHandlers(throwable);
            }
          } else {
            invokeDefaultErrorHandlers(throwable);
          }
        }
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(AuthenticationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jboss_errai_security_shared_service_AuthenticationServiceImpl();
      }
    });
    class org_optaplanner_workbench_screens_domaineditor_service_ComparatorDefinitionServiceImpl extends AbstractRpcProxy implements ComparatorDefinitionService { public JavaClass createComparatorObject(final DataObject a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.domaineditor.service.ComparatorDefinitionService").endpoint("createComparatorObject:org.kie.workbench.common.services.datamodeller.core.DataObject:", qualifiers, new Object[] { a0 }).respondTo(JavaClass.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_domaineditor_service_ComparatorDefinitionServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public JavaClass updateComparatorObject(final DataObject a0, final JavaClass a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.domaineditor.service.ComparatorDefinitionService").endpoint("updateComparatorObject:org.kie.workbench.common.services.datamodeller.core.DataObject:org.kie.workbench.common.services.datamodeller.core.JavaClass:", qualifiers, new Object[] { a0, a1 }).respondTo(JavaClass.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_domaineditor_service_ComparatorDefinitionServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ComparatorDefinitionService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_optaplanner_workbench_screens_domaineditor_service_ComparatorDefinitionServiceImpl();
      }
    });
    class org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl extends AbstractRpcProxy implements ProcessRuntimeDataService { public ProcessInstanceSummary getProcessInstance(final ProcessInstanceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessInstance:org.jbpm.workbench.pr.model.ProcessInstanceKey:", qualifiers, new Object[] { a0 }).respondTo(ProcessInstanceSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getProcessInstanceActiveNodes(final ProcessInstanceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessInstanceActiveNodes:org.jbpm.workbench.pr.model.ProcessInstanceKey:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getProcessInstanceCompletedNodes(final ProcessInstanceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessInstanceCompletedNodes:org.jbpm.workbench.pr.model.ProcessInstanceKey:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getProcessInstanceTimerInstances(final ProcessInstanceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessInstanceTimerInstances:org.jbpm.workbench.pr.model.ProcessInstanceKey:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ProcessInstanceDiagramSummary getProcessInstanceDiagramSummary(final ProcessInstanceKey a0, final String a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessInstanceDiagramSummary:org.jbpm.workbench.pr.model.ProcessInstanceKey:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(ProcessInstanceDiagramSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getProcesses(final String a0, final Integer a1, final Integer a2, final String a3, final Boolean a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcesses:java.lang.String:java.lang.Integer:java.lang.Integer:java.lang.String:java.lang.Boolean:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ProcessSummary getProcess(final ProcessDefinitionKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcess:org.jbpm.workbench.pr.model.ProcessDefinitionKey:", qualifiers, new Object[] { a0 }).respondTo(ProcessSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getProcessesByFilter(final String a0, final String a1, final Integer a2, final Integer a3, final String a4, final Boolean a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessesByFilter:java.lang.String:java.lang.String:java.lang.Integer:java.lang.Integer:java.lang.String:java.lang.Boolean:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getProcessUserTasks(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessUserTasks:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkItemSummary getWorkItemByProcessInstanceId(final String a0, final String a1, final Long a2, final Long a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getWorkItemByProcessInstanceId:java.lang.String:java.lang.String:java.lang.Long:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(WorkItemSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void triggerProcessInstanceNode(final ProcessInstanceKey a0, final Long a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("triggerProcessInstanceNode:org.jbpm.workbench.pr.model.ProcessInstanceKey:java.lang.Long:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
      }

      public void cancelProcessInstanceNode(final ProcessInstanceKey a0, final Long a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("cancelProcessInstanceNode:org.jbpm.workbench.pr.model.ProcessInstanceKey:java.lang.Long:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
      }

      public void reTriggerProcessInstanceNode(final ProcessInstanceKey a0, final Long a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("reTriggerProcessInstanceNode:org.jbpm.workbench.pr.model.ProcessInstanceKey:java.lang.Long:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
      }

      public void rescheduleTimerInstance(final ProcessInstanceKey a0, final TimerInstanceSummary a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("rescheduleTimerInstance:org.jbpm.workbench.pr.model.ProcessInstanceKey:org.jbpm.workbench.pr.model.TimerInstanceSummary:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
      }

      public ProcessInstanceSummary getProcessInstanceByCorrelationKey(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessRuntimeDataService").endpoint("getProcessInstanceByCorrelationKey:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(ProcessInstanceSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProcessRuntimeDataService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_pr_service_ProcessRuntimeDataServiceImpl();
      }
    });
    class org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl extends AbstractRpcProxy implements BackendExperimentalFeatureDefRegistry { public Collection loadFeatureDefinitions(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.backend.BackendExperimentalFeatureDefRegistry").endpoint("loadFeatureDefinitions:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ExperimentalFeatureDefinition getFeatureById(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.backend.BackendExperimentalFeatureDefRegistry").endpoint("getFeatureById:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(ExperimentalFeatureDefinition.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllFeatures() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.backend.BackendExperimentalFeatureDefRegistry").endpoint("getAllFeatures:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getGlobalFeatures() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.backend.BackendExperimentalFeatureDefRegistry").endpoint("getGlobalFeatures:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getUserFeatures() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.backend.BackendExperimentalFeatureDefRegistry").endpoint("getUserFeatures:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BackendExperimentalFeatureDefRegistry.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_experimental_service_backend_BackendExperimentalFeatureDefRegistryImpl();
      }
    });
    class org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl extends AbstractRpcProxy implements ProjectImportService { public WorkspaceProjectContextChangeEvent importProjects(final OrganizationalUnit a0, final List a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ProjectImportService").endpoint("importProjects:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.util.List:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProjectContextChangeEvent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject importProject(final OrganizationalUnit a0, final ImportProject a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ProjectImportService").endpoint("importProject:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.kie.workbench.common.screens.examples.model.ImportProject:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject importProject(final OrganizationalUnit a0, final String a1, final String a2, final String a3, final List a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ProjectImportService").endpoint("importProject:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:java.lang.String:java.lang.String:java.util.List:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getProjects(final ExampleRepository a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ProjectImportService").endpoint("getProjects:org.kie.workbench.common.screens.examples.model.ExampleRepository:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public int priority() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ProjectImportService").endpoint("priority:", qualifiers, new Object[] { }).respondTo(Integer.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl.this.sendRequest(bus, sendable);
        return 0;
      }

      public void dispose() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ProjectImportService").endpoint("dispose:", qualifiers, new Object[] { }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectImportService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_examples_service_ProjectImportServiceImpl();
      }
    });
    class org_guvnor_ala_ui_service_ProviderTypeServiceImpl extends AbstractRpcProxy implements ProviderTypeService { public Collection getAvailableProviderTypes() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderTypeService").endpoint("getAvailableProviderTypes:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderTypeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ProviderType getProviderType(final ProviderTypeKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderTypeService").endpoint("getProviderType:org.guvnor.ala.ui.model.ProviderTypeKey:", qualifiers, new Object[] { a0 }).respondTo(ProviderType.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderTypeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getEnabledProviderTypes() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderTypeService").endpoint("getEnabledProviderTypes:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderTypeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void enableProviderTypes(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderTypeService").endpoint("enableProviderTypes:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderTypeServiceImpl.this.sendRequest(bus, sendable);
      }

      public void disableProviderType(final ProviderType a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderTypeService").endpoint("disableProviderType:org.guvnor.ala.ui.model.ProviderType:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderTypeServiceImpl.this.sendRequest(bus, sendable);
      }

      public Map getProviderTypesStatus() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderTypeService").endpoint("getProviderTypesStatus:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderTypeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProviderTypeService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_service_ProviderTypeServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl extends AbstractRpcProxy implements ExamplesService { public ExamplesMetaData getMetaData() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("getMetaData:", qualifiers, new Object[] { }).respondTo(ExamplesMetaData.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ExampleRepository getPlaygroundRepository() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("getPlaygroundRepository:", qualifiers, new Object[] { }).respondTo(ExampleRepository.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProjectContextChangeEvent setupExamples(final ExampleOrganizationalUnit a0, final List a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("setupExamples:org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit:java.util.List:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProjectContextChangeEvent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getExampleProjects() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("getExampleProjects:", qualifiers, new Object[] { }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getProjects(final ExampleRepository a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("getProjects:org.kie.workbench.common.screens.examples.model.ExampleRepository:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public int priority() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("priority:", qualifiers, new Object[] { }).respondTo(Integer.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
        return 0;
      }

      public void dispose() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.examples.service.ExamplesService").endpoint("dispose:", qualifiers, new Object[] { }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ExamplesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_examples_service_ExamplesServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl extends AbstractRpcProxy implements DataSourceDefQueryService { public Collection findGlobalDataSources(final boolean a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findGlobalDataSources:boolean:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection findModuleDataSources(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findModuleDataSources:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection findModuleDataSources(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findModuleDataSources:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection findGlobalDrivers() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findGlobalDrivers:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection findModuleDrivers(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findModuleDrivers:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection findModuleDrivers(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findModuleDrivers:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DriverDefInfo findModuleDriver(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findModuleDriver:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(DriverDefInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DriverDefInfo findGlobalDriver(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefQueryService").endpoint("findGlobalDriver:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(DriverDefInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSourceDefQueryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DataSourceDefQueryServiceImpl();
      }
    });
    class org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl extends AbstractRpcProxy implements ModuleRepositoryResolver { public Set getRemoteRepositoriesMetaData() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoryResolver").endpoint("getRemoteRepositoriesMetaData:", qualifiers, new Object[] { }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getRemoteRepositoriesMetaData(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoryResolver").endpoint("getRemoteRepositoriesMetaData:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getRepositoriesResolvingArtifact(final GAV a0, final MavenRepositoryMetadata[] a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoryResolver").endpoint("getRepositoriesResolvingArtifact:org.guvnor.common.services.project.model.GAV:org.guvnor.common.services.project.model.MavenRepositoryMetadata[]:", qualifiers, new Object[] { a0, a1 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getRepositoriesResolvingArtifact(final GAV a0, final Module a1, final MavenRepositoryMetadata[] a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoryResolver").endpoint("getRepositoriesResolvingArtifact:org.guvnor.common.services.project.model.GAV:org.guvnor.common.services.project.model.Module:org.guvnor.common.services.project.model.MavenRepositoryMetadata[]:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getRepositoriesResolvingArtifact(final String a0, final MavenRepositoryMetadata[] a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoryResolver").endpoint("getRepositoriesResolvingArtifact:java.lang.String:org.guvnor.common.services.project.model.MavenRepositoryMetadata[]:", qualifiers, new Object[] { a0, a1 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ModuleRepositoryResolver.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_service_ModuleRepositoryResolverImpl();
      }
    });
    class org_guvnor_common_services_project_security_ProjectPermissionsServiceImpl extends AbstractRpcProxy implements ProjectPermissionsService { public BranchPermissions loadBranchPermissions(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.security.ProjectPermissionsService").endpoint("loadBranchPermissions:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(BranchPermissions.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_security_ProjectPermissionsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map loadBranchPermissions(final String a0, final String a1, final List a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.security.ProjectPermissionsService").endpoint("loadBranchPermissions:java.lang.String:java.lang.String:java.util.List:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_security_ProjectPermissionsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectPermissionsService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_security_ProjectPermissionsServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_core_service_DiagramLookupServiceImpl extends AbstractRpcProxy implements DiagramLookupService { public LookupResponse lookup(final DiagramLookupRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramLookupService").endpoint("lookup:org.kie.workbench.common.stunner.core.lookup.diagram.DiagramLookupRequest:", qualifiers, new Object[] { a0 }).respondTo(LookupResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramLookupServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DiagramLookupService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_core_service_DiagramLookupServiceImpl();
      }
    });
    class org_guvnor_structure_navigator_FileNavigatorServiceImpl extends AbstractRpcProxy implements FileNavigatorService { public NavigatorContent listContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.navigator.FileNavigatorService").endpoint("listContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(NavigatorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_navigator_FileNavigatorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List listRepositories(final Space a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.navigator.FileNavigatorService").endpoint("listRepositories:org.uberfire.spaces.Space:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_navigator_FileNavigatorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(FileNavigatorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_navigator_FileNavigatorServiceImpl();
      }
    });
    class org_kie_workbench_common_profile_api_preferences_ProfileServiceImpl extends AbstractRpcProxy implements ProfileService { public boolean isForce() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.profile.api.preferences.ProfileService").endpoint("isForce:", qualifiers, new Object[] { }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_profile_api_preferences_ProfileServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProfileService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_profile_api_preferences_ProfileServiceImpl();
      }
    });
    class org_kie_workbench_common_services_refactoring_service_AssetsUsageServiceImpl extends AbstractRpcProxy implements AssetsUsageService { public List getAssetUsages(final String a0, final ResourceType a1, final Path a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.AssetsUsageService").endpoint("getAssetUsages:java.lang.String:org.kie.workbench.common.services.refactoring.service.ResourceType:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_AssetsUsageServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getAssetPartUsages(final String a0, final String a1, final PartType a2, final Path a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.refactoring.service.AssetsUsageService").endpoint("getAssetPartUsages:java.lang.String:java.lang.String:org.kie.workbench.common.services.refactoring.service.PartType:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_refactoring_service_AssetsUsageServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(AssetsUsageService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_refactoring_service_AssetsUsageServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl extends AbstractRpcProxy implements DataModelerService { public Path createJavaFile(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("createJavaFile:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createJavaFile(final Path a0, final String a1, final String a2, final Map a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("createJavaFile:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:java.util.Map:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public EditorModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(EditorModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public EditorModelContent loadContent(final Path a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("loadContent:org.uberfire.backend.vfs.Path:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(EditorModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DataModel loadModel(final KieModule a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("loadModel:org.kie.workbench.common.services.shared.project.KieModule:", qualifiers, new Object[] { a0 }).respondTo(DataModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult saveModel(final DataModel a0, final KieModule a1, final boolean a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("saveModel:org.kie.workbench.common.services.datamodeller.core.DataModel:org.kie.workbench.common.services.shared.project.KieModule:boolean:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult saveModel(final DataModel a0, final KieModule a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("saveModel:org.kie.workbench.common.services.datamodeller.core.DataModel:org.kie.workbench.common.services.shared.project.KieModule:", qualifiers, new Object[] { a0, a1 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult saveSource(final String a0, final Path a1, final DataObject a2, final Metadata a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("saveSource:java.lang.String:org.uberfire.backend.vfs.Path:org.kie.workbench.common.services.datamodeller.core.DataObject:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult saveSource(final String a0, final Path a1, final DataObject a2, final Metadata a3, final String a4, final String a5, final String a6) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("saveSource:java.lang.String:org.uberfire.backend.vfs.Path:org.kie.workbench.common.services.datamodeller.core.DataObject:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5, a6 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult updateSource(final String a0, final Path a1, final DataObject a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("updateSource:java.lang.String:org.uberfire.backend.vfs.Path:org.kie.workbench.common.services.datamodeller.core.DataObject:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult updateDataObject(final DataObject a0, final String a1, final Path a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("updateDataObject:org.kie.workbench.common.services.datamodeller.core.DataObject:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final String a2, final boolean a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:boolean:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final String a2, final Path a3, final String a4, final boolean a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:boolean:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2, final boolean a3, final boolean a4, final String a5, final DataObject a6, final Metadata a7) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:boolean:boolean:java.lang.String:org.kie.workbench.common.services.datamodeller.core.DataObject:org.guvnor.common.services.shared.metadata.model.Metadata:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5, a6, a7 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
      }

      public GenerationResult refactorClass(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("refactorClass:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final String a0, final Path a1, final DataObject a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("validate:java.lang.String:org.uberfire.backend.vfs.Path:org.kie.workbench.common.services.datamodeller.core.DataObject:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TypeInfoResult loadJavaTypeInfo(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("loadJavaTypeInfo:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(TypeInfoResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerationResult loadDataObject(final Path a0, final String a1, final Path a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("loadDataObject:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(GenerationResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getBasePropertyTypes() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("getBasePropertyTypes:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map getAnnotationDefinitions() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("getAnnotationDefinitions:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List findPersistableClasses(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("findPersistableClasses:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Boolean isPersistableClass(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("isPersistableClass:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Boolean exists(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("exists:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public AnnotationSourceResponse resolveSourceRequest(final AnnotationSourceRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("resolveSourceRequest:org.kie.workbench.common.services.datamodeller.driver.model.AnnotationSourceRequest:", qualifiers, new Object[] { a0 }).respondTo(AnnotationSourceResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validateValuePair(final String a0, final ElementType a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("validateValuePair:java.lang.String:org.kie.workbench.common.services.datamodeller.core.ElementType:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public AnnotationParseResponse resolveParseRequest(final AnnotationParseRequest a0, final KieModule a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("resolveParseRequest:org.kie.workbench.common.services.datamodeller.driver.model.AnnotationParseRequest:org.kie.workbench.common.services.shared.project.KieModule:", qualifiers, new Object[] { a0, a1 }).respondTo(AnnotationParseResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public AnnotationDefinitionResponse resolveDefinitionRequest(final AnnotationDefinitionRequest a0, final KieModule a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.DataModelerService").endpoint("resolveDefinitionRequest:org.kie.workbench.common.services.datamodeller.driver.model.AnnotationDefinitionRequest:org.kie.workbench.common.services.shared.project.KieModule:", qualifiers, new Object[] { a0, a1 }).respondTo(AnnotationDefinitionResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataModelerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datamodeller_service_DataModelerServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datamodeller_validation_DataObjectValidationServiceImpl extends AbstractRpcProxy implements DataObjectValidationService { public Collection validateObjectPropertyDeletion(final DataObject a0, final ObjectProperty a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.validation.DataObjectValidationService").endpoint("validateObjectPropertyDeletion:org.kie.workbench.common.services.datamodeller.core.DataObject:org.kie.workbench.common.services.datamodeller.core.ObjectProperty:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_validation_DataObjectValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataObjectValidationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datamodeller_validation_DataObjectValidationServiceImpl();
      }
    });
    class org_jbpm_workbench_ht_service_TaskServiceImpl extends AbstractRpcProxy implements TaskService { public TaskSummary getTask(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("getTask:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(TaskSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TaskSummary getTaskWithSLA(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("getTaskWithSLA:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(TaskSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void updateTask(final String a0, final String a1, final Long a2, final Integer a3, final String a4, final Date a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("updateTask:java.lang.String:java.lang.String:java.lang.Long:java.lang.Integer:java.lang.String:java.util.Date:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void claimTask(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("claimTask:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void releaseTask(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("releaseTask:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void startTask(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("startTask:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void completeTask(final String a0, final String a1, final Long a2, final Map a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("completeTask:java.lang.String:java.lang.String:java.lang.Long:java.util.Map:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void resumeTask(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("resumeTask:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void suspendTask(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("suspendTask:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void saveTaskContent(final String a0, final String a1, final Long a2, final Map a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("saveTaskContent:java.lang.String:java.lang.String:java.lang.Long:java.util.Map:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void addTaskComment(final String a0, final String a1, final Long a2, final String a3, final Date a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("addTaskComment:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:java.util.Date:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deleteTaskComment(final String a0, final String a1, final Long a2, final Long a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("deleteTaskComment:java.lang.String:java.lang.String:java.lang.Long:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public List getTaskComments(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("getTaskComments:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getTaskEvents(final String a0, final String a1, final Long a2, final Integer a3, final Integer a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("getTaskEvents:java.lang.String:java.lang.String:java.lang.Long:java.lang.Integer:java.lang.Integer:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delegate(final String a0, final String a1, final Long a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("delegate:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public List delegateTasks(final String a0, final List a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("delegateTasks:java.lang.String:java.util.List:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void forward(final String a0, final String a1, final Long a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("forward:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public TaskAssignmentSummary getTaskAssignmentDetails(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("getTaskAssignmentDetails:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(TaskAssignmentSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void executeReminderForTask(final String a0, final String a1, final Long a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("executeReminderForTask:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public TaskSummary getTaskByWorkItemId(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.ht.service.TaskService").endpoint("getTaskByWorkItemId:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(TaskSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_ht_service_TaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(TaskService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_ht_service_TaskServiceImpl();
      }
    });
    class org_kie_workbench_common_dmn_api_editors_types_TimeZoneServiceImpl extends AbstractRpcProxy implements TimeZoneService { public List getTimeZones() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.types.TimeZoneService").endpoint("getTimeZones:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_types_TimeZoneServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(TimeZoneService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_dmn_api_editors_types_TimeZoneServiceImpl();
      }
    });
    class org_kie_workbench_common_dmn_api_editors_included_DMNIncludedModelsServiceImpl extends AbstractRpcProxy implements DMNIncludedModelsService { public List loadModels(final Path a0, final WorkspaceProject a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.included.DMNIncludedModelsService").endpoint("loadModels:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_included_DMNIncludedModelsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List loadNodesFromImports(final WorkspaceProject a0, final List a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.included.DMNIncludedModelsService").endpoint("loadNodesFromImports:org.guvnor.common.services.project.model.WorkspaceProject:java.util.List:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_included_DMNIncludedModelsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List loadPMMLDocumentsFromImports(final Path a0, final WorkspaceProject a1, final List a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.included.DMNIncludedModelsService").endpoint("loadPMMLDocumentsFromImports:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.WorkspaceProject:java.util.List:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_included_DMNIncludedModelsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List loadItemDefinitionsByNamespace(final WorkspaceProject a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.included.DMNIncludedModelsService").endpoint("loadItemDefinitionsByNamespace:org.guvnor.common.services.project.model.WorkspaceProject:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_included_DMNIncludedModelsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DMNIncludedModelsService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_dmn_api_editors_included_DMNIncludedModelsServiceImpl();
      }
    });
    class org_dashbuilder_dataset_service_DataSetLookupServicesImpl extends AbstractRpcProxy implements DataSetLookupServices { public DataSet lookupDataSet(final DataSetLookup a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetLookupServices").endpoint("lookupDataSet:org.dashbuilder.dataset.DataSetLookup:", qualifiers, new Object[] { a0 }).respondTo(DataSet.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetLookupServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DataSet lookupDataSet(final DataSetDef a0, final DataSetLookup a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetLookupServices").endpoint("lookupDataSet:org.dashbuilder.dataset.def.DataSetDef:org.dashbuilder.dataset.DataSetLookup:", qualifiers, new Object[] { a0, a1 }).respondTo(DataSet.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetLookupServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DataSetMetadata lookupDataSetMetadata(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetLookupServices").endpoint("lookupDataSetMetadata:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(DataSetMetadata.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetLookupServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSetLookupServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_dataset_service_DataSetLookupServicesImpl();
      }
    });
    class org_uberfire_ext_apps_api_AppsPersistenceAPIImpl extends AbstractRpcProxy implements AppsPersistenceAPI { public Directory getRootDirectory() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.apps.api.AppsPersistenceAPI").endpoint("getRootDirectory:", qualifiers, new Object[] { }).respondTo(Directory.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_apps_api_AppsPersistenceAPIImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Directory createDirectory(final Directory a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.apps.api.AppsPersistenceAPI").endpoint("createDirectory:org.uberfire.ext.apps.api.Directory:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Directory.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_apps_api_AppsPersistenceAPIImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Boolean deleteDirectory(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.apps.api.AppsPersistenceAPI").endpoint("deleteDirectory:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_apps_api_AppsPersistenceAPIImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(AppsPersistenceAPI.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_apps_api_AppsPersistenceAPIImpl();
      }
    });
    class org_guvnor_ala_ui_openshift_service_OpenShiftClientServiceImpl extends AbstractRpcProxy implements OpenShiftClientService { public DefaultSettings getDefaultSettings() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.openshift.service.OpenShiftClientService").endpoint("getDefaultSettings:", qualifiers, new Object[] { }).respondTo(DefaultSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_openshift_service_OpenShiftClientServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TemplateDescriptorModel getTemplateModel(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.openshift.service.OpenShiftClientService").endpoint("getTemplateModel:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(TemplateDescriptorModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_openshift_service_OpenShiftClientServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isValidProjectName(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.openshift.service.OpenShiftClientService").endpoint("isValidProjectName:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_openshift_service_OpenShiftClientServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(OpenShiftClientService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_openshift_service_OpenShiftClientServiceImpl();
      }
    });
    class org_guvnor_ala_ui_service_ProviderServiceImpl extends AbstractRpcProxy implements ProviderService { public Collection getProviders(final ProviderType a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderService").endpoint("getProviders:org.guvnor.ala.ui.model.ProviderType:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getProvidersKey(final ProviderType a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderService").endpoint("getProvidersKey:org.guvnor.ala.ui.model.ProviderType:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void createProvider(final ProviderType a0, final ProviderConfiguration a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderService").endpoint("createProvider:org.guvnor.ala.ui.model.ProviderType:org.guvnor.ala.ui.model.ProviderConfiguration:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deleteProvider(final ProviderKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderService").endpoint("deleteProvider:org.guvnor.ala.ui.model.ProviderKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderServiceImpl.this.sendRequest(bus, sendable);
      }

      public Provider getProvider(final ProviderKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProviderService").endpoint("getProvider:org.guvnor.ala.ui.model.ProviderKey:", qualifiers, new Object[] { a0 }).respondTo(Provider.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProviderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProviderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_service_ProviderServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl extends AbstractRpcProxy implements ExplorerService { public ProjectExplorerContent getContent(final String a0, final ActiveOptions a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("getContent:java.lang.String:org.kie.workbench.common.screens.explorer.service.ActiveOptions:", qualifiers, new Object[] { a0, a1 }).respondTo(ProjectExplorerContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ProjectExplorerContent getContent(final ProjectExplorerContentQuery a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("getContent:org.kie.workbench.common.screens.explorer.service.ProjectExplorerContentQuery:", qualifiers, new Object[] { a0 }).respondTo(ProjectExplorerContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public FolderListing getFolderListing(final WorkspaceProject a0, final Module a1, final FolderItem a2, final ActiveOptions a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("getFolderListing:org.guvnor.common.services.project.model.WorkspaceProject:org.guvnor.common.services.project.model.Module:org.kie.workbench.common.screens.explorer.model.FolderItem:org.kie.workbench.common.screens.explorer.service.ActiveOptions:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(FolderListing.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolvePackage(final FolderItem a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("resolvePackage:org.kie.workbench.common.screens.explorer.model.FolderItem:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getLastUserOptions() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("getLastUserOptions:", qualifiers, new Object[] { }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void deleteItem(final FolderItem a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("deleteItem:org.kie.workbench.common.screens.explorer.model.FolderItem:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
      }

      public void renameItem(final FolderItem a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("renameItem:org.kie.workbench.common.screens.explorer.model.FolderItem:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
      }

      public void copyItem(final FolderItem a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("copyItem:org.kie.workbench.common.screens.explorer.model.FolderItem:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
      }

      public WorkspaceProject resolveProject(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.explorer.service.ExplorerService").endpoint("resolveProject:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ExplorerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_explorer_service_ExplorerServiceImpl();
      }
    });
    class org_drools_workbench_screens_enums_service_EnumServiceImpl extends AbstractRpcProxy implements EnumService { public EnumModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(EnumModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public List validate(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("validate:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("validate:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.enums.service.EnumService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_enums_service_EnumServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(EnumService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_enums_service_EnumServiceImpl();
      }
    });
    class org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl extends AbstractRpcProxy implements WorkItemsEditorService { public WorkItemsModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(WorkItemsModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkItemDefinitionElements loadDefinitionElements() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("loadDefinitionElements:", qualifiers, new Object[] { }).respondTo(WorkItemDefinitionElements.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set loadWorkItemDefinitions(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("loadWorkItemDefinitions:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public List validate(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.workitems.service.WorkItemsEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(WorkItemsEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_workitems_service_WorkItemsEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_forms_data_modeller_service_shared_ModelFinderServiceImpl extends AbstractRpcProxy implements ModelFinderService { public DataObjectFormModel getModel(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.data.modeller.service.shared.ModelFinderService").endpoint("getModel:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(DataObjectFormModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_data_modeller_service_shared_ModelFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getModuleModels(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.data.modeller.service.shared.ModelFinderService").endpoint("getModuleModels:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_data_modeller_service_shared_ModelFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllModels(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.data.modeller.service.shared.ModelFinderService").endpoint("getAllModels:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_data_modeller_service_shared_ModelFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ModelFinderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_forms_data_modeller_service_shared_ModelFinderServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_conditions_ConditionEditorServiceImpl extends AbstractRpcProxy implements ConditionEditorService { public List findAvailableFunctions(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.forms.conditions.ConditionEditorService").endpoint("findAvailableFunctions:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_forms_conditions_ConditionEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ParseConditionResult parseCondition(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.forms.conditions.ConditionEditorService").endpoint("parseCondition:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(ParseConditionResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_forms_conditions_ConditionEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GenerateConditionResult generateCondition(final Condition a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.forms.conditions.ConditionEditorService").endpoint("generateCondition:org.kie.workbench.common.stunner.bpmn.forms.conditions.Condition:", qualifiers, new Object[] { a0 }).respondTo(GenerateConditionResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_forms_conditions_ConditionEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TypeMetadataQueryResult findMetadata(final TypeMetadataQuery a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.forms.conditions.ConditionEditorService").endpoint("findMetadata:org.kie.workbench.common.stunner.bpmn.forms.conditions.TypeMetadataQuery:", qualifiers, new Object[] { a0 }).respondTo(TypeMetadataQueryResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_forms_conditions_ConditionEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ConditionEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_conditions_ConditionEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_forms_editor_service_shared_ModuleFormFinderServiceImpl extends AbstractRpcProxy implements ModuleFormFinderService { public List findAllForms(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.ModuleFormFinderService").endpoint("findAllForms:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_ModuleFormFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List findFormsForType(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.ModuleFormFinderService").endpoint("findFormsForType:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_ModuleFormFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public FormDefinition findFormById(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.ModuleFormFinderService").endpoint("findFormById:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(FormDefinition.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_ModuleFormFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ModuleFormFinderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_forms_editor_service_shared_ModuleFormFinderServiceImpl();
      }
    });
    class org_uberfire_ext_services_shared_preferences_UserPreferencesServiceImpl extends AbstractRpcProxy implements UserPreferencesService { public void saveUserPreferences(final UserPreference a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.services.shared.preferences.UserPreferencesService").endpoint("saveUserPreferences:org.uberfire.ext.services.shared.preferences.UserPreference:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_services_shared_preferences_UserPreferencesServiceImpl.this.sendRequest(bus, sendable);
      }

      public UserPreference loadUserPreferences(final String a0, final UserPreferencesType a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.services.shared.preferences.UserPreferencesService").endpoint("loadUserPreferences:java.lang.String:org.uberfire.ext.services.shared.preferences.UserPreferencesType:", qualifiers, new Object[] { a0, a1 }).respondTo(UserPreference.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_services_shared_preferences_UserPreferencesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public UserPreference loadUserPreferences(final UserPreference a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.services.shared.preferences.UserPreferencesService").endpoint("loadUserPreferences:org.uberfire.ext.services.shared.preferences.UserPreference:", qualifiers, new Object[] { a0 }).respondTo(UserPreference.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_services_shared_preferences_UserPreferencesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(UserPreferencesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_services_shared_preferences_UserPreferencesServiceImpl();
      }
    });
    class org_drools_workbench_screens_scenariosimulation_service_ImportExportServiceImpl extends AbstractRpcProxy implements ImportExportService { public Object exportSimulation(final ImportExportType a0, final Simulation a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ImportExportService").endpoint("exportSimulation:org.drools.workbench.screens.scenariosimulation.service.ImportExportType:org.drools.scenariosimulation.api.model.Simulation:", qualifiers, new Object[] { a0, a1 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ImportExportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Simulation importSimulation(final ImportExportType a0, final Object a1, final Simulation a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ImportExportService").endpoint("importSimulation:org.drools.workbench.screens.scenariosimulation.service.ImportExportType:java.lang.Object:org.drools.scenariosimulation.api.model.Simulation:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Simulation.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ImportExportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ImportExportService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_scenariosimulation_service_ImportExportServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl extends AbstractRpcProxy implements PersistenceDescriptorEditorService { public PersistenceDescriptorEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(PersistenceDescriptorEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PersistenceDescriptorEditorContent loadContent(final Path a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(PersistenceDescriptorEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final PersistenceDescriptorEditorContent a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorEditorContent:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final PersistenceDescriptorEditorContent a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorEditorContent:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PersistenceDescriptorEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_services_datamodel_service_IncrementalDataModelServiceImpl extends AbstractRpcProxy implements IncrementalDataModelService { public PackageDataModelOracleIncrementalPayload getUpdates(final Path a0, final Imports a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.datamodel.service.IncrementalDataModelService").endpoint("getUpdates:org.uberfire.backend.vfs.Path:org.kie.soup.project.datamodel.imports.Imports:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(PackageDataModelOracleIncrementalPayload.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_datamodel_service_IncrementalDataModelServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(IncrementalDataModelService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_datamodel_service_IncrementalDataModelServiceImpl();
      }
    });
    class org_guvnor_common_services_shared_test_TestRunnerServiceImpl extends AbstractRpcProxy implements TestRunnerService { public void runAllTests(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.test.TestRunnerService").endpoint("runAllTests:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_test_TestRunnerServiceImpl.this.sendRequest(bus, sendable);
      }

      public void runAllTests(final String a0, final Path a1, final Event a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.test.TestRunnerService").endpoint("runAllTests:java.lang.String:org.uberfire.backend.vfs.Path:javax.enterprise.event.Event:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_test_TestRunnerServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(TestRunnerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_shared_test_TestRunnerServiceImpl();
      }
    });
    class org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl extends AbstractRpcProxy implements DDEditorService { public void createIfNotExists(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("createIfNotExists:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public List validate(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final DeploymentDescriptorModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.jbpm.workbench.wi.dd.model.DeploymentDescriptorModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final DeploymentDescriptorModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.jbpm.workbench.wi.dd.model.DeploymentDescriptorModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DeploymentDescriptorModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DeploymentDescriptorModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final DeploymentDescriptorModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.dd.service.DDEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.jbpm.workbench.wi.dd.model.DeploymentDescriptorModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DDEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_wi_dd_service_DDEditorServiceImpl();
      }
    });
    class org_guvnor_structure_repositories_RepositorySearchServiceImpl extends AbstractRpcProxy implements RepositorySearchService { public Collection searchByAlias(final String a0, final int a1, final boolean a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositorySearchService").endpoint("searchByAlias:java.lang.String:int:boolean:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositorySearchServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection searchById(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositorySearchService").endpoint("searchById:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositorySearchServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RepositorySearchService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_repositories_RepositorySearchServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_core_service_DiagramServiceImpl extends AbstractRpcProxy implements DiagramService { public Diagram getDiagramByPath(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("getDiagramByPath:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Diagram.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Path create(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public org.kie.workbench.common.stunner.core.diagram.Metadata saveOrUpdate(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("saveOrUpdate:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(org.kie.workbench.common.stunner.core.diagram.Metadata.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveOrUpdateSvg(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("saveOrUpdateSvg:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean delete(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("delete:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public String getRawContent(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.DiagramService").endpoint("getRawContent:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_DiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DiagramService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_core_service_DiagramServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl extends AbstractRpcProxy implements ProjectDiagramService { public Path create(final Path a0, final String a1, final String a2, final String a3, final Package a4, final Optional a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:java.lang.String:org.guvnor.common.services.project.model.Package:java.util.Optional:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAsXml(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("saveAsXml:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ProjectDiagram getDiagramByPath(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("getDiagramByPath:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ProjectDiagram.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Path create(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ProjectMetadata saveOrUpdate(final ProjectDiagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("saveOrUpdate:org.kie.workbench.common.stunner.project.diagram.ProjectDiagram:", qualifiers, new Object[] { a0 }).respondTo(ProjectMetadata.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveOrUpdateSvg(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("saveOrUpdateSvg:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean delete(final ProjectDiagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("delete:org.kie.workbench.common.stunner.project.diagram.ProjectDiagram:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public String getRawContent(final ProjectDiagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("getRawContent:org.kie.workbench.common.stunner.project.diagram.ProjectDiagram:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final ProjectDiagram a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.stunner.project.diagram.ProjectDiagram:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectDiagramService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_project_service_ProjectDiagramServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_cm_project_service_CaseManagementSwitchViewServiceImpl extends AbstractRpcProxy implements CaseManagementSwitchViewService { public Optional switchView(final Diagram a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.cm.project.service.CaseManagementSwitchViewService").endpoint("switchView:org.kie.workbench.common.stunner.core.diagram.Diagram:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Optional.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_cm_project_service_CaseManagementSwitchViewServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(CaseManagementSwitchViewService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_cm_project_service_CaseManagementSwitchViewServiceImpl();
      }
    });
    class org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl extends AbstractRpcProxy implements RoleManagerService { public SearchResponse search(final SearchRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.RoleManagerService").endpoint("search:org.uberfire.ext.security.management.api.AbstractEntityManager.SearchRequest:", qualifiers, new Object[] { a0 }).respondTo(SearchResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Role get(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.RoleManagerService").endpoint("get:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Role.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Role create(final Role a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.RoleManagerService").endpoint("create:org.jboss.errai.security.shared.api.Role:", qualifiers, new Object[] { a0 }).respondTo(Role.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Role update(final Role a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.RoleManagerService").endpoint("update:org.jboss.errai.security.shared.api.Role:", qualifiers, new Object[] { a0 }).respondTo(Role.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final String[] a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.RoleManagerService").endpoint("delete:java.lang.String[]:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public RoleManagerSettings getSettings() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.RoleManagerService").endpoint("getSettings:", qualifiers, new Object[] { }).respondTo(RoleManagerSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RoleManagerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_security_management_api_service_RoleManagerServiceImpl();
      }
    });
    class org_guvnor_structure_repositories_RepositoryServiceEditorImpl extends AbstractRpcProxy implements RepositoryServiceEditor { public List revertHistory(final String a0, final Path a1, final String a2, final VersionRecord a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryServiceEditor").endpoint("revertHistory:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.java.nio.base.version.VersionRecord:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceEditorImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RepositoryServiceEditor.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_repositories_RepositoryServiceEditorImpl();
      }
    });
    class org_jbpm_workbench_pr_service_ProcessDocumentsServiceImpl extends AbstractRpcProxy implements ProcessDocumentsService { public PageResponse getData(final QueryFilter a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessDocumentsService").endpoint("getData:org.jbpm.workbench.common.model.QueryFilter:", qualifiers, new Object[] { a0 }).respondTo(PageResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessDocumentsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProcessDocumentsService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_pr_service_ProcessDocumentsServiceImpl();
      }
    });
    class org_guvnor_common_services_project_service_POMServiceImpl extends AbstractRpcProxy implements POMService { public Path create(final Path a0, final POM a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.POMService").endpoint("create:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_POMServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final POM a1, final Metadata a2, final String a3, final boolean a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.POMService").endpoint("save:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:boolean:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_POMServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public POM load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.POMService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(POM.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_POMServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final POM a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.POMService").endpoint("save:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_POMServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(POMService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_service_POMServiceImpl();
      }
    });
    class org_uberfire_ext_editor_commons_service_DeleteServiceImpl extends AbstractRpcProxy implements DeleteService { public void deleteIfExists(final Collection a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.DeleteService").endpoint("deleteIfExists:java.util.Collection:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_DeleteServiceImpl.this.sendRequest(bus, sendable);
      }

      public boolean hasRestriction(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.DeleteService").endpoint("hasRestriction:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_DeleteServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.DeleteService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_DeleteServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DeleteService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_editor_commons_service_DeleteServiceImpl();
      }
    });
    class org_guvnor_common_services_project_service_ModuleServiceImpl extends AbstractRpcProxy implements ModuleService { public Module resolveModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module resolveModule(final Path a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveModule:org.uberfire.backend.vfs.Path:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module resolveParentModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveParentModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module resolveToParentModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveToParentModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set resolvePackages(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolvePackages:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set resolvePackages(final Package a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolvePackages:org.guvnor.common.services.project.model.Package:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolveDefaultPackage(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveDefaultPackage:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolveDefaultWorkspacePackage(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveDefaultWorkspacePackage:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolveParentPackage(final Package a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveParentPackage:org.guvnor.common.services.project.model.Package:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path resolveDefaultPath(final Package a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolveDefaultPath:org.guvnor.common.services.project.model.Package:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isPom(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("isPom:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Package resolvePackage(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("resolvePackage:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getAllModules(final Branch a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("getAllModules:org.guvnor.structure.repositories.Branch:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module newModule(final Path a0, final POM a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("newModule:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:", qualifiers, new Object[] { a0, a1 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module newModule(final Path a0, final POM a1, final DeploymentMode a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("newModule:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package newPackage(final Package a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("newPackage:org.guvnor.common.services.project.model.Package:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
      }

      public void copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
      }

      public void reImport(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleService").endpoint("reImport:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ModuleService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_service_ModuleServiceImpl();
      }
    });
    class org_uberfire_ext_security_management_api_service_UserManagerServiceImpl extends AbstractRpcProxy implements UserManagerService { public void assignGroups(final String a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("assignGroups:java.lang.String:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public void assignRoles(final String a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("assignRoles:java.lang.String:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public void changePassword(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("changePassword:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public SearchResponse search(final SearchRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("search:org.uberfire.ext.security.management.api.AbstractEntityManager.SearchRequest:", qualifiers, new Object[] { a0 }).respondTo(SearchResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public User get(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("get:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public User create(final User a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("create:org.jboss.errai.security.shared.api.identity.User:", qualifiers, new Object[] { a0 }).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public User update(final User a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("update:org.jboss.errai.security.shared.api.identity.User:", qualifiers, new Object[] { a0 }).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final String[] a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("delete:java.lang.String[]:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public UserManagerSettings getSettings() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("getSettings:", qualifiers, new Object[] { }).respondTo(UserManagerSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public User getUser(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.UserManagerService").endpoint("getUser:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_UserManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(UserManagerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_security_management_api_service_UserManagerServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_project_service_ProjectValidationServiceImpl extends AbstractRpcProxy implements ProjectValidationService { public Collection validate(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectValidationService").endpoint("validate:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectValidationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_project_service_ProjectValidationServiceImpl();
      }
    });
    class org_uberfire_ext_editor_commons_service_RenameServiceImpl extends AbstractRpcProxy implements RenameService { public void renameIfExists(final Collection a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.RenameService").endpoint("renameIfExists:java.util.Collection:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_RenameServiceImpl.this.sendRequest(bus, sendable);
      }

      public boolean hasRestriction(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.RenameService").endpoint("hasRestriction:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_RenameServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.RenameService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_RenameServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RenameService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_editor_commons_service_RenameServiceImpl();
      }
    });
    class org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl extends AbstractRpcProxy implements GlobalsEditorService { public GlobalsEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GlobalsEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path generate(final Path a0, final String a1, final GlobalsModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("generate:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.screens.globals.model.GlobalsModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final GlobalsModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.drools.workbench.screens.globals.model.GlobalsModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final GlobalsModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.drools.workbench.screens.globals.model.GlobalsModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final GlobalsModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.screens.globals.model.GlobalsModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GlobalsModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GlobalsModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final GlobalsModel a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.screens.globals.model.GlobalsModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final GlobalsModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.screens.globals.model.GlobalsModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.globals.service.GlobalsEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GlobalsEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_globals_service_GlobalsEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_forms_jbpm_service_shared_BPMFinderServiceImpl extends AbstractRpcProxy implements BPMFinderService { public List getAvailableProcessModels(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.jbpm.service.shared.BPMFinderService").endpoint("getAvailableProcessModels:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_jbpm_service_shared_BPMFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public JBPMProcessModel getModelForProcess(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.jbpm.service.shared.BPMFinderService").endpoint("getModelForProcess:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(JBPMProcessModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_jbpm_service_shared_BPMFinderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BPMFinderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_forms_jbpm_service_shared_BPMFinderServiceImpl();
      }
    });
    class org_guvnor_common_services_project_builder_service_BuildServiceImpl extends AbstractRpcProxy implements BuildService { public BuildResults build(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("build:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(BuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public BuildResults buildAndDeploy(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("buildAndDeploy:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(BuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public BuildResults buildAndDeploy(final Module a0, final DeploymentMode a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("buildAndDeploy:org.guvnor.common.services.project.model.Module:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1 }).respondTo(BuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public BuildResults buildAndDeploy(final Module a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("buildAndDeploy:org.guvnor.common.services.project.model.Module:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(BuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public BuildResults buildAndDeploy(final Module a0, final boolean a1, final DeploymentMode a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("buildAndDeploy:org.guvnor.common.services.project.model.Module:boolean:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(BuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isBuilt(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("isBuilt:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public IncrementalBuildResults addPackageResource(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("addPackageResource:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(IncrementalBuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public IncrementalBuildResults deletePackageResource(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("deletePackageResource:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(IncrementalBuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public IncrementalBuildResults updatePackageResource(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("updatePackageResource:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(IncrementalBuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public IncrementalBuildResults applyBatchResourceChanges(final Module a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.builder.service.BuildService").endpoint("applyBatchResourceChanges:org.guvnor.common.services.project.model.Module:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(IncrementalBuildResults.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_builder_service_BuildServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BuildService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_builder_service_BuildServiceImpl();
      }
    });
    class org_jbpm_workbench_forms_service_shared_FormServiceEntryPointImpl extends AbstractRpcProxy implements FormServiceEntryPoint { public FormRenderingSettings getFormDisplayTask(final String a0, final String a1, final long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.forms.service.shared.FormServiceEntryPoint").endpoint("getFormDisplayTask:java.lang.String:java.lang.String:long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(FormRenderingSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_forms_service_shared_FormServiceEntryPointImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public FormRenderingSettings getFormDisplayProcess(final String a0, final String a1, final String a2, final boolean a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.forms.service.shared.FormServiceEntryPoint").endpoint("getFormDisplayProcess:java.lang.String:java.lang.String:java.lang.String:boolean:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(FormRenderingSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_forms_service_shared_FormServiceEntryPointImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(FormServiceEntryPoint.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_forms_service_shared_FormServiceEntryPointImpl();
      }
    });
    class org_uberfire_ext_editor_commons_service_ValidationServiceImpl extends AbstractRpcProxy implements ValidationService { public boolean isFileNameValid(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.ValidationService").endpoint("isFileNameValid:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isFileNameValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.ValidationService").endpoint("isFileNameValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ValidationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_editor_commons_service_ValidationServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_kogito_api_service_KogitoDiagramServiceImpl extends AbstractRpcProxy implements KogitoDiagramService { public Diagram transform(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.kogito.api.service.KogitoDiagramService").endpoint("transform:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Diagram.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_kogito_api_service_KogitoDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String transform(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.kogito.api.service.KogitoDiagramService").endpoint("transform:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_kogito_api_service_KogitoDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(KogitoDiagramService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_kogito_api_service_KogitoDiagramServiceImpl();
      }
    });
    class org_guvnor_structure_repositories_RepositoryServiceImpl extends AbstractRpcProxy implements RepositoryService { public RepositoryInfo getRepositoryInfo(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepositoryInfo:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(RepositoryInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getRepositoryHistory(final Space a0, final String a1, final int a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepositoryHistory:org.uberfire.spaces.Space:java.lang.String:int:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getRepositoryHistory(final Space a0, final String a1, final int a2, final int a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepositoryHistory:org.uberfire.spaces.Space:java.lang.String:int:int:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getRepositoryHistoryAll(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepositoryHistoryAll:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Repository getRepositoryFromSpace(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepositoryFromSpace:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Repository.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Repository getRepository(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepository:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Repository.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Repository getRepository(final Space a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepository:org.uberfire.spaces.Space:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(Repository.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllRepositories(final Space a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getAllRepositories:org.uberfire.spaces.Space:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllRepositories(final Space a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getAllRepositories:org.uberfire.spaces.Space:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllDeletedRepositories(final Space a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getAllDeletedRepositories:org.uberfire.spaces.Space:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllRepositoriesFromAllUserSpaces() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getAllRepositoriesFromAllUserSpaces:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getRepositories(final Space a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("getRepositories:org.uberfire.spaces.Space:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Repository createRepository(final OrganizationalUnit a0, final String a1, final String a2, final RepositoryEnvironmentConfigurations a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("createRepository:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:java.lang.String:org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Repository.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Repository createRepository(final OrganizationalUnit a0, final String a1, final String a2, final RepositoryEnvironmentConfigurations a3, final Collection a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("createRepository:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:java.lang.String:org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations:java.util.Collection:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Repository.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String normalizeRepositoryName(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("normalizeRepositoryName:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean validateRepositoryName(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("validateRepositoryName:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public void addGroup(final Repository a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("addGroup:org.guvnor.structure.repositories.Repository:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeGroup(final Repository a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("removeGroup:org.guvnor.structure.repositories.Repository:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateContributors(final Repository a0, final List a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("updateContributors:org.guvnor.structure.repositories.Repository:java.util.List:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeRepository(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("removeRepository:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeRepositories(final Space a0, final Set a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.RepositoryService").endpoint("removeRepositories:org.uberfire.spaces.Space:java.util.Set:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_RepositoryServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RepositoryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_repositories_RepositoryServiceImpl();
      }
    });
    class org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl extends AbstractRpcProxy implements GuidedScoreCardEditorService { public ScoreCardModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ScoreCardModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final ScoreCardModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.scorecard.shared.ScoreCardModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final ScoreCardModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.scorecard.shared.ScoreCardModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final ScoreCardModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.models.guided.scorecard.shared.ScoreCardModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ScoreCardModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ScoreCardModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final ScoreCardModel a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.models.guided.scorecard.shared.ScoreCardModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final ScoreCardModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.scorecard.shared.ScoreCardModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.scorecard.service.GuidedScoreCardEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedScoreCardEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_scorecard_service_GuidedScoreCardEditorServiceImpl();
      }
    });
    class org_uberfire_ext_layout_editor_api_LayoutServicesImpl extends AbstractRpcProxy implements LayoutServices { public String convertLayoutToString(final LayoutTemplate a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.LayoutServices").endpoint("convertLayoutToString:org.uberfire.ext.layout.editor.api.editor.LayoutTemplate:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_LayoutServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate convertLayoutFromString(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.LayoutServices").endpoint("convertLayoutFromString:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_LayoutServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(LayoutServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_layout_editor_api_LayoutServicesImpl();
      }
    });
    class org_jbpm_workbench_pr_service_ProcessServiceImpl extends AbstractRpcProxy implements ProcessService { public void abortProcessInstance(final ProcessInstanceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessService").endpoint("abortProcessInstance:org.jbpm.workbench.pr.model.ProcessInstanceKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessServiceImpl.this.sendRequest(bus, sendable);
      }

      public void abortProcessInstances(final String a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessService").endpoint("abortProcessInstances:java.lang.String:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessServiceImpl.this.sendRequest(bus, sendable);
      }

      public Long startProcess(final String a0, final String a1, final String a2, final String a3, final Map a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessService").endpoint("startProcess:java.lang.String:java.lang.String:java.lang.String:java.lang.String:java.util.Map:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Long.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessServiceImpl.this.sendRequest(bus, sendable);
        return 0L;
      }

      public List getAvailableSignals(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessService").endpoint("getAvailableSignals:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void signalProcessInstances(final String a0, final List a1, final List a2, final String a3, final Object a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessService").endpoint("signalProcessInstances:java.lang.String:java.util.List:java.util.List:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessServiceImpl.this.sendRequest(bus, sendable);
      }

      public void setProcessVariable(final String a0, final String a1, final long a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessService").endpoint("setProcessVariable:java.lang.String:java.lang.String:long:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProcessService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_pr_service_ProcessServiceImpl();
      }
    });
    class org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl extends AbstractRpcProxy implements ServiceTaskService { public List getServiceTasks() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("getServiceTasks:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getEnabledServiceTasks(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("getEnabledServiceTasks:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void enableServiceTask(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("enableServiceTask:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void disableServiceTask(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("disableServiceTask:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void installServiceTask(final String a0, final String a1, final List a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("installServiceTask:java.lang.String:java.lang.String:java.util.List:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void uninstallServiceTask(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("uninstallServiceTask:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateInstalledServiceTasks(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("updateInstalledServiceTasks:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public ServiceTasksConfiguration getConfiguration() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("getConfiguration:", qualifiers, new Object[] { }).respondTo(ServiceTasksConfiguration.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void saveConfiguration(final ServiceTasksConfiguration a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("saveConfiguration:org.jbpm.workbench.wi.workitems.model.ServiceTasksConfiguration:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
      }

      public List addServiceTasks(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.workitems.service.ServiceTaskService").endpoint("addServiceTasks:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ServiceTaskService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_wi_workitems_service_ServiceTaskServiceImpl();
      }
    });
    class org_dashbuilder_renderer_service_RendererSettingsServiceImpl extends AbstractRpcProxy implements RendererSettingsService { public RendererSettings getSettings() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.renderer.service.RendererSettingsService").endpoint("getSettings:", qualifiers, new Object[] { }).respondTo(RendererSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_renderer_service_RendererSettingsServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RendererSettingsService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_renderer_service_RendererSettingsServiceImpl();
      }
    });
    class org_drools_workbench_screens_scenariosimulation_service_RunnerReportServiceImpl extends AbstractRpcProxy implements RunnerReportService { public Object getReport(final AuditLog a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.RunnerReportService").endpoint("getReport:org.drools.scenariosimulation.api.model.AuditLog:", qualifiers, new Object[] { a0 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_RunnerReportServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RunnerReportService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_scenariosimulation_service_RunnerReportServiceImpl();
      }
    });
    class org_guvnor_common_services_shared_metadata_MetadataServiceImpl extends AbstractRpcProxy implements MetadataService { public Metadata getMetadata(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.metadata.MetadataService").endpoint("getMetadata:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Metadata.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_metadata_MetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getTags(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.metadata.MetadataService").endpoint("getTags:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_metadata_MetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map configAttrs(final Map a0, final Metadata a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.metadata.MetadataService").endpoint("configAttrs:java.util.Map:org.guvnor.common.services.shared.metadata.model.Metadata:", qualifiers, new Object[] { a0, a1 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_metadata_MetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map setUpAttributes(final Path a0, final Metadata a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.metadata.MetadataService").endpoint("setUpAttributes:org.uberfire.backend.vfs.Path:org.guvnor.common.services.shared.metadata.model.Metadata:", qualifiers, new Object[] { a0, a1 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_metadata_MetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveMetadata(final Path a0, final Metadata a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.metadata.MetadataService").endpoint("saveMetadata:org.uberfire.backend.vfs.Path:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_metadata_MetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(MetadataService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_shared_metadata_MetadataServiceImpl();
      }
    });
    class org_jbpm_workbench_wi_casemgmt_service_CaseProjectServiceImpl extends AbstractRpcProxy implements CaseProjectService { public void configureNewCaseProject(final WorkspaceProject a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProjectService").endpoint("configureNewCaseProject:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProjectServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(CaseProjectService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_wi_casemgmt_service_CaseProjectServiceImpl();
      }
    });
    class org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl extends AbstractRpcProxy implements CaseProvisioningSettings { public boolean isProvisioningEnabled() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("isProvisioningEnabled:", qualifiers, new Object[] { }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isDeployFromLocalPath() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("isDeployFromLocalPath:", qualifiers, new Object[] { }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public String getPath() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getPath:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getHost() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getHost:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getManagementPort() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getManagementPort:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getUsername() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getUsername:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getPassword() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getPassword:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getGAV() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getGAV:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getURL() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningSettings").endpoint("getURL:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(CaseProvisioningSettings.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningSettingsImpl();
      }
    });
    class org_jbpm_workbench_forms_display_service_KieWorkbenchFormsEntryPointImpl extends AbstractRpcProxy implements KieWorkbenchFormsEntryPoint { public Long startProcessFromRenderContext(final Long a0, final Map a1, final String a2, final String a3, final String a4, final String a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.forms.display.service.KieWorkbenchFormsEntryPoint").endpoint("startProcessFromRenderContext:java.lang.Long:java.util.Map:java.lang.String:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(Long.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_forms_display_service_KieWorkbenchFormsEntryPointImpl.this.sendRequest(bus, sendable);
        return 0L;
      }

      public void saveTaskStateFromRenderContext(final Long a0, final Map a1, final String a2, final String a3, final Long a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.forms.display.service.KieWorkbenchFormsEntryPoint").endpoint("saveTaskStateFromRenderContext:java.lang.Long:java.util.Map:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_forms_display_service_KieWorkbenchFormsEntryPointImpl.this.sendRequest(bus, sendable);
      }

      public void completeTaskFromContext(final Long a0, final Map a1, final String a2, final String a3, final Long a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.forms.display.service.KieWorkbenchFormsEntryPoint").endpoint("completeTaskFromContext:java.lang.Long:java.util.Map:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_forms_display_service_KieWorkbenchFormsEntryPointImpl.this.sendRequest(bus, sendable);
      }

      public void clearContext(final long a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.forms.display.service.KieWorkbenchFormsEntryPoint").endpoint("clearContext:long:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_forms_display_service_KieWorkbenchFormsEntryPointImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(KieWorkbenchFormsEntryPoint.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_forms_display_service_KieWorkbenchFormsEntryPointImpl();
      }
    });
    class org_guvnor_structure_organizationalunit_OrganizationalUnitSearchServiceImpl extends AbstractRpcProxy implements OrganizationalUnitSearchService { public Collection searchByName(final String a0, final int a1, final boolean a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitSearchService").endpoint("searchByName:java.lang.String:int:boolean:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitSearchServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection searchById(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitSearchService").endpoint("searchById:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitSearchServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(OrganizationalUnitSearchService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_organizationalunit_OrganizationalUnitSearchServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_core_service_FactoryServiceImpl extends AbstractRpcProxy implements FactoryService { public Object newDefinition(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.FactoryService").endpoint("newDefinition:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_FactoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Element newElement(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.FactoryService").endpoint("newElement:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Element.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_FactoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Diagram newDiagram(final String a0, final String a1, final org.kie.workbench.common.stunner.core.diagram.Metadata a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.FactoryService").endpoint("newDiagram:java.lang.String:java.lang.String:org.kie.workbench.common.stunner.core.diagram.Metadata:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Diagram.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_FactoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public FactoryRegistry registry() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.core.service.FactoryService").endpoint("registry:", qualifiers, new Object[] { }).respondTo(FactoryRegistry.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_core_service_FactoryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(FactoryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_core_service_FactoryServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_project_service_DataTypesServiceImpl extends AbstractRpcProxy implements DataTypesService { public List getDataTypeNames(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.project.service.DataTypesService").endpoint("getDataTypeNames:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_project_service_DataTypesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataTypesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_bpmn_project_service_DataTypesServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_library_api_LibraryServiceImpl extends AbstractRpcProxy implements LibraryService { public OrganizationalUnitRepositoryInfo getDefaultOrganizationalUnitRepositoryInfo() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getDefaultOrganizationalUnitRepositoryInfo:", qualifiers, new Object[] { }).respondTo(OrganizationalUnitRepositoryInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnitRepositoryInfo getOrganizationalUnitRepositoryInfo(final OrganizationalUnit a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getOrganizationalUnitRepositoryInfo:org.guvnor.structure.organizationalunit.OrganizationalUnit:", qualifiers, new Object[] { a0 }).respondTo(OrganizationalUnitRepositoryInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LibraryInfo getLibraryInfo(final OrganizationalUnit a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getLibraryInfo:org.guvnor.structure.organizationalunit.OrganizationalUnit:", qualifiers, new Object[] { a0 }).respondTo(LibraryInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject createProject(final String a0, final OrganizationalUnit a1, final String a2, final DeploymentMode a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("createProject:java.lang.String:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject createProject(final OrganizationalUnit a0, final POM a1, final DeploymentMode a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("createProject:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Boolean thereIsAProjectInTheWorkbench() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("thereIsAProjectInTheWorkbench:", qualifiers, new Object[] { }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public AssetQueryResult getProjectAssets(final ProjectAssetsQuery a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getProjectAssets:org.kie.workbench.common.screens.library.api.ProjectAssetsQuery:", qualifiers, new Object[] { a0 }).respondTo(AssetQueryResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Boolean hasProjects(final OrganizationalUnit a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("hasProjects:org.guvnor.structure.organizationalunit.OrganizationalUnit:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public int getNumberOfAssets(final ProjectAssetsQuery a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getNumberOfAssets:org.kie.workbench.common.screens.library.api.ProjectAssetsQuery:", qualifiers, new Object[] { a0 }).respondTo(Integer.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return 0;
      }

      public int getNumberOfAssets(final WorkspaceProject a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getNumberOfAssets:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0 }).respondTo(Integer.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return 0;
      }

      public Boolean hasAssets(final WorkspaceProject a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("hasAssets:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Set getExampleProjects() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getExampleProjects:", qualifiers, new Object[] { }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getOrganizationalUnits() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getOrganizationalUnits:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit getDefaultOrganizationalUnit() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getDefaultOrganizationalUnit:", qualifiers, new Object[] { }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GAV createGAV(final String a0, final OrganizationalUnit a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("createGAV:java.lang.String:org.guvnor.structure.organizationalunit.OrganizationalUnit:", qualifiers, new Object[] { a0, a1 }).respondTo(GAV.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getAllUsers() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("getAllUsers:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void addBranch(final String a0, final String a1, final WorkspaceProject a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("addBranch:java.lang.String:java.lang.String:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeBranch(final WorkspaceProject a0, final Branch a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("removeBranch:org.guvnor.common.services.project.model.WorkspaceProject:org.guvnor.structure.repositories.Branch:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
      }

      public BranchPermissions loadBranchPermissions(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("loadBranchPermissions:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(BranchPermissions.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void saveBranchPermissions(final String a0, final String a1, final String a2, final BranchPermissions a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("saveBranchPermissions:java.lang.String:java.lang.String:java.lang.String:org.guvnor.structure.organizationalunit.config.BranchPermissions:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
      }

      public Boolean isClustered() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.library.api.LibraryService").endpoint("isClustered:", qualifiers, new Object[] { }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_library_api_LibraryServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(LibraryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_library_api_LibraryServiceImpl();
      }
    });
    class org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl extends AbstractRpcProxy implements DSLTextEditorService { public DSLTextEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DSLTextEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public List validate(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dsltext.service.DSLTextEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DSLTextEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_dsltext_service_DSLTextEditorServiceImpl();
      }
    });
    class org_jbpm_workbench_pr_service_ProcessVariablesServiceImpl extends AbstractRpcProxy implements ProcessVariablesService { public List getVariableHistory(final ProcessInstanceKey a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessVariablesService").endpoint("getVariableHistory:org.jbpm.workbench.pr.model.ProcessInstanceKey:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessVariablesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PageResponse getData(final QueryFilter a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessVariablesService").endpoint("getData:org.jbpm.workbench.common.model.QueryFilter:", qualifiers, new Object[] { a0 }).respondTo(PageResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessVariablesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProcessVariablesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_pr_service_ProcessVariablesServiceImpl();
      }
    });
    class org_guvnor_ala_ui_service_ProvisioningScreensServiceImpl extends AbstractRpcProxy implements ProvisioningScreensService { public ProvidersInfo getProvidersInfo(final ProviderTypeKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProvisioningScreensService").endpoint("getProvidersInfo:org.guvnor.ala.ui.model.ProviderTypeKey:", qualifiers, new Object[] { a0 }).respondTo(ProvidersInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProvisioningScreensServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public RuntimesInfo getRuntimesInfo(final ProviderKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProvisioningScreensService").endpoint("getRuntimesInfo:org.guvnor.ala.ui.model.ProviderKey:", qualifiers, new Object[] { a0 }).respondTo(RuntimesInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProvisioningScreensServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean hasRuntimes(final ProviderKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.ProvisioningScreensService").endpoint("hasRuntimes:org.guvnor.ala.ui.model.ProviderKey:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_ProvisioningScreensServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProvisioningScreensService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_service_ProvisioningScreensServiceImpl();
      }
    });
    class org_uberfire_backend_authz_AuthorizationServiceImpl extends AbstractRpcProxy implements AuthorizationService { public AuthorizationPolicy loadPolicy() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.authz.AuthorizationService").endpoint("loadPolicy:", qualifiers, new Object[] { }).respondTo(AuthorizationPolicy.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_authz_AuthorizationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void savePolicy(final AuthorizationPolicy a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.authz.AuthorizationService").endpoint("savePolicy:org.uberfire.security.authz.AuthorizationPolicy:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_authz_AuthorizationServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(AuthorizationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_backend_authz_AuthorizationServiceImpl();
      }
    });
    class org_guvnor_m2repo_service_M2RepoServiceImpl extends AbstractRpcProxy implements M2RepoService { public String getPomText(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.m2repo.service.M2RepoService").endpoint("getPomText:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_m2repo_service_M2RepoServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GAV loadGAVFromJar(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.m2repo.service.M2RepoService").endpoint("loadGAVFromJar:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(GAV.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_m2repo_service_M2RepoServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PageResponse listArtifacts(final JarListPageRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.m2repo.service.M2RepoService").endpoint("listArtifacts:org.guvnor.m2repo.model.JarListPageRequest:", qualifiers, new Object[] { a0 }).respondTo(PageResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_m2repo_service_M2RepoServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getRepositoryURL() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.m2repo.service.M2RepoService").endpoint("getRepositoryURL:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_m2repo_service_M2RepoServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(M2RepoService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_m2repo_service_M2RepoServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DatabaseMetadataServiceImpl extends AbstractRpcProxy implements DatabaseMetadataService { public DatabaseMetadata getMetadata(final String a0, final boolean a1, final boolean a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DatabaseMetadataService").endpoint("getMetadata:java.lang.String:boolean:boolean:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(DatabaseMetadata.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DatabaseMetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List findTables(final String a0, final String a1, final TableType[] a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DatabaseMetadataService").endpoint("findTables:java.lang.String:java.lang.String:org.kie.workbench.common.screens.datasource.management.metadata.DatabaseMetadata.TableType[]:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DatabaseMetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List findTables(final String a0, final String a1, final String a2, final TableType[] a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DatabaseMetadataService").endpoint("findTables:java.lang.String:java.lang.String:java.lang.String:org.kie.workbench.common.screens.datasource.management.metadata.DatabaseMetadata.TableType[]:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DatabaseMetadataServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DatabaseMetadataService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DatabaseMetadataServiceImpl();
      }
    });
    class org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphSaveAndRenameServiceImpl extends AbstractRpcProxy implements GuidedDecisionTableGraphSaveAndRenameService { public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final List a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.util.List:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphSaveAndRenameServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphSaveAndRenameServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final List a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService").endpoint("save:org.uberfire.backend.vfs.Path:java.util.List:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphSaveAndRenameServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedDecisionTableGraphSaveAndRenameService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphSaveAndRenameServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DefExplorerQueryServiceImpl extends AbstractRpcProxy implements DefExplorerQueryService { public DefExplorerQueryResult executeQuery(final DefExplorerQuery a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DefExplorerQueryService").endpoint("executeQuery:org.kie.workbench.common.screens.datasource.management.service.DefExplorerQuery:", qualifiers, new Object[] { a0 }).respondTo(DefExplorerQueryResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DefExplorerQueryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DefExplorerQueryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DefExplorerQueryServiceImpl();
      }
    });
    class org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl extends AbstractRpcProxy implements DRLTextEditorService { public DrlModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DrlModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List loadClassFields(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("loadClassFields:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String assertPackageName(final String a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("assertPackageName:java.lang.String:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.drltext.service.DRLTextEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DRLTextEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_drltext_service_DRLTextEditorServiceImpl();
      }
    });
    class org_uberfire_experimental_service_editor_FeaturesEditorServiceImpl extends AbstractRpcProxy implements FeaturesEditorService { public void save(final EditableExperimentalFeature a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.editor.FeaturesEditorService").endpoint("save:org.uberfire.experimental.service.editor.EditableExperimentalFeature:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_editor_FeaturesEditorServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(FeaturesEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_experimental_service_editor_FeaturesEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_forms_dynamic_service_shared_BackendSelectorDataProviderServiceImpl extends AbstractRpcProxy implements BackendSelectorDataProviderService { public Map availableProviders() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.dynamic.service.shared.BackendSelectorDataProviderService").endpoint("availableProviders:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_dynamic_service_shared_BackendSelectorDataProviderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public SelectorData getDataFromProvider(final FormRenderingContext a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.dynamic.service.shared.BackendSelectorDataProviderService").endpoint("getDataFromProvider:org.kie.workbench.common.forms.dynamic.service.shared.FormRenderingContext:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(SelectorData.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_dynamic_service_shared_BackendSelectorDataProviderServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BackendSelectorDataProviderService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_forms_dynamic_service_shared_BackendSelectorDataProviderServiceImpl();
      }
    });
    class org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl extends AbstractRpcProxy implements GuidedDecisionTreeEditorService { public GuidedDecisionTreeEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedDecisionTreeEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PackageDataModelOracleBaselinePayload loadDataModel(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("loadDataModel:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(PackageDataModelOracleBaselinePayload.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final GuidedDecisionTree a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final GuidedDecisionTree a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final GuidedDecisionTree a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GuidedDecisionTree load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedDecisionTree.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final GuidedDecisionTree a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final GuidedDecisionTree a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.dtree.shared.model.GuidedDecisionTree:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtree.service.GuidedDecisionTreeEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedDecisionTreeEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_dtree_service_GuidedDecisionTreeEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_whitelist_PackageNameWhiteListServiceImpl extends AbstractRpcProxy implements PackageNameWhiteListService { public WhiteList filterPackageNames(final Module a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService").endpoint("filterPackageNames:org.guvnor.common.services.project.model.Module:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(WhiteList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_whitelist_PackageNameWhiteListServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void createModuleWhiteList(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService").endpoint("createModuleWhiteList:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_whitelist_PackageNameWhiteListServiceImpl.this.sendRequest(bus, sendable);
      }

      public WhiteList load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(WhiteList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_whitelist_PackageNameWhiteListServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final WhiteList a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.services.shared.whitelist.WhiteList:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_whitelist_PackageNameWhiteListServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PackageNameWhiteListService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_whitelist_PackageNameWhiteListServiceImpl();
      }
    });
    class org_uberfire_preferences_shared_PreferenceStorageImpl extends AbstractRpcProxy implements PreferenceStorage { public boolean exists(final PreferenceScope a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("exists:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean exists(final PreferenceScopeResolutionStrategyInfo a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("exists:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Object read(final PreferenceScope a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("read:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Object read(final PreferenceScopeResolutionStrategyInfo a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("read:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceScopedValue readWithScope(final PreferenceScopeResolutionStrategyInfo a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("readWithScope:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(PreferenceScopedValue.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void write(final PreferenceScope a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("write:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
      }

      public void delete(final PreferenceScope a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("delete:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
      }

      public Collection allKeys(final PreferenceScope a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("allKeys:org.uberfire.preferences.shared.PreferenceScope:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection allKeys(final List a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStorage").endpoint("allKeys:java.util.List:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStorageImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PreferenceStorage.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_preferences_shared_PreferenceStorageImpl();
      }
    });
    class org_kie_workbench_common_stunner_forms_service_FormGenerationServiceImpl extends AbstractRpcProxy implements FormGenerationService { public void generateProcessForm(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.forms.service.FormGenerationService").endpoint("generateProcessForm:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_forms_service_FormGenerationServiceImpl.this.sendRequest(bus, sendable);
      }

      public void generateAllForms(final Diagram a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.forms.service.FormGenerationService").endpoint("generateAllForms:org.kie.workbench.common.stunner.core.diagram.Diagram:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_forms_service_FormGenerationServiceImpl.this.sendRequest(bus, sendable);
      }

      public void generateSelectedForms(final Diagram a0, final String[] a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.forms.service.FormGenerationService").endpoint("generateSelectedForms:org.kie.workbench.common.stunner.core.diagram.Diagram:java.lang.String[]:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_forms_service_FormGenerationServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(FormGenerationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_forms_service_FormGenerationServiceImpl();
      }
    });
    class org_dashbuilder_dataset_service_SQLProviderServicesImpl extends AbstractRpcProxy implements SQLProviderServices { public List getDataSourceDefs() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.SQLProviderServices").endpoint("getDataSourceDefs:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_SQLProviderServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(SQLProviderServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_dataset_service_SQLProviderServicesImpl();
      }
    });
    class org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl extends AbstractRpcProxy implements PersistenceDescriptorService { public PersistenceDescriptorModel createModuleDefaultDescriptor(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("createModuleDefaultDescriptor:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(PersistenceDescriptorModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PersistenceDescriptorModel load(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("load:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(PersistenceDescriptorModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path calculatePersistenceDescriptorPath(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("calculatePersistenceDescriptorPath:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final PersistenceDescriptorModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final PersistenceDescriptorModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PersistenceDescriptorModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(PersistenceDescriptorModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final PersistenceDescriptorModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datamodeller.service.PersistenceDescriptorService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.datamodeller.model.persistence.PersistenceDescriptorModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PersistenceDescriptorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datamodeller_service_PersistenceDescriptorServiceImpl();
      }
    });
    class org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl extends AbstractRpcProxy implements GuidedDecisionTableGraphEditorService { public GuidedDecisionTableEditorGraphContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedDecisionTableEditorGraphContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List listDecisionTablesInPackage(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("listDecisionTablesInPackage:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final GuidedDecisionTableEditorGraphModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public GuidedDecisionTableEditorGraphModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedDecisionTableEditorGraphModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final GuidedDecisionTableEditorGraphModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedDecisionTableGraphEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_dtable_service_GuidedDecisionTableGraphEditorServiceImpl();
      }
    });
    class org_dashbuilder_navigation_service_PerspectivePluginServicesImpl extends AbstractRpcProxy implements PerspectivePluginServices { public Collection listPlugins() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("listPlugins:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Plugin getPerspectivePlugin(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("getPerspectivePlugin:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Plugin.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate getLayoutTemplate(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("getLayoutTemplate:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate getLayoutTemplate(final Plugin a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("getLayoutTemplate:org.uberfire.ext.plugin.model.Plugin:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplateInfo getLayoutTemplateInfo(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("getLayoutTemplateInfo:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplateInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplateInfo getLayoutTemplateInfo(final Plugin a0, final LayoutTemplateContext a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("getLayoutTemplateInfo:org.uberfire.ext.plugin.model.Plugin:org.dashbuilder.navigation.layout.LayoutTemplateContext:", qualifiers, new Object[] { a0, a1 }).respondTo(LayoutTemplateInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplateInfo getLayoutTemplateInfo(final LayoutTemplate a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.navigation.service.PerspectivePluginServices").endpoint("getLayoutTemplateInfo:org.uberfire.ext.layout.editor.api.editor.LayoutTemplate:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplateInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_navigation_service_PerspectivePluginServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PerspectivePluginServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_navigation_service_PerspectivePluginServicesImpl();
      }
    });
    class org_jbpm_workbench_pr_service_ProcessImageServiceImpl extends AbstractRpcProxy implements ProcessImageService { public String getProcessInstanceDiagram(final String a0, final String a1, final Long a2, final String a3, final String a4, final String a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessImageService").endpoint("getProcessInstanceDiagram:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessImageServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getProcessDiagram(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.pr.service.ProcessImageService").endpoint("getProcessDiagram:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_pr_service_ProcessImageServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProcessImageService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_pr_service_ProcessImageServiceImpl();
      }
    });
    class org_uberfire_backend_vfs_VFSLockServiceImpl extends AbstractRpcProxy implements VFSLockService { public LockResult acquireLock(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSLockService").endpoint("acquireLock:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(LockResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSLockServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LockResult releaseLock(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSLockService").endpoint("releaseLock:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(LockResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSLockServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LockResult forceReleaseLock(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSLockService").endpoint("forceReleaseLock:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(LockResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSLockServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LockInfo retrieveLockInfo(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSLockService").endpoint("retrieveLockInfo:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(LockInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSLockServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List retrieveLockInfos(final Path a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSLockService").endpoint("retrieveLockInfos:org.uberfire.backend.vfs.Path:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSLockServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(VFSLockService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_backend_vfs_VFSLockServiceImpl();
      }
    });
    class org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningServiceImpl extends AbstractRpcProxy implements CaseProvisioningService { public CaseProvisioningStatus getProvisioningStatus() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningService").endpoint("getProvisioningStatus:", qualifiers, new Object[] { }).respondTo(CaseProvisioningStatus.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getApplicationContext() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.wi.casemgmt.service.CaseProvisioningService").endpoint("getApplicationContext:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(CaseProvisioningService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_wi_casemgmt_service_CaseProvisioningServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_workitem_service_WorkItemDefinitionLookupServiceImpl extends AbstractRpcProxy implements WorkItemDefinitionLookupService { public Collection execute(final org.kie.workbench.common.stunner.core.diagram.Metadata a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.workitem.service.WorkItemDefinitionLookupService").endpoint("execute:org.kie.workbench.common.stunner.core.diagram.Metadata:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_workitem_service_WorkItemDefinitionLookupServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(WorkItemDefinitionLookupService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_bpmn_workitem_service_WorkItemDefinitionLookupServiceImpl();
      }
    });
    class org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl extends AbstractRpcProxy implements ScoreCardXLSService { public ScoreCardXLSContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ScoreCardXLSContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService").endpoint("validate:org.uberfire.backend.vfs.Path:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ScoreCardXLSService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_scorecardxls_service_ScoreCardXLSServiceImpl();
      }
    });
    class org_guvnor_common_services_project_service_WorkspaceProjectSearchServiceImpl extends AbstractRpcProxy implements WorkspaceProjectSearchService { public Collection searchByName(final String a0, final int a1, final boolean a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectSearchService").endpoint("searchByName:java.lang.String:int:boolean:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectSearchServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(WorkspaceProjectSearchService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_service_WorkspaceProjectSearchServiceImpl();
      }
    });
    class org_uberfire_backend_plugin_RuntimePluginServiceImpl extends AbstractRpcProxy implements RuntimePluginService { public Collection listFrameworksContent() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.plugin.RuntimePluginService").endpoint("listFrameworksContent:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_plugin_RuntimePluginServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listPluginsContent() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.plugin.RuntimePluginService").endpoint("listPluginsContent:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_plugin_RuntimePluginServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getTemplateContent(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.plugin.RuntimePluginService").endpoint("getTemplateContent:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_plugin_RuntimePluginServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getRuntimePluginTemplateContent(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.plugin.RuntimePluginService").endpoint("getRuntimePluginTemplateContent:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_plugin_RuntimePluginServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getRuntimePlugins() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.plugin.RuntimePluginService").endpoint("getRuntimePlugins:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_plugin_RuntimePluginServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RuntimePluginService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_backend_plugin_RuntimePluginServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_kmodule_KModuleServiceImpl extends AbstractRpcProxy implements KModuleService { public boolean isKModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.kmodule.KModuleService").endpoint("isKModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_kmodule_KModuleServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Path setUpKModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.kmodule.KModuleService").endpoint("setUpKModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_kmodule_KModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public KModuleModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.kmodule.KModuleService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(KModuleModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_kmodule_KModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final KModuleModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.kmodule.KModuleService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.services.shared.kmodule.KModuleModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_kmodule_KModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(KModuleService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_kmodule_KModuleServiceImpl();
      }
    });
    class org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl extends AbstractRpcProxy implements HtmlEditorService { public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public String load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final DefaultMetadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.ext.editor.commons.file.DefaultMetadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final DefaultMetadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.htmleditor.HtmlEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.ext.editor.commons.file.DefaultMetadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(HtmlEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_editor_commons_service_htmleditor_HtmlEditorServiceImpl();
      }
    });
    class org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl extends AbstractRpcProxy implements GuidedRuleTemplateEditorService { public GuidedTemplateEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedTemplateEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean accepts(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("accepts:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public List validate(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final TemplateModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.template.shared.TemplateModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final TemplateModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.template.shared.TemplateModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final TemplateModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.models.guided.template.shared.TemplateModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TemplateModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(TemplateModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final TemplateModel a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.models.guided.template.shared.TemplateModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final TemplateModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.models.guided.template.shared.TemplateModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.template.service.GuidedRuleTemplateEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedRuleTemplateEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_template_service_GuidedRuleTemplateEditorServiceImpl();
      }
    });
    class org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl extends AbstractRpcProxy implements GroupManagerService { public void assignUsers(final String a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("assignUsers:java.lang.String:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public SearchResponse search(final SearchRequest a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("search:org.uberfire.ext.security.management.api.AbstractEntityManager.SearchRequest:", qualifiers, new Object[] { a0 }).respondTo(SearchResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Group get(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("get:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Group.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Group create(final Group a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("create:org.jboss.errai.security.shared.api.Group:", qualifiers, new Object[] { a0 }).respondTo(Group.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Group update(final Group a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("update:org.jboss.errai.security.shared.api.Group:", qualifiers, new Object[] { a0 }).respondTo(Group.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final String[] a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("delete:java.lang.String[]:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
      }

      public GroupManagerSettings getSettings() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.security.management.api.service.GroupManagerService").endpoint("getSettings:", qualifiers, new Object[] { }).respondTo(GroupManagerSettings.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GroupManagerService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_security_management_api_service_GroupManagerServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_rulename_RuleNamesServiceImpl extends AbstractRpcProxy implements RuleNamesService { public Collection getRuleNames(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.rulename.RuleNamesService").endpoint("getRuleNames:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_rulename_RuleNamesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RuleNamesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_rulename_RuleNamesServiceImpl();
      }
    });
    class org_guvnor_common_services_shared_config_ResourceConfigServiceImpl extends AbstractRpcProxy implements ResourceConfigService { public Map configAttrs(final Map a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.shared.config.ResourceConfigService").endpoint("configAttrs:java.util.Map:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_shared_config_ResourceConfigServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ResourceConfigService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_shared_config_ResourceConfigServiceImpl();
      }
    });
    class org_uberfire_preferences_shared_PreferenceStoreImpl extends AbstractRpcProxy implements PreferenceStore { public PreferenceScopeResolutionStrategyInfo getDefaultScopeResolutionStrategyInfo() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("getDefaultScopeResolutionStrategyInfo:", qualifiers, new Object[] { }).respondTo(PreferenceScopeResolutionStrategyInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceScopeResolver getDefaultScopeResolver() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("getDefaultScopeResolver:", qualifiers, new Object[] { }).respondTo(PreferenceScopeResolver.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void put(final PreferenceScope a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("put:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void put(final PreferenceScopeResolutionStrategyInfo a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("put:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void put(final String a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("put:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void put(final PreferenceScope a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("put:org.uberfire.preferences.shared.PreferenceScope:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void put(final PreferenceScopeResolutionStrategyInfo a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("put:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void put(final Map a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("put:java.util.Map:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void putIfAbsent(final PreferenceScope a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("putIfAbsent:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void putIfAbsent(final PreferenceScopeResolutionStrategyInfo a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("putIfAbsent:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void putIfAbsent(final String a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("putIfAbsent:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void putIfAbsent(final PreferenceScope a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("putIfAbsent:org.uberfire.preferences.shared.PreferenceScope:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void putIfAbsent(final PreferenceScopeResolutionStrategyInfo a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("putIfAbsent:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void putIfAbsent(final Map a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("putIfAbsent:java.util.Map:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public Object get(final PreferenceScope a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("get:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Object get(final PreferenceScope a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("get:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Object get(final PreferenceScopeResolutionStrategyInfo a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("get:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Object get(final PreferenceScopeResolutionStrategyInfo a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("get:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Object get(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("get:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Object get(final String a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("get:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(Object.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceScopedValue getScoped(final PreferenceScopeResolutionStrategyInfo a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("getScoped:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(PreferenceScopedValue.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceScopedValue getScoped(final PreferenceScopeResolutionStrategyInfo a0, final String a1, final Object a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("getScoped:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(PreferenceScopedValue.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceScopedValue getScoped(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("getScoped:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(PreferenceScopedValue.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceScopedValue getScoped(final String a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("getScoped:java.lang.String:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(PreferenceScopedValue.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map search(final PreferenceScope a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("search:org.uberfire.preferences.shared.PreferenceScope:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map search(final PreferenceScopeResolutionStrategyInfo a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("search:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map search(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("search:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map searchScoped(final PreferenceScopeResolutionStrategyInfo a0, final Collection a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("searchScoped:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:java.util.Collection:", qualifiers, new Object[] { a0, a1 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map searchScoped(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("searchScoped:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map all(final PreferenceScope a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("all:org.uberfire.preferences.shared.PreferenceScope:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map all(final PreferenceScopeResolutionStrategyInfo a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("all:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map all() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("all:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map allScoped(final PreferenceScopeResolutionStrategyInfo a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("allScoped:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map allScoped() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("allScoped:", qualifiers, new Object[] { }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void remove(final PreferenceScope a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("remove:org.uberfire.preferences.shared.PreferenceScope:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }

      public void remove(final List a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.PreferenceStore").endpoint("remove:java.util.List:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_PreferenceStoreImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PreferenceStore.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_preferences_shared_PreferenceStoreImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DataSourceRuntimeManagerClientServiceImpl extends AbstractRpcProxy implements DataSourceRuntimeManagerClientService { public DataSourceDeploymentInfo getDataSourceDeploymentInfo(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceRuntimeManagerClientService").endpoint("getDataSourceDeploymentInfo:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(DataSourceDeploymentInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceRuntimeManagerClientServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DriverDeploymentInfo getDriverDeploymentInfo(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceRuntimeManagerClientService").endpoint("getDriverDeploymentInfo:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(DriverDeploymentInfo.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceRuntimeManagerClientServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TestResult testDataSource(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceRuntimeManagerClientService").endpoint("testDataSource:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(TestResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceRuntimeManagerClientServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSourceRuntimeManagerClientService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DataSourceRuntimeManagerClientServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl extends AbstractRpcProxy implements DataSourceDefEditorService { public DataSourceDefEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DataSourceDefEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final DataSourceDefEditorContent a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.screens.datasource.management.model.DataSourceDefEditorContent:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final DataSourceDef a0, final Module a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("create:org.kie.workbench.common.screens.datasource.management.model.DataSourceDef:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createGlobal(final DataSourceDef a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("createGlobal:org.kie.workbench.common.screens.datasource.management.model.DataSourceDef:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public TestResult testConnection(final DataSourceDef a0, final Module a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("testConnection:org.kie.workbench.common.screens.datasource.management.model.DataSourceDef:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0, a1 }).respondTo(TestResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TestResult testConnection(final DataSourceDef a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.datasource.management.service.DataSourceDefEditorService").endpoint("testConnection:org.kie.workbench.common.screens.datasource.management.model.DataSourceDef:", qualifiers, new Object[] { a0 }).respondTo(TestResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSourceDefEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_datasource_management_service_DataSourceDefEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl extends AbstractRpcProxy implements FormEditorService { public Path createForm(final Path a0, final String a1, final FormModel a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.FormEditorService").endpoint("createForm:org.uberfire.backend.vfs.Path:java.lang.String:org.kie.workbench.common.forms.model.FormModel:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public FormModelerContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.FormEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(FormModelerContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.FormEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path save(final Path a0, final FormModelerContent a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.FormEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.forms.editor.model.FormModelerContent:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public FormModelerContent rename(final Path a0, final String a1, final String a2, final boolean a3, final FormModelerContent a4, final Metadata a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.FormEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:boolean:org.kie.workbench.common.forms.editor.model.FormModelerContent:org.guvnor.common.services.shared.metadata.model.Metadata:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(FormModelerContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void copy(final Path a0, final String a1, final String a2, final boolean a3, final FormModelerContent a4, final Metadata a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.editor.service.shared.FormEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:boolean:org.kie.workbench.common.forms.editor.model.FormModelerContent:org.guvnor.common.services.shared.metadata.model.Metadata:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(FormEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_forms_editor_service_shared_FormEditorServiceImpl();
      }
    });
    class org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl extends AbstractRpcProxy implements OrganizationalUnitService { public OrganizationalUnit getOrganizationalUnit(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getOrganizationalUnit:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit getOrganizationalUnit(final String a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getOrganizationalUnit:java.lang.String:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllOrganizationalUnits() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getAllOrganizationalUnits:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllOrganizationalUnits(final boolean a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getAllOrganizationalUnits:boolean:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllOrganizationalUnits(final boolean a0, final Predicate a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getAllOrganizationalUnits:boolean:java.util.function.Predicate:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllDeletedOrganizationalUnit() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getAllDeletedOrganizationalUnit:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllUserSpaces() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getAllUserSpaces:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getOrganizationalUnits() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getOrganizationalUnits:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getOrganizationalUnits(final boolean a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getOrganizationalUnits:boolean:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getOrganizationalUnits(final Repository a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getOrganizationalUnits:org.guvnor.structure.repositories.Repository:", qualifiers, new Object[] { a0 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit createOrganizationalUnit(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("createOrganizationalUnit:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit createOrganizationalUnit(final String a0, final String a1, final Collection a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("createOrganizationalUnit:java.lang.String:java.lang.String:java.util.Collection:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit createOrganizationalUnit(final String a0, final String a1, final Collection a2, final Collection a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("createOrganizationalUnit:java.lang.String:java.lang.String:java.util.Collection:java.util.Collection:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit updateOrganizationalUnit(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("updateOrganizationalUnit:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public OrganizationalUnit updateOrganizationalUnit(final String a0, final String a1, final Collection a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("updateOrganizationalUnit:java.lang.String:java.lang.String:java.util.Collection:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void addRepository(final OrganizationalUnit a0, final Repository a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("addRepository:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.guvnor.structure.repositories.Repository:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeRepository(final OrganizationalUnit a0, final Repository a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("removeRepository:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.guvnor.structure.repositories.Repository:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
      }

      public void addGroup(final OrganizationalUnit a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("addGroup:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeGroup(final OrganizationalUnit a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("removeGroup:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
      }

      public void removeOrganizationalUnit(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("removeOrganizationalUnit:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
      }

      public OrganizationalUnit getParentOrganizationalUnit(final Repository a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getParentOrganizationalUnit:org.guvnor.structure.repositories.Repository:", qualifiers, new Object[] { a0 }).respondTo(OrganizationalUnit.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getSanitizedDefaultGroupId(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("getSanitizedDefaultGroupId:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Boolean isValidGroupId(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.organizationalunit.OrganizationalUnitService").endpoint("isValidGroupId:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(OrganizationalUnitService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_organizationalunit_OrganizationalUnitServiceImpl();
      }
    });
    class org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl extends AbstractRpcProxy implements ScenarioSimulationService { public ScenarioSimulationModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ScenarioSimulationModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public SimulationRunResult runScenario(final Path a0, final SimulationDescriptor a1, final List a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("runScenario:org.uberfire.backend.vfs.Path:org.drools.scenariosimulation.api.model.SimulationDescriptor:java.util.List:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(SimulationRunResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final ScenarioSimulationModel a2, final String a3, final Type a4, final String a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.scenariosimulation.api.model.ScenarioSimulationModel:java.lang.String:org.drools.scenariosimulation.api.model.ScenarioSimulationModel.Type:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Simulation a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("validate:org.drools.scenariosimulation.api.model.Simulation:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final ScenarioSimulationModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.scenariosimulation.api.model.ScenarioSimulationModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ScenarioSimulationModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ScenarioSimulationModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final ScenarioSimulationModel a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.scenariosimulation.api.model.ScenarioSimulationModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final ScenarioSimulationModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.scenariosimulation.api.model.ScenarioSimulationModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ScenarioSimulationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_scenariosimulation_service_ScenarioSimulationServiceImpl();
      }
    });
    class org_guvnor_common_services_project_service_ModuleRepositoriesServiceImpl extends AbstractRpcProxy implements ModuleRepositoriesService { public ModuleRepositories create(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoriesService").endpoint("create:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ModuleRepositories.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoriesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final ModuleRepositories a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoriesService").endpoint("save:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.ModuleRepositories:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoriesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ModuleRepositories load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.ModuleRepositoriesService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ModuleRepositories.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_ModuleRepositoriesServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ModuleRepositoriesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_service_ModuleRepositoriesServiceImpl();
      }
    });
    class org_jbpm_designer_service_DesignerAssetServiceImpl extends AbstractRpcProxy implements DesignerAssetService { public DesignerContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DesignerContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void updateMetadata(final Path a0, final Metadata a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("updateMetadata:org.uberfire.backend.vfs.Path:org.guvnor.common.services.shared.metadata.model.Metadata:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
      }

      public Map getEditorParameters(final Path a0, final String a1, final String a2, final PlaceRequest a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("getEditorParameters:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:org.uberfire.mvp.PlaceRequest:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getEditorID() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("getEditorID:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createProcess(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("createProcess:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createCaseDefinition(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("createCaseDefinition:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isCaseProject(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.designer.service.DesignerAssetService").endpoint("isCaseProject:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_designer_service_DesignerAssetServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DesignerAssetService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_designer_service_DesignerAssetServiceImpl();
      }
    });
    class org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl extends AbstractRpcProxy implements SolverEditorService { public SolverModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(SolverModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List smokeTest(final Path a0, final SolverConfigModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("smokeTest:org.uberfire.backend.vfs.Path:org.optaplanner.workbench.screens.solver.model.SolverConfigModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final SolverConfigModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.optaplanner.workbench.screens.solver.model.SolverConfigModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final SolverConfigModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.optaplanner.workbench.screens.solver.model.SolverConfigModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final SolverConfigModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.optaplanner.workbench.screens.solver.model.SolverConfigModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public SolverConfigModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(SolverConfigModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final SolverConfigModel a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.optaplanner.workbench.screens.solver.model.SolverConfigModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final SolverConfigModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.optaplanner.workbench.screens.solver.model.SolverConfigModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.optaplanner.workbench.screens.solver.service.SolverEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(SolverEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_optaplanner_workbench_screens_solver_service_SolverEditorServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_validation_ValidationServiceImpl extends AbstractRpcProxy implements org.kie.workbench.common.services.shared.validation.ValidationService { public boolean isProjectNameValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isProjectNameValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isPackageNameValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isPackageNameValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isFileNameValid(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isFileNameValid:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isFileNameValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isFileNameValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isJavaFileNameValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isJavaFileNameValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isBranchNameValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isBranchNameValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Map evaluateJavaIdentifiers(final String[] a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("evaluateJavaIdentifiers:java.lang.String[]:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map evaluateMavenIdentifiers(final String[] a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("evaluateMavenIdentifiers:java.lang.String[]:", qualifiers, new Object[] { a0 }).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isTimerIntervalValid(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("isTimerIntervalValid:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean validate(final POM a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validate:org.guvnor.common.services.project.model.POM:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean validateGroupId(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateGroupId:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean validateArtifactId(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateArtifactId:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean validateGAVVersion(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateGAVVersion:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Collection validateForSave(final Path a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateForSave:org.uberfire.backend.vfs.Path:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection validateForCopy(final Path a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateForCopy:org.uberfire.backend.vfs.Path:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection validateForCopy(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateForCopy:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection validateForDelete(final Path a0, final Object a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateForDelete:org.uberfire.backend.vfs.Path:java.lang.Object:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection validateForDelete(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.validation.ValidationService").endpoint("validateForDelete:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_validation_ValidationServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(org.kie.workbench.common.services.shared.validation.ValidationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_validation_ValidationServiceImpl();
      }
    });
    class org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl extends AbstractRpcProxy implements ChangeRequestService { public ChangeRequest createChangeRequest(final String a0, final String a1, final String a2, final String a3, final String a4, final String a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("createChangeRequest:java.lang.String:java.lang.String:java.lang.String:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(ChangeRequest.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getChangeRequests(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequests:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getChangeRequests(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequests:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getChangeRequests(final String a0, final String a1, final List a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequests:java.lang.String:java.lang.String:java.util.List:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getChangeRequests(final String a0, final String a1, final List a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequests:java.lang.String:java.lang.String:java.util.List:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PaginatedChangeRequestList getChangeRequests(final String a0, final String a1, final Integer a2, final Integer a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequests:java.lang.String:java.lang.String:java.lang.Integer:java.lang.Integer:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(PaginatedChangeRequestList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PaginatedChangeRequestList getChangeRequests(final String a0, final String a1, final Integer a2, final Integer a3, final List a4, final String a5) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequests:java.lang.String:java.lang.String:java.lang.Integer:java.lang.Integer:java.util.List:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4, a5 }).respondTo(PaginatedChangeRequestList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ChangeRequest getChangeRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getChangeRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(ChangeRequest.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public ChangeRequestCountSummary countChangeRequests(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("countChangeRequests:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(ChangeRequestCountSummary.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getDiff(final String a0, final String a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getDiff:java.lang.String:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List getDiff(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getDiff:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void deleteChangeRequests(final String a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("deleteChangeRequests:java.lang.String:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public void rejectChangeRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("rejectChangeRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public Boolean acceptChangeRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("acceptChangeRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Boolean revertChangeRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("revertChangeRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public void closeChangeRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("closeChangeRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public void reopenChangeRequest(final String a0, final String a1, final Long a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("reopenChangeRequest:java.lang.String:java.lang.String:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateChangeRequestSummary(final String a0, final String a1, final Long a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("updateChangeRequestSummary:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public void updateChangeRequestDescription(final String a0, final String a1, final Long a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("updateChangeRequestDescription:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public PaginatedChangeRequestCommentList getComments(final String a0, final String a1, final Long a2, final Integer a3, final Integer a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("getComments:java.lang.String:java.lang.String:java.lang.Long:java.lang.Integer:java.lang.Integer:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(PaginatedChangeRequestCommentList.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void addComment(final String a0, final String a1, final Long a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("addComment:java.lang.String:java.lang.String:java.lang.Long:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deleteComment(final String a0, final String a1, final Long a2, final Long a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.structure.repositories.changerequest.ChangeRequestService").endpoint("deleteComment:java.lang.String:java.lang.String:java.lang.Long:java.lang.Long:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ChangeRequestService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_structure_repositories_changerequest_ChangeRequestServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_project_KieModuleServiceImpl extends AbstractRpcProxy implements KieModuleService { public KieModule resolveModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(KieModule.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public KieModule resolveModule(final Path a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveModule:org.uberfire.backend.vfs.Path:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(KieModule.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module resolveParentModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveParentModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Module resolveToParentModule(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveToParentModule:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Module.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set resolvePackages(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolvePackages:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set resolvePackages(final Package a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolvePackages:org.guvnor.common.services.project.model.Package:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolveDefaultPackage(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveDefaultPackage:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolveDefaultWorkspacePackage(final Module a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveDefaultWorkspacePackage:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package resolveParentPackage(final Package a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveParentPackage:org.guvnor.common.services.project.model.Package:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path resolveDefaultPath(final Package a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolveDefaultPath:org.guvnor.common.services.project.model.Package:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isPom(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("isPom:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Package resolvePackage(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("resolvePackage:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set getAllModules(final Branch a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("getAllModules:org.guvnor.structure.repositories.Branch:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public KieModule newModule(final Path a0, final POM a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("newModule:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:", qualifiers, new Object[] { a0, a1 }).respondTo(KieModule.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public KieModule newModule(final Path a0, final POM a1, final DeploymentMode a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("newModule:org.uberfire.backend.vfs.Path:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(KieModule.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Package newPackage(final Package a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("newPackage:org.guvnor.common.services.project.model.Package:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Package.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
      }

      public void copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
      }

      public void reImport(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.project.KieModuleService").endpoint("reImport:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_project_KieModuleServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(KieModuleService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_project_KieModuleServiceImpl();
      }
    });
    class org_kie_workbench_common_forms_jbpm_service_shared_documents_UploadedDocumentServiceImpl extends AbstractRpcProxy implements UploadedDocumentService { public DocumentUploadResponse uploadContent(final DocumentUploadChunk a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.jbpm.service.shared.documents.UploadedDocumentService").endpoint("uploadContent:org.kie.workbench.common.forms.jbpm.service.shared.documents.DocumentUploadChunk:", qualifiers, new Object[] { a0 }).respondTo(DocumentUploadResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_jbpm_service_shared_documents_UploadedDocumentServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void removeContent(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.forms.jbpm.service.shared.documents.UploadedDocumentService").endpoint("removeContent:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_forms_jbpm_service_shared_documents_UploadedDocumentServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(UploadedDocumentService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_forms_jbpm_service_shared_documents_UploadedDocumentServiceImpl();
      }
    });
    class org_jboss_errai_security_shared_service_NonCachingUserServiceImpl extends AbstractRpcProxy implements NonCachingUserService { public User getUser() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jboss.errai.security.shared.service.NonCachingUserService").endpoint("getUser:", qualifiers, new Object[] { }).respondTo(User.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jboss_errai_security_shared_service_NonCachingUserServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(NonCachingUserService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jboss_errai_security_shared_service_NonCachingUserServiceImpl();
      }
    });
    class org_uberfire_ext_editor_commons_service_CopyServiceImpl extends AbstractRpcProxy implements CopyService { public void copyIfExists(final Collection a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.CopyService").endpoint("copyIfExists:java.util.Collection:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_CopyServiceImpl.this.sendRequest(bus, sendable);
      }

      public boolean hasRestriction(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.CopyService").endpoint("hasRestriction:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_CopyServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.CopyService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_CopyServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.editor.commons.service.CopyService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_editor_commons_service_CopyServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(CopyService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_editor_commons_service_CopyServiceImpl();
      }
    });
    class org_drools_workbench_screens_scenariosimulation_service_DMNTypeServiceImpl extends AbstractRpcProxy implements DMNTypeService { public FactModelTuple retrieveFactModelTuple(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.DMNTypeService").endpoint("retrieveFactModelTuple:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(FactModelTuple.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_DMNTypeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void initializeNameAndNamespace(final Simulation a0, final Path a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.scenariosimulation.service.DMNTypeService").endpoint("initializeNameAndNamespace:org.drools.scenariosimulation.api.model.Simulation:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_scenariosimulation_service_DMNTypeServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DMNTypeService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_scenariosimulation_service_DMNTypeServiceImpl();
      }
    });
    class org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl extends AbstractRpcProxy implements DecisionTableXLSService { public ConversionResult convert(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("convert:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ConversionResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DecisionTableXLSContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DecisionTableXLSContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String getSource(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("getSource:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final InputStream a1, final String a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("create:org.uberfire.backend.vfs.Path:java.io.InputStream:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("validate:org.uberfire.backend.vfs.Path:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DecisionTableXLSService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_dtablexls_service_DecisionTableXLSServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_server_management_service_RuleCapabilitiesServiceImpl extends AbstractRpcProxy implements RuleCapabilitiesService { public void scanNow(final ContainerSpecKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.RuleCapabilitiesService").endpoint("scanNow:org.kie.server.controller.api.model.spec.ContainerSpecKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_RuleCapabilitiesServiceImpl.this.sendRequest(bus, sendable);
      }

      public void startScanner(final ContainerSpecKey a0, final Long a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.RuleCapabilitiesService").endpoint("startScanner:org.kie.server.controller.api.model.spec.ContainerSpecKey:java.lang.Long:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_RuleCapabilitiesServiceImpl.this.sendRequest(bus, sendable);
      }

      public void stopScanner(final ContainerSpecKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.RuleCapabilitiesService").endpoint("stopScanner:org.kie.server.controller.api.model.spec.ContainerSpecKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_RuleCapabilitiesServiceImpl.this.sendRequest(bus, sendable);
      }

      public void upgradeContainer(final ContainerSpecKey a0, final ReleaseId a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.server.management.service.RuleCapabilitiesService").endpoint("upgradeContainer:org.kie.server.controller.api.model.spec.ContainerSpecKey:org.kie.server.api.model.ReleaseId:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_server_management_service_RuleCapabilitiesServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RuleCapabilitiesService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_server_management_service_RuleCapabilitiesServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl extends AbstractRpcProxy implements PomEditorService { public DefaultEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.PomEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DefaultEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3, final DeploymentMode a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.PomEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.PomEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.PomEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.projecteditor.service.PomEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PomEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_projecteditor_service_PomEditorServiceImpl();
      }
    });
    class org_guvnor_ala_ui_service_SourceServiceImpl extends AbstractRpcProxy implements SourceService { public Collection getOrganizationUnits() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.SourceService").endpoint("getOrganizationUnits:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_SourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getRepositories(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.SourceService").endpoint("getRepositories:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_SourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getBranches(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.SourceService").endpoint("getBranches:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_SourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getModules(final Space a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.SourceService").endpoint("getModules:org.uberfire.spaces.Space:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_SourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(SourceService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_service_SourceServiceImpl();
      }
    });
    class org_dashbuilder_transfer_DataTransferServicesImpl extends AbstractRpcProxy implements DataTransferServices { public String doExport() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.transfer.DataTransferServices").endpoint("doExport:", qualifiers, new Object[] { }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_transfer_DataTransferServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List doImport() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.transfer.DataTransferServices").endpoint("doImport:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_transfer_DataTransferServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataTransferServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_transfer_DataTransferServicesImpl();
      }
    });
    class org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl extends AbstractRpcProxy implements GuidedRuleEditorService { public GuidedEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(GuidedEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String toSource(final Path a0, final RuleModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("toSource:org.uberfire.backend.vfs.Path:org.drools.workbench.models.datamodel.rule.RuleModel:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public List validate(final Path a0, final RuleModel a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("validate:org.uberfire.backend.vfs.Path:org.drools.workbench.models.datamodel.rule.RuleModel:", qualifiers, new Object[] { a0, a1 }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final RuleModel a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.models.datamodel.rule.RuleModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public RuleModel load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(RuleModel.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final RuleModel a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.models.datamodel.rule.RuleModel:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final RuleModel a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.models.datamodel.rule.RuleModel:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.guided.rule.service.GuidedRuleEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GuidedRuleEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_guided_rule_service_GuidedRuleEditorServiceImpl();
      }
    });
    class org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl extends AbstractRpcProxy implements ScenarioTestEditorService { public TestScenarioModelContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(TestScenarioModelContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public TestScenarioResult runScenario(final String a0, final Path a1, final Scenario a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("runScenario:java.lang.String:org.uberfire.backend.vfs.Path:org.drools.workbench.models.testscenarios.shared.Scenario:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(TestScenarioResult.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path create(final Path a0, final String a1, final Scenario a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("create:org.uberfire.backend.vfs.Path:java.lang.String:org.drools.workbench.models.testscenarios.shared.Scenario:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Scenario load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Scenario.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final Scenario a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.drools.workbench.models.testscenarios.shared.Scenario:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final Scenario a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("save:org.uberfire.backend.vfs.Path:org.drools.workbench.models.testscenarios.shared.Scenario:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ScenarioTestEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_drools_workbench_screens_testscenario_service_ScenarioTestEditorServiceImpl();
      }
    });
    class org_jbpm_workbench_common_service_GenericServiceEntryPointImpl extends AbstractRpcProxy implements GenericServiceEntryPoint { public PageResponse getData(final QueryFilter a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.jbpm.workbench.common.service.GenericServiceEntryPoint").endpoint("getData:org.jbpm.workbench.common.model.QueryFilter:", qualifiers, new Object[] { a0 }).respondTo(PageResponse.class, remoteCallback).errorsHandledBy(errorCallback);
        org_jbpm_workbench_common_service_GenericServiceEntryPointImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(GenericServiceEntryPoint.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_jbpm_workbench_common_service_GenericServiceEntryPointImpl();
      }
    });
    class org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl extends AbstractRpcProxy implements DataSetDefVfsServices { public Path resolve(final DataSetDef a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("resolve:org.dashbuilder.dataset.def.DataSetDef:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DataSetDef get(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("get:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DataSetDef.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public EditDataSetDef load(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("load:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(EditDataSetDef.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final DataSetDef a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("save:org.dashbuilder.dataset.def.DataSetDef:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefVfsServices").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSetDefVfsServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_dataset_service_DataSetDefVfsServicesImpl();
      }
    });
    class org_uberfire_experimental_service_backend_BackendExperimentalFeaturesRegistryServiceImpl extends AbstractRpcProxy implements BackendExperimentalFeaturesRegistryService { public ExperimentalFeaturesSession getExperimentalFeaturesSession() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.experimental.service.backend.BackendExperimentalFeaturesRegistryService").endpoint("getExperimentalFeaturesSession:", qualifiers, new Object[] { }).respondTo(ExperimentalFeaturesSession.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_experimental_service_backend_BackendExperimentalFeaturesRegistryServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BackendExperimentalFeaturesRegistryService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_experimental_service_backend_BackendExperimentalFeaturesRegistryServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_project_service_BPMNDiagramServiceImpl extends AbstractRpcProxy implements BPMNDiagramService { public ProjectType getProjectType(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.bpmn.project.service.BPMNDiagramService").endpoint("getProjectType:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(ProjectType.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_bpmn_project_service_BPMNDiagramServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(BPMNDiagramService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_bpmn_project_service_BPMNDiagramServiceImpl();
      }
    });
    class org_kie_workbench_common_screens_defaulteditor_service_DefaultEditorServiceImpl extends AbstractRpcProxy implements DefaultEditorService { public DefaultEditorContent loadContent(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.defaulteditor.service.DefaultEditorService").endpoint("loadContent:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DefaultEditorContent.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_defaulteditor_service_DefaultEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final String a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.defaulteditor.service.DefaultEditorService").endpoint("save:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_defaulteditor_service_DefaultEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final String a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.defaulteditor.service.DefaultEditorService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_defaulteditor_service_DefaultEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.screens.defaulteditor.service.DefaultEditorService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_screens_defaulteditor_service_DefaultEditorServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DefaultEditorService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_screens_defaulteditor_service_DefaultEditorServiceImpl();
      }
    });
    class org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl extends AbstractRpcProxy implements WorkspaceProjectService { public Collection getAllWorkspaceProjects() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("getAllWorkspaceProjects:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllWorkspaceProjects(final OrganizationalUnit a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("getAllWorkspaceProjects:org.guvnor.structure.organizationalunit.OrganizationalUnit:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getAllWorkspaceProjectsByName(final OrganizationalUnit a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("getAllWorkspaceProjectsByName:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean spaceHasNoProjectsWithName(final OrganizationalUnit a0, final String a1, final WorkspaceProject a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("spaceHasNoProjectsWithName:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:org.guvnor.common.services.project.model.WorkspaceProject:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public WorkspaceProject newProject(final OrganizationalUnit a0, final POM a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("newProject:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.guvnor.common.services.project.model.POM:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject newProject(final OrganizationalUnit a0, final POM a1, final DeploymentMode a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("newProject:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.project.service.DeploymentMode:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject newProject(final OrganizationalUnit a0, final POM a1, final DeploymentMode a2, final List a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("newProject:org.guvnor.structure.organizationalunit.OrganizationalUnit:org.guvnor.common.services.project.model.POM:org.guvnor.common.services.project.service.DeploymentMode:java.util.List:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String createFreshProjectName(final OrganizationalUnit a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("createFreshProjectName:org.guvnor.structure.organizationalunit.OrganizationalUnit:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProject(final Repository a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProject:org.guvnor.structure.repositories.Repository:", qualifiers, new Object[] { a0 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProject(final Space a0, final Branch a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProject:org.uberfire.spaces.Space:org.guvnor.structure.repositories.Branch:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProject(final Space a0, final Module a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProject:org.uberfire.spaces.Space:org.guvnor.common.services.project.model.Module:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProject(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProject:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProject(final Space a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProject:org.uberfire.spaces.Space:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProject(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProject:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public WorkspaceProject resolveProjectByRepositoryAlias(final Space a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.common.services.project.service.WorkspaceProjectService").endpoint("resolveProjectByRepositoryAlias:org.uberfire.spaces.Space:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(WorkspaceProject.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(WorkspaceProjectService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_common_services_project_service_WorkspaceProjectServiceImpl();
      }
    });
    class org_uberfire_backend_vfs_VFSServiceImpl extends AbstractRpcProxy implements VFSService { public Path get(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("get:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DirectoryStream newDirectoryStream(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("newDirectoryStream:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(DirectoryStream.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DirectoryStream newDirectoryStream(final Path a0, final Filter a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("newDirectoryStream:org.uberfire.backend.vfs.Path:org.uberfire.backend.vfs.DirectoryStream.Filter:", qualifiers, new Object[] { a0, a1 }).respondTo(DirectoryStream.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createDirectory(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("createDirectory:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createDirectory(final Path a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("createDirectory:org.uberfire.backend.vfs.Path:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createDirectories(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("createDirectories:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path createDirectories(final Path a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("createDirectories:org.uberfire.backend.vfs.Path:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Map readAttributes(final Path a0) {
        try {
          final CallContextStatus status = new CallContextStatus(VFSCacheInterceptor.class);
          final RemoteCallContext callContext = new RemoteCallContext() {
            public String getMethodName() {
              return "readAttributes";
            }
            public Class getReturnType() {
              return Map.class;
            }
            public Annotation[] getAnnotations() {
              return new Annotation[] { new InterceptedCall() {
                  public Class annotationType() {
                    return InterceptedCall.class;
                  }
                  public String toString() {
                    return "@org.jboss.errai.common.client.api.interceptor.InterceptedCall(value=[class org.uberfire.backend.vfs.impl.VFSCacheInterceptor])";
                  }
                  public Class[] value() {
                    return new Class[] { VFSCacheInterceptor.class };
                  }
              } };
            }
            public Annotation[] getTypeAnnotations() {
              return new Annotation[] { };
            }
            public Object proceed() {
              status.proceed();
              if (status.getNextInterceptor() == null) {
                RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("readAttributes:org.uberfire.backend.vfs.Path:", qualifiers, getParameters()).respondTo(Map.class, remoteCallback).errorsHandledBy(errorCallback);
                org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
              } else if (status.getNextInterceptor() == VFSCacheInterceptor.class) {
                final RemoteCallContext ctx = this;
                final CreationalCallback icc = new CreationalCallback() {
                  public void callback(final Object beanInstance) {
                    status.setProceeding(false);
                    ((VFSCacheInterceptor) beanInstance).aroundInvoke(ctx);
                    if ((!status.isProceeding()) && (VFSCacheInterceptor.class == status.getNextInterceptor())) {
                      remoteCallback.callback(ctx.getResult());
                    }
                  }
                };
                AsyncBeanFactory.createBean(new VFSCacheInterceptor(), icc);
              }
              return null;
            }
            public void proceed(final RemoteCallback interceptorCallback) {
              final RemoteCallback providedCallback = org_uberfire_backend_vfs_VFSServiceImpl.this.remoteCallback;
              remoteCallback = new RemoteCallback() {
                public void callback(Object response) {
                  RemoteCallback intCallback = interceptorCallback;
                  setResult(response);
                  intCallback.callback(getResult());
                  providedCallback.callback(getResult());
                }
              };
              proceed();
            }
            public void proceed(RemoteCallback interceptorCallback, final ErrorCallback interceptorErrorCallback) {
              final ErrorCallback providedErrorCallback = org_uberfire_backend_vfs_VFSServiceImpl.this.errorCallback;
              errorCallback = new ErrorCallback() {
                public boolean error(Object message, Throwable throwable) {
                  interceptorErrorCallback.error(message, throwable);
                  if (getResult() != null) {
                    remoteCallback.callback(getResult());
                    return false;
                  } else if (providedErrorCallback != null) {
                    return providedErrorCallback.error(message, throwable);
                  }
                  return true;
                }
              };
              proceed(interceptorCallback);
            }
          };
          callContext.setParameters(new Object[] { a0 });
          callContext.proceed();
        } catch (Throwable throwable) {
          if (errorCallback != null) {
            if (errorCallback.error(null, throwable)) {
              invokeDefaultErrorHandlers(throwable);
            }
          } else {
            invokeDefaultErrorHandlers(throwable);
          }
        }
        return null;
      }

      public void setAttributes(final Path a0, final Map a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("setAttributes:org.uberfire.backend.vfs.Path:java.util.Map:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
      }

      public void delete(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("delete:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
      }

      public boolean deleteIfExists(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("deleteIfExists:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public Path copy(final Path a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("copy:org.uberfire.backend.vfs.Path:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path move(final Path a0, final Path a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("move:org.uberfire.backend.vfs.Path:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String readAllString(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("readAllString:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path write(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("write:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path write(final Path a0, final String a1, final Map a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("write:org.uberfire.backend.vfs.Path:java.lang.String:java.util.Map:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public boolean isRegularFile(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("isRegularFile:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isRegularFile(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("isRegularFile:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isDirectory(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("isDirectory:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }

      public boolean isDirectory(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.backend.vfs.VFSService").endpoint("isDirectory:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_backend_vfs_VFSServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(VFSService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_backend_vfs_VFSServiceImpl();
      }
    });
    class org_kie_workbench_common_stunner_project_service_ProjectDiagramResourceServiceImpl extends AbstractRpcProxy implements ProjectDiagramResourceService { public Path saveAndRename(final Path a0, final String a1, final Metadata a2, final ProjectDiagramResource a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramResourceService").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.guvnor.common.services.shared.metadata.model.Metadata:org.kie.workbench.common.stunner.project.diagram.editor.ProjectDiagramResource:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramResourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramResourceService").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramResourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final ProjectDiagramResource a1, final Metadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.stunner.project.service.ProjectDiagramResourceService").endpoint("save:org.uberfire.backend.vfs.Path:org.kie.workbench.common.stunner.project.diagram.editor.ProjectDiagramResource:org.guvnor.common.services.shared.metadata.model.Metadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_stunner_project_service_ProjectDiagramResourceServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(ProjectDiagramResourceService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_stunner_project_service_ProjectDiagramResourceServiceImpl();
      }
    });
    class org_kie_workbench_common_services_shared_dependencies_DependencyServiceImpl extends AbstractRpcProxy implements DependencyService { public Collection loadDependencies(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.dependencies.DependencyService").endpoint("loadDependencies:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_dependencies_DependencyServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection loadDependencies(final GAV a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.dependencies.DependencyService").endpoint("loadDependencies:org.guvnor.common.services.project.model.GAV:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_dependencies_DependencyServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Set loadPackageNames(final GAV a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.dependencies.DependencyService").endpoint("loadPackageNames:org.guvnor.common.services.project.model.GAV:", qualifiers, new Object[] { a0 }).respondTo(Set.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_dependencies_DependencyServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public EnhancedDependencies loadEnhancedDependencies(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.services.shared.dependencies.DependencyService").endpoint("loadEnhancedDependencies:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(EnhancedDependencies.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_services_shared_dependencies_DependencyServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DependencyService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_services_shared_dependencies_DependencyServiceImpl();
      }
    });
    class org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl extends AbstractRpcProxy implements PerspectiveServices { public Plugin createNewPerspective(final String a0, final Style a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("createNewPerspective:java.lang.String:org.uberfire.ext.layout.editor.api.editor.LayoutTemplate.Style:", qualifiers, new Object[] { a0, a1 }).respondTo(Plugin.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection listLayoutTemplates() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("listLayoutTemplates:", qualifiers, new Object[] { }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate getLayoutTemplate(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("getLayoutTemplate:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate getLayoutTemplate(final Path a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("getLayoutTemplate:org.uberfire.backend.vfs.Path:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate getLayoutTemplate(final Plugin a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("getLayoutTemplate:org.uberfire.ext.plugin.model.Plugin:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public LayoutTemplate convertToLayoutTemplate(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("convertToLayoutTemplate:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(LayoutTemplate.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path saveLayoutTemplate(final Path a0, final LayoutTemplate a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("saveLayoutTemplate:org.uberfire.backend.vfs.Path:org.uberfire.ext.layout.editor.api.editor.LayoutTemplate:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path copy(final Path a0, final String a1, final Path a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("copy:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void delete(final Path a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("delete:org.uberfire.backend.vfs.Path:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
      }

      public Path saveAndRename(final Path a0, final String a1, final DefaultMetadata a2, final LayoutTemplate a3, final String a4) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("saveAndRename:org.uberfire.backend.vfs.Path:java.lang.String:org.uberfire.ext.editor.commons.file.DefaultMetadata:org.uberfire.ext.layout.editor.api.editor.LayoutTemplate:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3, a4 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path rename(final Path a0, final String a1, final String a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("rename:org.uberfire.backend.vfs.Path:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Path save(final Path a0, final LayoutTemplate a1, final DefaultMetadata a2, final String a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.ext.layout.editor.api.PerspectiveServices").endpoint("save:org.uberfire.backend.vfs.Path:org.uberfire.ext.layout.editor.api.editor.LayoutTemplate:org.uberfire.ext.editor.commons.file.DefaultMetadata:java.lang.String:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(Path.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PerspectiveServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_ext_layout_editor_api_PerspectiveServicesImpl();
      }
    });
    class org_kie_workbench_common_dmn_api_editors_types_DMNValidationServiceImpl extends AbstractRpcProxy implements DMNValidationService { public boolean isValidVariableName(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.kie.workbench.common.dmn.api.editors.types.DMNValidationService").endpoint("isValidVariableName:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(Boolean.class, remoteCallback).errorsHandledBy(errorCallback);
        org_kie_workbench_common_dmn_api_editors_types_DMNValidationServiceImpl.this.sendRequest(bus, sendable);
        return false;
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DMNValidationService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_kie_workbench_common_dmn_api_editors_types_DMNValidationServiceImpl();
      }
    });
    class org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl extends AbstractRpcProxy implements PreferenceBeanServerStore { public BasePreferencePortable load(final BasePreferencePortable a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("load:org.uberfire.preferences.shared.bean.BasePreferencePortable:", qualifiers, new Object[] { a0 }).respondTo(BasePreferencePortable.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public BasePreferencePortable load(final BasePreferencePortable a0, final PreferenceScopeResolutionStrategyInfo a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("load:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:", qualifiers, new Object[] { a0, a1 }).respondTo(BasePreferencePortable.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void save(final BasePreferencePortable a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:org.uberfire.preferences.shared.bean.BasePreferencePortable:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final BasePreferencePortable a0, final PreferenceScopeResolutionStrategyInfo a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final BasePreferencePortable a0, final PreferenceScope a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.preferences.shared.PreferenceScope:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final Collection a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:java.util.Collection:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final Collection a0, final PreferenceScopeResolutionStrategyInfo a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:java.util.Collection:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final Collection a0, final PreferenceScope a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:java.util.Collection:org.uberfire.preferences.shared.PreferenceScope:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public PreferenceHierarchyElement buildHierarchyStructureForPreference(final String a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("buildHierarchyStructureForPreference:java.lang.String:", qualifiers, new Object[] { a0 }).respondTo(PreferenceHierarchyElement.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PreferenceHierarchyElement buildHierarchyStructureForPreference(final String a0, final PreferenceScopeResolutionStrategyInfo a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("buildHierarchyStructureForPreference:java.lang.String:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:", qualifiers, new Object[] { a0, a1 }).respondTo(PreferenceHierarchyElement.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void load(final BasePreferencePortable a0, final ParameterizedCommand a1, final ParameterizedCommand a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("load:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.mvp.ParameterizedCommand:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void load(final BasePreferencePortable a0, final PreferenceScopeResolutionStrategyInfo a1, final ParameterizedCommand a2, final ParameterizedCommand a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("load:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:org.uberfire.mvp.ParameterizedCommand:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final BasePreferencePortable a0, final Command a1, final ParameterizedCommand a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.mvp.Command:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final BasePreferencePortable a0, final PreferenceScopeResolutionStrategyInfo a1, final Command a2, final ParameterizedCommand a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:org.uberfire.mvp.Command:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final BasePreferencePortable a0, final PreferenceScope a1, final Command a2, final ParameterizedCommand a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:org.uberfire.preferences.shared.bean.BasePreferencePortable:org.uberfire.preferences.shared.PreferenceScope:org.uberfire.mvp.Command:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final Collection a0, final Command a1, final ParameterizedCommand a2) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:java.util.Collection:org.uberfire.mvp.Command:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final Collection a0, final PreferenceScopeResolutionStrategyInfo a1, final Command a2, final ParameterizedCommand a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:java.util.Collection:org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo:org.uberfire.mvp.Command:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }

      public void save(final Collection a0, final PreferenceScope a1, final Command a2, final ParameterizedCommand a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.uberfire.preferences.shared.bean.PreferenceBeanServerStore").endpoint("save:java.util.Collection:org.uberfire.preferences.shared.PreferenceScope:org.uberfire.mvp.Command:org.uberfire.mvp.ParameterizedCommand:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(PreferenceBeanServerStore.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_uberfire_preferences_shared_bean_PreferenceBeanServerStoreImpl();
      }
    });
    class org_guvnor_ala_ui_service_RuntimeServiceImpl extends AbstractRpcProxy implements RuntimeService { public Collection getRuntimeItems(final ProviderKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("getRuntimeItems:org.guvnor.ala.ui.model.ProviderKey:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public RuntimeListItem getRuntimeItem(final PipelineExecutionTraceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("getRuntimeItem:org.guvnor.ala.ui.model.PipelineExecutionTraceKey:", qualifiers, new Object[] { a0 }).respondTo(RuntimeListItem.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public RuntimeListItem getRuntimeItem(final RuntimeKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("getRuntimeItem:org.guvnor.ala.ui.model.RuntimeKey:", qualifiers, new Object[] { a0 }).respondTo(RuntimeListItem.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public Collection getPipelines(final ProviderTypeKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("getPipelines:org.guvnor.ala.ui.model.ProviderTypeKey:", qualifiers, new Object[] { a0 }).respondTo(Collection.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public PipelineExecutionTraceKey createRuntime(final ProviderKey a0, final String a1, final PipelineKey a2, final Map a3) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("createRuntime:org.guvnor.ala.ui.model.ProviderKey:java.lang.String:org.guvnor.ala.ui.model.PipelineKey:java.util.Map:", qualifiers, new Object[] { a0, a1, a2, a3 }).respondTo(PipelineExecutionTraceKey.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void stopPipelineExecution(final PipelineExecutionTraceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("stopPipelineExecution:org.guvnor.ala.ui.model.PipelineExecutionTraceKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deletePipelineExecution(final PipelineExecutionTraceKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("deletePipelineExecution:org.guvnor.ala.ui.model.PipelineExecutionTraceKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
      }

      public void stopRuntime(final RuntimeKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("stopRuntime:org.guvnor.ala.ui.model.RuntimeKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
      }

      public void startRuntime(final RuntimeKey a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("startRuntime:org.guvnor.ala.ui.model.RuntimeKey:", qualifiers, new Object[] { a0 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
      }

      public void deleteRuntime(final RuntimeKey a0, final boolean a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.guvnor.ala.ui.service.RuntimeService").endpoint("deleteRuntime:org.guvnor.ala.ui.model.RuntimeKey:boolean:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_guvnor_ala_ui_service_RuntimeServiceImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(RuntimeService.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_guvnor_ala_ui_service_RuntimeServiceImpl();
      }
    });
    class org_dashbuilder_dataset_service_DataSetDefServicesImpl extends AbstractRpcProxy implements DataSetDefServices { public List getPublicDataSetDefs() {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefServices").endpoint("getPublicDataSetDefs:", qualifiers, new Object[] { }).respondTo(List.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public DataSetDef createDataSetDef(final DataSetProviderType a0) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefServices").endpoint("createDataSetDef:org.dashbuilder.dataprovider.DataSetProviderType:", qualifiers, new Object[] { a0 }).respondTo(DataSetDef.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public String registerDataSetDef(final DataSetDef a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefServices").endpoint("registerDataSetDef:org.dashbuilder.dataset.def.DataSetDef:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(String.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefServicesImpl.this.sendRequest(bus, sendable);
        return null;
      }

      public void removeDataSetDef(final String a0, final String a1) {
        RemoteCallSendable sendable = MessageBuilder.createCall().call("org.dashbuilder.dataset.service.DataSetDefServices").endpoint("removeDataSetDef:java.lang.String:java.lang.String:", qualifiers, new Object[] { a0, a1 }).respondTo(void.class, remoteCallback).errorsHandledBy(errorCallback);
        org_dashbuilder_dataset_service_DataSetDefServicesImpl.this.sendRequest(bus, sendable);
      }
    }
    RemoteServiceProxyFactory.addRemoteProxy(DataSetDefServices.class, new ProxyProvider() {
      public Object getProxy() {
        return new org_dashbuilder_dataset_service_DataSetDefServicesImpl();
      }
    });
  }
}