package org.jboss.errai.databinding.client;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.Set;
import java.util.function.Consumer;
import org.jboss.errai.databinding.client.api.Convert;
import org.jboss.errai.databinding.client.api.StateSync;
import org.jboss.errai.ui.shared.api.Locale;
import org.jbpm.designer.client.shared.AssignmentRow;
import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
import org.jbpm.workbench.common.model.GenericSummary.LabeledCommand;
import org.jbpm.workbench.df.client.filter.SavedFilter;
import org.jbpm.workbench.es.model.ExecutionErrorSummary;
import org.jbpm.workbench.es.model.RequestParameterSummary;
import org.jbpm.workbench.es.model.RequestSummary;
import org.jbpm.workbench.es.util.ExecutionErrorType;
import org.jbpm.workbench.es.util.RequestStatus;
import org.jbpm.workbench.ht.model.CommentSummary;
import org.jbpm.workbench.ht.model.TaskEventSummary;
import org.jbpm.workbench.pr.model.NodeInstanceSummary;
import org.jbpm.workbench.pr.model.ProcessInstanceLogSummary;
import org.jbpm.workbench.pr.model.ProcessNodeSummary;
import org.jbpm.workbench.pr.model.TimerInstanceSummary;
import org.jbpm.workbench.pr.model.TimerSummary;
import org.jbpm.workbench.pr.model.WorkItemParameterSummary;
import org.jbpm.workbench.wi.workitems.model.ServiceTaskSummary;
import org.kie.workbench.common.dmn.api.DMNDefinitionSet;
import org.kie.workbench.common.dmn.api.definition.HasExpression;
import org.kie.workbench.common.dmn.api.definition.NOPDomainObject;
import org.kie.workbench.common.dmn.api.definition.model.Association;
import org.kie.workbench.common.dmn.api.definition.model.AuthorityRequirement;
import org.kie.workbench.common.dmn.api.definition.model.BusinessKnowledgeModel;
import org.kie.workbench.common.dmn.api.definition.model.ConstraintType;
import org.kie.workbench.common.dmn.api.definition.model.DMNDiagram;
import org.kie.workbench.common.dmn.api.definition.model.DMNElement.ExtensionElements;
import org.kie.workbench.common.dmn.api.definition.model.DMNModelInstrumentedBase;
import org.kie.workbench.common.dmn.api.definition.model.Decision;
import org.kie.workbench.common.dmn.api.definition.model.DecisionService;
import org.kie.workbench.common.dmn.api.definition.model.Definitions;
import org.kie.workbench.common.dmn.api.definition.model.Expression;
import org.kie.workbench.common.dmn.api.definition.model.FunctionDefinition;
import org.kie.workbench.common.dmn.api.definition.model.ImportedValues;
import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
import org.kie.workbench.common.dmn.api.definition.model.InformationItemPrimary;
import org.kie.workbench.common.dmn.api.definition.model.InformationRequirement;
import org.kie.workbench.common.dmn.api.definition.model.InputClause;
import org.kie.workbench.common.dmn.api.definition.model.InputClauseLiteralExpression;
import org.kie.workbench.common.dmn.api.definition.model.InputClauseUnaryTests;
import org.kie.workbench.common.dmn.api.definition.model.InputData;
import org.kie.workbench.common.dmn.api.definition.model.KnowledgeRequirement;
import org.kie.workbench.common.dmn.api.definition.model.KnowledgeSource;
import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
import org.kie.workbench.common.dmn.api.definition.model.LiteralExpressionPMMLDocument;
import org.kie.workbench.common.dmn.api.definition.model.LiteralExpressionPMMLDocumentModel;
import org.kie.workbench.common.dmn.api.definition.model.OutputClause;
import org.kie.workbench.common.dmn.api.definition.model.OutputClauseLiteralExpression;
import org.kie.workbench.common.dmn.api.definition.model.OutputClauseUnaryTests;
import org.kie.workbench.common.dmn.api.definition.model.TextAnnotation;
import org.kie.workbench.common.dmn.api.definition.model.UnaryTests;
import org.kie.workbench.common.dmn.api.property.background.BgColour;
import org.kie.workbench.common.dmn.api.property.background.BorderColour;
import org.kie.workbench.common.dmn.api.property.background.BorderSize;
import org.kie.workbench.common.dmn.api.property.dimensions.DecisionServiceRectangleDimensionsSet;
import org.kie.workbench.common.dmn.api.property.dimensions.GeneralRectangleDimensionsSet;
import org.kie.workbench.common.dmn.api.property.dimensions.Width;
import org.kie.workbench.common.dmn.api.property.dmn.AllowedAnswers;
import org.kie.workbench.common.dmn.api.property.dmn.ConstraintTypeProperty;
import org.kie.workbench.common.dmn.api.property.dmn.DecisionServiceDividerLineY;
import org.kie.workbench.common.dmn.api.property.dmn.DocumentationLinks;
import org.kie.workbench.common.dmn.api.property.dmn.DocumentationLinksFieldType;
import org.kie.workbench.common.dmn.api.property.dmn.DocumentationLinksHolder;
import org.kie.workbench.common.dmn.api.property.dmn.ExpressionLanguage;
import org.kie.workbench.common.dmn.api.property.dmn.Id;
import org.kie.workbench.common.dmn.api.property.dmn.KnowledgeSourceType;
import org.kie.workbench.common.dmn.api.property.dmn.LocationURI;
import org.kie.workbench.common.dmn.api.property.dmn.QName;
import org.kie.workbench.common.dmn.api.property.dmn.QNameFieldType;
import org.kie.workbench.common.dmn.api.property.dmn.QNameHolder;
import org.kie.workbench.common.dmn.api.property.dmn.Question;
import org.kie.workbench.common.dmn.api.property.dmn.Text;
import org.kie.workbench.common.dmn.api.property.dmn.TextFormat;
import org.kie.workbench.common.dmn.api.property.font.FontColour;
import org.kie.workbench.common.dmn.api.property.font.FontSize;
import org.kie.workbench.common.dmn.client.property.dmn.DocumentationLinksFieldDefinition;
import org.kie.workbench.common.dmn.client.property.dmn.QNameFieldDefinition;
import org.kie.workbench.common.forms.adf.definitions.DynamicReadOnly.ReadOnly;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.checkBox.definition.CheckBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.checkBox.type.CheckBoxFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.datePicker.definition.DatePickerFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.datePicker.type.DatePickerFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.decimalBox.definition.DecimalBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.decimalBox.type.DecimalBoxFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.image.definition.PictureFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.image.definition.PictureSize;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.image.type.PictureFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.integerBox.definition.IntegerBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.integerBox.type.IntegerBoxFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.BooleanMultipleInputFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.CharacterMultipleInputFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.DateMultipleInputFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.DecimalMultipleInputFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.IntegerMultipleInputFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.StringMultipleInputFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.selector.impl.BooleanMultipleSelectorFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.selector.impl.CharacterMultipleSelectorFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.selector.impl.DateMultipleSelectorFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.selector.impl.DecimalMultipleSelectorFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.selector.impl.IntegerMultipleSelectorFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.selector.impl.StringMultipleSelectorFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.CharacterSelectorOption;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.DecimalSelectorOption;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.DefaultSelectorOption;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.EnumSelectorOption;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.IntegerSelectorOption;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.StringSelectorOption;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.CharacterListBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.DecimalListBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.EnumListBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.IntegerListBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.StringListBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.type.ListBoxFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.radioGroup.definition.CharacterRadioGroupFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.radioGroup.definition.DecimalRadioGroupFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.radioGroup.definition.IntegerRadioGroupFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.radioGroup.definition.StringRadioGroupFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.radioGroup.type.RadioGroupFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.slider.definition.DoubleSliderDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.slider.definition.IntegerSliderDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.slider.type.SliderFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.definition.TextAreaFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.type.TextAreaFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.definition.CharacterBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.definition.TextBoxFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.type.TextBoxFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.Container;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.TableColumnMeta;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.multipleSubform.definition.MultipleSubFormFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.multipleSubform.type.MultipleSubFormFieldType;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.subForm.definition.SubFormFieldDefinition;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.subForm.type.SubFormFieldType;
import org.kie.workbench.common.forms.jbpm.model.authoring.document.definition.DocumentFieldDefinition;
import org.kie.workbench.common.forms.jbpm.model.authoring.document.type.DocumentFieldType;
import org.kie.workbench.common.forms.jbpm.model.authoring.documents.definition.DocumentCollectionFieldDefinition;
import org.kie.workbench.common.forms.jbpm.model.authoring.documents.type.DocumentCollectionFieldType;
import org.kie.workbench.common.forms.jbpm.model.document.DocumentData;
import org.kie.workbench.common.forms.jbpm.model.document.DocumentStatus;
import org.kie.workbench.common.forms.model.FieldDefinition;
import org.kie.workbench.common.forms.model.FieldType;
import org.kie.workbench.common.forms.model.TypeInfo;
import org.kie.workbench.common.stunner.bpmn.BPMNDefinitionSet;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssigneeRow;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.Expiration;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.KeyValueRow;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.NotificationRow;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.NotificationType;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.ReassignmentRow;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.ReassignmentType;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.Variable.VariableType;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.VariableRow;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.notificationsEditor.converter.NotificationTypeDateConverter;
import org.kie.workbench.common.stunner.bpmn.client.forms.fields.reassignmentsEditor.converter.ReassignmentTypeDateConverter;
import org.kie.workbench.common.stunner.bpmn.definition.BPMNBaseInfo;
import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
import org.kie.workbench.common.stunner.bpmn.definition.DirectionalAssociation;
import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
import org.kie.workbench.common.stunner.bpmn.definition.EndCompensationEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EndErrorEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EndEscalationEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EndMessageEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EndSignalEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
import org.kie.workbench.common.stunner.bpmn.definition.EventGateway;
import org.kie.workbench.common.stunner.bpmn.definition.EventSubprocess;
import org.kie.workbench.common.stunner.bpmn.definition.ExclusiveGateway;
import org.kie.workbench.common.stunner.bpmn.definition.GenericServiceTask;
import org.kie.workbench.common.stunner.bpmn.definition.InclusiveGateway;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEvent;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEventThrowing;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateConditionalEvent;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEvent;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEventThrowing;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventThrowing;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventThrowing;
import org.kie.workbench.common.stunner.bpmn.definition.IntermediateTimerEvent;
import org.kie.workbench.common.stunner.bpmn.definition.Lane;
import org.kie.workbench.common.stunner.bpmn.definition.MultipleInstanceSubprocess;
import org.kie.workbench.common.stunner.bpmn.definition.NonDirectionalAssociation;
import org.kie.workbench.common.stunner.bpmn.definition.NoneTask;
import org.kie.workbench.common.stunner.bpmn.definition.ParallelGateway;
import org.kie.workbench.common.stunner.bpmn.definition.ReusableSubprocess;
import org.kie.workbench.common.stunner.bpmn.definition.ScriptTask;
import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
import org.kie.workbench.common.stunner.bpmn.definition.StartCompensationEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartConditionalEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartErrorEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartEscalationEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartMessageEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
import org.kie.workbench.common.stunner.bpmn.definition.StartTimerEvent;
import org.kie.workbench.common.stunner.bpmn.definition.property.assignee.Actors;
import org.kie.workbench.common.stunner.bpmn.definition.property.assignee.Groupid;
import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.background.BgColor;
import org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderColor;
import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseFileVariables;
import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseIdPrefix;
import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseManagementSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseRoles;
import org.kie.workbench.common.stunner.bpmn.definition.property.common.ConditionExpression;
import org.kie.workbench.common.stunner.bpmn.definition.property.connectors.Priority;
import org.kie.workbench.common.stunner.bpmn.definition.property.connectors.SequenceFlowExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.AssignmentsInfo;
import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.AdHoc;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.DiagramSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Executable;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.GlobalVariables;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Package;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.ProcessInstanceDescription;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Version;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.DefaultImport;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.Imports;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.ImportsValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.WSDLImport;
import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Height;
import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Radius;
import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.RectangleDimensionsSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.BaseCancellingEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.BaseStartEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.CancelActivity;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.IsInterrupting;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.compensation.ActivityRef;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.compensation.CompensationEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.conditional.CancellingConditionalEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.conditional.InterruptingConditionalEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.CancellingErrorEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.ErrorEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.ErrorRef;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.InterruptingErrorEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.CancellingEscalationEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.EscalationEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.EscalationRef;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.InterruptingEscalationEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.CancellingMessageEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.InterruptingMessageEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.MessageEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.MessageRef;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.CancellingSignalEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.InterruptingSignalEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.ScopedSignalEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.SignalRef;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.SignalScope;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.CancellingTimerEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.InterruptingTimerEventExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.TimerSettings;
import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.TimerSettingsValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontBorderColor;
import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontBorderSize;
import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontColor;
import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontFamily;
import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.gateway.DefaultRoute;
import org.kie.workbench.common.stunner.bpmn.definition.property.gateway.GatewayExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.general.Documentation;
import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
import org.kie.workbench.common.stunner.bpmn.definition.property.general.SLADueDate;
import org.kie.workbench.common.stunner.bpmn.definition.property.general.TaskGeneralSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.notification.NotificationSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.notification.NotificationTypeListValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.notification.NotificationValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.notification.NotificationsInfo;
import org.kie.workbench.common.stunner.bpmn.definition.property.reassignment.ReassignmentSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.reassignment.ReassignmentTypeListValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.reassignment.ReassignmentValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.reassignment.ReassignmentsInfo;
import org.kie.workbench.common.stunner.bpmn.definition.property.service.GenericServiceTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.service.GenericServiceTaskInfo;
import org.kie.workbench.common.stunner.bpmn.definition.property.service.GenericServiceTaskValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Currency;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.DistributionType;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Max;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Mean;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Min;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Quantity;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.StandardDeviation;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.TimeUnit;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.UnitCost;
import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.WorkingHours;
import org.kie.workbench.common.stunner.bpmn.definition.property.subProcess.IsCase;
import org.kie.workbench.common.stunner.bpmn.definition.property.subProcess.execution.EmbeddedSubprocessExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.subProcess.execution.EventSubprocessExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.AbortParent;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocAutostart;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocOrdering;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.BaseSubprocessTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.BusinessRuleTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.CalledElement;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Content;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.CreatedBy;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.DecisionName;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Description;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.DmnModelName;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.EmptyTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Independent;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.IsAsync;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.IsMultipleInstance;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceCollectionInput;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceCollectionOutput;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceCompletionCondition;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceDataInput;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceDataOutput;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceExecutionMode;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceSubprocessTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Namespace;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.OnEntryAction;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.OnExitAction;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.ReusableSubprocessTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.RuleFlowGroup;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.RuleLanguage;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Script;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptTaskExecutionSet;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptTypeListValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptTypeValue;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Skippable;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.Subject;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskName;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskType;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskTypes;
import org.kie.workbench.common.stunner.bpmn.definition.property.task.WaitForCompletion;
import org.kie.workbench.common.stunner.bpmn.forms.model.AssigneeEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.AssigneeEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.AssigneeType;
import org.kie.workbench.common.stunner.bpmn.forms.model.AssignmentsEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.AssignmentsEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.ComboBoxFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.ConditionalComboBoxFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.ConditionalComboBoxFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.GenericServiceTaskEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.GenericServiceTaskEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.ImportsFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.ImportsFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.MultipleInstanceVariableFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.NotificationsEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.NotificationsEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.ReassignmentsEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.ReassignmentsEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.ScriptTypeFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.ScriptTypeFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.ScriptTypeListFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.ScriptTypeListFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.ScriptTypeMode;
import org.kie.workbench.common.stunner.bpmn.forms.model.TimerSettingsFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.TimerSettingsFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.VariablesEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.VariablesEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.forms.model.cm.RolesEditorFieldDefinition;
import org.kie.workbench.common.stunner.bpmn.forms.model.cm.RolesEditorFieldType;
import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask;
import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTaskExecutionSet;
import org.kie.workbench.common.stunner.cm.CaseManagementDefinitionSet;
import org.kie.workbench.common.stunner.cm.definition.AdHocSubprocess;
import org.kie.workbench.common.stunner.cm.definition.CaseManagementDiagram;
import org.kie.workbench.common.stunner.cm.definition.CaseReusableSubprocess;
import org.kie.workbench.common.stunner.cm.definition.ProcessReusableSubprocess;
import org.kie.workbench.common.stunner.cm.definition.UserTask;
import org.kie.workbench.common.stunner.cm.definition.property.task.AdHocActivationCondition;
import org.kie.workbench.common.stunner.cm.definition.property.task.AdHocCompletionCondition;
import org.kie.workbench.common.stunner.cm.definition.property.task.AdHocSubprocessTaskExecutionSet;
import org.kie.workbench.common.stunner.cm.definition.property.task.CaseReusableSubprocessTaskExecutionSet;
import org.kie.workbench.common.stunner.cm.definition.property.task.ProcessReusableSubprocessTaskExecutionSet;
import org.kie.workbench.common.stunner.cm.definition.property.task.UserTaskExecutionSet;
import org.kie.workbench.common.stunner.cm.definition.property.variables.ProcessData;
import org.kie.workbench.common.stunner.cm.definition.property.variables.ProcessVariables;
import org.kie.workbench.common.stunner.forms.model.ColorPickerFieldDefinition;
import org.kie.workbench.common.stunner.forms.model.ColorPickerFieldType;
import org.uberfire.mvp.Command;
import org.uberfire.paging.AbstractPageRow;

public class BindableProxyLoaderImpl implements BindableProxyLoader { public void loadBindableProxies() {
    class org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy extends UserTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<UserTaskExecutionSet> agent;
      private UserTaskExecutionSet target;
      public org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy() {
        this(new UserTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy(UserTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<UserTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("subject", new PropertyType(Subject.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("description", new PropertyType(Description.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("content", new PropertyType(Content.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("reassignmentsInfo", new PropertyType(ReassignmentsInfo.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("assignmentsinfo", new PropertyType(AssignmentsInfo.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("notificationsInfo", new PropertyType(NotificationsInfo.class, true, false));
        p.put("groupid", new PropertyType(Groupid.class, true, false));
        p.put("skippable", new PropertyType(Skippable.class, true, false));
        p.put("priority", new PropertyType(Priority.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("actors", new PropertyType(Actors.class, true, false));
        p.put("createdBy", new PropertyType(CreatedBy.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("taskName", new PropertyType(TaskName.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("this", new PropertyType(UserTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public UserTaskExecutionSet unwrap() {
        return target;
      }

      public UserTaskExecutionSet deepUnwrap() {
        final UserTaskExecutionSet clone = new UserTaskExecutionSet();
        final UserTaskExecutionSet t = unwrap();
        if (t.getSubject() instanceof BindableProxy) {
          clone.setSubject((Subject) ((BindableProxy) getSubject()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSubject())) {
          clone.setSubject((Subject) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSubject())).deepUnwrap());
        } else {
          clone.setSubject(t.getSubject());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getContent() instanceof BindableProxy) {
          clone.setContent((Content) ((BindableProxy) getContent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getContent())) {
          clone.setContent((Content) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getContent())).deepUnwrap());
        } else {
          clone.setContent(t.getContent());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getReassignmentsInfo() instanceof BindableProxy) {
          clone.setReassignmentsInfo((ReassignmentsInfo) ((BindableProxy) getReassignmentsInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getReassignmentsInfo())) {
          clone.setReassignmentsInfo((ReassignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getReassignmentsInfo())).deepUnwrap());
        } else {
          clone.setReassignmentsInfo(t.getReassignmentsInfo());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getAssignmentsinfo() instanceof BindableProxy) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) getAssignmentsinfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAssignmentsinfo())) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAssignmentsinfo())).deepUnwrap());
        } else {
          clone.setAssignmentsinfo(t.getAssignmentsinfo());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getNotificationsInfo() instanceof BindableProxy) {
          clone.setNotificationsInfo((NotificationsInfo) ((BindableProxy) getNotificationsInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getNotificationsInfo())) {
          clone.setNotificationsInfo((NotificationsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getNotificationsInfo())).deepUnwrap());
        } else {
          clone.setNotificationsInfo(t.getNotificationsInfo());
        }
        if (t.getGroupid() instanceof BindableProxy) {
          clone.setGroupid((Groupid) ((BindableProxy) getGroupid()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGroupid())) {
          clone.setGroupid((Groupid) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGroupid())).deepUnwrap());
        } else {
          clone.setGroupid(t.getGroupid());
        }
        if (t.getSkippable() instanceof BindableProxy) {
          clone.setSkippable((Skippable) ((BindableProxy) getSkippable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSkippable())) {
          clone.setSkippable((Skippable) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSkippable())).deepUnwrap());
        } else {
          clone.setSkippable(t.getSkippable());
        }
        if (t.getPriority() instanceof BindableProxy) {
          clone.setPriority((Priority) ((BindableProxy) getPriority()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getPriority())) {
          clone.setPriority((Priority) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getPriority())).deepUnwrap());
        } else {
          clone.setPriority(t.getPriority());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getActors() instanceof BindableProxy) {
          clone.setActors((Actors) ((BindableProxy) getActors()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getActors())) {
          clone.setActors((Actors) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getActors())).deepUnwrap());
        } else {
          clone.setActors(t.getActors());
        }
        if (t.getCreatedBy() instanceof BindableProxy) {
          clone.setCreatedBy((CreatedBy) ((BindableProxy) getCreatedBy()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCreatedBy())) {
          clone.setCreatedBy((CreatedBy) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCreatedBy())).deepUnwrap());
        } else {
          clone.setCreatedBy(t.getCreatedBy());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getTaskName() instanceof BindableProxy) {
          clone.setTaskName((TaskName) ((BindableProxy) getTaskName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskName())) {
          clone.setTaskName((TaskName) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskName())).deepUnwrap());
        } else {
          clone.setTaskName(t.getTaskName());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Subject getSubject() {
        return target.getSubject();
      }

      public void setSubject(Subject subject) {
        if (agent.binders.containsKey("subject")) {
          subject = (Subject) agent.binders.get("subject").setModel(subject, StateSync.FROM_MODEL, true);
        }
        changeAndFire("subject", subject);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(Description description) {
        if (agent.binders.containsKey("description")) {
          description = (Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public Content getContent() {
        return target.getContent();
      }

      public void setContent(Content content) {
        if (agent.binders.containsKey("content")) {
          content = (Content) agent.binders.get("content").setModel(content, StateSync.FROM_MODEL, true);
        }
        changeAndFire("content", content);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public ReassignmentsInfo getReassignmentsInfo() {
        return target.getReassignmentsInfo();
      }

      public void setReassignmentsInfo(ReassignmentsInfo reassignmentsInfo) {
        if (agent.binders.containsKey("reassignmentsInfo")) {
          reassignmentsInfo = (ReassignmentsInfo) agent.binders.get("reassignmentsInfo").setModel(reassignmentsInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("reassignmentsInfo", reassignmentsInfo);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public AssignmentsInfo getAssignmentsinfo() {
        return target.getAssignmentsinfo();
      }

      public void setAssignmentsinfo(AssignmentsInfo assignmentsinfo) {
        if (agent.binders.containsKey("assignmentsinfo")) {
          assignmentsinfo = (AssignmentsInfo) agent.binders.get("assignmentsinfo").setModel(assignmentsinfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("assignmentsinfo", assignmentsinfo);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public NotificationsInfo getNotificationsInfo() {
        return target.getNotificationsInfo();
      }

      public void setNotificationsInfo(NotificationsInfo notificationsInfo) {
        if (agent.binders.containsKey("notificationsInfo")) {
          notificationsInfo = (NotificationsInfo) agent.binders.get("notificationsInfo").setModel(notificationsInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("notificationsInfo", notificationsInfo);
      }

      public Groupid getGroupid() {
        return target.getGroupid();
      }

      public void setGroupid(Groupid groupid) {
        if (agent.binders.containsKey("groupid")) {
          groupid = (Groupid) agent.binders.get("groupid").setModel(groupid, StateSync.FROM_MODEL, true);
        }
        changeAndFire("groupid", groupid);
      }

      public Skippable getSkippable() {
        return target.getSkippable();
      }

      public void setSkippable(Skippable skippable) {
        if (agent.binders.containsKey("skippable")) {
          skippable = (Skippable) agent.binders.get("skippable").setModel(skippable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("skippable", skippable);
      }

      public Priority getPriority() {
        return target.getPriority();
      }

      public void setPriority(Priority priority) {
        if (agent.binders.containsKey("priority")) {
          priority = (Priority) agent.binders.get("priority").setModel(priority, StateSync.FROM_MODEL, true);
        }
        changeAndFire("priority", priority);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public Actors getActors() {
        return target.getActors();
      }

      public void setActors(Actors actors) {
        if (agent.binders.containsKey("actors")) {
          actors = (Actors) agent.binders.get("actors").setModel(actors, StateSync.FROM_MODEL, true);
        }
        changeAndFire("actors", actors);
      }

      public CreatedBy getCreatedBy() {
        return target.getCreatedBy();
      }

      public void setCreatedBy(CreatedBy createdBy) {
        if (agent.binders.containsKey("createdBy")) {
          createdBy = (CreatedBy) agent.binders.get("createdBy").setModel(createdBy, StateSync.FROM_MODEL, true);
        }
        changeAndFire("createdBy", createdBy);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public TaskName getTaskName() {
        return target.getTaskName();
      }

      public void setTaskName(TaskName taskName) {
        if (agent.binders.containsKey("taskName")) {
          taskName = (TaskName) agent.binders.get("taskName").setModel(taskName, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskName", taskName);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public Object get(String property) {
        switch (property) {
          case "subject": return getSubject();
          case "isAsync": return getIsAsync();
          case "description": return getDescription();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "content": return getContent();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "reassignmentsInfo": return getReassignmentsInfo();
          case "slaDueDate": return getSlaDueDate();
          case "assignmentsinfo": return getAssignmentsinfo();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "onExitAction": return getOnExitAction();
          case "notificationsInfo": return getNotificationsInfo();
          case "groupid": return getGroupid();
          case "skippable": return getSkippable();
          case "priority": return getPriority();
          case "onEntryAction": return getOnEntryAction();
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "actors": return getActors();
          case "createdBy": return getCreatedBy();
          case "adHocAutostart": return getAdHocAutostart();
          case "taskName": return getTaskName();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "this": return target;
          default: throw new NonExistingPropertyException("UserTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "subject": target.setSubject((Subject) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "description": target.setDescription((Description) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "content": target.setContent((Content) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "reassignmentsInfo": target.setReassignmentsInfo((ReassignmentsInfo) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "assignmentsinfo": target.setAssignmentsinfo((AssignmentsInfo) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "notificationsInfo": target.setNotificationsInfo((NotificationsInfo) value);
          break;
          case "groupid": target.setGroupid((Groupid) value);
          break;
          case "skippable": target.setSkippable((Skippable) value);
          break;
          case "priority": target.setPriority((Priority) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "actors": target.setActors((Actors) value);
          break;
          case "createdBy": target.setCreatedBy((CreatedBy) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "taskName": target.setTaskName((TaskName) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "this": target = (UserTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("UserTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(UserTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy((UserTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_UserTaskExecutionSetProxy();
      }
    });
    class org_jbpm_workbench_df_client_filter_SavedFilterProxy extends SavedFilter implements BindableProxy {
      private BindableProxyAgent<SavedFilter> agent;
      private SavedFilter target;
      public org_jbpm_workbench_df_client_filter_SavedFilterProxy() {
        this(new SavedFilter());
      }

      public org_jbpm_workbench_df_client_filter_SavedFilterProxy(SavedFilter targetVal) {
        agent = new BindableProxyAgent<SavedFilter>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("defaultFilter", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("key", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(SavedFilter.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SavedFilter unwrap() {
        return target;
      }

      public SavedFilter deepUnwrap() {
        final SavedFilter clone = new SavedFilter();
        final SavedFilter t = unwrap();
        clone.setDefaultFilter(t.isDefaultFilter());
        clone.setName(t.getName());
        clone.setKey(t.getKey());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_df_client_filter_SavedFilterProxy) {
          obj = ((org_jbpm_workbench_df_client_filter_SavedFilterProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public boolean isDefaultFilter() {
        return target.isDefaultFilter();
      }

      public void setDefaultFilter(boolean defaultFilter) {
        changeAndFire("defaultFilter", defaultFilter);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getKey() {
        return target.getKey();
      }

      public void setKey(String key) {
        changeAndFire("key", key);
      }

      public Object get(String property) {
        switch (property) {
          case "defaultFilter": return isDefaultFilter();
          case "name": return getName();
          case "key": return getKey();
          case "this": return target;
          default: throw new NonExistingPropertyException("SavedFilter", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "defaultFilter": target.setDefaultFilter((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "key": target.setKey((String) value);
          break;
          case "this": target = (SavedFilter) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SavedFilter", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SavedFilter.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_df_client_filter_SavedFilterProxy((SavedFilter) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_df_client_filter_SavedFilterProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy extends OutputClauseUnaryTests implements BindableProxy {
      private BindableProxyAgent<OutputClauseUnaryTests> agent;
      private OutputClauseUnaryTests target;
      public org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy() {
        this(new OutputClauseUnaryTests());
      }

      public org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy(OutputClauseUnaryTests targetVal) {
        agent = new BindableProxyAgent<OutputClauseUnaryTests>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("constraintType", new PropertyType(ConstraintType.class, false, false));
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(OutputClauseUnaryTests.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public OutputClauseUnaryTests unwrap() {
        return target;
      }

      public OutputClauseUnaryTests deepUnwrap() {
        final OutputClauseUnaryTests clone = new OutputClauseUnaryTests();
        final OutputClauseUnaryTests t = unwrap();
        clone.setParent(t.getParent());
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ConstraintType getConstraintType() {
        return target.getConstraintType();
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Id getId() {
        return target.getId();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "constraintType": return getConstraintType();
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "nsContext": return getNsContext();
          case "id": return getId();
          case "text": return getText();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("OutputClauseUnaryTests", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (OutputClauseUnaryTests) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("OutputClauseUnaryTests", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void setConstraintTypeField(ConstraintType a0) {
        target.setConstraintTypeField(a0);
        agent.updateWidgetsAndFireEvents();
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(OutputClauseUnaryTests.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy((OutputClauseUnaryTests) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_OutputClauseUnaryTestsProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy extends FontFamily implements BindableProxy {
      private BindableProxyAgent<FontFamily> agent;
      private FontFamily target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy() {
        this(new FontFamily());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy(FontFamily targetVal) {
        agent = new BindableProxyAgent<FontFamily>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(FontFamily.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontFamily unwrap() {
        return target;
      }

      public FontFamily deepUnwrap() {
        final FontFamily clone = new FontFamily();
        final FontFamily t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontFamily", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (FontFamily) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontFamily", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontFamily.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy((FontFamily) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontFamilyProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy extends BusinessRuleTask implements BindableProxy {
      private BindableProxyAgent<BusinessRuleTask> agent;
      private BusinessRuleTask target;
      public org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy() {
        this(new BusinessRuleTask());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy(BusinessRuleTask targetVal) {
        agent = new BindableProxyAgent<BusinessRuleTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(BusinessRuleTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(BusinessRuleTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BusinessRuleTask unwrap() {
        return target;
      }

      public BusinessRuleTask deepUnwrap() {
        final BusinessRuleTask clone = new BusinessRuleTask();
        final BusinessRuleTask t = unwrap();
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((BusinessRuleTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((BusinessRuleTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public BusinessRuleTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(BusinessRuleTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (BusinessRuleTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Object get(String property) {
        switch (property) {
          case "dataIOSet": return getDataIOSet();
          case "labels": return getLabels();
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "this": return target;
          default: throw new NonExistingPropertyException("BusinessRuleTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((BusinessRuleTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (BusinessRuleTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BusinessRuleTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(BusinessRuleTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy((BusinessRuleTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_BusinessRuleTaskProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy extends org.kie.workbench.common.dmn.api.property.background.BackgroundSet implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.dmn.api.property.background.BackgroundSet> agent;
      private org.kie.workbench.common.dmn.api.property.background.BackgroundSet target;
      public org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy() {
        this(new org.kie.workbench.common.dmn.api.property.background.BackgroundSet());
      }

      public org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy(org.kie.workbench.common.dmn.api.property.background.BackgroundSet targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.dmn.api.property.background.BackgroundSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("borderColour", new PropertyType(BorderColour.class, true, false));
        p.put("borderSize", new PropertyType(BorderSize.class, true, false));
        p.put("bgColour", new PropertyType(BgColour.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet unwrap() {
        return target;
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet deepUnwrap() {
        final org.kie.workbench.common.dmn.api.property.background.BackgroundSet clone = new org.kie.workbench.common.dmn.api.property.background.BackgroundSet();
        final org.kie.workbench.common.dmn.api.property.background.BackgroundSet t = unwrap();
        if (t.getBorderColour() instanceof BindableProxy) {
          clone.setBorderColour((BorderColour) ((BindableProxy) getBorderColour()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBorderColour())) {
          clone.setBorderColour((BorderColour) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBorderColour())).deepUnwrap());
        } else {
          clone.setBorderColour(t.getBorderColour());
        }
        if (t.getBorderSize() instanceof BindableProxy) {
          clone.setBorderSize((BorderSize) ((BindableProxy) getBorderSize()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBorderSize())) {
          clone.setBorderSize((BorderSize) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBorderSize())).deepUnwrap());
        } else {
          clone.setBorderSize(t.getBorderSize());
        }
        if (t.getBgColour() instanceof BindableProxy) {
          clone.setBgColour((BgColour) ((BindableProxy) getBgColour()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBgColour())) {
          clone.setBgColour((BgColour) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBgColour())).deepUnwrap());
        } else {
          clone.setBgColour(t.getBgColour());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BorderColour getBorderColour() {
        return target.getBorderColour();
      }

      public void setBorderColour(BorderColour borderColour) {
        if (agent.binders.containsKey("borderColour")) {
          borderColour = (BorderColour) agent.binders.get("borderColour").setModel(borderColour, StateSync.FROM_MODEL, true);
        }
        changeAndFire("borderColour", borderColour);
      }

      public BorderSize getBorderSize() {
        return target.getBorderSize();
      }

      public void setBorderSize(BorderSize borderSize) {
        if (agent.binders.containsKey("borderSize")) {
          borderSize = (BorderSize) agent.binders.get("borderSize").setModel(borderSize, StateSync.FROM_MODEL, true);
        }
        changeAndFire("borderSize", borderSize);
      }

      public BgColour getBgColour() {
        return target.getBgColour();
      }

      public void setBgColour(BgColour bgColour) {
        if (agent.binders.containsKey("bgColour")) {
          bgColour = (BgColour) agent.binders.get("bgColour").setModel(bgColour, StateSync.FROM_MODEL, true);
        }
        changeAndFire("bgColour", bgColour);
      }

      public Object get(String property) {
        switch (property) {
          case "borderColour": return getBorderColour();
          case "borderSize": return getBorderSize();
          case "bgColour": return getBgColour();
          case "this": return target;
          default: throw new NonExistingPropertyException("BackgroundSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "borderColour": target.setBorderColour((BorderColour) value);
          break;
          case "borderSize": target.setBorderSize((BorderSize) value);
          break;
          case "bgColour": target.setBgColour((BgColour) value);
          break;
          case "this": target = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BackgroundSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_background_BackgroundSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy extends AdHocSubprocess implements BindableProxy {
      private BindableProxyAgent<AdHocSubprocess> agent;
      private AdHocSubprocess target;
      public org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy() {
        this(new AdHocSubprocess());
      }

      public org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy(AdHocSubprocess targetVal) {
        agent = new BindableProxyAgent<AdHocSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("processData", new PropertyType(ProcessData.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(AdHocSubprocessTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(AdHocSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHocSubprocess unwrap() {
        return target;
      }

      public AdHocSubprocess deepUnwrap() {
        final AdHocSubprocess clone = new AdHocSubprocess();
        final AdHocSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((AdHocSubprocessTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((AdHocSubprocessTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public AdHocSubprocessTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(AdHocSubprocessTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (AdHocSubprocessTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "processData": return getProcessData();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "processData": target.setProcessData((ProcessData) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((AdHocSubprocessTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (AdHocSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHocSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy((AdHocSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_AdHocSubprocessProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy extends BusinessRuleTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<BusinessRuleTaskExecutionSet> agent;
      private BusinessRuleTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy() {
        this(new BusinessRuleTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy(BusinessRuleTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<BusinessRuleTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("ruleFlowGroup", new PropertyType(RuleFlowGroup.class, true, false));
        p.put("dmnModelName", new PropertyType(DmnModelName.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("namespace", new PropertyType(Namespace.class, true, false));
        p.put("ruleLanguage", new PropertyType(RuleLanguage.class, true, false));
        p.put("decisionName", new PropertyType(DecisionName.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("this", new PropertyType(BusinessRuleTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BusinessRuleTaskExecutionSet unwrap() {
        return target;
      }

      public BusinessRuleTaskExecutionSet deepUnwrap() {
        final BusinessRuleTaskExecutionSet clone = new BusinessRuleTaskExecutionSet();
        final BusinessRuleTaskExecutionSet t = unwrap();
        if (t.getRuleFlowGroup() instanceof BindableProxy) {
          clone.setRuleFlowGroup((RuleFlowGroup) ((BindableProxy) getRuleFlowGroup()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getRuleFlowGroup())) {
          clone.setRuleFlowGroup((RuleFlowGroup) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getRuleFlowGroup())).deepUnwrap());
        } else {
          clone.setRuleFlowGroup(t.getRuleFlowGroup());
        }
        if (t.getDmnModelName() instanceof BindableProxy) {
          clone.setDmnModelName((DmnModelName) ((BindableProxy) getDmnModelName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDmnModelName())) {
          clone.setDmnModelName((DmnModelName) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDmnModelName())).deepUnwrap());
        } else {
          clone.setDmnModelName(t.getDmnModelName());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getNamespace() instanceof BindableProxy) {
          clone.setNamespace((Namespace) ((BindableProxy) getNamespace()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getNamespace())) {
          clone.setNamespace((Namespace) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getNamespace())).deepUnwrap());
        } else {
          clone.setNamespace(t.getNamespace());
        }
        if (t.getRuleLanguage() instanceof BindableProxy) {
          clone.setRuleLanguage((RuleLanguage) ((BindableProxy) getRuleLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getRuleLanguage())) {
          clone.setRuleLanguage((RuleLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getRuleLanguage())).deepUnwrap());
        } else {
          clone.setRuleLanguage(t.getRuleLanguage());
        }
        if (t.getDecisionName() instanceof BindableProxy) {
          clone.setDecisionName((DecisionName) ((BindableProxy) getDecisionName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDecisionName())) {
          clone.setDecisionName((DecisionName) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDecisionName())).deepUnwrap());
        } else {
          clone.setDecisionName(t.getDecisionName());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public RuleFlowGroup getRuleFlowGroup() {
        return target.getRuleFlowGroup();
      }

      public void setRuleFlowGroup(RuleFlowGroup ruleFlowGroup) {
        if (agent.binders.containsKey("ruleFlowGroup")) {
          ruleFlowGroup = (RuleFlowGroup) agent.binders.get("ruleFlowGroup").setModel(ruleFlowGroup, StateSync.FROM_MODEL, true);
        }
        changeAndFire("ruleFlowGroup", ruleFlowGroup);
      }

      public DmnModelName getDmnModelName() {
        return target.getDmnModelName();
      }

      public void setDmnModelName(DmnModelName dmnModelName) {
        if (agent.binders.containsKey("dmnModelName")) {
          dmnModelName = (DmnModelName) agent.binders.get("dmnModelName").setModel(dmnModelName, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dmnModelName", dmnModelName);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Namespace getNamespace() {
        return target.getNamespace();
      }

      public void setNamespace(Namespace namespace) {
        if (agent.binders.containsKey("namespace")) {
          namespace = (Namespace) agent.binders.get("namespace").setModel(namespace, StateSync.FROM_MODEL, true);
        }
        changeAndFire("namespace", namespace);
      }

      public RuleLanguage getRuleLanguage() {
        return target.getRuleLanguage();
      }

      public void setRuleLanguage(RuleLanguage ruleLanguage) {
        if (agent.binders.containsKey("ruleLanguage")) {
          ruleLanguage = (RuleLanguage) agent.binders.get("ruleLanguage").setModel(ruleLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("ruleLanguage", ruleLanguage);
      }

      public DecisionName getDecisionName() {
        return target.getDecisionName();
      }

      public void setDecisionName(DecisionName decisionName) {
        if (agent.binders.containsKey("decisionName")) {
          decisionName = (DecisionName) agent.binders.get("decisionName").setModel(decisionName, StateSync.FROM_MODEL, true);
        }
        changeAndFire("decisionName", decisionName);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public Object get(String property) {
        switch (property) {
          case "ruleFlowGroup": return getRuleFlowGroup();
          case "dmnModelName": return getDmnModelName();
          case "adHocAutostart": return getAdHocAutostart();
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "namespace": return getNamespace();
          case "ruleLanguage": return getRuleLanguage();
          case "decisionName": return getDecisionName();
          case "onExitAction": return getOnExitAction();
          case "onEntryAction": return getOnEntryAction();
          case "this": return target;
          default: throw new NonExistingPropertyException("BusinessRuleTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "ruleFlowGroup": target.setRuleFlowGroup((RuleFlowGroup) value);
          break;
          case "dmnModelName": target.setDmnModelName((DmnModelName) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "namespace": target.setNamespace((Namespace) value);
          break;
          case "ruleLanguage": target.setRuleLanguage((RuleLanguage) value);
          break;
          case "decisionName": target.setDecisionName((DecisionName) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "this": target = (BusinessRuleTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BusinessRuleTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BusinessRuleTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy((BusinessRuleTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_BusinessRuleTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy extends ReusableSubprocess implements BindableProxy {
      private BindableProxyAgent<ReusableSubprocess> agent;
      private ReusableSubprocess target;
      public org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy() {
        this(new ReusableSubprocess());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy(ReusableSubprocess targetVal) {
        agent = new BindableProxyAgent<ReusableSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(ReusableSubprocessTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(ReusableSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReusableSubprocess unwrap() {
        return target;
      }

      public ReusableSubprocess deepUnwrap() {
        final ReusableSubprocess clone = new ReusableSubprocess();
        final ReusableSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ReusableSubprocessTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ReusableSubprocessTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public ReusableSubprocessTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ReusableSubprocessTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ReusableSubprocessTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReusableSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((ReusableSubprocessTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (ReusableSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReusableSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ReusableSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy((ReusableSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_ReusableSubprocessProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy extends CaseFileVariables implements BindableProxy {
      private BindableProxyAgent<CaseFileVariables> agent;
      private CaseFileVariables target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy() {
        this(new CaseFileVariables());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy(CaseFileVariables targetVal) {
        agent = new BindableProxyAgent<CaseFileVariables>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("rawValue", new PropertyType(String.class, false, false));
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CaseFileVariables.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseFileVariables unwrap() {
        return target;
      }

      public CaseFileVariables deepUnwrap() {
        final CaseFileVariables clone = new CaseFileVariables();
        final CaseFileVariables t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRawValue() {
        return target.getRawValue();
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "rawValue": return getRawValue();
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseFileVariables", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (CaseFileVariables) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseFileVariables", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseFileVariables.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy((CaseFileVariables) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseFileVariablesProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy extends CheckBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<CheckBoxFieldDefinition> agent;
      private CheckBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy() {
        this(new CheckBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy(CheckBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<CheckBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(CheckBoxFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CheckBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CheckBoxFieldDefinition unwrap() {
        return target;
      }

      public CheckBoxFieldDefinition deepUnwrap() {
        final CheckBoxFieldDefinition clone = new CheckBoxFieldDefinition();
        final CheckBoxFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public CheckBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("CheckBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (CheckBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CheckBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(CheckBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy((CheckBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_checkBox_definition_CheckBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy extends EndEscalationEvent implements BindableProxy {
      private BindableProxyAgent<EndEscalationEvent> agent;
      private EndEscalationEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy() {
        this(new EndEscalationEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy(EndEscalationEvent targetVal) {
        agent = new BindableProxyAgent<EndEscalationEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(EscalationEventExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndEscalationEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndEscalationEvent unwrap() {
        return target;
      }

      public EndEscalationEvent deepUnwrap() {
        final EndEscalationEvent clone = new EndEscalationEvent();
        final EndEscalationEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((EscalationEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((EscalationEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public EscalationEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(EscalationEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (EscalationEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndEscalationEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((EscalationEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndEscalationEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndEscalationEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndEscalationEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy((EndEscalationEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndEscalationEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy extends SequenceFlowExecutionSet implements BindableProxy {
      private BindableProxyAgent<SequenceFlowExecutionSet> agent;
      private SequenceFlowExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy() {
        this(new SequenceFlowExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy(SequenceFlowExecutionSet targetVal) {
        agent = new BindableProxyAgent<SequenceFlowExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("conditionExpression", new PropertyType(ConditionExpression.class, true, false));
        p.put("priority", new PropertyType(Priority.class, true, false));
        p.put("this", new PropertyType(SequenceFlowExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SequenceFlowExecutionSet unwrap() {
        return target;
      }

      public SequenceFlowExecutionSet deepUnwrap() {
        final SequenceFlowExecutionSet clone = new SequenceFlowExecutionSet();
        final SequenceFlowExecutionSet t = unwrap();
        if (t.getConditionExpression() instanceof BindableProxy) {
          clone.setConditionExpression((ConditionExpression) ((BindableProxy) getConditionExpression()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getConditionExpression())) {
          clone.setConditionExpression((ConditionExpression) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getConditionExpression())).deepUnwrap());
        } else {
          clone.setConditionExpression(t.getConditionExpression());
        }
        if (t.getPriority() instanceof BindableProxy) {
          clone.setPriority((Priority) ((BindableProxy) getPriority()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getPriority())) {
          clone.setPriority((Priority) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getPriority())).deepUnwrap());
        } else {
          clone.setPriority(t.getPriority());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ConditionExpression getConditionExpression() {
        return target.getConditionExpression();
      }

      public void setConditionExpression(ConditionExpression conditionExpression) {
        if (agent.binders.containsKey("conditionExpression")) {
          conditionExpression = (ConditionExpression) agent.binders.get("conditionExpression").setModel(conditionExpression, StateSync.FROM_MODEL, true);
        }
        changeAndFire("conditionExpression", conditionExpression);
      }

      public Priority getPriority() {
        return target.getPriority();
      }

      public void setPriority(Priority priority) {
        if (agent.binders.containsKey("priority")) {
          priority = (Priority) agent.binders.get("priority").setModel(priority, StateSync.FROM_MODEL, true);
        }
        changeAndFire("priority", priority);
      }

      public Object get(String property) {
        switch (property) {
          case "conditionExpression": return getConditionExpression();
          case "priority": return getPriority();
          case "this": return target;
          default: throw new NonExistingPropertyException("SequenceFlowExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "conditionExpression": target.setConditionExpression((ConditionExpression) value);
          break;
          case "priority": target.setPriority((Priority) value);
          break;
          case "this": target = (SequenceFlowExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SequenceFlowExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SequenceFlowExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy((SequenceFlowExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_connectors_SequenceFlowExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy extends FontColor implements BindableProxy {
      private BindableProxyAgent<FontColor> agent;
      private FontColor target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy() {
        this(new FontColor());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy(FontColor targetVal) {
        agent = new BindableProxyAgent<FontColor>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(FontColor.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontColor unwrap() {
        return target;
      }

      public FontColor deepUnwrap() {
        final FontColor clone = new FontColor();
        final FontColor t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontColor", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (FontColor) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontColor", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontColor.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy((FontColor) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontColorProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy extends Version implements BindableProxy {
      private BindableProxyAgent<Version> agent;
      private Version target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy() {
        this(new Version());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy(Version targetVal) {
        agent = new BindableProxyAgent<Version>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Version.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Version unwrap() {
        return target;
      }

      public Version deepUnwrap() {
        final Version clone = new Version();
        final Version t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Version", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Version) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Version", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Version.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy((Version) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_VersionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy extends Width implements BindableProxy {
      private BindableProxyAgent<Width> agent;
      private Width target;
      public org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy() {
        this(new Width());
      }

      public org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy(Width targetVal) {
        agent = new BindableProxyAgent<Width>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Width.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Width unwrap() {
        return target;
      }

      public Width deepUnwrap() {
        final Width clone = new Width();
        final Width t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Width", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Width) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Width", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Width.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy((Width) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dimensions_WidthProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy extends DataIOSet implements BindableProxy {
      private BindableProxyAgent<DataIOSet> agent;
      private DataIOSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy() {
        this(new DataIOSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy(DataIOSet targetVal) {
        agent = new BindableProxyAgent<DataIOSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("assignmentsinfo", new PropertyType(AssignmentsInfo.class, true, false));
        p.put("this", new PropertyType(DataIOSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DataIOSet unwrap() {
        return target;
      }

      public DataIOSet deepUnwrap() {
        final DataIOSet clone = new DataIOSet();
        final DataIOSet t = unwrap();
        if (t.getAssignmentsinfo() instanceof BindableProxy) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) getAssignmentsinfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAssignmentsinfo())) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAssignmentsinfo())).deepUnwrap());
        } else {
          clone.setAssignmentsinfo(t.getAssignmentsinfo());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AssignmentsInfo getAssignmentsinfo() {
        return target.getAssignmentsinfo();
      }

      public void setAssignmentsinfo(AssignmentsInfo assignmentsinfo) {
        if (agent.binders.containsKey("assignmentsinfo")) {
          assignmentsinfo = (AssignmentsInfo) agent.binders.get("assignmentsinfo").setModel(assignmentsinfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("assignmentsinfo", assignmentsinfo);
      }

      public Object get(String property) {
        switch (property) {
          case "assignmentsinfo": return getAssignmentsinfo();
          case "this": return target;
          default: throw new NonExistingPropertyException("DataIOSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "assignmentsinfo": target.setAssignmentsinfo((AssignmentsInfo) value);
          break;
          case "this": target = (DataIOSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DataIOSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DataIOSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy((DataIOSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dataio_DataIOSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_AssociationProxy extends Association implements BindableProxy {
      private BindableProxyAgent<Association> agent;
      private Association target;
      public org_kie_workbench_common_dmn_api_definition_model_AssociationProxy() {
        this(new Association());
      }

      public org_kie_workbench_common_dmn_api_definition_model_AssociationProxy(Association targetVal) {
        agent = new BindableProxyAgent<Association>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(Association.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Association unwrap() {
        return target;
      }

      public Association deepUnwrap() {
        final Association clone = new Association();
        final Association t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_AssociationProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_AssociationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "nsContext": return getNsContext();
          case "extensionElements": return getExtensionElements();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "id": return getId();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("Association", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (Association) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Association", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(Association.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_AssociationProxy((Association) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_AssociationProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy extends InputClauseUnaryTests implements BindableProxy {
      private BindableProxyAgent<InputClauseUnaryTests> agent;
      private InputClauseUnaryTests target;
      public org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy() {
        this(new InputClauseUnaryTests());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy(InputClauseUnaryTests targetVal) {
        agent = new BindableProxyAgent<InputClauseUnaryTests>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("constraintType", new PropertyType(ConstraintType.class, false, false));
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("constraintTypeProperty", new PropertyType(ConstraintTypeProperty.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InputClauseUnaryTests.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InputClauseUnaryTests unwrap() {
        return target;
      }

      public InputClauseUnaryTests deepUnwrap() {
        final InputClauseUnaryTests clone = new InputClauseUnaryTests();
        final InputClauseUnaryTests t = unwrap();
        clone.setParent(t.getParent());
        if (t.getConstraintTypeProperty() instanceof BindableProxy) {
          clone.setConstraintTypeProperty((ConstraintTypeProperty) ((BindableProxy) getConstraintTypeProperty()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getConstraintTypeProperty())) {
          clone.setConstraintTypeProperty((ConstraintTypeProperty) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getConstraintTypeProperty())).deepUnwrap());
        } else {
          clone.setConstraintTypeProperty(t.getConstraintTypeProperty());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ConstraintType getConstraintType() {
        return target.getConstraintType();
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public ConstraintTypeProperty getConstraintTypeProperty() {
        return target.getConstraintTypeProperty();
      }

      public void setConstraintTypeProperty(ConstraintTypeProperty constraintTypeProperty) {
        if (agent.binders.containsKey("constraintTypeProperty")) {
          constraintTypeProperty = (ConstraintTypeProperty) agent.binders.get("constraintTypeProperty").setModel(constraintTypeProperty, StateSync.FROM_MODEL, true);
        }
        changeAndFire("constraintTypeProperty", constraintTypeProperty);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Id getId() {
        return target.getId();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "constraintType": return getConstraintType();
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "constraintTypeProperty": return getConstraintTypeProperty();
          case "nsContext": return getNsContext();
          case "id": return getId();
          case "text": return getText();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InputClauseUnaryTests", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "constraintTypeProperty": target.setConstraintTypeProperty((ConstraintTypeProperty) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InputClauseUnaryTests) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InputClauseUnaryTests", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InputClauseUnaryTests.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy((InputClauseUnaryTests) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InputClauseUnaryTestsProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy extends GenericServiceTaskValue implements BindableProxy {
      private BindableProxyAgent<GenericServiceTaskValue> agent;
      private GenericServiceTaskValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy() {
        this(new GenericServiceTaskValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy(GenericServiceTaskValue targetVal) {
        agent = new BindableProxyAgent<GenericServiceTaskValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("outMessagetructure", new PropertyType(String.class, false, false));
        p.put("serviceOperation", new PropertyType(String.class, false, false));
        p.put("serviceImplementation", new PropertyType(String.class, false, false));
        p.put("serviceInterface", new PropertyType(String.class, false, false));
        p.put("inMessageStructure", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(GenericServiceTaskValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GenericServiceTaskValue unwrap() {
        return target;
      }

      public GenericServiceTaskValue deepUnwrap() {
        final GenericServiceTaskValue clone = new GenericServiceTaskValue();
        final GenericServiceTaskValue t = unwrap();
        clone.setOutMessagetructure(t.getOutMessagetructure());
        clone.setServiceOperation(t.getServiceOperation());
        clone.setServiceImplementation(t.getServiceImplementation());
        clone.setServiceInterface(t.getServiceInterface());
        clone.setInMessageStructure(t.getInMessageStructure());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getOutMessagetructure() {
        return target.getOutMessagetructure();
      }

      public void setOutMessagetructure(String outMessagetructure) {
        changeAndFire("outMessagetructure", outMessagetructure);
      }

      public String getServiceOperation() {
        return target.getServiceOperation();
      }

      public void setServiceOperation(String serviceOperation) {
        changeAndFire("serviceOperation", serviceOperation);
      }

      public String getServiceImplementation() {
        return target.getServiceImplementation();
      }

      public void setServiceImplementation(String serviceImplementation) {
        changeAndFire("serviceImplementation", serviceImplementation);
      }

      public String getServiceInterface() {
        return target.getServiceInterface();
      }

      public void setServiceInterface(String serviceInterface) {
        changeAndFire("serviceInterface", serviceInterface);
      }

      public String getInMessageStructure() {
        return target.getInMessageStructure();
      }

      public void setInMessageStructure(String inMessageStructure) {
        changeAndFire("inMessageStructure", inMessageStructure);
      }

      public Object get(String property) {
        switch (property) {
          case "outMessagetructure": return getOutMessagetructure();
          case "serviceOperation": return getServiceOperation();
          case "serviceImplementation": return getServiceImplementation();
          case "serviceInterface": return getServiceInterface();
          case "inMessageStructure": return getInMessageStructure();
          case "this": return target;
          default: throw new NonExistingPropertyException("GenericServiceTaskValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "outMessagetructure": target.setOutMessagetructure((String) value);
          break;
          case "serviceOperation": target.setServiceOperation((String) value);
          break;
          case "serviceImplementation": target.setServiceImplementation((String) value);
          break;
          case "serviceInterface": target.setServiceInterface((String) value);
          break;
          case "inMessageStructure": target.setInMessageStructure((String) value);
          break;
          case "this": target = (GenericServiceTaskValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GenericServiceTaskValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(GenericServiceTaskValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy((GenericServiceTaskValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskValueProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy extends BackgroundSet implements BindableProxy {
      private BindableProxyAgent<BackgroundSet> agent;
      private BackgroundSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy() {
        this(new BackgroundSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy(BackgroundSet targetVal) {
        agent = new BindableProxyAgent<BackgroundSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("borderColor", new PropertyType(BorderColor.class, true, false));
        p.put("bgColor", new PropertyType(BgColor.class, true, false));
        p.put("borderSize", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize.class, true, false));
        p.put("this", new PropertyType(BackgroundSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BackgroundSet unwrap() {
        return target;
      }

      public BackgroundSet deepUnwrap() {
        final BackgroundSet clone = new BackgroundSet();
        final BackgroundSet t = unwrap();
        if (t.getBorderColor() instanceof BindableProxy) {
          clone.setBorderColor((BorderColor) ((BindableProxy) getBorderColor()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBorderColor())) {
          clone.setBorderColor((BorderColor) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBorderColor())).deepUnwrap());
        } else {
          clone.setBorderColor(t.getBorderColor());
        }
        if (t.getBgColor() instanceof BindableProxy) {
          clone.setBgColor((BgColor) ((BindableProxy) getBgColor()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBgColor())) {
          clone.setBgColor((BgColor) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBgColor())).deepUnwrap());
        } else {
          clone.setBgColor(t.getBgColor());
        }
        if (t.getBorderSize() instanceof BindableProxy) {
          clone.setBorderSize((org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize) ((BindableProxy) getBorderSize()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBorderSize())) {
          clone.setBorderSize((org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBorderSize())).deepUnwrap());
        } else {
          clone.setBorderSize(t.getBorderSize());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BorderColor getBorderColor() {
        return target.getBorderColor();
      }

      public void setBorderColor(BorderColor borderColor) {
        if (agent.binders.containsKey("borderColor")) {
          borderColor = (BorderColor) agent.binders.get("borderColor").setModel(borderColor, StateSync.FROM_MODEL, true);
        }
        changeAndFire("borderColor", borderColor);
      }

      public BgColor getBgColor() {
        return target.getBgColor();
      }

      public void setBgColor(BgColor bgColor) {
        if (agent.binders.containsKey("bgColor")) {
          bgColor = (BgColor) agent.binders.get("bgColor").setModel(bgColor, StateSync.FROM_MODEL, true);
        }
        changeAndFire("bgColor", bgColor);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize getBorderSize() {
        return target.getBorderSize();
      }

      public void setBorderSize(org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize borderSize) {
        if (agent.binders.containsKey("borderSize")) {
          borderSize = (org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize) agent.binders.get("borderSize").setModel(borderSize, StateSync.FROM_MODEL, true);
        }
        changeAndFire("borderSize", borderSize);
      }

      public Object get(String property) {
        switch (property) {
          case "borderColor": return getBorderColor();
          case "bgColor": return getBgColor();
          case "borderSize": return getBorderSize();
          case "this": return target;
          default: throw new NonExistingPropertyException("BackgroundSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "borderColor": target.setBorderColor((BorderColor) value);
          break;
          case "bgColor": target.setBgColor((BgColor) value);
          break;
          case "borderSize": target.setBorderSize((org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize) value);
          break;
          case "this": target = (BackgroundSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BackgroundSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BackgroundSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy((BackgroundSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BackgroundSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy extends AssigneeEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<AssigneeEditorFieldDefinition> agent;
      private AssigneeEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy() {
        this(new AssigneeEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy(AssigneeEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<AssigneeEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("max", new PropertyType(Integer.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("type", new PropertyType(AssigneeType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(AssigneeEditorFieldType.class, false, false));
        p.put("this", new PropertyType(AssigneeEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AssigneeEditorFieldDefinition unwrap() {
        return target;
      }

      public AssigneeEditorFieldDefinition deepUnwrap() {
        final AssigneeEditorFieldDefinition clone = new AssigneeEditorFieldDefinition();
        final AssigneeEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setMax(t.getMax());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setType(t.getType());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getMax() {
        return target.getMax();
      }

      public void setMax(Integer max) {
        changeAndFire("max", max);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public AssigneeType getType() {
        return target.getType();
      }

      public void setType(AssigneeType type) {
        changeAndFire("type", type);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public AssigneeEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "max": return getMax();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "type": return getType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("AssigneeEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "max": target.setMax((Integer) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "type": target.setType((AssigneeType) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (AssigneeEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AssigneeEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(AssigneeEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy((AssigneeEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_AssigneeEditorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy extends CancellingEscalationEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CancellingEscalationEventExecutionSet> agent;
      private CancellingEscalationEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy() {
        this(new CancellingEscalationEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy(CancellingEscalationEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CancellingEscalationEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("escalationRef", new PropertyType(EscalationRef.class, true, false));
        p.put("this", new PropertyType(CancellingEscalationEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancellingEscalationEventExecutionSet unwrap() {
        return target;
      }

      public CancellingEscalationEventExecutionSet deepUnwrap() {
        final CancellingEscalationEventExecutionSet clone = new CancellingEscalationEventExecutionSet();
        final CancellingEscalationEventExecutionSet t = unwrap();
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getEscalationRef() instanceof BindableProxy) {
          clone.setEscalationRef((EscalationRef) ((BindableProxy) getEscalationRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getEscalationRef())) {
          clone.setEscalationRef((EscalationRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getEscalationRef())).deepUnwrap());
        } else {
          clone.setEscalationRef(t.getEscalationRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public EscalationRef getEscalationRef() {
        return target.getEscalationRef();
      }

      public void setEscalationRef(EscalationRef escalationRef) {
        if (agent.binders.containsKey("escalationRef")) {
          escalationRef = (EscalationRef) agent.binders.get("escalationRef").setModel(escalationRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("escalationRef", escalationRef);
      }

      public Object get(String property) {
        switch (property) {
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "escalationRef": return getEscalationRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancellingEscalationEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "escalationRef": target.setEscalationRef((EscalationRef) value);
          break;
          case "this": target = (CancellingEscalationEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancellingEscalationEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancellingEscalationEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy((CancellingEscalationEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_CancellingEscalationEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy extends IntermediateMessageEventCatching implements BindableProxy {
      private BindableProxyAgent<IntermediateMessageEventCatching> agent;
      private IntermediateMessageEventCatching target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy() {
        this(new IntermediateMessageEventCatching());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy(IntermediateMessageEventCatching targetVal) {
        agent = new BindableProxyAgent<IntermediateMessageEventCatching>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CancellingMessageEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateMessageEventCatching.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateMessageEventCatching unwrap() {
        return target;
      }

      public IntermediateMessageEventCatching deepUnwrap() {
        final IntermediateMessageEventCatching clone = new IntermediateMessageEventCatching();
        final IntermediateMessageEventCatching t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CancellingMessageEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CancellingMessageEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CancellingMessageEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CancellingMessageEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CancellingMessageEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateMessageEventCatching", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CancellingMessageEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateMessageEventCatching) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateMessageEventCatching", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateMessageEventCatching.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy((IntermediateMessageEventCatching) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventCatchingProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy extends BgColor implements BindableProxy {
      private BindableProxyAgent<BgColor> agent;
      private BgColor target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy() {
        this(new BgColor());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy(BgColor targetVal) {
        agent = new BindableProxyAgent<BgColor>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(BgColor.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BgColor unwrap() {
        return target;
      }

      public BgColor deepUnwrap() {
        final BgColor clone = new BgColor();
        final BgColor t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("BgColor", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (BgColor) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BgColor", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BgColor.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy((BgColor) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BgColorProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy extends KnowledgeRequirement implements BindableProxy {
      private BindableProxyAgent<KnowledgeRequirement> agent;
      private KnowledgeRequirement target;
      public org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy() {
        this(new KnowledgeRequirement());
      }

      public org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy(KnowledgeRequirement targetVal) {
        agent = new BindableProxyAgent<KnowledgeRequirement>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(KnowledgeRequirement.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public KnowledgeRequirement unwrap() {
        return target;
      }

      public KnowledgeRequirement deepUnwrap() {
        final KnowledgeRequirement clone = new KnowledgeRequirement();
        final KnowledgeRequirement t = unwrap();
        clone.setParent(t.getParent());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "nsContext": return getNsContext();
          case "stunnerLabels": return getStunnerLabels();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("KnowledgeRequirement", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (KnowledgeRequirement) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("KnowledgeRequirement", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(KnowledgeRequirement.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy((KnowledgeRequirement) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_KnowledgeRequirementProxy();
      }
    });
    class org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy extends ProcessInstanceLogSummary implements BindableProxy {
      private BindableProxyAgent<ProcessInstanceLogSummary> agent;
      private ProcessInstanceLogSummary target;
      public org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy() {
        this(new ProcessInstanceLogSummary());
      }

      public org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy(ProcessInstanceLogSummary targetVal) {
        agent = new BindableProxyAgent<ProcessInstanceLogSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("date", new PropertyType(Date.class, false, false));
        p.put("logType", new PropertyType(Long.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("completed", new PropertyType(Boolean.class, false, false));
        p.put("workItemId", new PropertyType(Long.class, false, false));
        p.put("nodeType", new PropertyType(String.class, false, false));
        p.put("referenceId", new PropertyType(Long.class, false, false));
        p.put("logDeploymentId", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("nodeContainerId", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("nodeId", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ProcessInstanceLogSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessInstanceLogSummary unwrap() {
        return target;
      }

      public ProcessInstanceLogSummary deepUnwrap() {
        final ProcessInstanceLogSummary clone = new ProcessInstanceLogSummary();
        final ProcessInstanceLogSummary t = unwrap();
        clone.setDate(t.getDate());
        clone.setLogType(t.getLogType());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setCompleted(t.isCompleted());
        clone.setWorkItemId(t.getWorkItemId());
        clone.setNodeType(t.getNodeType());
        clone.setReferenceId(t.getReferenceId());
        clone.setLogDeploymentId(t.getLogDeploymentId());
        clone.setName(t.getName());
        clone.setNodeContainerId(t.getNodeContainerId());
        clone.setId(t.getId());
        clone.setNodeId(t.getNodeId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy) {
          obj = ((org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Date getDate() {
        return target.getDate();
      }

      public void setDate(Date date) {
        changeAndFire("date", date);
      }

      public Long getLogType() {
        return target.getLogType();
      }

      public void setLogType(Long logType) {
        changeAndFire("logType", logType);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public boolean isCompleted() {
        return target.isCompleted();
      }

      public void setCompleted(boolean completed) {
        changeAndFire("completed", completed);
      }

      public Long getWorkItemId() {
        return target.getWorkItemId();
      }

      public void setWorkItemId(Long workItemId) {
        changeAndFire("workItemId", workItemId);
      }

      public String getNodeType() {
        return target.getNodeType();
      }

      public void setNodeType(String nodeType) {
        changeAndFire("nodeType", nodeType);
      }

      public Long getReferenceId() {
        return target.getReferenceId();
      }

      public void setReferenceId(Long referenceId) {
        changeAndFire("referenceId", referenceId);
      }

      public String getLogDeploymentId() {
        return target.getLogDeploymentId();
      }

      public void setLogDeploymentId(String logDeploymentId) {
        changeAndFire("logDeploymentId", logDeploymentId);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getNodeContainerId() {
        return target.getNodeContainerId();
      }

      public void setNodeContainerId(String nodeContainerId) {
        changeAndFire("nodeContainerId", nodeContainerId);
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public String getNodeId() {
        return target.getNodeId();
      }

      public void setNodeId(String nodeId) {
        changeAndFire("nodeId", nodeId);
      }

      public Object get(String property) {
        switch (property) {
          case "date": return getDate();
          case "logType": return getLogType();
          case "callbacks": return getCallbacks();
          case "completed": return isCompleted();
          case "workItemId": return getWorkItemId();
          case "nodeType": return getNodeType();
          case "referenceId": return getReferenceId();
          case "logDeploymentId": return getLogDeploymentId();
          case "name": return getName();
          case "nodeContainerId": return getNodeContainerId();
          case "id": return getId();
          case "nodeId": return getNodeId();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessInstanceLogSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "date": target.setDate((Date) value);
          break;
          case "logType": target.setLogType((Long) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "completed": target.setCompleted((Boolean) value);
          break;
          case "workItemId": target.setWorkItemId((Long) value);
          break;
          case "nodeType": target.setNodeType((String) value);
          break;
          case "referenceId": target.setReferenceId((Long) value);
          break;
          case "logDeploymentId": target.setLogDeploymentId((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "nodeContainerId": target.setNodeContainerId((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "nodeId": target.setNodeId((String) value);
          break;
          case "this": target = (ProcessInstanceLogSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessInstanceLogSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessInstanceLogSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy((ProcessInstanceLogSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_pr_model_ProcessInstanceLogSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy extends CancellingSignalEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CancellingSignalEventExecutionSet> agent;
      private CancellingSignalEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy() {
        this(new CancellingSignalEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy(CancellingSignalEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CancellingSignalEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("signalRef", new PropertyType(SignalRef.class, true, false));
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(CancellingSignalEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancellingSignalEventExecutionSet unwrap() {
        return target;
      }

      public CancellingSignalEventExecutionSet deepUnwrap() {
        final CancellingSignalEventExecutionSet clone = new CancellingSignalEventExecutionSet();
        final CancellingSignalEventExecutionSet t = unwrap();
        if (t.getSignalRef() instanceof BindableProxy) {
          clone.setSignalRef((SignalRef) ((BindableProxy) getSignalRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSignalRef())) {
          clone.setSignalRef((SignalRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSignalRef())).deepUnwrap());
        } else {
          clone.setSignalRef(t.getSignalRef());
        }
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public SignalRef getSignalRef() {
        return target.getSignalRef();
      }

      public void setSignalRef(SignalRef signalRef) {
        if (agent.binders.containsKey("signalRef")) {
          signalRef = (SignalRef) agent.binders.get("signalRef").setModel(signalRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("signalRef", signalRef);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "signalRef": return getSignalRef();
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancellingSignalEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "signalRef": target.setSignalRef((SignalRef) value);
          break;
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (CancellingSignalEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancellingSignalEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancellingSignalEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy((CancellingSignalEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_CancellingSignalEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy extends ScriptTypeFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ScriptTypeFieldDefinition> agent;
      private ScriptTypeFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy() {
        this(new ScriptTypeFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy(ScriptTypeFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ScriptTypeFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("mode", new PropertyType(ScriptTypeMode.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ScriptTypeFieldType.class, false, false));
        p.put("this", new PropertyType(ScriptTypeFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScriptTypeFieldDefinition unwrap() {
        return target;
      }

      public ScriptTypeFieldDefinition deepUnwrap() {
        final ScriptTypeFieldDefinition clone = new ScriptTypeFieldDefinition();
        final ScriptTypeFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMode(t.getMode());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public ScriptTypeMode getMode() {
        return target.getMode();
      }

      public void setMode(ScriptTypeMode mode) {
        changeAndFire("mode", mode);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ScriptTypeFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "mode": return getMode();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScriptTypeFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "mode": target.setMode((ScriptTypeMode) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (ScriptTypeFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScriptTypeFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ScriptTypeFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy((ScriptTypeFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy extends DecimalRadioGroupFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DecimalRadioGroupFieldDefinition> agent;
      private DecimalRadioGroupFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy() {
        this(new DecimalRadioGroupFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy(DecimalRadioGroupFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DecimalRadioGroupFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Double.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("inline", new PropertyType(Boolean.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(RadioGroupFieldType.class, false, false));
        p.put("this", new PropertyType(DecimalRadioGroupFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecimalRadioGroupFieldDefinition unwrap() {
        return target;
      }

      public DecimalRadioGroupFieldDefinition deepUnwrap() {
        final DecimalRadioGroupFieldDefinition clone = new DecimalRadioGroupFieldDefinition();
        final DecimalRadioGroupFieldDefinition t = unwrap();
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setInline(t.getInline());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Double getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Double defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Boolean getInline() {
        return target.getInline();
      }

      public void setInline(Boolean inline) {
        changeAndFire("inline", inline);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<DecimalSelectorOption> options) {
        List<DecimalSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public RadioGroupFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "inline": return getInline();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecimalRadioGroupFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Double) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "inline": target.setInline((Boolean) value);
          break;
          case "options": target.setOptions((List<DecimalSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DecimalRadioGroupFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecimalRadioGroupFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DecimalRadioGroupFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy((DecimalRadioGroupFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_DecimalRadioGroupFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy extends TimerSettings implements BindableProxy {
      private BindableProxyAgent<TimerSettings> agent;
      private TimerSettings target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy() {
        this(new TimerSettings());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy(TimerSettings targetVal) {
        agent = new BindableProxyAgent<TimerSettings>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(TimerSettingsValue.class, true, false));
        p.put("this", new PropertyType(TimerSettings.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TimerSettings unwrap() {
        return target;
      }

      public TimerSettings deepUnwrap() {
        final TimerSettings clone = new TimerSettings();
        final TimerSettings t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((TimerSettingsValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((TimerSettingsValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public TimerSettingsValue getValue() {
        return target.getValue();
      }

      public void setValue(TimerSettingsValue value) {
        if (agent.binders.containsKey("value")) {
          value = (TimerSettingsValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("TimerSettings", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((TimerSettingsValue) value);
          break;
          case "this": target = (TimerSettings) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TimerSettings", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TimerSettings.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy((TimerSettings) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsProxy();
      }
    });
    class org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy extends QNameFieldDefinition implements BindableProxy {
      private BindableProxyAgent<QNameFieldDefinition> agent;
      private QNameFieldDefinition target;
      public org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy() {
        this(new QNameFieldDefinition());
      }

      public org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy(QNameFieldDefinition targetVal) {
        agent = new BindableProxyAgent<QNameFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(QNameFieldType.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(QNameFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public QNameFieldDefinition unwrap() {
        return target;
      }

      public QNameFieldDefinition deepUnwrap() {
        final QNameFieldDefinition clone = new QNameFieldDefinition();
        final QNameFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setPlaceHolder(t.getPlaceHolder());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public QNameFieldType getFieldType() {
        return target.getFieldType();
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "placeHolder": return getPlaceHolder();
          case "this": return target;
          default: throw new NonExistingPropertyException("QNameFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "this": target = (QNameFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("QNameFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(QNameFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy((QNameFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_client_property_dmn_QNameFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy extends InterruptingSignalEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<InterruptingSignalEventExecutionSet> agent;
      private InterruptingSignalEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy() {
        this(new InterruptingSignalEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy(InterruptingSignalEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<InterruptingSignalEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("signalRef", new PropertyType(SignalRef.class, true, false));
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(InterruptingSignalEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InterruptingSignalEventExecutionSet unwrap() {
        return target;
      }

      public InterruptingSignalEventExecutionSet deepUnwrap() {
        final InterruptingSignalEventExecutionSet clone = new InterruptingSignalEventExecutionSet();
        final InterruptingSignalEventExecutionSet t = unwrap();
        if (t.getSignalRef() instanceof BindableProxy) {
          clone.setSignalRef((SignalRef) ((BindableProxy) getSignalRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSignalRef())) {
          clone.setSignalRef((SignalRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSignalRef())).deepUnwrap());
        } else {
          clone.setSignalRef(t.getSignalRef());
        }
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public SignalRef getSignalRef() {
        return target.getSignalRef();
      }

      public void setSignalRef(SignalRef signalRef) {
        if (agent.binders.containsKey("signalRef")) {
          signalRef = (SignalRef) agent.binders.get("signalRef").setModel(signalRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("signalRef", signalRef);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "signalRef": return getSignalRef();
          case "isInterrupting": return getIsInterrupting();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("InterruptingSignalEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "signalRef": target.setSignalRef((SignalRef) value);
          break;
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (InterruptingSignalEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InterruptingSignalEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InterruptingSignalEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy((InterruptingSignalEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_InterruptingSignalEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy extends CharacterRadioGroupFieldDefinition implements BindableProxy {
      private BindableProxyAgent<CharacterRadioGroupFieldDefinition> agent;
      private CharacterRadioGroupFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy() {
        this(new CharacterRadioGroupFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy(CharacterRadioGroupFieldDefinition targetVal) {
        agent = new BindableProxyAgent<CharacterRadioGroupFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Character.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("inline", new PropertyType(Boolean.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(RadioGroupFieldType.class, false, false));
        p.put("this", new PropertyType(CharacterRadioGroupFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CharacterRadioGroupFieldDefinition unwrap() {
        return target;
      }

      public CharacterRadioGroupFieldDefinition deepUnwrap() {
        final CharacterRadioGroupFieldDefinition clone = new CharacterRadioGroupFieldDefinition();
        final CharacterRadioGroupFieldDefinition t = unwrap();
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setInline(t.getInline());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Character getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Character defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Boolean getInline() {
        return target.getInline();
      }

      public void setInline(Boolean inline) {
        changeAndFire("inline", inline);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<CharacterSelectorOption> options) {
        List<CharacterSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public RadioGroupFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "inline": return getInline();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("CharacterRadioGroupFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Character) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "inline": target.setInline((Boolean) value);
          break;
          case "options": target.setOptions((List<CharacterSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (CharacterRadioGroupFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CharacterRadioGroupFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(CharacterRadioGroupFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy((CharacterRadioGroupFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_CharacterRadioGroupFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy extends ReusableSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<ReusableSubprocessTaskExecutionSet> agent;
      private ReusableSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy() {
        this(new ReusableSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy(ReusableSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<ReusableSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("abortParent", new PropertyType(AbortParent.class, true, false));
        p.put("independent", new PropertyType(Independent.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("waitForCompletion", new PropertyType(WaitForCompletion.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("isCase", new PropertyType(IsCase.class, true, false));
        p.put("calledElement", new PropertyType(CalledElement.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("this", new PropertyType(ReusableSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReusableSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public ReusableSubprocessTaskExecutionSet deepUnwrap() {
        final ReusableSubprocessTaskExecutionSet clone = new ReusableSubprocessTaskExecutionSet();
        final ReusableSubprocessTaskExecutionSet t = unwrap();
        if (t.getAbortParent() instanceof BindableProxy) {
          clone.setAbortParent((AbortParent) ((BindableProxy) getAbortParent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAbortParent())) {
          clone.setAbortParent((AbortParent) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAbortParent())).deepUnwrap());
        } else {
          clone.setAbortParent(t.getAbortParent());
        }
        if (t.getIndependent() instanceof BindableProxy) {
          clone.setIndependent((Independent) ((BindableProxy) getIndependent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIndependent())) {
          clone.setIndependent((Independent) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIndependent())).deepUnwrap());
        } else {
          clone.setIndependent(t.getIndependent());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getWaitForCompletion() instanceof BindableProxy) {
          clone.setWaitForCompletion((WaitForCompletion) ((BindableProxy) getWaitForCompletion()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWaitForCompletion())) {
          clone.setWaitForCompletion((WaitForCompletion) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWaitForCompletion())).deepUnwrap());
        } else {
          clone.setWaitForCompletion(t.getWaitForCompletion());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getIsCase() instanceof BindableProxy) {
          clone.setIsCase((IsCase) ((BindableProxy) getIsCase()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsCase())) {
          clone.setIsCase((IsCase) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsCase())).deepUnwrap());
        } else {
          clone.setIsCase(t.getIsCase());
        }
        if (t.getCalledElement() instanceof BindableProxy) {
          clone.setCalledElement((CalledElement) ((BindableProxy) getCalledElement()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCalledElement())) {
          clone.setCalledElement((CalledElement) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCalledElement())).deepUnwrap());
        } else {
          clone.setCalledElement(t.getCalledElement());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AbortParent getAbortParent() {
        return target.getAbortParent();
      }

      public void setAbortParent(AbortParent abortParent) {
        if (agent.binders.containsKey("abortParent")) {
          abortParent = (AbortParent) agent.binders.get("abortParent").setModel(abortParent, StateSync.FROM_MODEL, true);
        }
        changeAndFire("abortParent", abortParent);
      }

      public Independent getIndependent() {
        return target.getIndependent();
      }

      public void setIndependent(Independent independent) {
        if (agent.binders.containsKey("independent")) {
          independent = (Independent) agent.binders.get("independent").setModel(independent, StateSync.FROM_MODEL, true);
        }
        changeAndFire("independent", independent);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public WaitForCompletion getWaitForCompletion() {
        return target.getWaitForCompletion();
      }

      public void setWaitForCompletion(WaitForCompletion waitForCompletion) {
        if (agent.binders.containsKey("waitForCompletion")) {
          waitForCompletion = (WaitForCompletion) agent.binders.get("waitForCompletion").setModel(waitForCompletion, StateSync.FROM_MODEL, true);
        }
        changeAndFire("waitForCompletion", waitForCompletion);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public IsCase getIsCase() {
        return target.getIsCase();
      }

      public void setIsCase(IsCase isCase) {
        if (agent.binders.containsKey("isCase")) {
          isCase = (IsCase) agent.binders.get("isCase").setModel(isCase, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isCase", isCase);
      }

      public CalledElement getCalledElement() {
        return target.getCalledElement();
      }

      public void setCalledElement(CalledElement calledElement) {
        if (agent.binders.containsKey("calledElement")) {
          calledElement = (CalledElement) agent.binders.get("calledElement").setModel(calledElement, StateSync.FROM_MODEL, true);
        }
        changeAndFire("calledElement", calledElement);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public Object get(String property) {
        switch (property) {
          case "abortParent": return getAbortParent();
          case "independent": return getIndependent();
          case "isAsync": return getIsAsync();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "waitForCompletion": return getWaitForCompletion();
          case "onEntryAction": return getOnEntryAction();
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "adHocAutostart": return getAdHocAutostart();
          case "slaDueDate": return getSlaDueDate();
          case "isCase": return getIsCase();
          case "calledElement": return getCalledElement();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "onExitAction": return getOnExitAction();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReusableSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "abortParent": target.setAbortParent((AbortParent) value);
          break;
          case "independent": target.setIndependent((Independent) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "waitForCompletion": target.setWaitForCompletion((WaitForCompletion) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "isCase": target.setIsCase((IsCase) value);
          break;
          case "calledElement": target.setCalledElement((CalledElement) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "this": target = (ReusableSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReusableSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ReusableSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy((ReusableSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ReusableSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy extends InclusiveGateway implements BindableProxy {
      private BindableProxyAgent<InclusiveGateway> agent;
      private InclusiveGateway target;
      public org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy() {
        this(new InclusiveGateway());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy(InclusiveGateway targetVal) {
        agent = new BindableProxyAgent<InclusiveGateway>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(GatewayExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(InclusiveGateway.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InclusiveGateway unwrap() {
        return target;
      }

      public InclusiveGateway deepUnwrap() {
        final InclusiveGateway clone = new InclusiveGateway();
        final InclusiveGateway t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((GatewayExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((GatewayExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public GatewayExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(GatewayExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (GatewayExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("InclusiveGateway", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((GatewayExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (InclusiveGateway) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InclusiveGateway", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InclusiveGateway.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy((InclusiveGateway) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_InclusiveGatewayProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy extends ReassignmentRow implements BindableProxy {
      private BindableProxyAgent<ReassignmentRow> agent;
      private ReassignmentRow target;
      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy() {
        this(new ReassignmentRow());
      }

      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy(ReassignmentRow targetVal) {
        agent = new BindableProxyAgent<ReassignmentRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("duration", new PropertyType(String.class, false, false));
        p.put("groups", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("type", new PropertyType(ReassignmentType.class, false, false));
        p.put("users", new PropertyType(List.class, false, true));
        p.put("this", new PropertyType(ReassignmentRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReassignmentRow unwrap() {
        return target;
      }

      public ReassignmentRow deepUnwrap() {
        final ReassignmentRow clone = new ReassignmentRow();
        final ReassignmentRow t = unwrap();
        clone.setDuration(t.getDuration());
        if (t.getGroups() != null) {
          final List groupsClone = new ArrayList();
          for (Object groupsElem : t.getGroups()) {
            if (groupsElem instanceof BindableProxy) {
              groupsClone.add(((BindableProxy) groupsElem).deepUnwrap());
            } else {
              groupsClone.add(groupsElem);
            }
          }
          clone.setGroups(groupsClone);
        }
        clone.setId(t.getId());
        clone.setType(t.getType());
        if (t.getUsers() != null) {
          final List usersClone = new ArrayList();
          for (Object usersElem : t.getUsers()) {
            if (usersElem instanceof BindableProxy) {
              usersClone.add(((BindableProxy) usersElem).deepUnwrap());
            } else {
              usersClone.add(usersElem);
            }
          }
          clone.setUsers(usersClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getDuration() {
        return target.getDuration();
      }

      public void setDuration(String duration) {
        changeAndFire("duration", duration);
      }

      public List getGroups() {
        return target.getGroups();
      }

      public void setGroups(List<String> groups) {
        List<String> oldValue = target.getGroups();
        groups = agent.ensureBoundListIsProxied("groups", groups);
        target.setGroups(groups);
        agent.updateWidgetsAndFireEvent(true, "groups", oldValue, groups);
      }

      public long getId() {
        return target.getId();
      }

      public void setId(long id) {
        changeAndFire("id", id);
      }

      public ReassignmentType getType() {
        return target.getType();
      }

      public void setType(ReassignmentType type) {
        changeAndFire("type", type);
      }

      public List getUsers() {
        return target.getUsers();
      }

      public void setUsers(List<String> users) {
        List<String> oldValue = target.getUsers();
        users = agent.ensureBoundListIsProxied("users", users);
        target.setUsers(users);
        agent.updateWidgetsAndFireEvent(true, "users", oldValue, users);
      }

      public Object get(String property) {
        switch (property) {
          case "duration": return getDuration();
          case "groups": return getGroups();
          case "id": return getId();
          case "type": return getType();
          case "users": return getUsers();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReassignmentRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "duration": target.setDuration((String) value);
          break;
          case "groups": target.setGroups((List<String>) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "type": target.setType((ReassignmentType) value);
          break;
          case "users": target.setUsers((List<String>) value);
          break;
          case "this": target = (ReassignmentRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReassignmentRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public ReassignmentRow clone() {
        final ReassignmentRow returnValue = target.clone();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public ReassignmentValue toReassignmentValue() {
        final ReassignmentValue returnValue = target.toReassignmentValue();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ReassignmentRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy((ReassignmentRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_ReassignmentRowProxy();
      }
    });
    class org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy extends NodeInstanceSummary implements BindableProxy {
      private BindableProxyAgent<NodeInstanceSummary> agent;
      private NodeInstanceSummary target;
      public org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy() {
        this(new NodeInstanceSummary());
      }

      public org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy(NodeInstanceSummary targetVal) {
        agent = new BindableProxyAgent<NodeInstanceSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("nodeUniqueName", new PropertyType(String.class, false, false));
        p.put("description", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("completed", new PropertyType(Boolean.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("type", new PropertyType(String.class, false, false));
        p.put("referenceId", new PropertyType(Long.class, false, false));
        p.put("processId", new PropertyType(Long.class, false, false));
        p.put("slaCompliance", new PropertyType(Integer.class, false, false));
        p.put("slaDueDate", new PropertyType(Date.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("connection", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("timestamp", new PropertyType(Date.class, false, false));
        p.put("this", new PropertyType(NodeInstanceSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NodeInstanceSummary unwrap() {
        return target;
      }

      public NodeInstanceSummary deepUnwrap() {
        final NodeInstanceSummary clone = new NodeInstanceSummary();
        final NodeInstanceSummary t = unwrap();
        clone.setNodeUniqueName(t.getNodeUniqueName());
        clone.setDescription(t.getDescription());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setCompleted(t.isCompleted());
        clone.setType(t.getType());
        clone.setReferenceId(t.getReferenceId());
        clone.setProcessId(t.getProcessId());
        clone.setSlaCompliance(t.getSlaCompliance());
        clone.setSlaDueDate(t.getSlaDueDate());
        clone.setName(t.getName());
        clone.setConnection(t.getConnection());
        clone.setId(t.getId());
        clone.setTimestamp(t.getTimestamp());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy) {
          obj = ((org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getNodeUniqueName() {
        return target.getNodeUniqueName();
      }

      public void setNodeUniqueName(String nodeUniqueName) {
        changeAndFire("nodeUniqueName", nodeUniqueName);
      }

      public String getDescription() {
        return target.getDescription();
      }

      public void setDescription(String description) {
        changeAndFire("description", description);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public Boolean isCompleted() {
        return target.isCompleted();
      }

      public void setCompleted(Boolean completed) {
        changeAndFire("completed", completed);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public String getType() {
        return target.getType();
      }

      public void setType(String type) {
        changeAndFire("type", type);
      }

      public Long getReferenceId() {
        return target.getReferenceId();
      }

      public void setReferenceId(Long referenceId) {
        changeAndFire("referenceId", referenceId);
      }

      public Long getProcessId() {
        return target.getProcessId();
      }

      public void setProcessId(Long processId) {
        changeAndFire("processId", processId);
      }

      public Integer getSlaCompliance() {
        return target.getSlaCompliance();
      }

      public void setSlaCompliance(Integer slaCompliance) {
        changeAndFire("slaCompliance", slaCompliance);
      }

      public Date getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(Date slaDueDate) {
        changeAndFire("slaDueDate", slaDueDate);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getConnection() {
        return target.getConnection();
      }

      public void setConnection(String connection) {
        changeAndFire("connection", connection);
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public Date getTimestamp() {
        return target.getTimestamp();
      }

      public void setTimestamp(Date timestamp) {
        changeAndFire("timestamp", timestamp);
      }

      public Object get(String property) {
        switch (property) {
          case "nodeUniqueName": return getNodeUniqueName();
          case "description": return getDescription();
          case "callbacks": return getCallbacks();
          case "completed": return isCompleted();
          case "label": return getLabel();
          case "type": return getType();
          case "referenceId": return getReferenceId();
          case "processId": return getProcessId();
          case "slaCompliance": return getSlaCompliance();
          case "slaDueDate": return getSlaDueDate();
          case "name": return getName();
          case "connection": return getConnection();
          case "id": return getId();
          case "timestamp": return getTimestamp();
          case "this": return target;
          default: throw new NonExistingPropertyException("NodeInstanceSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "nodeUniqueName": target.setNodeUniqueName((String) value);
          break;
          case "description": target.setDescription((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "completed": target.setCompleted((Boolean) value);
          break;
          case "type": target.setType((String) value);
          break;
          case "referenceId": target.setReferenceId((Long) value);
          break;
          case "processId": target.setProcessId((Long) value);
          break;
          case "slaCompliance": target.setSlaCompliance((Integer) value);
          break;
          case "slaDueDate": target.setSlaDueDate((Date) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "connection": target.setConnection((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "timestamp": target.setTimestamp((Date) value);
          break;
          case "this": target = (NodeInstanceSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NodeInstanceSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(NodeInstanceSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy((NodeInstanceSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_pr_model_NodeInstanceSummaryProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy extends DecimalMultipleInputFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DecimalMultipleInputFieldDefinition> agent;
      private DecimalMultipleInputFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy() {
        this(new DecimalMultipleInputFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy(DecimalMultipleInputFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DecimalMultipleInputFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("pageSize", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(DecimalMultipleInputFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecimalMultipleInputFieldDefinition unwrap() {
        return target;
      }

      public DecimalMultipleInputFieldDefinition deepUnwrap() {
        final DecimalMultipleInputFieldDefinition clone = new DecimalMultipleInputFieldDefinition();
        final DecimalMultipleInputFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setPageSize(t.getPageSize());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getPageSize() {
        return target.getPageSize();
      }

      public void setPageSize(Integer pageSize) {
        changeAndFire("pageSize", pageSize);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "pageSize": return getPageSize();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecimalMultipleInputFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "pageSize": target.setPageSize((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DecimalMultipleInputFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecimalMultipleInputFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DecimalMultipleInputFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy((DecimalMultipleInputFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DecimalMultipleInputFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy extends EmbeddedSubprocessExecutionSet implements BindableProxy {
      private BindableProxyAgent<EmbeddedSubprocessExecutionSet> agent;
      private EmbeddedSubprocessExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy() {
        this(new EmbeddedSubprocessExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy(EmbeddedSubprocessExecutionSet targetVal) {
        agent = new BindableProxyAgent<EmbeddedSubprocessExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("this", new PropertyType(EmbeddedSubprocessExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EmbeddedSubprocessExecutionSet unwrap() {
        return target;
      }

      public EmbeddedSubprocessExecutionSet deepUnwrap() {
        final EmbeddedSubprocessExecutionSet clone = new EmbeddedSubprocessExecutionSet();
        final EmbeddedSubprocessExecutionSet t = unwrap();
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public Object get(String property) {
        switch (property) {
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "onExitAction": return getOnExitAction();
          case "onEntryAction": return getOnEntryAction();
          case "this": return target;
          default: throw new NonExistingPropertyException("EmbeddedSubprocessExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "this": target = (EmbeddedSubprocessExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EmbeddedSubprocessExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EmbeddedSubprocessExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy((EmbeddedSubprocessExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EmbeddedSubprocessExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy extends StringListBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<StringListBoxFieldDefinition> agent;
      private StringListBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy() {
        this(new StringListBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy(StringListBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<StringListBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("addEmptyOption", new PropertyType(Boolean.class, false, false));
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ListBoxFieldType.class, false, false));
        p.put("this", new PropertyType(StringListBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StringListBoxFieldDefinition unwrap() {
        return target;
      }

      public StringListBoxFieldDefinition deepUnwrap() {
        final StringListBoxFieldDefinition clone = new StringListBoxFieldDefinition();
        final StringListBoxFieldDefinition t = unwrap();
        clone.setAddEmptyOption(t.getAddEmptyOption());
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getAddEmptyOption() {
        return target.getAddEmptyOption();
      }

      public void setAddEmptyOption(Boolean addEmptyOption) {
        changeAndFire("addEmptyOption", addEmptyOption);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<StringSelectorOption> options) {
        List<StringSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ListBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "addEmptyOption": return getAddEmptyOption();
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("StringListBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "addEmptyOption": target.setAddEmptyOption((Boolean) value);
          break;
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<StringSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (StringListBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StringListBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(StringListBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy((StringListBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_StringListBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy extends DatePickerFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DatePickerFieldDefinition> agent;
      private DatePickerFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy() {
        this(new DatePickerFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy(DatePickerFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DatePickerFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("showTime", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(DatePickerFieldType.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DatePickerFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DatePickerFieldDefinition unwrap() {
        return target;
      }

      public DatePickerFieldDefinition deepUnwrap() {
        final DatePickerFieldDefinition clone = new DatePickerFieldDefinition();
        final DatePickerFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setShowTime(t.getShowTime());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setPlaceHolder(t.getPlaceHolder());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Boolean getShowTime() {
        return target.getShowTime();
      }

      public void setShowTime(Boolean showTime) {
        changeAndFire("showTime", showTime);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public DatePickerFieldType getFieldType() {
        return target.getFieldType();
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "showTime": return getShowTime();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "placeHolder": return getPlaceHolder();
          case "this": return target;
          default: throw new NonExistingPropertyException("DatePickerFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "showTime": target.setShowTime((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "this": target = (DatePickerFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DatePickerFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DatePickerFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy((DatePickerFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_datePicker_definition_DatePickerFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy extends IntegerMultipleInputFieldDefinition implements BindableProxy {
      private BindableProxyAgent<IntegerMultipleInputFieldDefinition> agent;
      private IntegerMultipleInputFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy() {
        this(new IntegerMultipleInputFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy(IntegerMultipleInputFieldDefinition targetVal) {
        agent = new BindableProxyAgent<IntegerMultipleInputFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("pageSize", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(IntegerMultipleInputFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerMultipleInputFieldDefinition unwrap() {
        return target;
      }

      public IntegerMultipleInputFieldDefinition deepUnwrap() {
        final IntegerMultipleInputFieldDefinition clone = new IntegerMultipleInputFieldDefinition();
        final IntegerMultipleInputFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setPageSize(t.getPageSize());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getPageSize() {
        return target.getPageSize();
      }

      public void setPageSize(Integer pageSize) {
        changeAndFire("pageSize", pageSize);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "pageSize": return getPageSize();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerMultipleInputFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "pageSize": target.setPageSize((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (IntegerMultipleInputFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerMultipleInputFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerMultipleInputFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy((IntegerMultipleInputFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_IntegerMultipleInputFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy extends ReassignmentsInfo implements BindableProxy {
      private BindableProxyAgent<ReassignmentsInfo> agent;
      private ReassignmentsInfo target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy() {
        this(new ReassignmentsInfo());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy(ReassignmentsInfo targetVal) {
        agent = new BindableProxyAgent<ReassignmentsInfo>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(ReassignmentTypeListValue.class, true, false));
        p.put("this", new PropertyType(ReassignmentsInfo.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReassignmentsInfo unwrap() {
        return target;
      }

      public ReassignmentsInfo deepUnwrap() {
        final ReassignmentsInfo clone = new ReassignmentsInfo();
        final ReassignmentsInfo t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ReassignmentTypeListValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ReassignmentTypeListValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ReassignmentTypeListValue getValue() {
        return target.getValue();
      }

      public void setValue(ReassignmentTypeListValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ReassignmentTypeListValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReassignmentsInfo", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ReassignmentTypeListValue) value);
          break;
          case "this": target = (ReassignmentsInfo) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReassignmentsInfo", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ReassignmentsInfo.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy((ReassignmentsInfo) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentsInfoProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy extends EndCompensationEvent implements BindableProxy {
      private BindableProxyAgent<EndCompensationEvent> agent;
      private EndCompensationEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy() {
        this(new EndCompensationEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy(EndCompensationEvent targetVal) {
        agent = new BindableProxyAgent<EndCompensationEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CompensationEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndCompensationEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndCompensationEvent unwrap() {
        return target;
      }

      public EndCompensationEvent deepUnwrap() {
        final EndCompensationEvent clone = new EndCompensationEvent();
        final EndCompensationEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CompensationEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CompensationEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CompensationEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CompensationEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CompensationEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndCompensationEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CompensationEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndCompensationEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndCompensationEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndCompensationEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy((EndCompensationEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndCompensationEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy extends ScriptTypeListFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ScriptTypeListFieldDefinition> agent;
      private ScriptTypeListFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy() {
        this(new ScriptTypeListFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy(ScriptTypeListFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ScriptTypeListFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("mode", new PropertyType(ScriptTypeMode.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ScriptTypeListFieldType.class, false, false));
        p.put("this", new PropertyType(ScriptTypeListFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScriptTypeListFieldDefinition unwrap() {
        return target;
      }

      public ScriptTypeListFieldDefinition deepUnwrap() {
        final ScriptTypeListFieldDefinition clone = new ScriptTypeListFieldDefinition();
        final ScriptTypeListFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMode(t.getMode());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public ScriptTypeMode getMode() {
        return target.getMode();
      }

      public void setMode(ScriptTypeMode mode) {
        changeAndFire("mode", mode);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ScriptTypeListFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "mode": return getMode();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScriptTypeListFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "mode": target.setMode((ScriptTypeMode) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (ScriptTypeListFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScriptTypeListFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ScriptTypeListFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy((ScriptTypeListFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ScriptTypeListFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy extends CharacterListBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<CharacterListBoxFieldDefinition> agent;
      private CharacterListBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy() {
        this(new CharacterListBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy(CharacterListBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<CharacterListBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("addEmptyOption", new PropertyType(Boolean.class, false, false));
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Character.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ListBoxFieldType.class, false, false));
        p.put("this", new PropertyType(CharacterListBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CharacterListBoxFieldDefinition unwrap() {
        return target;
      }

      public CharacterListBoxFieldDefinition deepUnwrap() {
        final CharacterListBoxFieldDefinition clone = new CharacterListBoxFieldDefinition();
        final CharacterListBoxFieldDefinition t = unwrap();
        clone.setAddEmptyOption(t.getAddEmptyOption());
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getAddEmptyOption() {
        return target.getAddEmptyOption();
      }

      public void setAddEmptyOption(Boolean addEmptyOption) {
        changeAndFire("addEmptyOption", addEmptyOption);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Character getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Character defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<CharacterSelectorOption> options) {
        List<CharacterSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ListBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "addEmptyOption": return getAddEmptyOption();
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("CharacterListBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "addEmptyOption": target.setAddEmptyOption((Boolean) value);
          break;
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Character) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<CharacterSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (CharacterListBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CharacterListBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(CharacterListBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy((CharacterListBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_CharacterListBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy extends Radius implements BindableProxy {
      private BindableProxyAgent<Radius> agent;
      private Radius target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy() {
        this(new Radius());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy(Radius targetVal) {
        agent = new BindableProxyAgent<Radius>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Radius.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Radius unwrap() {
        return target;
      }

      public Radius deepUnwrap() {
        final Radius clone = new Radius();
        final Radius t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Radius", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Radius) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Radius", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Radius.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy((Radius) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RadiusProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy extends IsMultipleInstance implements BindableProxy {
      private BindableProxyAgent<IsMultipleInstance> agent;
      private IsMultipleInstance target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy() {
        this(new IsMultipleInstance());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy(IsMultipleInstance targetVal) {
        agent = new BindableProxyAgent<IsMultipleInstance>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(IsMultipleInstance.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IsMultipleInstance unwrap() {
        return target;
      }

      public IsMultipleInstance deepUnwrap() {
        final IsMultipleInstance clone = new IsMultipleInstance();
        final IsMultipleInstance t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("IsMultipleInstance", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (IsMultipleInstance) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IsMultipleInstance", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(IsMultipleInstance.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy((IsMultipleInstance) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_IsMultipleInstanceProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy extends NonDirectionalAssociation implements BindableProxy {
      private BindableProxyAgent<NonDirectionalAssociation> agent;
      private NonDirectionalAssociation target;
      public org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy() {
        this(new NonDirectionalAssociation());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy(NonDirectionalAssociation targetVal) {
        agent = new BindableProxyAgent<NonDirectionalAssociation>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(NonDirectionalAssociation.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NonDirectionalAssociation unwrap() {
        return target;
      }

      public NonDirectionalAssociation deepUnwrap() {
        final NonDirectionalAssociation clone = new NonDirectionalAssociation();
        final NonDirectionalAssociation t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("NonDirectionalAssociation", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "this": target = (NonDirectionalAssociation) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NonDirectionalAssociation", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(NonDirectionalAssociation.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy((NonDirectionalAssociation) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_NonDirectionalAssociationProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy extends EventGateway implements BindableProxy {
      private BindableProxyAgent<EventGateway> agent;
      private EventGateway target;
      public org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy() {
        this(new EventGateway());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy(EventGateway targetVal) {
        agent = new BindableProxyAgent<EventGateway>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EventGateway.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EventGateway unwrap() {
        return target;
      }

      public EventGateway deepUnwrap() {
        final EventGateway clone = new EventGateway();
        final EventGateway t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EventGateway", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EventGateway) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EventGateway", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EventGateway.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy((EventGateway) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EventGatewayProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy extends RuleLanguage implements BindableProxy {
      private BindableProxyAgent<RuleLanguage> agent;
      private RuleLanguage target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy() {
        this(new RuleLanguage());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy(RuleLanguage targetVal) {
        agent = new BindableProxyAgent<RuleLanguage>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(RuleLanguage.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public RuleLanguage unwrap() {
        return target;
      }

      public RuleLanguage deepUnwrap() {
        final RuleLanguage clone = new RuleLanguage();
        final RuleLanguage t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("RuleLanguage", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (RuleLanguage) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("RuleLanguage", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(RuleLanguage.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy((RuleLanguage) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleLanguageProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy extends BPMNDefinitionSet implements BindableProxy {
      private BindableProxyAgent<BPMNDefinitionSet> agent;
      private BPMNDefinitionSet target;
      public org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy() {
        this(new BPMNDefinitionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy(BPMNDefinitionSet targetVal) {
        agent = new BindableProxyAgent<BPMNDefinitionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("this", new PropertyType(BPMNDefinitionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BPMNDefinitionSet unwrap() {
        return target;
      }

      public BPMNDefinitionSet deepUnwrap() {
        final BPMNDefinitionSet clone = new BPMNDefinitionSet();
        final BPMNDefinitionSet t = unwrap();
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Object get(String property) {
        switch (property) {
          case "this": return target;
          default: throw new NonExistingPropertyException("BPMNDefinitionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "this": target = (BPMNDefinitionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BPMNDefinitionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BPMNDefinitionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy((BPMNDefinitionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_BPMNDefinitionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy extends MultipleInstanceCompletionCondition implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceCompletionCondition> agent;
      private MultipleInstanceCompletionCondition target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy() {
        this(new MultipleInstanceCompletionCondition());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy(MultipleInstanceCompletionCondition targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceCompletionCondition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceCompletionCondition unwrap() {
        return target;
      }

      public MultipleInstanceCompletionCondition deepUnwrap() {
        final MultipleInstanceCompletionCondition clone = new MultipleInstanceCompletionCondition();
        final MultipleInstanceCompletionCondition t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceCompletionCondition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (MultipleInstanceCompletionCondition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceCompletionCondition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceCompletionCondition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy((MultipleInstanceCompletionCondition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCompletionConditionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy extends BaseSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<BaseSubprocessTaskExecutionSet> agent;
      private BaseSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy() {
        this(new BaseSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy(BaseSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<BaseSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(BaseSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BaseSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public BaseSubprocessTaskExecutionSet deepUnwrap() {
        final BaseSubprocessTaskExecutionSet clone = new BaseSubprocessTaskExecutionSet();
        final BaseSubprocessTaskExecutionSet t = unwrap();
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("BaseSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (BaseSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BaseSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BaseSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy((BaseSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_BaseSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy extends GenericServiceTask implements BindableProxy {
      private BindableProxyAgent<GenericServiceTask> agent;
      private GenericServiceTask target;
      public org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy() {
        this(new GenericServiceTask());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy(GenericServiceTask targetVal) {
        agent = new BindableProxyAgent<GenericServiceTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(GenericServiceTaskExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(GenericServiceTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GenericServiceTask unwrap() {
        return target;
      }

      public GenericServiceTask deepUnwrap() {
        final GenericServiceTask clone = new GenericServiceTask();
        final GenericServiceTask t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((GenericServiceTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((GenericServiceTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public GenericServiceTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(GenericServiceTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (GenericServiceTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Object get(String property) {
        switch (property) {
          case "labels": return getLabels();
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "this": return target;
          default: throw new NonExistingPropertyException("GenericServiceTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((GenericServiceTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (GenericServiceTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GenericServiceTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void setDataIOSet(DataIOSet a0) {
        target.setDataIOSet(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(GenericServiceTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy((GenericServiceTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_GenericServiceTaskProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy extends ConditionExpression implements BindableProxy {
      private BindableProxyAgent<ConditionExpression> agent;
      private ConditionExpression target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy() {
        this(new ConditionExpression());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy(ConditionExpression targetVal) {
        agent = new BindableProxyAgent<ConditionExpression>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ScriptTypeValue.class, true, false));
        p.put("this", new PropertyType(ConditionExpression.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ConditionExpression unwrap() {
        return target;
      }

      public ConditionExpression deepUnwrap() {
        final ConditionExpression clone = new ConditionExpression();
        final ConditionExpression t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ScriptTypeValue getValue() {
        return target.getValue();
      }

      public void setValue(ScriptTypeValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ScriptTypeValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ConditionExpression", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ScriptTypeValue) value);
          break;
          case "this": target = (ConditionExpression) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ConditionExpression", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ConditionExpression.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy((ConditionExpression) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_common_ConditionExpressionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy extends InputClauseLiteralExpression implements BindableProxy {
      private BindableProxyAgent<InputClauseLiteralExpression> agent;
      private InputClauseLiteralExpression target;
      public org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy() {
        this(new InputClauseLiteralExpression());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy(InputClauseLiteralExpression targetVal) {
        agent = new BindableProxyAgent<InputClauseLiteralExpression>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("typeRefHolder", new PropertyType(QNameHolder.class, true, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("importedValues", new PropertyType(ImportedValues.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InputClauseLiteralExpression.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InputClauseLiteralExpression unwrap() {
        return target;
      }

      public InputClauseLiteralExpression deepUnwrap() {
        final InputClauseLiteralExpression clone = new InputClauseLiteralExpression();
        final InputClauseLiteralExpression t = unwrap();
        clone.setParent(t.getParent());
        if (t.getTypeRefHolder() instanceof BindableProxy) {
          clone.setTypeRefHolder((QNameHolder) ((BindableProxy) getTypeRefHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTypeRefHolder())) {
          clone.setTypeRefHolder((QNameHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTypeRefHolder())).deepUnwrap());
        } else {
          clone.setTypeRefHolder(t.getTypeRefHolder());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getImportedValues() instanceof BindableProxy) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) getImportedValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImportedValues())) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImportedValues())).deepUnwrap());
        } else {
          clone.setImportedValues(t.getImportedValues());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public QNameHolder getTypeRefHolder() {
        return target.getTypeRefHolder();
      }

      public void setTypeRefHolder(QNameHolder typeRefHolder) {
        if (agent.binders.containsKey("typeRefHolder")) {
          typeRefHolder = (QNameHolder) agent.binders.get("typeRefHolder").setModel(typeRefHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("typeRefHolder", typeRefHolder);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public ImportedValues getImportedValues() {
        return target.getImportedValues();
      }

      public void setImportedValues(ImportedValues importedValues) {
        if (agent.binders.containsKey("importedValues")) {
          importedValues = (ImportedValues) agent.binders.get("importedValues").setModel(importedValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("importedValues", importedValues);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public Id getId() {
        return target.getId();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "typeRefHolder": return getTypeRefHolder();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "importedValues": return getImportedValues();
          case "nsContext": return getNsContext();
          case "hasTypeRefs": return getHasTypeRefs();
          case "id": return getId();
          case "text": return getText();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InputClauseLiteralExpression", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "typeRefHolder": target.setTypeRefHolder((QNameHolder) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "importedValues": target.setImportedValues((ImportedValues) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InputClauseLiteralExpression) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InputClauseLiteralExpression", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InputClauseLiteralExpression.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy((InputClauseLiteralExpression) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InputClauseLiteralExpressionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy extends MultipleInstanceSubprocess implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceSubprocess> agent;
      private MultipleInstanceSubprocess target;
      public org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy() {
        this(new MultipleInstanceSubprocess());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy(MultipleInstanceSubprocess targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("processData", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(MultipleInstanceSubprocessTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceSubprocess unwrap() {
        return target;
      }

      public MultipleInstanceSubprocess deepUnwrap() {
        final MultipleInstanceSubprocess clone = new MultipleInstanceSubprocess();
        final MultipleInstanceSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((MultipleInstanceSubprocessTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((MultipleInstanceSubprocessTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public MultipleInstanceSubprocessTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(MultipleInstanceSubprocessTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (MultipleInstanceSubprocessTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "processData": return getProcessData();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "processData": target.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((MultipleInstanceSubprocessTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (MultipleInstanceSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy((MultipleInstanceSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_MultipleInstanceSubprocessProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy extends InputClause implements BindableProxy {
      private BindableProxyAgent<InputClause> agent;
      private InputClause target;
      public org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy() {
        this(new InputClause());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy(InputClause targetVal) {
        agent = new BindableProxyAgent<InputClause>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("inputExpression", new PropertyType(InputClauseLiteralExpression.class, true, false));
        p.put("inputValues", new PropertyType(InputClauseUnaryTests.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InputClause.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InputClause unwrap() {
        return target;
      }

      public InputClause deepUnwrap() {
        final InputClause clone = new InputClause();
        final InputClause t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getInputExpression() instanceof BindableProxy) {
          clone.setInputExpression((InputClauseLiteralExpression) ((BindableProxy) getInputExpression()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getInputExpression())) {
          clone.setInputExpression((InputClauseLiteralExpression) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getInputExpression())).deepUnwrap());
        } else {
          clone.setInputExpression(t.getInputExpression());
        }
        if (t.getInputValues() instanceof BindableProxy) {
          clone.setInputValues((InputClauseUnaryTests) ((BindableProxy) getInputValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getInputValues())) {
          clone.setInputValues((InputClauseUnaryTests) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getInputValues())).deepUnwrap());
        } else {
          clone.setInputValues(t.getInputValues());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public InputClauseLiteralExpression getInputExpression() {
        return target.getInputExpression();
      }

      public void setInputExpression(InputClauseLiteralExpression inputExpression) {
        if (agent.binders.containsKey("inputExpression")) {
          inputExpression = (InputClauseLiteralExpression) agent.binders.get("inputExpression").setModel(inputExpression, StateSync.FROM_MODEL, true);
        }
        changeAndFire("inputExpression", inputExpression);
      }

      public InputClauseUnaryTests getInputValues() {
        return target.getInputValues();
      }

      public void setInputValues(InputClauseUnaryTests inputValues) {
        if (agent.binders.containsKey("inputValues")) {
          inputValues = (InputClauseUnaryTests) agent.binders.get("inputValues").setModel(inputValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("inputValues", inputValues);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "nsContext": return getNsContext();
          case "hasTypeRefs": return getHasTypeRefs();
          case "id": return getId();
          case "inputExpression": return getInputExpression();
          case "inputValues": return getInputValues();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InputClause", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "inputExpression": target.setInputExpression((InputClauseLiteralExpression) value);
          break;
          case "inputValues": target.setInputValues((InputClauseUnaryTests) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InputClause) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InputClause", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InputClause.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy((InputClause) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InputClauseProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy extends TimeUnit implements BindableProxy {
      private BindableProxyAgent<TimeUnit> agent;
      private TimeUnit target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy() {
        this(new TimeUnit());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy(TimeUnit targetVal) {
        agent = new BindableProxyAgent<TimeUnit>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TimeUnit.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TimeUnit unwrap() {
        return target;
      }

      public TimeUnit deepUnwrap() {
        final TimeUnit clone = new TimeUnit();
        final TimeUnit t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("TimeUnit", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (TimeUnit) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TimeUnit", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TimeUnit.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy((TimeUnit) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_TimeUnitProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy extends IntermediateEscalationEvent implements BindableProxy {
      private BindableProxyAgent<IntermediateEscalationEvent> agent;
      private IntermediateEscalationEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy() {
        this(new IntermediateEscalationEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy(IntermediateEscalationEvent targetVal) {
        agent = new BindableProxyAgent<IntermediateEscalationEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CancellingEscalationEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateEscalationEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateEscalationEvent unwrap() {
        return target;
      }

      public IntermediateEscalationEvent deepUnwrap() {
        final IntermediateEscalationEvent clone = new IntermediateEscalationEvent();
        final IntermediateEscalationEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CancellingEscalationEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CancellingEscalationEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CancellingEscalationEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CancellingEscalationEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CancellingEscalationEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateEscalationEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CancellingEscalationEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateEscalationEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateEscalationEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateEscalationEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy((IntermediateEscalationEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy extends ScriptTypeValue implements BindableProxy {
      private BindableProxyAgent<ScriptTypeValue> agent;
      private ScriptTypeValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy() {
        this(new ScriptTypeValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy(ScriptTypeValue targetVal) {
        agent = new BindableProxyAgent<ScriptTypeValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("language", new PropertyType(String.class, false, false));
        p.put("script", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ScriptTypeValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScriptTypeValue unwrap() {
        return target;
      }

      public ScriptTypeValue deepUnwrap() {
        final ScriptTypeValue clone = new ScriptTypeValue();
        final ScriptTypeValue t = unwrap();
        clone.setLanguage(t.getLanguage());
        clone.setScript(t.getScript());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getLanguage() {
        return target.getLanguage();
      }

      public void setLanguage(String language) {
        changeAndFire("language", language);
      }

      public String getScript() {
        return target.getScript();
      }

      public void setScript(String script) {
        changeAndFire("script", script);
      }

      public Object get(String property) {
        switch (property) {
          case "language": return getLanguage();
          case "script": return getScript();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScriptTypeValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "language": target.setLanguage((String) value);
          break;
          case "script": target.setScript((String) value);
          break;
          case "this": target = (ScriptTypeValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScriptTypeValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ScriptTypeValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy((ScriptTypeValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeValueProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy extends CharacterMultipleInputFieldDefinition implements BindableProxy {
      private BindableProxyAgent<CharacterMultipleInputFieldDefinition> agent;
      private CharacterMultipleInputFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy() {
        this(new CharacterMultipleInputFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy(CharacterMultipleInputFieldDefinition targetVal) {
        agent = new BindableProxyAgent<CharacterMultipleInputFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("pageSize", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(CharacterMultipleInputFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CharacterMultipleInputFieldDefinition unwrap() {
        return target;
      }

      public CharacterMultipleInputFieldDefinition deepUnwrap() {
        final CharacterMultipleInputFieldDefinition clone = new CharacterMultipleInputFieldDefinition();
        final CharacterMultipleInputFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setPageSize(t.getPageSize());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getPageSize() {
        return target.getPageSize();
      }

      public void setPageSize(Integer pageSize) {
        changeAndFire("pageSize", pageSize);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "pageSize": return getPageSize();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("CharacterMultipleInputFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "pageSize": target.setPageSize((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (CharacterMultipleInputFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CharacterMultipleInputFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(CharacterMultipleInputFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy((CharacterMultipleInputFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_CharacterMultipleInputFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy extends DMNDiagram implements BindableProxy {
      private BindableProxyAgent<DMNDiagram> agent;
      private DMNDiagram target;
      public org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy() {
        this(new DMNDiagram());
      }

      public org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy(DMNDiagram targetVal) {
        agent = new BindableProxyAgent<DMNDiagram>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("definitions", new PropertyType(Definitions.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(DMNDiagram.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DMNDiagram unwrap() {
        return target;
      }

      public DMNDiagram deepUnwrap() {
        final DMNDiagram clone = new DMNDiagram();
        final DMNDiagram t = unwrap();
        clone.setParent(t.getParent());
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getDefinitions() instanceof BindableProxy) {
          clone.setDefinitions((Definitions) ((BindableProxy) getDefinitions()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDefinitions())) {
          clone.setDefinitions((Definitions) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDefinitions())).deepUnwrap());
        } else {
          clone.setDefinitions(t.getDefinitions());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public Definitions getDefinitions() {
        return target.getDefinitions();
      }

      public void setDefinitions(Definitions definitions) {
        if (agent.binders.containsKey("definitions")) {
          definitions = (Definitions) agent.binders.get("definitions").setModel(definitions, StateSync.FROM_MODEL, true);
        }
        changeAndFire("definitions", definitions);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "nsContext": return getNsContext();
          case "stunnerLabels": return getStunnerLabels();
          case "id": return getId();
          case "definitions": return getDefinitions();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("DMNDiagram", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "definitions": target.setDefinitions((Definitions) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (DMNDiagram) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DMNDiagram", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(DMNDiagram.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy((DMNDiagram) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_DMNDiagramProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy extends NoneTask implements BindableProxy {
      private BindableProxyAgent<NoneTask> agent;
      private NoneTask target;
      public org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy() {
        this(new NoneTask());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy(NoneTask targetVal) {
        agent = new BindableProxyAgent<NoneTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(EmptyTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(NoneTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NoneTask unwrap() {
        return target;
      }

      public NoneTask deepUnwrap() {
        final NoneTask clone = new NoneTask();
        final NoneTask t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((EmptyTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((EmptyTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public EmptyTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(EmptyTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (EmptyTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("NoneTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((EmptyTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (NoneTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NoneTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(NoneTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy((NoneTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_NoneTaskProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy extends DiagramSet implements BindableProxy {
      private BindableProxyAgent<DiagramSet> agent;
      private DiagramSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy() {
        this(new DiagramSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy(DiagramSet targetVal) {
        agent = new BindableProxyAgent<DiagramSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("globalVariables", new PropertyType(GlobalVariables.class, true, false));
        p.put("processInstanceDescription", new PropertyType(ProcessInstanceDescription.class, true, false));
        p.put("imports", new PropertyType(Imports.class, true, false));
        p.put("packageProperty", new PropertyType(Package.class, true, false));
        p.put("documentation", new PropertyType(Documentation.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("name", new PropertyType(Name.class, true, false));
        p.put("id", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id.class, true, false));
        p.put("adHoc", new PropertyType(AdHoc.class, true, false));
        p.put("version", new PropertyType(Version.class, true, false));
        p.put("executable", new PropertyType(Executable.class, true, false));
        p.put("this", new PropertyType(DiagramSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DiagramSet unwrap() {
        return target;
      }

      public DiagramSet deepUnwrap() {
        final DiagramSet clone = new DiagramSet();
        final DiagramSet t = unwrap();
        if (t.getGlobalVariables() instanceof BindableProxy) {
          clone.setGlobalVariables((GlobalVariables) ((BindableProxy) getGlobalVariables()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGlobalVariables())) {
          clone.setGlobalVariables((GlobalVariables) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGlobalVariables())).deepUnwrap());
        } else {
          clone.setGlobalVariables(t.getGlobalVariables());
        }
        if (t.getProcessInstanceDescription() instanceof BindableProxy) {
          clone.setProcessInstanceDescription((ProcessInstanceDescription) ((BindableProxy) getProcessInstanceDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessInstanceDescription())) {
          clone.setProcessInstanceDescription((ProcessInstanceDescription) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessInstanceDescription())).deepUnwrap());
        } else {
          clone.setProcessInstanceDescription(t.getProcessInstanceDescription());
        }
        if (t.getImports() instanceof BindableProxy) {
          clone.setImports((Imports) ((BindableProxy) getImports()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImports())) {
          clone.setImports((Imports) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImports())).deepUnwrap());
        } else {
          clone.setImports(t.getImports());
        }
        if (t.getPackageProperty() instanceof BindableProxy) {
          clone.setPackageProperty((Package) ((BindableProxy) getPackageProperty()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getPackageProperty())) {
          clone.setPackageProperty((Package) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getPackageProperty())).deepUnwrap());
        } else {
          clone.setPackageProperty(t.getPackageProperty());
        }
        if (t.getDocumentation() instanceof BindableProxy) {
          clone.setDocumentation((Documentation) ((BindableProxy) getDocumentation()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDocumentation())) {
          clone.setDocumentation((Documentation) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDocumentation())).deepUnwrap());
        } else {
          clone.setDocumentation(t.getDocumentation());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getAdHoc() instanceof BindableProxy) {
          clone.setAdHoc((AdHoc) ((BindableProxy) getAdHoc()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHoc())) {
          clone.setAdHoc((AdHoc) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHoc())).deepUnwrap());
        } else {
          clone.setAdHoc(t.getAdHoc());
        }
        if (t.getVersion() instanceof BindableProxy) {
          clone.setVersion((Version) ((BindableProxy) getVersion()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getVersion())) {
          clone.setVersion((Version) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getVersion())).deepUnwrap());
        } else {
          clone.setVersion(t.getVersion());
        }
        if (t.getExecutable() instanceof BindableProxy) {
          clone.setExecutable((Executable) ((BindableProxy) getExecutable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutable())) {
          clone.setExecutable((Executable) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutable())).deepUnwrap());
        } else {
          clone.setExecutable(t.getExecutable());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public GlobalVariables getGlobalVariables() {
        return target.getGlobalVariables();
      }

      public void setGlobalVariables(GlobalVariables globalVariables) {
        if (agent.binders.containsKey("globalVariables")) {
          globalVariables = (GlobalVariables) agent.binders.get("globalVariables").setModel(globalVariables, StateSync.FROM_MODEL, true);
        }
        changeAndFire("globalVariables", globalVariables);
      }

      public ProcessInstanceDescription getProcessInstanceDescription() {
        return target.getProcessInstanceDescription();
      }

      public void setProcessInstanceDescription(ProcessInstanceDescription processInstanceDescription) {
        if (agent.binders.containsKey("processInstanceDescription")) {
          processInstanceDescription = (ProcessInstanceDescription) agent.binders.get("processInstanceDescription").setModel(processInstanceDescription, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processInstanceDescription", processInstanceDescription);
      }

      public Imports getImports() {
        return target.getImports();
      }

      public void setImports(Imports imports) {
        if (agent.binders.containsKey("imports")) {
          imports = (Imports) agent.binders.get("imports").setModel(imports, StateSync.FROM_MODEL, true);
        }
        changeAndFire("imports", imports);
      }

      public Package getPackageProperty() {
        return target.getPackageProperty();
      }

      public void setPackageProperty(Package packageProperty) {
        if (agent.binders.containsKey("packageProperty")) {
          packageProperty = (Package) agent.binders.get("packageProperty").setModel(packageProperty, StateSync.FROM_MODEL, true);
        }
        changeAndFire("packageProperty", packageProperty);
      }

      public Documentation getDocumentation() {
        return target.getDocumentation();
      }

      public void setDocumentation(Documentation documentation) {
        if (agent.binders.containsKey("documentation")) {
          documentation = (Documentation) agent.binders.get("documentation").setModel(documentation, StateSync.FROM_MODEL, true);
        }
        changeAndFire("documentation", documentation);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Name getName() {
        return target.getName();
      }

      public void setName(Name name) {
        if (agent.binders.containsKey("name")) {
          name = (Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id getId() {
        return target.getId();
      }

      public void setId(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id id) {
        if (agent.binders.containsKey("id")) {
          id = (org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public AdHoc getAdHoc() {
        return target.getAdHoc();
      }

      public void setAdHoc(AdHoc adHoc) {
        if (agent.binders.containsKey("adHoc")) {
          adHoc = (AdHoc) agent.binders.get("adHoc").setModel(adHoc, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHoc", adHoc);
      }

      public Version getVersion() {
        return target.getVersion();
      }

      public void setVersion(Version version) {
        if (agent.binders.containsKey("version")) {
          version = (Version) agent.binders.get("version").setModel(version, StateSync.FROM_MODEL, true);
        }
        changeAndFire("version", version);
      }

      public Executable getExecutable() {
        return target.getExecutable();
      }

      public void setExecutable(Executable executable) {
        if (agent.binders.containsKey("executable")) {
          executable = (Executable) agent.binders.get("executable").setModel(executable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executable", executable);
      }

      public Object get(String property) {
        switch (property) {
          case "globalVariables": return getGlobalVariables();
          case "processInstanceDescription": return getProcessInstanceDescription();
          case "imports": return getImports();
          case "packageProperty": return getPackageProperty();
          case "documentation": return getDocumentation();
          case "slaDueDate": return getSlaDueDate();
          case "name": return getName();
          case "id": return getId();
          case "adHoc": return getAdHoc();
          case "version": return getVersion();
          case "executable": return getExecutable();
          case "this": return target;
          default: throw new NonExistingPropertyException("DiagramSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "globalVariables": target.setGlobalVariables((GlobalVariables) value);
          break;
          case "processInstanceDescription": target.setProcessInstanceDescription((ProcessInstanceDescription) value);
          break;
          case "imports": target.setImports((Imports) value);
          break;
          case "packageProperty": target.setPackageProperty((Package) value);
          break;
          case "documentation": target.setDocumentation((Documentation) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "name": target.setName((Name) value);
          break;
          case "id": target.setId((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) value);
          break;
          case "adHoc": target.setAdHoc((AdHoc) value);
          break;
          case "version": target.setVersion((Version) value);
          break;
          case "executable": target.setExecutable((Executable) value);
          break;
          case "this": target = (DiagramSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DiagramSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DiagramSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy((DiagramSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_DiagramSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy extends LiteralExpressionPMMLDocumentModel implements BindableProxy {
      private BindableProxyAgent<LiteralExpressionPMMLDocumentModel> agent;
      private LiteralExpressionPMMLDocumentModel target;
      public org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy() {
        this(new LiteralExpressionPMMLDocumentModel());
      }

      public org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy(LiteralExpressionPMMLDocumentModel targetVal) {
        agent = new BindableProxyAgent<LiteralExpressionPMMLDocumentModel>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("expressionLanguage", new PropertyType(ExpressionLanguage.class, true, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("importedValues", new PropertyType(ImportedValues.class, true, false));
        p.put("requiredComponentWidthCount", new PropertyType(Integer.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("componentWidths", new PropertyType(List.class, false, true));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(LiteralExpressionPMMLDocumentModel.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public LiteralExpressionPMMLDocumentModel unwrap() {
        return target;
      }

      public LiteralExpressionPMMLDocumentModel deepUnwrap() {
        final LiteralExpressionPMMLDocumentModel clone = new LiteralExpressionPMMLDocumentModel();
        final LiteralExpressionPMMLDocumentModel t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getExpressionLanguage() instanceof BindableProxy) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) getExpressionLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExpressionLanguage())) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExpressionLanguage())).deepUnwrap());
        } else {
          clone.setExpressionLanguage(t.getExpressionLanguage());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getImportedValues() instanceof BindableProxy) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) getImportedValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImportedValues())) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImportedValues())).deepUnwrap());
        } else {
          clone.setImportedValues(t.getImportedValues());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public ExpressionLanguage getExpressionLanguage() {
        return target.getExpressionLanguage();
      }

      public void setExpressionLanguage(ExpressionLanguage expressionLanguage) {
        if (agent.binders.containsKey("expressionLanguage")) {
          expressionLanguage = (ExpressionLanguage) agent.binders.get("expressionLanguage").setModel(expressionLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("expressionLanguage", expressionLanguage);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public ImportedValues getImportedValues() {
        return target.getImportedValues();
      }

      public void setImportedValues(ImportedValues importedValues) {
        if (agent.binders.containsKey("importedValues")) {
          importedValues = (ImportedValues) agent.binders.get("importedValues").setModel(importedValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("importedValues", importedValues);
      }

      public int getRequiredComponentWidthCount() {
        return target.getRequiredComponentWidthCount();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getComponentWidths() {
        return target.getComponentWidths();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "expressionLanguage": return getExpressionLanguage();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "importedValues": return getImportedValues();
          case "requiredComponentWidthCount": return getRequiredComponentWidthCount();
          case "nsContext": return getNsContext();
          case "componentWidths": return getComponentWidths();
          case "hasTypeRefs": return getHasTypeRefs();
          case "text": return getText();
          case "id": return getId();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("LiteralExpressionPMMLDocumentModel", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "expressionLanguage": target.setExpressionLanguage((ExpressionLanguage) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "importedValues": target.setImportedValues((ImportedValues) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (LiteralExpressionPMMLDocumentModel) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("LiteralExpressionPMMLDocumentModel", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(LiteralExpressionPMMLDocumentModel.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy((LiteralExpressionPMMLDocumentModel) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentModelProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy extends MultipleSubFormFieldDefinition implements BindableProxy {
      private BindableProxyAgent<MultipleSubFormFieldDefinition> agent;
      private MultipleSubFormFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy() {
        this(new MultipleSubFormFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy(MultipleSubFormFieldDefinition targetVal) {
        agent = new BindableProxyAgent<MultipleSubFormFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("container", new PropertyType(Container.class, false, false));
        p.put("creationForm", new PropertyType(String.class, false, false));
        p.put("columnMetas", new PropertyType(List.class, false, true));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("editionForm", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(MultipleSubFormFieldType.class, false, false));
        p.put("this", new PropertyType(MultipleSubFormFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleSubFormFieldDefinition unwrap() {
        return target;
      }

      public MultipleSubFormFieldDefinition deepUnwrap() {
        final MultipleSubFormFieldDefinition clone = new MultipleSubFormFieldDefinition();
        final MultipleSubFormFieldDefinition t = unwrap();
        clone.setContainer(t.getContainer());
        clone.setCreationForm(t.getCreationForm());
        if (t.getColumnMetas() != null) {
          final List columnMetasClone = new ArrayList();
          for (Object columnMetasElem : t.getColumnMetas()) {
            if (columnMetasElem instanceof BindableProxy) {
              columnMetasClone.add(((BindableProxy) columnMetasElem).deepUnwrap());
            } else {
              columnMetasClone.add(columnMetasElem);
            }
          }
          clone.setColumnMetas(columnMetasClone);
        }
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setEditionForm(t.getEditionForm());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Container getContainer() {
        return target.getContainer();
      }

      public void setContainer(Container container) {
        changeAndFire("container", container);
      }

      public String getCreationForm() {
        return target.getCreationForm();
      }

      public void setCreationForm(String creationForm) {
        changeAndFire("creationForm", creationForm);
      }

      public List getColumnMetas() {
        return target.getColumnMetas();
      }

      public void setColumnMetas(List<TableColumnMeta> columnMetas) {
        List<TableColumnMeta> oldValue = target.getColumnMetas();
        columnMetas = agent.ensureBoundListIsProxied("columnMetas", columnMetas);
        target.setColumnMetas(columnMetas);
        agent.updateWidgetsAndFireEvent(true, "columnMetas", oldValue, columnMetas);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public String getEditionForm() {
        return target.getEditionForm();
      }

      public void setEditionForm(String editionForm) {
        changeAndFire("editionForm", editionForm);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public MultipleSubFormFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "container": return getContainer();
          case "creationForm": return getCreationForm();
          case "columnMetas": return getColumnMetas();
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "editionForm": return getEditionForm();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleSubFormFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "container": target.setContainer((Container) value);
          break;
          case "creationForm": target.setCreationForm((String) value);
          break;
          case "columnMetas": target.setColumnMetas((List<TableColumnMeta>) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "editionForm": target.setEditionForm((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (MultipleSubFormFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleSubFormFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleSubFormFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy((MultipleSubFormFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_multipleSubform_definition_MultipleSubFormFieldDefinitionProxy();
      }
    });
    class org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy extends TimerInstanceSummary implements BindableProxy {
      private BindableProxyAgent<TimerInstanceSummary> agent;
      private TimerInstanceSummary target;
      public org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy() {
        this(new TimerInstanceSummary());
      }

      public org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy(TimerInstanceSummary targetVal) {
        agent = new BindableProxyAgent<TimerInstanceSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("lastFireTime", new PropertyType(Date.class, false, false));
        p.put("processInstanceId", new PropertyType(Long.class, false, false));
        p.put("period", new PropertyType(Long.class, false, false));
        p.put("repeatLimit", new PropertyType(Integer.class, false, false));
        p.put("nextFireTime", new PropertyType(Date.class, false, false));
        p.put("description", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("timerId", new PropertyType(Long.class, false, false));
        p.put("delay", new PropertyType(Long.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("activationTime", new PropertyType(Date.class, false, false));
        p.put("relative", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(TimerInstanceSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TimerInstanceSummary unwrap() {
        return target;
      }

      public TimerInstanceSummary deepUnwrap() {
        final TimerInstanceSummary clone = new TimerInstanceSummary();
        final TimerInstanceSummary t = unwrap();
        clone.setLastFireTime(t.getLastFireTime());
        clone.setProcessInstanceId(t.getProcessInstanceId());
        clone.setPeriod(t.getPeriod());
        clone.setRepeatLimit(t.getRepeatLimit());
        clone.setNextFireTime(t.getNextFireTime());
        clone.setDescription(t.getDescription());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setTimerId(t.getTimerId());
        clone.setDelay(t.getDelay());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setActivationTime(t.getActivationTime());
        clone.setRelative(t.isRelative());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy) {
          obj = ((org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Date getLastFireTime() {
        return target.getLastFireTime();
      }

      public void setLastFireTime(Date lastFireTime) {
        changeAndFire("lastFireTime", lastFireTime);
      }

      public Long getProcessInstanceId() {
        return target.getProcessInstanceId();
      }

      public void setProcessInstanceId(Long processInstanceId) {
        changeAndFire("processInstanceId", processInstanceId);
      }

      public Long getPeriod() {
        return target.getPeriod();
      }

      public void setPeriod(Long period) {
        changeAndFire("period", period);
      }

      public Integer getRepeatLimit() {
        return target.getRepeatLimit();
      }

      public void setRepeatLimit(Integer repeatLimit) {
        changeAndFire("repeatLimit", repeatLimit);
      }

      public Date getNextFireTime() {
        return target.getNextFireTime();
      }

      public void setNextFireTime(Date nextFireTime) {
        changeAndFire("nextFireTime", nextFireTime);
      }

      public String getDescription() {
        return target.getDescription();
      }

      public void setDescription(String description) {
        changeAndFire("description", description);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public Long getTimerId() {
        return target.getTimerId();
      }

      public void setTimerId(Long timerId) {
        changeAndFire("timerId", timerId);
      }

      public Long getDelay() {
        return target.getDelay();
      }

      public void setDelay(Long delay) {
        changeAndFire("delay", delay);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public Date getActivationTime() {
        return target.getActivationTime();
      }

      public void setActivationTime(Date activationTime) {
        changeAndFire("activationTime", activationTime);
      }

      public Boolean isRelative() {
        return target.isRelative();
      }

      public void setRelative(Boolean relative) {
        changeAndFire("relative", relative);
      }

      public Object get(String property) {
        switch (property) {
          case "lastFireTime": return getLastFireTime();
          case "processInstanceId": return getProcessInstanceId();
          case "period": return getPeriod();
          case "repeatLimit": return getRepeatLimit();
          case "nextFireTime": return getNextFireTime();
          case "description": return getDescription();
          case "callbacks": return getCallbacks();
          case "label": return getLabel();
          case "timerId": return getTimerId();
          case "delay": return getDelay();
          case "name": return getName();
          case "id": return getId();
          case "activationTime": return getActivationTime();
          case "relative": return isRelative();
          case "this": return target;
          default: throw new NonExistingPropertyException("TimerInstanceSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "lastFireTime": target.setLastFireTime((Date) value);
          break;
          case "processInstanceId": target.setProcessInstanceId((Long) value);
          break;
          case "period": target.setPeriod((Long) value);
          break;
          case "repeatLimit": target.setRepeatLimit((Integer) value);
          break;
          case "nextFireTime": target.setNextFireTime((Date) value);
          break;
          case "description": target.setDescription((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "timerId": target.setTimerId((Long) value);
          break;
          case "delay": target.setDelay((Long) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "activationTime": target.setActivationTime((Date) value);
          break;
          case "relative": target.setRelative((Boolean) value);
          break;
          case "this": target = (TimerInstanceSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TimerInstanceSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(TimerInstanceSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy((TimerInstanceSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_pr_model_TimerInstanceSummaryProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy extends IntegerRadioGroupFieldDefinition implements BindableProxy {
      private BindableProxyAgent<IntegerRadioGroupFieldDefinition> agent;
      private IntegerRadioGroupFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy() {
        this(new IntegerRadioGroupFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy(IntegerRadioGroupFieldDefinition targetVal) {
        agent = new BindableProxyAgent<IntegerRadioGroupFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Long.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("inline", new PropertyType(Boolean.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(RadioGroupFieldType.class, false, false));
        p.put("this", new PropertyType(IntegerRadioGroupFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerRadioGroupFieldDefinition unwrap() {
        return target;
      }

      public IntegerRadioGroupFieldDefinition deepUnwrap() {
        final IntegerRadioGroupFieldDefinition clone = new IntegerRadioGroupFieldDefinition();
        final IntegerRadioGroupFieldDefinition t = unwrap();
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setInline(t.getInline());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Long getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Long defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Boolean getInline() {
        return target.getInline();
      }

      public void setInline(Boolean inline) {
        changeAndFire("inline", inline);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<IntegerSelectorOption> options) {
        List<IntegerSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public RadioGroupFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "inline": return getInline();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerRadioGroupFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Long) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "inline": target.setInline((Boolean) value);
          break;
          case "options": target.setOptions((List<IntegerSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (IntegerRadioGroupFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerRadioGroupFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerRadioGroupFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy((IntegerRadioGroupFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_IntegerRadioGroupFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy extends AdHocAutostart implements BindableProxy {
      private BindableProxyAgent<AdHocAutostart> agent;
      private AdHocAutostart target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy() {
        this(new AdHocAutostart());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy(AdHocAutostart targetVal) {
        agent = new BindableProxyAgent<AdHocAutostart>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(AdHocAutostart.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHocAutostart unwrap() {
        return target;
      }

      public AdHocAutostart deepUnwrap() {
        final AdHocAutostart clone = new AdHocAutostart();
        final AdHocAutostart t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocAutostart", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (AdHocAutostart) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocAutostart", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHocAutostart.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy((AdHocAutostart) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocAutostartProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy extends ErrorRef implements BindableProxy {
      private BindableProxyAgent<ErrorRef> agent;
      private ErrorRef target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy() {
        this(new ErrorRef());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy(ErrorRef targetVal) {
        agent = new BindableProxyAgent<ErrorRef>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ErrorRef.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ErrorRef unwrap() {
        return target;
      }

      public ErrorRef deepUnwrap() {
        final ErrorRef clone = new ErrorRef();
        final ErrorRef t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ErrorRef", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (ErrorRef) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ErrorRef", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ErrorRef.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy((ErrorRef) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorRefProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy extends WorkingHours implements BindableProxy {
      private BindableProxyAgent<WorkingHours> agent;
      private WorkingHours target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy() {
        this(new WorkingHours());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy(WorkingHours targetVal) {
        agent = new BindableProxyAgent<WorkingHours>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(WorkingHours.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public WorkingHours unwrap() {
        return target;
      }

      public WorkingHours deepUnwrap() {
        final WorkingHours clone = new WorkingHours();
        final WorkingHours t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("WorkingHours", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (WorkingHours) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("WorkingHours", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(WorkingHours.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy((WorkingHours) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_WorkingHoursProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy extends VariableRow implements BindableProxy {
      private BindableProxyAgent<VariableRow> agent;
      private VariableRow target;
      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy() {
        this(new VariableRow());
      }

      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy(VariableRow targetVal) {
        agent = new BindableProxyAgent<VariableRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("variableType", new PropertyType(VariableType.class, false, false));
        p.put("kpi", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("customDataType", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("dataTypeDisplayName", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(VariableRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public VariableRow unwrap() {
        return target;
      }

      public VariableRow deepUnwrap() {
        final VariableRow clone = new VariableRow();
        final VariableRow t = unwrap();
        clone.setVariableType(t.getVariableType());
        clone.setKpi(t.getKpi());
        clone.setName(t.getName());
        clone.setCustomDataType(t.getCustomDataType());
        clone.setId(t.getId());
        clone.setDataTypeDisplayName(t.getDataTypeDisplayName());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public VariableType getVariableType() {
        return target.getVariableType();
      }

      public void setVariableType(VariableType variableType) {
        changeAndFire("variableType", variableType);
      }

      public boolean getKpi() {
        return target.getKpi();
      }

      public void setKpi(boolean kpi) {
        changeAndFire("kpi", kpi);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getCustomDataType() {
        return target.getCustomDataType();
      }

      public void setCustomDataType(String customDataType) {
        changeAndFire("customDataType", customDataType);
      }

      public long getId() {
        return target.getId();
      }

      public void setId(long id) {
        changeAndFire("id", id);
      }

      public String getDataTypeDisplayName() {
        return target.getDataTypeDisplayName();
      }

      public void setDataTypeDisplayName(String dataTypeDisplayName) {
        changeAndFire("dataTypeDisplayName", dataTypeDisplayName);
      }

      public Object get(String property) {
        switch (property) {
          case "variableType": return getVariableType();
          case "kpi": return getKpi();
          case "name": return getName();
          case "customDataType": return getCustomDataType();
          case "id": return getId();
          case "dataTypeDisplayName": return getDataTypeDisplayName();
          case "this": return target;
          default: throw new NonExistingPropertyException("VariableRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "variableType": target.setVariableType((VariableType) value);
          break;
          case "kpi": target.setKpi((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "customDataType": target.setCustomDataType((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "dataTypeDisplayName": target.setDataTypeDisplayName((String) value);
          break;
          case "this": target = (VariableRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("VariableRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(VariableRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy((VariableRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_VariableRowProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy extends AssignmentsEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<AssignmentsEditorFieldDefinition> agent;
      private AssignmentsEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy() {
        this(new AssignmentsEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy(AssignmentsEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<AssignmentsEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(AssignmentsEditorFieldType.class, false, false));
        p.put("this", new PropertyType(AssignmentsEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AssignmentsEditorFieldDefinition unwrap() {
        return target;
      }

      public AssignmentsEditorFieldDefinition deepUnwrap() {
        final AssignmentsEditorFieldDefinition clone = new AssignmentsEditorFieldDefinition();
        final AssignmentsEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public AssignmentsEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("AssignmentsEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (AssignmentsEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AssignmentsEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(AssignmentsEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy((AssignmentsEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_AssignmentsEditorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_font_FontColourProxy extends FontColour implements BindableProxy {
      private BindableProxyAgent<FontColour> agent;
      private FontColour target;
      public org_kie_workbench_common_dmn_api_property_font_FontColourProxy() {
        this(new FontColour());
      }

      public org_kie_workbench_common_dmn_api_property_font_FontColourProxy(FontColour targetVal) {
        agent = new BindableProxyAgent<FontColour>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(FontColour.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontColour unwrap() {
        return target;
      }

      public FontColour deepUnwrap() {
        final FontColour clone = new FontColour();
        final FontColour t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_font_FontColourProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_font_FontColourProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontColour", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (FontColour) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontColour", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontColour.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_font_FontColourProxy((FontColour) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_font_FontColourProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy extends FontBorderSize implements BindableProxy {
      private BindableProxyAgent<FontBorderSize> agent;
      private FontBorderSize target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy() {
        this(new FontBorderSize());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy(FontBorderSize targetVal) {
        agent = new BindableProxyAgent<FontBorderSize>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(FontBorderSize.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontBorderSize unwrap() {
        return target;
      }

      public FontBorderSize deepUnwrap() {
        final FontBorderSize clone = new FontBorderSize();
        final FontBorderSize t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontBorderSize", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (FontBorderSize) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontBorderSize", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontBorderSize.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy((FontBorderSize) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderSizeProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy extends StandardDeviation implements BindableProxy {
      private BindableProxyAgent<StandardDeviation> agent;
      private StandardDeviation target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy() {
        this(new StandardDeviation());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy(StandardDeviation targetVal) {
        agent = new BindableProxyAgent<StandardDeviation>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(StandardDeviation.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StandardDeviation unwrap() {
        return target;
      }

      public StandardDeviation deepUnwrap() {
        final StandardDeviation clone = new StandardDeviation();
        final StandardDeviation t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("StandardDeviation", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (StandardDeviation) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StandardDeviation", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(StandardDeviation.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy((StandardDeviation) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_StandardDeviationProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_background_BorderColourProxy extends BorderColour implements BindableProxy {
      private BindableProxyAgent<BorderColour> agent;
      private BorderColour target;
      public org_kie_workbench_common_dmn_api_property_background_BorderColourProxy() {
        this(new BorderColour());
      }

      public org_kie_workbench_common_dmn_api_property_background_BorderColourProxy(BorderColour targetVal) {
        agent = new BindableProxyAgent<BorderColour>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(BorderColour.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BorderColour unwrap() {
        return target;
      }

      public BorderColour deepUnwrap() {
        final BorderColour clone = new BorderColour();
        final BorderColour t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_background_BorderColourProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_background_BorderColourProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("BorderColour", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (BorderColour) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BorderColour", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BorderColour.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_background_BorderColourProxy((BorderColour) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_background_BorderColourProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy extends ImportsValue implements BindableProxy {
      private BindableProxyAgent<ImportsValue> agent;
      private ImportsValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy() {
        this(new ImportsValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy(ImportsValue targetVal) {
        agent = new BindableProxyAgent<ImportsValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("wSDLImports", new PropertyType(List.class, false, true));
        p.put("defaultImports", new PropertyType(List.class, false, true));
        p.put("this", new PropertyType(ImportsValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ImportsValue unwrap() {
        return target;
      }

      public ImportsValue deepUnwrap() {
        final ImportsValue clone = new ImportsValue();
        final ImportsValue t = unwrap();
        if (t.getWSDLImports() != null) {
          final List wSDLImportsClone = new ArrayList();
          for (Object wSDLImportsElem : t.getWSDLImports()) {
            if (wSDLImportsElem instanceof BindableProxy) {
              wSDLImportsClone.add(((BindableProxy) wSDLImportsElem).deepUnwrap());
            } else {
              wSDLImportsClone.add(wSDLImportsElem);
            }
          }
          clone.setWSDLImports(wSDLImportsClone);
        }
        if (t.getDefaultImports() != null) {
          final List defaultImportsClone = new ArrayList();
          for (Object defaultImportsElem : t.getDefaultImports()) {
            if (defaultImportsElem instanceof BindableProxy) {
              defaultImportsClone.add(((BindableProxy) defaultImportsElem).deepUnwrap());
            } else {
              defaultImportsClone.add(defaultImportsElem);
            }
          }
          clone.setDefaultImports(defaultImportsClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public List getWSDLImports() {
        return target.getWSDLImports();
      }

      public void setWSDLImports(List<WSDLImport> wSDLImports) {
        List<WSDLImport> oldValue = target.getWSDLImports();
        wSDLImports = agent.ensureBoundListIsProxied("wSDLImports", wSDLImports);
        target.setWSDLImports(wSDLImports);
        agent.updateWidgetsAndFireEvent(true, "wSDLImports", oldValue, wSDLImports);
      }

      public List getDefaultImports() {
        return target.getDefaultImports();
      }

      public void setDefaultImports(List<DefaultImport> defaultImports) {
        List<DefaultImport> oldValue = target.getDefaultImports();
        defaultImports = agent.ensureBoundListIsProxied("defaultImports", defaultImports);
        target.setDefaultImports(defaultImports);
        agent.updateWidgetsAndFireEvent(true, "defaultImports", oldValue, defaultImports);
      }

      public Object get(String property) {
        switch (property) {
          case "wSDLImports": return getWSDLImports();
          case "defaultImports": return getDefaultImports();
          case "this": return target;
          default: throw new NonExistingPropertyException("ImportsValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "wSDLImports": target.setWSDLImports((List<WSDLImport>) value);
          break;
          case "defaultImports": target.setDefaultImports((List<DefaultImport>) value);
          break;
          case "this": target = (ImportsValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ImportsValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void addImport(DefaultImport a0) {
        target.addImport(a0);
        agent.updateWidgetsAndFireEvents();
      }

      public void addImport(WSDLImport a0) {
        target.addImport(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ImportsValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy((ImportsValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsValueProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_font_FontSetProxy extends org.kie.workbench.common.dmn.api.property.font.FontSet implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.dmn.api.property.font.FontSet> agent;
      private org.kie.workbench.common.dmn.api.property.font.FontSet target;
      public org_kie_workbench_common_dmn_api_property_font_FontSetProxy() {
        this(new org.kie.workbench.common.dmn.api.property.font.FontSet());
      }

      public org_kie_workbench_common_dmn_api_property_font_FontSetProxy(org.kie.workbench.common.dmn.api.property.font.FontSet targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.dmn.api.property.font.FontSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("fontFamily", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontFamily.class, true, false));
        p.put("fontSize", new PropertyType(FontSize.class, true, false));
        p.put("fontColour", new PropertyType(FontColour.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet unwrap() {
        return target;
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet deepUnwrap() {
        final org.kie.workbench.common.dmn.api.property.font.FontSet clone = new org.kie.workbench.common.dmn.api.property.font.FontSet();
        final org.kie.workbench.common.dmn.api.property.font.FontSet t = unwrap();
        if (t.getFontFamily() instanceof BindableProxy) {
          clone.setFontFamily((org.kie.workbench.common.dmn.api.property.font.FontFamily) ((BindableProxy) getFontFamily()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontFamily())) {
          clone.setFontFamily((org.kie.workbench.common.dmn.api.property.font.FontFamily) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontFamily())).deepUnwrap());
        } else {
          clone.setFontFamily(t.getFontFamily());
        }
        if (t.getFontSize() instanceof BindableProxy) {
          clone.setFontSize((FontSize) ((BindableProxy) getFontSize()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSize())) {
          clone.setFontSize((FontSize) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSize())).deepUnwrap());
        } else {
          clone.setFontSize(t.getFontSize());
        }
        if (t.getFontColour() instanceof BindableProxy) {
          clone.setFontColour((FontColour) ((BindableProxy) getFontColour()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontColour())) {
          clone.setFontColour((FontColour) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontColour())).deepUnwrap());
        } else {
          clone.setFontColour(t.getFontColour());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_font_FontSetProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_font_FontSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontFamily getFontFamily() {
        return target.getFontFamily();
      }

      public void setFontFamily(org.kie.workbench.common.dmn.api.property.font.FontFamily fontFamily) {
        if (agent.binders.containsKey("fontFamily")) {
          fontFamily = (org.kie.workbench.common.dmn.api.property.font.FontFamily) agent.binders.get("fontFamily").setModel(fontFamily, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontFamily", fontFamily);
      }

      public FontSize getFontSize() {
        return target.getFontSize();
      }

      public void setFontSize(FontSize fontSize) {
        if (agent.binders.containsKey("fontSize")) {
          fontSize = (FontSize) agent.binders.get("fontSize").setModel(fontSize, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSize", fontSize);
      }

      public FontColour getFontColour() {
        return target.getFontColour();
      }

      public void setFontColour(FontColour fontColour) {
        if (agent.binders.containsKey("fontColour")) {
          fontColour = (FontColour) agent.binders.get("fontColour").setModel(fontColour, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontColour", fontColour);
      }

      public Object get(String property) {
        switch (property) {
          case "fontFamily": return getFontFamily();
          case "fontSize": return getFontSize();
          case "fontColour": return getFontColour();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "fontFamily": target.setFontFamily((org.kie.workbench.common.dmn.api.property.font.FontFamily) value);
          break;
          case "fontSize": target.setFontSize((FontSize) value);
          break;
          case "fontColour": target.setFontColour((FontColour) value);
          break;
          case "this": target = (org.kie.workbench.common.dmn.api.property.font.FontSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.dmn.api.property.font.FontSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_font_FontSetProxy((org.kie.workbench.common.dmn.api.property.font.FontSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_font_FontSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy extends MultipleInstanceExecutionMode implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceExecutionMode> agent;
      private MultipleInstanceExecutionMode target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy() {
        this(new MultipleInstanceExecutionMode());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy(MultipleInstanceExecutionMode targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceExecutionMode>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("sequential", new PropertyType(Boolean.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceExecutionMode unwrap() {
        return target;
      }

      public MultipleInstanceExecutionMode deepUnwrap() {
        final MultipleInstanceExecutionMode clone = new MultipleInstanceExecutionMode();
        final MultipleInstanceExecutionMode t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public boolean isSequential() {
        return target.isSequential();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "sequential": return isSequential();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceExecutionMode", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (MultipleInstanceExecutionMode) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceExecutionMode", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceExecutionMode.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy((MultipleInstanceExecutionMode) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceExecutionModeProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy extends CharacterMultipleSelectorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<CharacterMultipleSelectorFieldDefinition> agent;
      private CharacterMultipleSelectorFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy() {
        this(new CharacterMultipleSelectorFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy(CharacterMultipleSelectorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<CharacterMultipleSelectorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDropdownElements", new PropertyType(Integer.class, false, false));
        p.put("listOfValues", new PropertyType(List.class, false, true));
        p.put("maxElementsOnTitle", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("allowFilter", new PropertyType(Boolean.class, false, false));
        p.put("allowClearSelection", new PropertyType(Boolean.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(CharacterMultipleSelectorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CharacterMultipleSelectorFieldDefinition unwrap() {
        return target;
      }

      public CharacterMultipleSelectorFieldDefinition deepUnwrap() {
        final CharacterMultipleSelectorFieldDefinition clone = new CharacterMultipleSelectorFieldDefinition();
        final CharacterMultipleSelectorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDropdownElements(t.getMaxDropdownElements());
        if (t.getListOfValues() != null) {
          final List listOfValuesClone = new ArrayList();
          for (Object listOfValuesElem : t.getListOfValues()) {
            if (listOfValuesElem instanceof BindableProxy) {
              listOfValuesClone.add(((BindableProxy) listOfValuesElem).deepUnwrap());
            } else {
              listOfValuesClone.add(listOfValuesElem);
            }
          }
          clone.setListOfValues(listOfValuesClone);
        }
        clone.setMaxElementsOnTitle(t.getMaxElementsOnTitle());
        clone.setName(t.getName());
        clone.setAllowFilter(t.getAllowFilter());
        clone.setAllowClearSelection(t.getAllowClearSelection());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDropdownElements() {
        return target.getMaxDropdownElements();
      }

      public void setMaxDropdownElements(Integer maxDropdownElements) {
        changeAndFire("maxDropdownElements", maxDropdownElements);
      }

      public List getListOfValues() {
        return target.getListOfValues();
      }

      public void setListOfValues(List<Character> listOfValues) {
        List<Character> oldValue = target.getListOfValues();
        listOfValues = agent.ensureBoundListIsProxied("listOfValues", listOfValues);
        target.setListOfValues(listOfValues);
        agent.updateWidgetsAndFireEvent(true, "listOfValues", oldValue, listOfValues);
      }

      public Integer getMaxElementsOnTitle() {
        return target.getMaxElementsOnTitle();
      }

      public void setMaxElementsOnTitle(Integer maxElementsOnTitle) {
        changeAndFire("maxElementsOnTitle", maxElementsOnTitle);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Boolean getAllowFilter() {
        return target.getAllowFilter();
      }

      public void setAllowFilter(Boolean allowFilter) {
        changeAndFire("allowFilter", allowFilter);
      }

      public Boolean getAllowClearSelection() {
        return target.getAllowClearSelection();
      }

      public void setAllowClearSelection(Boolean allowClearSelection) {
        changeAndFire("allowClearSelection", allowClearSelection);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDropdownElements": return getMaxDropdownElements();
          case "listOfValues": return getListOfValues();
          case "maxElementsOnTitle": return getMaxElementsOnTitle();
          case "name": return getName();
          case "allowFilter": return getAllowFilter();
          case "allowClearSelection": return getAllowClearSelection();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("CharacterMultipleSelectorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDropdownElements": target.setMaxDropdownElements((Integer) value);
          break;
          case "listOfValues": target.setListOfValues((List<Character>) value);
          break;
          case "maxElementsOnTitle": target.setMaxElementsOnTitle((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "allowFilter": target.setAllowFilter((Boolean) value);
          break;
          case "allowClearSelection": target.setAllowClearSelection((Boolean) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (CharacterMultipleSelectorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CharacterMultipleSelectorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(CharacterMultipleSelectorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy((CharacterMultipleSelectorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_CharacterMultipleSelectorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy extends ProcessData implements BindableProxy {
      private BindableProxyAgent<ProcessData> agent;
      private ProcessData target;
      public org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy() {
        this(new ProcessData());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy(ProcessData targetVal) {
        agent = new BindableProxyAgent<ProcessData>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("processVariables", new PropertyType(ProcessVariables.class, true, false));
        p.put("this", new PropertyType(ProcessData.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessData unwrap() {
        return target;
      }

      public ProcessData deepUnwrap() {
        final ProcessData clone = new ProcessData();
        final ProcessData t = unwrap();
        if (t.getProcessVariables() instanceof BindableProxy) {
          clone.setProcessVariables((ProcessVariables) ((BindableProxy) getProcessVariables()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessVariables())) {
          clone.setProcessVariables((ProcessVariables) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessVariables())).deepUnwrap());
        } else {
          clone.setProcessVariables(t.getProcessVariables());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ProcessVariables getProcessVariables() {
        return target.getProcessVariables();
      }

      public void setProcessVariables(ProcessVariables processVariables) {
        if (agent.binders.containsKey("processVariables")) {
          processVariables = (ProcessVariables) agent.binders.get("processVariables").setModel(processVariables, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processVariables", processVariables);
      }

      public Object get(String property) {
        switch (property) {
          case "processVariables": return getProcessVariables();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessData", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "processVariables": target.setProcessVariables((ProcessVariables) value);
          break;
          case "this": target = (ProcessData) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessData", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessData.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy((ProcessData) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessDataProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy extends RectangleDimensionsSet implements BindableProxy {
      private BindableProxyAgent<RectangleDimensionsSet> agent;
      private RectangleDimensionsSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy() {
        this(new RectangleDimensionsSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy(RectangleDimensionsSet targetVal) {
        agent = new BindableProxyAgent<RectangleDimensionsSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("width", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width.class, true, false));
        p.put("height", new PropertyType(Height.class, true, false));
        p.put("this", new PropertyType(RectangleDimensionsSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public RectangleDimensionsSet unwrap() {
        return target;
      }

      public RectangleDimensionsSet deepUnwrap() {
        final RectangleDimensionsSet clone = new RectangleDimensionsSet();
        final RectangleDimensionsSet t = unwrap();
        if (t.getWidth() instanceof BindableProxy) {
          clone.setWidth((org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width) ((BindableProxy) getWidth()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWidth())) {
          clone.setWidth((org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWidth())).deepUnwrap());
        } else {
          clone.setWidth(t.getWidth());
        }
        if (t.getHeight() instanceof BindableProxy) {
          clone.setHeight((Height) ((BindableProxy) getHeight()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getHeight())) {
          clone.setHeight((Height) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getHeight())).deepUnwrap());
        } else {
          clone.setHeight(t.getHeight());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width getWidth() {
        return target.getWidth();
      }

      public void setWidth(org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width width) {
        if (agent.binders.containsKey("width")) {
          width = (org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width) agent.binders.get("width").setModel(width, StateSync.FROM_MODEL, true);
        }
        changeAndFire("width", width);
      }

      public Height getHeight() {
        return target.getHeight();
      }

      public void setHeight(Height height) {
        if (agent.binders.containsKey("height")) {
          height = (Height) agent.binders.get("height").setModel(height, StateSync.FROM_MODEL, true);
        }
        changeAndFire("height", height);
      }

      public Object get(String property) {
        switch (property) {
          case "width": return getWidth();
          case "height": return getHeight();
          case "this": return target;
          default: throw new NonExistingPropertyException("RectangleDimensionsSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "width": target.setWidth((org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width) value);
          break;
          case "height": target.setHeight((Height) value);
          break;
          case "this": target = (RectangleDimensionsSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("RectangleDimensionsSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(RectangleDimensionsSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy((RectangleDimensionsSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_RectangleDimensionsSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy extends ImportsFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ImportsFieldDefinition> agent;
      private ImportsFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy() {
        this(new ImportsFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy(ImportsFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ImportsFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ImportsFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ImportsFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ImportsFieldDefinition unwrap() {
        return target;
      }

      public ImportsFieldDefinition deepUnwrap() {
        final ImportsFieldDefinition clone = new ImportsFieldDefinition();
        final ImportsFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public ImportsFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("ImportsFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (ImportsFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ImportsFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ImportsFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy((ImportsFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ImportsFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy extends GenericServiceTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<GenericServiceTaskExecutionSet> agent;
      private GenericServiceTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy() {
        this(new GenericServiceTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy(GenericServiceTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<GenericServiceTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("genericServiceTaskInfo", new PropertyType(GenericServiceTaskInfo.class, true, false));
        p.put("assignmentsinfo", new PropertyType(AssignmentsInfo.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("this", new PropertyType(GenericServiceTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GenericServiceTaskExecutionSet unwrap() {
        return target;
      }

      public GenericServiceTaskExecutionSet deepUnwrap() {
        final GenericServiceTaskExecutionSet clone = new GenericServiceTaskExecutionSet();
        final GenericServiceTaskExecutionSet t = unwrap();
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getGenericServiceTaskInfo() instanceof BindableProxy) {
          clone.setGenericServiceTaskInfo((GenericServiceTaskInfo) ((BindableProxy) getGenericServiceTaskInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGenericServiceTaskInfo())) {
          clone.setGenericServiceTaskInfo((GenericServiceTaskInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGenericServiceTaskInfo())).deepUnwrap());
        } else {
          clone.setGenericServiceTaskInfo(t.getGenericServiceTaskInfo());
        }
        if (t.getAssignmentsinfo() instanceof BindableProxy) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) getAssignmentsinfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAssignmentsinfo())) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAssignmentsinfo())).deepUnwrap());
        } else {
          clone.setAssignmentsinfo(t.getAssignmentsinfo());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public GenericServiceTaskInfo getGenericServiceTaskInfo() {
        return target.getGenericServiceTaskInfo();
      }

      public void setGenericServiceTaskInfo(GenericServiceTaskInfo genericServiceTaskInfo) {
        if (agent.binders.containsKey("genericServiceTaskInfo")) {
          genericServiceTaskInfo = (GenericServiceTaskInfo) agent.binders.get("genericServiceTaskInfo").setModel(genericServiceTaskInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("genericServiceTaskInfo", genericServiceTaskInfo);
      }

      public AssignmentsInfo getAssignmentsinfo() {
        return target.getAssignmentsinfo();
      }

      public void setAssignmentsinfo(AssignmentsInfo assignmentsinfo) {
        if (agent.binders.containsKey("assignmentsinfo")) {
          assignmentsinfo = (AssignmentsInfo) agent.binders.get("assignmentsinfo").setModel(assignmentsinfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("assignmentsinfo", assignmentsinfo);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public Object get(String property) {
        switch (property) {
          case "isAsync": return getIsAsync();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "onEntryAction": return getOnEntryAction();
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "adHocAutostart": return getAdHocAutostart();
          case "slaDueDate": return getSlaDueDate();
          case "genericServiceTaskInfo": return getGenericServiceTaskInfo();
          case "assignmentsinfo": return getAssignmentsinfo();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "onExitAction": return getOnExitAction();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "this": return target;
          default: throw new NonExistingPropertyException("GenericServiceTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "genericServiceTaskInfo": target.setGenericServiceTaskInfo((GenericServiceTaskInfo) value);
          break;
          case "assignmentsinfo": target.setAssignmentsinfo((AssignmentsInfo) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "this": target = (GenericServiceTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GenericServiceTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(GenericServiceTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy((GenericServiceTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy extends StringMultipleSelectorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<StringMultipleSelectorFieldDefinition> agent;
      private StringMultipleSelectorFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy() {
        this(new StringMultipleSelectorFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy(StringMultipleSelectorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<StringMultipleSelectorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDropdownElements", new PropertyType(Integer.class, false, false));
        p.put("listOfValues", new PropertyType(List.class, false, true));
        p.put("maxElementsOnTitle", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("allowFilter", new PropertyType(Boolean.class, false, false));
        p.put("allowClearSelection", new PropertyType(Boolean.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(StringMultipleSelectorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StringMultipleSelectorFieldDefinition unwrap() {
        return target;
      }

      public StringMultipleSelectorFieldDefinition deepUnwrap() {
        final StringMultipleSelectorFieldDefinition clone = new StringMultipleSelectorFieldDefinition();
        final StringMultipleSelectorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDropdownElements(t.getMaxDropdownElements());
        if (t.getListOfValues() != null) {
          final List listOfValuesClone = new ArrayList();
          for (Object listOfValuesElem : t.getListOfValues()) {
            if (listOfValuesElem instanceof BindableProxy) {
              listOfValuesClone.add(((BindableProxy) listOfValuesElem).deepUnwrap());
            } else {
              listOfValuesClone.add(listOfValuesElem);
            }
          }
          clone.setListOfValues(listOfValuesClone);
        }
        clone.setMaxElementsOnTitle(t.getMaxElementsOnTitle());
        clone.setName(t.getName());
        clone.setAllowFilter(t.getAllowFilter());
        clone.setAllowClearSelection(t.getAllowClearSelection());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDropdownElements() {
        return target.getMaxDropdownElements();
      }

      public void setMaxDropdownElements(Integer maxDropdownElements) {
        changeAndFire("maxDropdownElements", maxDropdownElements);
      }

      public List getListOfValues() {
        return target.getListOfValues();
      }

      public void setListOfValues(List<String> listOfValues) {
        List<String> oldValue = target.getListOfValues();
        listOfValues = agent.ensureBoundListIsProxied("listOfValues", listOfValues);
        target.setListOfValues(listOfValues);
        agent.updateWidgetsAndFireEvent(true, "listOfValues", oldValue, listOfValues);
      }

      public Integer getMaxElementsOnTitle() {
        return target.getMaxElementsOnTitle();
      }

      public void setMaxElementsOnTitle(Integer maxElementsOnTitle) {
        changeAndFire("maxElementsOnTitle", maxElementsOnTitle);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Boolean getAllowFilter() {
        return target.getAllowFilter();
      }

      public void setAllowFilter(Boolean allowFilter) {
        changeAndFire("allowFilter", allowFilter);
      }

      public Boolean getAllowClearSelection() {
        return target.getAllowClearSelection();
      }

      public void setAllowClearSelection(Boolean allowClearSelection) {
        changeAndFire("allowClearSelection", allowClearSelection);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDropdownElements": return getMaxDropdownElements();
          case "listOfValues": return getListOfValues();
          case "maxElementsOnTitle": return getMaxElementsOnTitle();
          case "name": return getName();
          case "allowFilter": return getAllowFilter();
          case "allowClearSelection": return getAllowClearSelection();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("StringMultipleSelectorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDropdownElements": target.setMaxDropdownElements((Integer) value);
          break;
          case "listOfValues": target.setListOfValues((List<String>) value);
          break;
          case "maxElementsOnTitle": target.setMaxElementsOnTitle((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "allowFilter": target.setAllowFilter((Boolean) value);
          break;
          case "allowClearSelection": target.setAllowClearSelection((Boolean) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (StringMultipleSelectorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StringMultipleSelectorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(StringMultipleSelectorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy((StringMultipleSelectorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_StringMultipleSelectorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy extends ColorPickerFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ColorPickerFieldDefinition> agent;
      private ColorPickerFieldDefinition target;
      public org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy() {
        this(new ColorPickerFieldDefinition());
      }

      public org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy(ColorPickerFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ColorPickerFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ColorPickerFieldType.class, false, false));
        p.put("this", new PropertyType(ColorPickerFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ColorPickerFieldDefinition unwrap() {
        return target;
      }

      public ColorPickerFieldDefinition deepUnwrap() {
        final ColorPickerFieldDefinition clone = new ColorPickerFieldDefinition();
        final ColorPickerFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ColorPickerFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("ColorPickerFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (ColorPickerFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ColorPickerFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ColorPickerFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy((ColorPickerFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_forms_model_ColorPickerFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy extends FontSet implements BindableProxy {
      private BindableProxyAgent<FontSet> agent;
      private FontSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy() {
        this(new FontSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy(FontSet targetVal) {
        agent = new BindableProxyAgent<FontSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("fontFamily", new PropertyType(FontFamily.class, true, false));
        p.put("fontBorderSize", new PropertyType(FontBorderSize.class, true, false));
        p.put("fontBorderColor", new PropertyType(FontBorderColor.class, true, false));
        p.put("fontSize", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize.class, true, false));
        p.put("fontColor", new PropertyType(FontColor.class, true, false));
        p.put("this", new PropertyType(FontSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontSet unwrap() {
        return target;
      }

      public FontSet deepUnwrap() {
        final FontSet clone = new FontSet();
        final FontSet t = unwrap();
        if (t.getFontFamily() instanceof BindableProxy) {
          clone.setFontFamily((FontFamily) ((BindableProxy) getFontFamily()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontFamily())) {
          clone.setFontFamily((FontFamily) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontFamily())).deepUnwrap());
        } else {
          clone.setFontFamily(t.getFontFamily());
        }
        if (t.getFontBorderSize() instanceof BindableProxy) {
          clone.setFontBorderSize((FontBorderSize) ((BindableProxy) getFontBorderSize()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontBorderSize())) {
          clone.setFontBorderSize((FontBorderSize) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontBorderSize())).deepUnwrap());
        } else {
          clone.setFontBorderSize(t.getFontBorderSize());
        }
        if (t.getFontBorderColor() instanceof BindableProxy) {
          clone.setFontBorderColor((FontBorderColor) ((BindableProxy) getFontBorderColor()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontBorderColor())) {
          clone.setFontBorderColor((FontBorderColor) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontBorderColor())).deepUnwrap());
        } else {
          clone.setFontBorderColor(t.getFontBorderColor());
        }
        if (t.getFontSize() instanceof BindableProxy) {
          clone.setFontSize((org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize) ((BindableProxy) getFontSize()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSize())) {
          clone.setFontSize((org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSize())).deepUnwrap());
        } else {
          clone.setFontSize(t.getFontSize());
        }
        if (t.getFontColor() instanceof BindableProxy) {
          clone.setFontColor((FontColor) ((BindableProxy) getFontColor()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontColor())) {
          clone.setFontColor((FontColor) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontColor())).deepUnwrap());
        } else {
          clone.setFontColor(t.getFontColor());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public FontFamily getFontFamily() {
        return target.getFontFamily();
      }

      public void setFontFamily(FontFamily fontFamily) {
        if (agent.binders.containsKey("fontFamily")) {
          fontFamily = (FontFamily) agent.binders.get("fontFamily").setModel(fontFamily, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontFamily", fontFamily);
      }

      public FontBorderSize getFontBorderSize() {
        return target.getFontBorderSize();
      }

      public void setFontBorderSize(FontBorderSize fontBorderSize) {
        if (agent.binders.containsKey("fontBorderSize")) {
          fontBorderSize = (FontBorderSize) agent.binders.get("fontBorderSize").setModel(fontBorderSize, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontBorderSize", fontBorderSize);
      }

      public FontBorderColor getFontBorderColor() {
        return target.getFontBorderColor();
      }

      public void setFontBorderColor(FontBorderColor fontBorderColor) {
        if (agent.binders.containsKey("fontBorderColor")) {
          fontBorderColor = (FontBorderColor) agent.binders.get("fontBorderColor").setModel(fontBorderColor, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontBorderColor", fontBorderColor);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize getFontSize() {
        return target.getFontSize();
      }

      public void setFontSize(org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize fontSize) {
        if (agent.binders.containsKey("fontSize")) {
          fontSize = (org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize) agent.binders.get("fontSize").setModel(fontSize, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSize", fontSize);
      }

      public FontColor getFontColor() {
        return target.getFontColor();
      }

      public void setFontColor(FontColor fontColor) {
        if (agent.binders.containsKey("fontColor")) {
          fontColor = (FontColor) agent.binders.get("fontColor").setModel(fontColor, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontColor", fontColor);
      }

      public Object get(String property) {
        switch (property) {
          case "fontFamily": return getFontFamily();
          case "fontBorderSize": return getFontBorderSize();
          case "fontBorderColor": return getFontBorderColor();
          case "fontSize": return getFontSize();
          case "fontColor": return getFontColor();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "fontFamily": target.setFontFamily((FontFamily) value);
          break;
          case "fontBorderSize": target.setFontBorderSize((FontBorderSize) value);
          break;
          case "fontBorderColor": target.setFontBorderColor((FontBorderColor) value);
          break;
          case "fontSize": target.setFontSize((org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize) value);
          break;
          case "fontColor": target.setFontColor((FontColor) value);
          break;
          case "this": target = (FontSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy((FontSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSetProxy();
      }
    });
    class org_jbpm_workbench_es_model_RequestParameterSummaryProxy extends RequestParameterSummary implements BindableProxy {
      private BindableProxyAgent<RequestParameterSummary> agent;
      private RequestParameterSummary target;
      public org_jbpm_workbench_es_model_RequestParameterSummaryProxy() {
        this(new RequestParameterSummary());
      }

      public org_jbpm_workbench_es_model_RequestParameterSummaryProxy(RequestParameterSummary targetVal) {
        agent = new BindableProxyAgent<RequestParameterSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("name", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Object.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("key", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(RequestParameterSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public RequestParameterSummary unwrap() {
        return target;
      }

      public RequestParameterSummary deepUnwrap() {
        final RequestParameterSummary clone = new RequestParameterSummary();
        final RequestParameterSummary t = unwrap();
        clone.setName(t.getName());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setId(t.getId());
        clone.setValue(t.getValue());
        clone.setKey(t.getKey());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_es_model_RequestParameterSummaryProxy) {
          obj = ((org_jbpm_workbench_es_model_RequestParameterSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List callbacks) {
        List oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public Object getId() {
        return target.getId();
      }

      public void setId(Object id) {
        changeAndFire("id", id);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public String getKey() {
        return target.getKey();
      }

      public void setKey(String key) {
        changeAndFire("key", key);
      }

      public Object get(String property) {
        switch (property) {
          case "name": return getName();
          case "callbacks": return getCallbacks();
          case "id": return getId();
          case "value": return getValue();
          case "key": return getKey();
          case "this": return target;
          default: throw new NonExistingPropertyException("RequestParameterSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "name": target.setName((String) value);
          break;
          case "callbacks": target.setCallbacks((List) value);
          break;
          case "id": target.setId(value);
          break;
          case "value": target.setValue((String) value);
          break;
          case "key": target.setKey((String) value);
          break;
          case "this": target = (RequestParameterSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("RequestParameterSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(RequestParameterSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_es_model_RequestParameterSummaryProxy((RequestParameterSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_es_model_RequestParameterSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy extends ProcessVariables implements BindableProxy {
      private BindableProxyAgent<ProcessVariables> agent;
      private ProcessVariables target;
      public org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy() {
        this(new ProcessVariables());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy(ProcessVariables targetVal) {
        agent = new BindableProxyAgent<ProcessVariables>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ProcessVariables.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessVariables unwrap() {
        return target;
      }

      public ProcessVariables deepUnwrap() {
        final ProcessVariables clone = new ProcessVariables();
        final ProcessVariables t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessVariables", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (ProcessVariables) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessVariables", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessVariables.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy((ProcessVariables) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_variables_ProcessVariablesProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy extends DefaultImport implements BindableProxy {
      private BindableProxyAgent<DefaultImport> agent;
      private DefaultImport target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy() {
        this(new DefaultImport());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy(DefaultImport targetVal) {
        agent = new BindableProxyAgent<DefaultImport>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("className", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DefaultImport.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DefaultImport unwrap() {
        return target;
      }

      public DefaultImport deepUnwrap() {
        final DefaultImport clone = new DefaultImport();
        final DefaultImport t = unwrap();
        clone.setClassName(t.getClassName());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getClassName() {
        return target.getClassName();
      }

      public void setClassName(String className) {
        changeAndFire("className", className);
      }

      public Object get(String property) {
        switch (property) {
          case "className": return getClassName();
          case "this": return target;
          default: throw new NonExistingPropertyException("DefaultImport", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "className": target.setClassName((String) value);
          break;
          case "this": target = (DefaultImport) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DefaultImport", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DefaultImport.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy((DefaultImport) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_DefaultImportProxy();
      }
    });
    class org_jbpm_workbench_ht_model_CommentSummaryProxy extends CommentSummary implements BindableProxy {
      private BindableProxyAgent<CommentSummary> agent;
      private CommentSummary target;
      public org_jbpm_workbench_ht_model_CommentSummaryProxy() {
        this(new CommentSummary());
      }

      public org_jbpm_workbench_ht_model_CommentSummaryProxy(CommentSummary targetVal) {
        agent = new BindableProxyAgent<CommentSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("addedAt", new PropertyType(Date.class, false, false));
        p.put("addedBy", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("text", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CommentSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CommentSummary unwrap() {
        return target;
      }

      public CommentSummary deepUnwrap() {
        final CommentSummary clone = new CommentSummary();
        final CommentSummary t = unwrap();
        clone.setAddedAt(t.getAddedAt());
        clone.setAddedBy(t.getAddedBy());
        clone.setId(t.getId());
        clone.setText(t.getText());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_ht_model_CommentSummaryProxy) {
          obj = ((org_jbpm_workbench_ht_model_CommentSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Date getAddedAt() {
        return target.getAddedAt();
      }

      public void setAddedAt(Date addedAt) {
        changeAndFire("addedAt", addedAt);
      }

      public String getAddedBy() {
        return target.getAddedBy();
      }

      public void setAddedBy(String addedBy) {
        changeAndFire("addedBy", addedBy);
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public Object get(String property) {
        switch (property) {
          case "addedAt": return getAddedAt();
          case "addedBy": return getAddedBy();
          case "id": return getId();
          case "text": return getText();
          case "this": return target;
          default: throw new NonExistingPropertyException("CommentSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "addedAt": target.setAddedAt((Date) value);
          break;
          case "addedBy": target.setAddedBy((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "text": target.setText((String) value);
          break;
          case "this": target = (CommentSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CommentSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CommentSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_ht_model_CommentSummaryProxy((CommentSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_ht_model_CommentSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy extends EventSubprocess implements BindableProxy {
      private BindableProxyAgent<EventSubprocess> agent;
      private EventSubprocess target;
      public org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy() {
        this(new EventSubprocess());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy(EventSubprocess targetVal) {
        agent = new BindableProxyAgent<EventSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("processData", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(EventSubprocessExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EventSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EventSubprocess unwrap() {
        return target;
      }

      public EventSubprocess deepUnwrap() {
        final EventSubprocess clone = new EventSubprocess();
        final EventSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((EventSubprocessExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((EventSubprocessExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public EventSubprocessExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(EventSubprocessExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (EventSubprocessExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "processData": return getProcessData();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EventSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "processData": target.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((EventSubprocessExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (EventSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EventSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EventSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy((EventSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EventSubprocessProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy extends AssignmentsInfo implements BindableProxy {
      private BindableProxyAgent<AssignmentsInfo> agent;
      private AssignmentsInfo target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy() {
        this(new AssignmentsInfo());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy(AssignmentsInfo targetVal) {
        agent = new BindableProxyAgent<AssignmentsInfo>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(AssignmentsInfo.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AssignmentsInfo unwrap() {
        return target;
      }

      public AssignmentsInfo deepUnwrap() {
        final AssignmentsInfo clone = new AssignmentsInfo();
        final AssignmentsInfo t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AssignmentsInfo", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (AssignmentsInfo) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AssignmentsInfo", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AssignmentsInfo.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy((AssignmentsInfo) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dataio_AssignmentsInfoProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy extends MessageRef implements BindableProxy {
      private BindableProxyAgent<MessageRef> agent;
      private MessageRef target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy() {
        this(new MessageRef());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy(MessageRef targetVal) {
        agent = new BindableProxyAgent<MessageRef>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("structure", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MessageRef.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MessageRef unwrap() {
        return target;
      }

      public MessageRef deepUnwrap() {
        final MessageRef clone = new MessageRef();
        final MessageRef t = unwrap();
        clone.setValue(t.getValue());
        clone.setStructure(t.getStructure());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public String getStructure() {
        return target.getStructure();
      }

      public void setStructure(String structure) {
        changeAndFire("structure", structure);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "structure": return getStructure();
          case "this": return target;
          default: throw new NonExistingPropertyException("MessageRef", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "structure": target.setStructure((String) value);
          break;
          case "this": target = (MessageRef) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MessageRef", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MessageRef.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy((MessageRef) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageRefProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy extends ParallelGateway implements BindableProxy {
      private BindableProxyAgent<ParallelGateway> agent;
      private ParallelGateway target;
      public org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy() {
        this(new ParallelGateway());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy(ParallelGateway targetVal) {
        agent = new BindableProxyAgent<ParallelGateway>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(ParallelGateway.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ParallelGateway unwrap() {
        return target;
      }

      public ParallelGateway deepUnwrap() {
        final ParallelGateway clone = new ParallelGateway();
        final ParallelGateway t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("ParallelGateway", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (ParallelGateway) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ParallelGateway", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ParallelGateway.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy((ParallelGateway) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_ParallelGatewayProxy();
      }
    });
    class org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy extends ProcessNodeSummary implements BindableProxy {
      private BindableProxyAgent<ProcessNodeSummary> agent;
      private ProcessNodeSummary target;
      public org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy() {
        this(new ProcessNodeSummary());
      }

      public org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy(ProcessNodeSummary targetVal) {
        agent = new BindableProxyAgent<ProcessNodeSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("name", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("type", new PropertyType(String.class, false, false));
        p.put("uniqueId", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ProcessNodeSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessNodeSummary unwrap() {
        return target;
      }

      public ProcessNodeSummary deepUnwrap() {
        final ProcessNodeSummary clone = new ProcessNodeSummary();
        final ProcessNodeSummary t = unwrap();
        clone.setName(t.getName());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setId(t.getId());
        clone.setType(t.getType());
        clone.setUniqueId(t.getUniqueId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy) {
          obj = ((org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public String getType() {
        return target.getType();
      }

      public void setType(String type) {
        changeAndFire("type", type);
      }

      public String getUniqueId() {
        return target.getUniqueId();
      }

      public void setUniqueId(String uniqueId) {
        changeAndFire("uniqueId", uniqueId);
      }

      public Object get(String property) {
        switch (property) {
          case "name": return getName();
          case "callbacks": return getCallbacks();
          case "label": return getLabel();
          case "id": return getId();
          case "type": return getType();
          case "uniqueId": return getUniqueId();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessNodeSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "name": target.setName((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "type": target.setType((String) value);
          break;
          case "uniqueId": target.setUniqueId((String) value);
          break;
          case "this": target = (ProcessNodeSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessNodeSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessNodeSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy((ProcessNodeSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_pr_model_ProcessNodeSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy extends TaskGeneralSet implements BindableProxy {
      private BindableProxyAgent<TaskGeneralSet> agent;
      private TaskGeneralSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy() {
        this(new TaskGeneralSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy(TaskGeneralSet targetVal) {
        agent = new BindableProxyAgent<TaskGeneralSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("documentation", new PropertyType(Documentation.class, true, false));
        p.put("name", new PropertyType(Name.class, true, false));
        p.put("this", new PropertyType(TaskGeneralSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TaskGeneralSet unwrap() {
        return target;
      }

      public TaskGeneralSet deepUnwrap() {
        final TaskGeneralSet clone = new TaskGeneralSet();
        final TaskGeneralSet t = unwrap();
        if (t.getDocumentation() instanceof BindableProxy) {
          clone.setDocumentation((Documentation) ((BindableProxy) getDocumentation()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDocumentation())) {
          clone.setDocumentation((Documentation) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDocumentation())).deepUnwrap());
        } else {
          clone.setDocumentation(t.getDocumentation());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Documentation getDocumentation() {
        return target.getDocumentation();
      }

      public void setDocumentation(Documentation documentation) {
        if (agent.binders.containsKey("documentation")) {
          documentation = (Documentation) agent.binders.get("documentation").setModel(documentation, StateSync.FROM_MODEL, true);
        }
        changeAndFire("documentation", documentation);
      }

      public Name getName() {
        return target.getName();
      }

      public void setName(Name name) {
        if (agent.binders.containsKey("name")) {
          name = (Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public Object get(String property) {
        switch (property) {
          case "documentation": return getDocumentation();
          case "name": return getName();
          case "this": return target;
          default: throw new NonExistingPropertyException("TaskGeneralSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "documentation": target.setDocumentation((Documentation) value);
          break;
          case "name": target.setName((Name) value);
          break;
          case "this": target = (TaskGeneralSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TaskGeneralSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TaskGeneralSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy((TaskGeneralSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_TaskGeneralSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy extends DistributionType implements BindableProxy {
      private BindableProxyAgent<DistributionType> agent;
      private DistributionType target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy() {
        this(new DistributionType());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy(DistributionType targetVal) {
        agent = new BindableProxyAgent<DistributionType>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DistributionType.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DistributionType unwrap() {
        return target;
      }

      public DistributionType deepUnwrap() {
        final DistributionType clone = new DistributionType();
        final DistributionType t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DistributionType", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (DistributionType) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DistributionType", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DistributionType.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy((DistributionType) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_DistributionTypeProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_NameProxy extends org.kie.workbench.common.dmn.api.property.dmn.Name implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.dmn.api.property.dmn.Name> agent;
      private org.kie.workbench.common.dmn.api.property.dmn.Name target;
      public org_kie_workbench_common_dmn_api_property_dmn_NameProxy() {
        this(new org.kie.workbench.common.dmn.api.property.dmn.Name());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_NameProxy(org.kie.workbench.common.dmn.api.property.dmn.Name targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.dmn.api.property.dmn.Name>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name unwrap() {
        return target;
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name deepUnwrap() {
        final org.kie.workbench.common.dmn.api.property.dmn.Name clone = new org.kie.workbench.common.dmn.api.property.dmn.Name();
        final org.kie.workbench.common.dmn.api.property.dmn.Name t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_NameProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_NameProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Name", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.dmn.api.property.dmn.Name) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Name", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.dmn.api.property.dmn.Name.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_NameProxy((org.kie.workbench.common.dmn.api.property.dmn.Name) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_NameProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy extends EmptyTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<EmptyTaskExecutionSet> agent;
      private EmptyTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy() {
        this(new EmptyTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy(EmptyTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<EmptyTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("this", new PropertyType(EmptyTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EmptyTaskExecutionSet unwrap() {
        return target;
      }

      public EmptyTaskExecutionSet deepUnwrap() {
        final EmptyTaskExecutionSet clone = new EmptyTaskExecutionSet();
        final EmptyTaskExecutionSet t = unwrap();
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Object get(String property) {
        switch (property) {
          case "this": return target;
          default: throw new NonExistingPropertyException("EmptyTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "this": target = (EmptyTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EmptyTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EmptyTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy((EmptyTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_EmptyTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy extends StartCompensationEvent implements BindableProxy {
      private BindableProxyAgent<StartCompensationEvent> agent;
      private StartCompensationEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy() {
        this(new StartCompensationEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy(StartCompensationEvent targetVal) {
        agent = new BindableProxyAgent<StartCompensationEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(BaseStartEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartCompensationEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartCompensationEvent unwrap() {
        return target;
      }

      public StartCompensationEvent deepUnwrap() {
        final StartCompensationEvent clone = new StartCompensationEvent();
        final StartCompensationEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((BaseStartEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((BaseStartEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public BaseStartEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(BaseStartEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (BaseStartEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartCompensationEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((BaseStartEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartCompensationEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartCompensationEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartCompensationEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy((StartCompensationEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartCompensationEventProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy extends CharacterSelectorOption implements BindableProxy {
      private BindableProxyAgent<CharacterSelectorOption> agent;
      private CharacterSelectorOption target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy() {
        this(new CharacterSelectorOption());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy(CharacterSelectorOption targetVal) {
        agent = new BindableProxyAgent<CharacterSelectorOption>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("text", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(Character.class, false, false));
        p.put("this", new PropertyType(CharacterSelectorOption.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CharacterSelectorOption unwrap() {
        return target;
      }

      public CharacterSelectorOption deepUnwrap() {
        final CharacterSelectorOption clone = new CharacterSelectorOption();
        final CharacterSelectorOption t = unwrap();
        clone.setText(t.getText());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public Character getValue() {
        return target.getValue();
      }

      public void setValue(Character value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "text": return getText();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CharacterSelectorOption", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "text": target.setText((String) value);
          break;
          case "value": target.setValue((Character) value);
          break;
          case "this": target = (CharacterSelectorOption) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CharacterSelectorOption", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CharacterSelectorOption.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy((CharacterSelectorOption) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_CharacterSelectorOptionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy extends Script implements BindableProxy {
      private BindableProxyAgent<Script> agent;
      private Script target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy() {
        this(new Script());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy(Script targetVal) {
        agent = new BindableProxyAgent<Script>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ScriptTypeValue.class, true, false));
        p.put("this", new PropertyType(Script.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Script unwrap() {
        return target;
      }

      public Script deepUnwrap() {
        final Script clone = new Script();
        final Script t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ScriptTypeValue getValue() {
        return target.getValue();
      }

      public void setValue(ScriptTypeValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ScriptTypeValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Script", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ScriptTypeValue) value);
          break;
          case "this": target = (Script) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Script", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Script.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy((Script) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy extends IntegerSliderDefinition implements BindableProxy {
      private BindableProxyAgent<IntegerSliderDefinition> agent;
      private IntegerSliderDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy() {
        this(new IntegerSliderDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy(IntegerSliderDefinition targetVal) {
        agent = new BindableProxyAgent<IntegerSliderDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("max", new PropertyType(Integer.class, false, false));
        p.put("precision", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("min", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("step", new PropertyType(Integer.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(SliderFieldType.class, false, false));
        p.put("this", new PropertyType(IntegerSliderDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerSliderDefinition unwrap() {
        return target;
      }

      public IntegerSliderDefinition deepUnwrap() {
        final IntegerSliderDefinition clone = new IntegerSliderDefinition();
        final IntegerSliderDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setMax(t.getMax());
        clone.setPrecision(t.getPrecision());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMin(t.getMin());
        clone.setName(t.getName());
        clone.setStep(t.getStep());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getMax() {
        return target.getMax();
      }

      public void setMax(Integer max) {
        changeAndFire("max", max);
      }

      public Integer getPrecision() {
        return target.getPrecision();
      }

      public void setPrecision(Integer precision) {
        changeAndFire("precision", precision);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMin() {
        return target.getMin();
      }

      public void setMin(Integer min) {
        changeAndFire("min", min);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Integer getStep() {
        return target.getStep();
      }

      public void setStep(Integer step) {
        changeAndFire("step", step);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public SliderFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "max": return getMax();
          case "precision": return getPrecision();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "min": return getMin();
          case "name": return getName();
          case "step": return getStep();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerSliderDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "max": target.setMax((Integer) value);
          break;
          case "precision": target.setPrecision((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "min": target.setMin((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "step": target.setStep((Integer) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (IntegerSliderDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerSliderDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerSliderDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy((IntegerSliderDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_IntegerSliderDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy extends StartErrorEvent implements BindableProxy {
      private BindableProxyAgent<StartErrorEvent> agent;
      private StartErrorEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy() {
        this(new StartErrorEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy(StartErrorEvent targetVal) {
        agent = new BindableProxyAgent<StartErrorEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(InterruptingErrorEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartErrorEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartErrorEvent unwrap() {
        return target;
      }

      public StartErrorEvent deepUnwrap() {
        final StartErrorEvent clone = new StartErrorEvent();
        final StartErrorEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((InterruptingErrorEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((InterruptingErrorEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InterruptingErrorEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(InterruptingErrorEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (InterruptingErrorEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartErrorEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((InterruptingErrorEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartErrorEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartErrorEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartErrorEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy((StartErrorEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartErrorEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy extends AssigneeRow implements BindableProxy {
      private BindableProxyAgent<AssigneeRow> agent;
      private AssigneeRow target;
      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy() {
        this(new AssigneeRow());
      }

      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy(AssigneeRow targetVal) {
        agent = new BindableProxyAgent<AssigneeRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("name", new PropertyType(String.class, false, false));
        p.put("customName", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("empty", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(AssigneeRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AssigneeRow unwrap() {
        return target;
      }

      public AssigneeRow deepUnwrap() {
        final AssigneeRow clone = new AssigneeRow();
        final AssigneeRow t = unwrap();
        clone.setName(t.getName());
        clone.setCustomName(t.getCustomName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getCustomName() {
        return target.getCustomName();
      }

      public void setCustomName(String customName) {
        changeAndFire("customName", customName);
      }

      public long getId() {
        return target.getId();
      }

      public void setId(long id) {
        changeAndFire("id", id);
      }

      public boolean isEmpty() {
        return target.isEmpty();
      }

      public Object get(String property) {
        switch (property) {
          case "name": return getName();
          case "customName": return getCustomName();
          case "id": return getId();
          case "empty": return isEmpty();
          case "this": return target;
          default: throw new NonExistingPropertyException("AssigneeRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "name": target.setName((String) value);
          break;
          case "customName": target.setCustomName((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "this": target = (AssigneeRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AssigneeRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AssigneeRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy((AssigneeRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssigneeRowProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy extends org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess target;
      public org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy(org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("processData", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess clone = new org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess();
        final org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "processData": return getProcessData();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "processData": target.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy((org.kie.workbench.common.stunner.bpmn.definition.AdHocSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_AdHocSubprocessProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy extends IntegerBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<IntegerBoxFieldDefinition> agent;
      private IntegerBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy() {
        this(new IntegerBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy(IntegerBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<IntegerBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(IntegerBoxFieldType.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("maxLength", new PropertyType(Integer.class, false, false));
        p.put("this", new PropertyType(IntegerBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerBoxFieldDefinition unwrap() {
        return target;
      }

      public IntegerBoxFieldDefinition deepUnwrap() {
        final IntegerBoxFieldDefinition clone = new IntegerBoxFieldDefinition();
        final IntegerBoxFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setPlaceHolder(t.getPlaceHolder());
        clone.setMaxLength(t.getMaxLength());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public IntegerBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Integer getMaxLength() {
        return target.getMaxLength();
      }

      public void setMaxLength(Integer maxLength) {
        changeAndFire("maxLength", maxLength);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "placeHolder": return getPlaceHolder();
          case "maxLength": return getMaxLength();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "maxLength": target.setMaxLength((Integer) value);
          break;
          case "this": target = (IntegerBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy((IntegerBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_integerBox_definition_IntegerBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy extends CaseManagementSet implements BindableProxy {
      private BindableProxyAgent<CaseManagementSet> agent;
      private CaseManagementSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy() {
        this(new CaseManagementSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy(CaseManagementSet targetVal) {
        agent = new BindableProxyAgent<CaseManagementSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("caseIdPrefix", new PropertyType(CaseIdPrefix.class, true, false));
        p.put("caseRoles", new PropertyType(CaseRoles.class, true, false));
        p.put("caseFileVariables", new PropertyType(CaseFileVariables.class, true, false));
        p.put("this", new PropertyType(CaseManagementSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseManagementSet unwrap() {
        return target;
      }

      public CaseManagementSet deepUnwrap() {
        final CaseManagementSet clone = new CaseManagementSet();
        final CaseManagementSet t = unwrap();
        if (t.getCaseIdPrefix() instanceof BindableProxy) {
          clone.setCaseIdPrefix((CaseIdPrefix) ((BindableProxy) getCaseIdPrefix()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCaseIdPrefix())) {
          clone.setCaseIdPrefix((CaseIdPrefix) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCaseIdPrefix())).deepUnwrap());
        } else {
          clone.setCaseIdPrefix(t.getCaseIdPrefix());
        }
        if (t.getCaseRoles() instanceof BindableProxy) {
          clone.setCaseRoles((CaseRoles) ((BindableProxy) getCaseRoles()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCaseRoles())) {
          clone.setCaseRoles((CaseRoles) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCaseRoles())).deepUnwrap());
        } else {
          clone.setCaseRoles(t.getCaseRoles());
        }
        if (t.getCaseFileVariables() instanceof BindableProxy) {
          clone.setCaseFileVariables((CaseFileVariables) ((BindableProxy) getCaseFileVariables()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCaseFileVariables())) {
          clone.setCaseFileVariables((CaseFileVariables) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCaseFileVariables())).deepUnwrap());
        } else {
          clone.setCaseFileVariables(t.getCaseFileVariables());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public CaseIdPrefix getCaseIdPrefix() {
        return target.getCaseIdPrefix();
      }

      public void setCaseIdPrefix(CaseIdPrefix caseIdPrefix) {
        if (agent.binders.containsKey("caseIdPrefix")) {
          caseIdPrefix = (CaseIdPrefix) agent.binders.get("caseIdPrefix").setModel(caseIdPrefix, StateSync.FROM_MODEL, true);
        }
        changeAndFire("caseIdPrefix", caseIdPrefix);
      }

      public CaseRoles getCaseRoles() {
        return target.getCaseRoles();
      }

      public void setCaseRoles(CaseRoles caseRoles) {
        if (agent.binders.containsKey("caseRoles")) {
          caseRoles = (CaseRoles) agent.binders.get("caseRoles").setModel(caseRoles, StateSync.FROM_MODEL, true);
        }
        changeAndFire("caseRoles", caseRoles);
      }

      public CaseFileVariables getCaseFileVariables() {
        return target.getCaseFileVariables();
      }

      public void setCaseFileVariables(CaseFileVariables caseFileVariables) {
        if (agent.binders.containsKey("caseFileVariables")) {
          caseFileVariables = (CaseFileVariables) agent.binders.get("caseFileVariables").setModel(caseFileVariables, StateSync.FROM_MODEL, true);
        }
        changeAndFire("caseFileVariables", caseFileVariables);
      }

      public Object get(String property) {
        switch (property) {
          case "caseIdPrefix": return getCaseIdPrefix();
          case "caseRoles": return getCaseRoles();
          case "caseFileVariables": return getCaseFileVariables();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseManagementSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "caseIdPrefix": target.setCaseIdPrefix((CaseIdPrefix) value);
          break;
          case "caseRoles": target.setCaseRoles((CaseRoles) value);
          break;
          case "caseFileVariables": target.setCaseFileVariables((CaseFileVariables) value);
          break;
          case "this": target = (CaseManagementSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseManagementSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseManagementSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy((CaseManagementSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseManagementSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy extends AllowedAnswers implements BindableProxy {
      private BindableProxyAgent<AllowedAnswers> agent;
      private AllowedAnswers target;
      public org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy() {
        this(new AllowedAnswers());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy(AllowedAnswers targetVal) {
        agent = new BindableProxyAgent<AllowedAnswers>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(AllowedAnswers.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AllowedAnswers unwrap() {
        return target;
      }

      public AllowedAnswers deepUnwrap() {
        final AllowedAnswers clone = new AllowedAnswers();
        final AllowedAnswers t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AllowedAnswers", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (AllowedAnswers) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AllowedAnswers", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AllowedAnswers.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy((AllowedAnswers) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_AllowedAnswersProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy extends CaseIdPrefix implements BindableProxy {
      private BindableProxyAgent<CaseIdPrefix> agent;
      private CaseIdPrefix target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy() {
        this(new CaseIdPrefix());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy(CaseIdPrefix targetVal) {
        agent = new BindableProxyAgent<CaseIdPrefix>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CaseIdPrefix.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseIdPrefix unwrap() {
        return target;
      }

      public CaseIdPrefix deepUnwrap() {
        final CaseIdPrefix clone = new CaseIdPrefix();
        final CaseIdPrefix t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseIdPrefix", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (CaseIdPrefix) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseIdPrefix", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseIdPrefix.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy((CaseIdPrefix) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseIdPrefixProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy extends Mean implements BindableProxy {
      private BindableProxyAgent<Mean> agent;
      private Mean target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy() {
        this(new Mean());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy(Mean targetVal) {
        agent = new BindableProxyAgent<Mean>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Mean.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Mean unwrap() {
        return target;
      }

      public Mean deepUnwrap() {
        final Mean clone = new Mean();
        final Mean t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Mean", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Mean) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Mean", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Mean.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy((Mean) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MeanProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy extends EscalationEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<EscalationEventExecutionSet> agent;
      private EscalationEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy() {
        this(new EscalationEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy(EscalationEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<EscalationEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("escalationRef", new PropertyType(EscalationRef.class, true, false));
        p.put("this", new PropertyType(EscalationEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EscalationEventExecutionSet unwrap() {
        return target;
      }

      public EscalationEventExecutionSet deepUnwrap() {
        final EscalationEventExecutionSet clone = new EscalationEventExecutionSet();
        final EscalationEventExecutionSet t = unwrap();
        if (t.getEscalationRef() instanceof BindableProxy) {
          clone.setEscalationRef((EscalationRef) ((BindableProxy) getEscalationRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getEscalationRef())) {
          clone.setEscalationRef((EscalationRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getEscalationRef())).deepUnwrap());
        } else {
          clone.setEscalationRef(t.getEscalationRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public EscalationRef getEscalationRef() {
        return target.getEscalationRef();
      }

      public void setEscalationRef(EscalationRef escalationRef) {
        if (agent.binders.containsKey("escalationRef")) {
          escalationRef = (EscalationRef) agent.binders.get("escalationRef").setModel(escalationRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("escalationRef", escalationRef);
      }

      public Object get(String property) {
        switch (property) {
          case "escalationRef": return getEscalationRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("EscalationEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "escalationRef": target.setEscalationRef((EscalationRef) value);
          break;
          case "this": target = (EscalationEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EscalationEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EscalationEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy((EscalationEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy extends Content implements BindableProxy {
      private BindableProxyAgent<Content> agent;
      private Content target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy() {
        this(new Content());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy(Content targetVal) {
        agent = new BindableProxyAgent<Content>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Content.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Content unwrap() {
        return target;
      }

      public Content deepUnwrap() {
        final Content clone = new Content();
        final Content t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Content", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Content) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Content", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Content.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy((Content) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ContentProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy extends NotificationsEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<NotificationsEditorFieldDefinition> agent;
      private NotificationsEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy() {
        this(new NotificationsEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy(NotificationsEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<NotificationsEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(NotificationsEditorFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(NotificationsEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NotificationsEditorFieldDefinition unwrap() {
        return target;
      }

      public NotificationsEditorFieldDefinition deepUnwrap() {
        final NotificationsEditorFieldDefinition clone = new NotificationsEditorFieldDefinition();
        final NotificationsEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public NotificationsEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("NotificationsEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (NotificationsEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NotificationsEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(NotificationsEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy((NotificationsEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_NotificationsEditorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy extends CaseRoles implements BindableProxy {
      private BindableProxyAgent<CaseRoles> agent;
      private CaseRoles target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy() {
        this(new CaseRoles());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy(CaseRoles targetVal) {
        agent = new BindableProxyAgent<CaseRoles>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CaseRoles.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseRoles unwrap() {
        return target;
      }

      public CaseRoles deepUnwrap() {
        final CaseRoles clone = new CaseRoles();
        final CaseRoles t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseRoles", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (CaseRoles) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseRoles", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseRoles.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy((CaseRoles) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_cm_CaseRolesProxy();
      }
    });
    class org_jbpm_workbench_ht_model_TaskEventSummaryProxy extends TaskEventSummary implements BindableProxy {
      private BindableProxyAgent<TaskEventSummary> agent;
      private TaskEventSummary target;
      public org_jbpm_workbench_ht_model_TaskEventSummaryProxy() {
        this(new TaskEventSummary());
      }

      public org_jbpm_workbench_ht_model_TaskEventSummaryProxy(TaskEventSummary targetVal) {
        agent = new BindableProxyAgent<TaskEventSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("eventId", new PropertyType(Long.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("workItemId", new PropertyType(Long.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("type", new PropertyType(String.class, false, false));
        p.put("message", new PropertyType(String.class, false, false));
        p.put("userId", new PropertyType(String.class, false, false));
        p.put("taskId", new PropertyType(Long.class, false, false));
        p.put("logTime", new PropertyType(Date.class, false, false));
        p.put("this", new PropertyType(TaskEventSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TaskEventSummary unwrap() {
        return target;
      }

      public TaskEventSummary deepUnwrap() {
        final TaskEventSummary clone = new TaskEventSummary();
        final TaskEventSummary t = unwrap();
        clone.setName(t.getName());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_ht_model_TaskEventSummaryProxy) {
          obj = ((org_jbpm_workbench_ht_model_TaskEventSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Long getEventId() {
        return target.getEventId();
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public Long getWorkItemId() {
        return target.getWorkItemId();
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public String getType() {
        return target.getType();
      }

      public String getMessage() {
        return target.getMessage();
      }

      public String getUserId() {
        return target.getUserId();
      }

      public Long getTaskId() {
        return target.getTaskId();
      }

      public Date getLogTime() {
        return target.getLogTime();
      }

      public Object get(String property) {
        switch (property) {
          case "eventId": return getEventId();
          case "name": return getName();
          case "callbacks": return getCallbacks();
          case "workItemId": return getWorkItemId();
          case "id": return getId();
          case "type": return getType();
          case "message": return getMessage();
          case "userId": return getUserId();
          case "taskId": return getTaskId();
          case "logTime": return getLogTime();
          case "this": return target;
          default: throw new NonExistingPropertyException("TaskEventSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "name": target.setName((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "this": target = (TaskEventSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TaskEventSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(TaskEventSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_ht_model_TaskEventSummaryProxy((TaskEventSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_ht_model_TaskEventSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy extends StartNoneEvent implements BindableProxy {
      private BindableProxyAgent<StartNoneEvent> agent;
      private StartNoneEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy() {
        this(new StartNoneEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy(StartNoneEvent targetVal) {
        agent = new BindableProxyAgent<StartNoneEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(BaseStartEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartNoneEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartNoneEvent unwrap() {
        return target;
      }

      public StartNoneEvent deepUnwrap() {
        final StartNoneEvent clone = new StartNoneEvent();
        final StartNoneEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((BaseStartEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((BaseStartEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public BaseStartEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(BaseStartEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (BaseStartEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartNoneEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((BaseStartEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartNoneEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartNoneEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartNoneEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy((StartNoneEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartNoneEventProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy extends org.kie.workbench.common.dmn.api.property.dimensions.Height implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.dmn.api.property.dimensions.Height> agent;
      private org.kie.workbench.common.dmn.api.property.dimensions.Height target;
      public org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy() {
        this(new org.kie.workbench.common.dmn.api.property.dimensions.Height());
      }

      public org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy(org.kie.workbench.common.dmn.api.property.dimensions.Height targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.dmn.api.property.dimensions.Height>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.dmn.api.property.dimensions.Height.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.dmn.api.property.dimensions.Height unwrap() {
        return target;
      }

      public org.kie.workbench.common.dmn.api.property.dimensions.Height deepUnwrap() {
        final org.kie.workbench.common.dmn.api.property.dimensions.Height clone = new org.kie.workbench.common.dmn.api.property.dimensions.Height();
        final org.kie.workbench.common.dmn.api.property.dimensions.Height t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Height", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (org.kie.workbench.common.dmn.api.property.dimensions.Height) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Height", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.dmn.api.property.dimensions.Height.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy((org.kie.workbench.common.dmn.api.property.dimensions.Height) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dimensions_HeightProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy extends InterruptingMessageEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<InterruptingMessageEventExecutionSet> agent;
      private InterruptingMessageEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy() {
        this(new InterruptingMessageEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy(InterruptingMessageEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<InterruptingMessageEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("messageRef", new PropertyType(MessageRef.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(InterruptingMessageEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InterruptingMessageEventExecutionSet unwrap() {
        return target;
      }

      public InterruptingMessageEventExecutionSet deepUnwrap() {
        final InterruptingMessageEventExecutionSet clone = new InterruptingMessageEventExecutionSet();
        final InterruptingMessageEventExecutionSet t = unwrap();
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getMessageRef() instanceof BindableProxy) {
          clone.setMessageRef((MessageRef) ((BindableProxy) getMessageRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMessageRef())) {
          clone.setMessageRef((MessageRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMessageRef())).deepUnwrap());
        } else {
          clone.setMessageRef(t.getMessageRef());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public MessageRef getMessageRef() {
        return target.getMessageRef();
      }

      public void setMessageRef(MessageRef messageRef) {
        if (agent.binders.containsKey("messageRef")) {
          messageRef = (MessageRef) agent.binders.get("messageRef").setModel(messageRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("messageRef", messageRef);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "isInterrupting": return getIsInterrupting();
          case "messageRef": return getMessageRef();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("InterruptingMessageEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "messageRef": target.setMessageRef((MessageRef) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (InterruptingMessageEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InterruptingMessageEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InterruptingMessageEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy((InterruptingMessageEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_InterruptingMessageEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy extends CircleDimensionSet implements BindableProxy {
      private BindableProxyAgent<CircleDimensionSet> agent;
      private CircleDimensionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy() {
        this(new CircleDimensionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy(CircleDimensionSet targetVal) {
        agent = new BindableProxyAgent<CircleDimensionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("radius", new PropertyType(Radius.class, true, false));
        p.put("this", new PropertyType(CircleDimensionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CircleDimensionSet unwrap() {
        return target;
      }

      public CircleDimensionSet deepUnwrap() {
        final CircleDimensionSet clone = new CircleDimensionSet();
        final CircleDimensionSet t = unwrap();
        if (t.getRadius() instanceof BindableProxy) {
          clone.setRadius((Radius) ((BindableProxy) getRadius()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getRadius())) {
          clone.setRadius((Radius) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getRadius())).deepUnwrap());
        } else {
          clone.setRadius(t.getRadius());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Radius getRadius() {
        return target.getRadius();
      }

      public void setRadius(Radius radius) {
        if (agent.binders.containsKey("radius")) {
          radius = (Radius) agent.binders.get("radius").setModel(radius, StateSync.FROM_MODEL, true);
        }
        changeAndFire("radius", radius);
      }

      public Object get(String property) {
        switch (property) {
          case "radius": return getRadius();
          case "this": return target;
          default: throw new NonExistingPropertyException("CircleDimensionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "radius": target.setRadius((Radius) value);
          break;
          case "this": target = (CircleDimensionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CircleDimensionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CircleDimensionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy((CircleDimensionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_CircleDimensionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy extends SubFormFieldDefinition implements BindableProxy {
      private BindableProxyAgent<SubFormFieldDefinition> agent;
      private SubFormFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy() {
        this(new SubFormFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy(SubFormFieldDefinition targetVal) {
        agent = new BindableProxyAgent<SubFormFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("container", new PropertyType(Container.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(SubFormFieldType.class, false, false));
        p.put("nestedForm", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(SubFormFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SubFormFieldDefinition unwrap() {
        return target;
      }

      public SubFormFieldDefinition deepUnwrap() {
        final SubFormFieldDefinition clone = new SubFormFieldDefinition();
        final SubFormFieldDefinition t = unwrap();
        clone.setContainer(t.getContainer());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setNestedForm(t.getNestedForm());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Container getContainer() {
        return target.getContainer();
      }

      public void setContainer(Container container) {
        changeAndFire("container", container);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public SubFormFieldType getFieldType() {
        return target.getFieldType();
      }

      public String getNestedForm() {
        return target.getNestedForm();
      }

      public void setNestedForm(String nestedForm) {
        changeAndFire("nestedForm", nestedForm);
      }

      public Object get(String property) {
        switch (property) {
          case "container": return getContainer();
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "nestedForm": return getNestedForm();
          case "this": return target;
          default: throw new NonExistingPropertyException("SubFormFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "container": target.setContainer((Container) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "nestedForm": target.setNestedForm((String) value);
          break;
          case "this": target = (SubFormFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SubFormFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(SubFormFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy((SubFormFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_subForm_definition_SubFormFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy extends LiteralExpression implements BindableProxy {
      private BindableProxyAgent<LiteralExpression> agent;
      private LiteralExpression target;
      public org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy() {
        this(new LiteralExpression());
      }

      public org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy(LiteralExpression targetVal) {
        agent = new BindableProxyAgent<LiteralExpression>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("expressionLanguage", new PropertyType(ExpressionLanguage.class, true, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("importedValues", new PropertyType(ImportedValues.class, true, false));
        p.put("requiredComponentWidthCount", new PropertyType(Integer.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("componentWidths", new PropertyType(List.class, false, true));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(LiteralExpression.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public LiteralExpression unwrap() {
        return target;
      }

      public LiteralExpression deepUnwrap() {
        final LiteralExpression clone = new LiteralExpression();
        final LiteralExpression t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getExpressionLanguage() instanceof BindableProxy) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) getExpressionLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExpressionLanguage())) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExpressionLanguage())).deepUnwrap());
        } else {
          clone.setExpressionLanguage(t.getExpressionLanguage());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getImportedValues() instanceof BindableProxy) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) getImportedValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImportedValues())) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImportedValues())).deepUnwrap());
        } else {
          clone.setImportedValues(t.getImportedValues());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public ExpressionLanguage getExpressionLanguage() {
        return target.getExpressionLanguage();
      }

      public void setExpressionLanguage(ExpressionLanguage expressionLanguage) {
        if (agent.binders.containsKey("expressionLanguage")) {
          expressionLanguage = (ExpressionLanguage) agent.binders.get("expressionLanguage").setModel(expressionLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("expressionLanguage", expressionLanguage);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public ImportedValues getImportedValues() {
        return target.getImportedValues();
      }

      public void setImportedValues(ImportedValues importedValues) {
        if (agent.binders.containsKey("importedValues")) {
          importedValues = (ImportedValues) agent.binders.get("importedValues").setModel(importedValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("importedValues", importedValues);
      }

      public int getRequiredComponentWidthCount() {
        return target.getRequiredComponentWidthCount();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getComponentWidths() {
        return target.getComponentWidths();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "expressionLanguage": return getExpressionLanguage();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "importedValues": return getImportedValues();
          case "requiredComponentWidthCount": return getRequiredComponentWidthCount();
          case "nsContext": return getNsContext();
          case "componentWidths": return getComponentWidths();
          case "hasTypeRefs": return getHasTypeRefs();
          case "text": return getText();
          case "id": return getId();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("LiteralExpression", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "expressionLanguage": target.setExpressionLanguage((ExpressionLanguage) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "importedValues": target.setImportedValues((ImportedValues) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (LiteralExpression) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("LiteralExpression", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(LiteralExpression.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy((LiteralExpression) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy extends ExpressionLanguage implements BindableProxy {
      private BindableProxyAgent<ExpressionLanguage> agent;
      private ExpressionLanguage target;
      public org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy() {
        this(new ExpressionLanguage());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy(ExpressionLanguage targetVal) {
        agent = new BindableProxyAgent<ExpressionLanguage>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ExpressionLanguage.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ExpressionLanguage unwrap() {
        return target;
      }

      public ExpressionLanguage deepUnwrap() {
        final ExpressionLanguage clone = new ExpressionLanguage();
        final ExpressionLanguage t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ExpressionLanguage", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (ExpressionLanguage) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ExpressionLanguage", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ExpressionLanguage.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy((ExpressionLanguage) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_ExpressionLanguageProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy extends SimulationAttributeSet implements BindableProxy {
      private BindableProxyAgent<SimulationAttributeSet> agent;
      private SimulationAttributeSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy() {
        this(new SimulationAttributeSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy(SimulationAttributeSet targetVal) {
        agent = new BindableProxyAgent<SimulationAttributeSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("min", new PropertyType(Min.class, true, false));
        p.put("distributionType", new PropertyType(DistributionType.class, true, false));
        p.put("max", new PropertyType(Max.class, true, false));
        p.put("mean", new PropertyType(Mean.class, true, false));
        p.put("standardDeviation", new PropertyType(StandardDeviation.class, true, false));
        p.put("timeUnit", new PropertyType(TimeUnit.class, true, false));
        p.put("this", new PropertyType(SimulationAttributeSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SimulationAttributeSet unwrap() {
        return target;
      }

      public SimulationAttributeSet deepUnwrap() {
        final SimulationAttributeSet clone = new SimulationAttributeSet();
        final SimulationAttributeSet t = unwrap();
        if (t.getMin() instanceof BindableProxy) {
          clone.setMin((Min) ((BindableProxy) getMin()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMin())) {
          clone.setMin((Min) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMin())).deepUnwrap());
        } else {
          clone.setMin(t.getMin());
        }
        if (t.getDistributionType() instanceof BindableProxy) {
          clone.setDistributionType((DistributionType) ((BindableProxy) getDistributionType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDistributionType())) {
          clone.setDistributionType((DistributionType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDistributionType())).deepUnwrap());
        } else {
          clone.setDistributionType(t.getDistributionType());
        }
        if (t.getMax() instanceof BindableProxy) {
          clone.setMax((Max) ((BindableProxy) getMax()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMax())) {
          clone.setMax((Max) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMax())).deepUnwrap());
        } else {
          clone.setMax(t.getMax());
        }
        if (t.getMean() instanceof BindableProxy) {
          clone.setMean((Mean) ((BindableProxy) getMean()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMean())) {
          clone.setMean((Mean) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMean())).deepUnwrap());
        } else {
          clone.setMean(t.getMean());
        }
        if (t.getStandardDeviation() instanceof BindableProxy) {
          clone.setStandardDeviation((StandardDeviation) ((BindableProxy) getStandardDeviation()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getStandardDeviation())) {
          clone.setStandardDeviation((StandardDeviation) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getStandardDeviation())).deepUnwrap());
        } else {
          clone.setStandardDeviation(t.getStandardDeviation());
        }
        if (t.getTimeUnit() instanceof BindableProxy) {
          clone.setTimeUnit((TimeUnit) ((BindableProxy) getTimeUnit()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTimeUnit())) {
          clone.setTimeUnit((TimeUnit) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTimeUnit())).deepUnwrap());
        } else {
          clone.setTimeUnit(t.getTimeUnit());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Min getMin() {
        return target.getMin();
      }

      public void setMin(Min min) {
        if (agent.binders.containsKey("min")) {
          min = (Min) agent.binders.get("min").setModel(min, StateSync.FROM_MODEL, true);
        }
        changeAndFire("min", min);
      }

      public DistributionType getDistributionType() {
        return target.getDistributionType();
      }

      public void setDistributionType(DistributionType distributionType) {
        if (agent.binders.containsKey("distributionType")) {
          distributionType = (DistributionType) agent.binders.get("distributionType").setModel(distributionType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("distributionType", distributionType);
      }

      public Max getMax() {
        return target.getMax();
      }

      public void setMax(Max max) {
        if (agent.binders.containsKey("max")) {
          max = (Max) agent.binders.get("max").setModel(max, StateSync.FROM_MODEL, true);
        }
        changeAndFire("max", max);
      }

      public Mean getMean() {
        return target.getMean();
      }

      public void setMean(Mean mean) {
        if (agent.binders.containsKey("mean")) {
          mean = (Mean) agent.binders.get("mean").setModel(mean, StateSync.FROM_MODEL, true);
        }
        changeAndFire("mean", mean);
      }

      public StandardDeviation getStandardDeviation() {
        return target.getStandardDeviation();
      }

      public void setStandardDeviation(StandardDeviation standardDeviation) {
        if (agent.binders.containsKey("standardDeviation")) {
          standardDeviation = (StandardDeviation) agent.binders.get("standardDeviation").setModel(standardDeviation, StateSync.FROM_MODEL, true);
        }
        changeAndFire("standardDeviation", standardDeviation);
      }

      public TimeUnit getTimeUnit() {
        return target.getTimeUnit();
      }

      public void setTimeUnit(TimeUnit timeUnit) {
        if (agent.binders.containsKey("timeUnit")) {
          timeUnit = (TimeUnit) agent.binders.get("timeUnit").setModel(timeUnit, StateSync.FROM_MODEL, true);
        }
        changeAndFire("timeUnit", timeUnit);
      }

      public Object get(String property) {
        switch (property) {
          case "min": return getMin();
          case "distributionType": return getDistributionType();
          case "max": return getMax();
          case "mean": return getMean();
          case "standardDeviation": return getStandardDeviation();
          case "timeUnit": return getTimeUnit();
          case "this": return target;
          default: throw new NonExistingPropertyException("SimulationAttributeSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "min": target.setMin((Min) value);
          break;
          case "distributionType": target.setDistributionType((DistributionType) value);
          break;
          case "max": target.setMax((Max) value);
          break;
          case "mean": target.setMean((Mean) value);
          break;
          case "standardDeviation": target.setStandardDeviation((StandardDeviation) value);
          break;
          case "timeUnit": target.setTimeUnit((TimeUnit) value);
          break;
          case "this": target = (SimulationAttributeSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SimulationAttributeSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SimulationAttributeSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy((SimulationAttributeSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationAttributeSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy extends BooleanMultipleInputFieldDefinition implements BindableProxy {
      private BindableProxyAgent<BooleanMultipleInputFieldDefinition> agent;
      private BooleanMultipleInputFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy() {
        this(new BooleanMultipleInputFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy(BooleanMultipleInputFieldDefinition targetVal) {
        agent = new BindableProxyAgent<BooleanMultipleInputFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("pageSize", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(BooleanMultipleInputFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BooleanMultipleInputFieldDefinition unwrap() {
        return target;
      }

      public BooleanMultipleInputFieldDefinition deepUnwrap() {
        final BooleanMultipleInputFieldDefinition clone = new BooleanMultipleInputFieldDefinition();
        final BooleanMultipleInputFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setPageSize(t.getPageSize());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getPageSize() {
        return target.getPageSize();
      }

      public void setPageSize(Integer pageSize) {
        changeAndFire("pageSize", pageSize);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "pageSize": return getPageSize();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("BooleanMultipleInputFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "pageSize": target.setPageSize((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (BooleanMultipleInputFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BooleanMultipleInputFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(BooleanMultipleInputFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy((BooleanMultipleInputFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_BooleanMultipleInputFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy extends NOPDomainObject implements BindableProxy {
      private BindableProxyAgent<NOPDomainObject> agent;
      private NOPDomainObject target;
      public org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy() {
        this(new NOPDomainObject());
      }

      public org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy(NOPDomainObject targetVal) {
        agent = new BindableProxyAgent<NOPDomainObject>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(NOPDomainObject.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NOPDomainObject unwrap() {
        return target;
      }

      public NOPDomainObject deepUnwrap() {
        final NOPDomainObject clone = new NOPDomainObject();
        final NOPDomainObject t = unwrap();
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "domainObjectUUID": return getDomainObjectUUID();
          case "stunnerCategory": return getStunnerCategory();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("NOPDomainObject", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "this": target = (NOPDomainObject) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NOPDomainObject", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(NOPDomainObject.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy((NOPDomainObject) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_NOPDomainObjectProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy extends KnowledgeSource implements BindableProxy {
      private BindableProxyAgent<KnowledgeSource> agent;
      private KnowledgeSource target;
      public org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy() {
        this(new KnowledgeSource());
      }

      public org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy(KnowledgeSource targetVal) {
        agent = new BindableProxyAgent<KnowledgeSource>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("allowOnlyVisualChange", new PropertyType(Boolean.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("type", new PropertyType(KnowledgeSourceType.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("backgroundSet", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("fontSet", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(GeneralRectangleDimensionsSet.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("locationURI", new PropertyType(LocationURI.class, true, false));
        p.put("linksHolder", new PropertyType(DocumentationLinksHolder.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(KnowledgeSource.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public KnowledgeSource unwrap() {
        return target;
      }

      public KnowledgeSource deepUnwrap() {
        final KnowledgeSource clone = new KnowledgeSource();
        final KnowledgeSource t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        clone.setAllowOnlyVisualChange(t.isAllowOnlyVisualChange());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getType() instanceof BindableProxy) {
          clone.setType((KnowledgeSourceType) ((BindableProxy) getType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getType())) {
          clone.setType((KnowledgeSourceType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getType())).deepUnwrap());
        } else {
          clone.setType(t.getType());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getLocationURI() instanceof BindableProxy) {
          clone.setLocationURI((LocationURI) ((BindableProxy) getLocationURI()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLocationURI())) {
          clone.setLocationURI((LocationURI) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLocationURI())).deepUnwrap());
        } else {
          clone.setLocationURI(t.getLocationURI());
        }
        if (t.getLinksHolder() instanceof BindableProxy) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) getLinksHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLinksHolder())) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLinksHolder())).deepUnwrap());
        } else {
          clone.setLinksHolder(t.getLinksHolder());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public boolean isAllowOnlyVisualChange() {
        return target.isAllowOnlyVisualChange();
      }

      public void setAllowOnlyVisualChange(boolean allowOnlyVisualChange) {
        changeAndFire("allowOnlyVisualChange", allowOnlyVisualChange);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public KnowledgeSourceType getType() {
        return target.getType();
      }

      public void setType(KnowledgeSourceType type) {
        if (agent.binders.containsKey("type")) {
          type = (KnowledgeSourceType) agent.binders.get("type").setModel(type, StateSync.FROM_MODEL, true);
        }
        changeAndFire("type", type);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(org.kie.workbench.common.dmn.api.property.background.BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(org.kie.workbench.common.dmn.api.property.font.FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (org.kie.workbench.common.dmn.api.property.font.FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public GeneralRectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(GeneralRectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (GeneralRectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public LocationURI getLocationURI() {
        return target.getLocationURI();
      }

      public void setLocationURI(LocationURI locationURI) {
        if (agent.binders.containsKey("locationURI")) {
          locationURI = (LocationURI) agent.binders.get("locationURI").setModel(locationURI, StateSync.FROM_MODEL, true);
        }
        changeAndFire("locationURI", locationURI);
      }

      public DocumentationLinksHolder getLinksHolder() {
        return target.getLinksHolder();
      }

      public void setLinksHolder(DocumentationLinksHolder linksHolder) {
        if (agent.binders.containsKey("linksHolder")) {
          linksHolder = (DocumentationLinksHolder) agent.binders.get("linksHolder").setModel(linksHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("linksHolder", linksHolder);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "stunnerLabels": return getStunnerLabels();
          case "allowOnlyVisualChange": return isAllowOnlyVisualChange();
          case "description": return getDescription();
          case "type": return getType();
          case "nsContext": return getNsContext();
          case "backgroundSet": return getBackgroundSet();
          case "name": return getName();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "id": return getId();
          case "locationURI": return getLocationURI();
          case "linksHolder": return getLinksHolder();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("KnowledgeSource", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "allowOnlyVisualChange": target.setAllowOnlyVisualChange((Boolean) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "type": target.setType((KnowledgeSourceType) value);
          break;
          case "backgroundSet": target.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "fontSet": target.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((GeneralRectangleDimensionsSet) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "locationURI": target.setLocationURI((LocationURI) value);
          break;
          case "linksHolder": target.setLinksHolder((DocumentationLinksHolder) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (KnowledgeSource) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("KnowledgeSource", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public ReadOnly getReadOnly(String a0) {
        final ReadOnly returnValue = target.getReadOnly(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(KnowledgeSource.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy((KnowledgeSource) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_KnowledgeSourceProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_LaneProxy extends Lane implements BindableProxy {
      private BindableProxyAgent<Lane> agent;
      private Lane target;
      public org_kie_workbench_common_stunner_bpmn_definition_LaneProxy() {
        this(new Lane());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_LaneProxy(Lane targetVal) {
        agent = new BindableProxyAgent<Lane>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(Lane.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Lane unwrap() {
        return target;
      }

      public Lane deepUnwrap() {
        final Lane clone = new Lane();
        final Lane t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_LaneProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_LaneProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("Lane", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (Lane) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Lane", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Lane.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_LaneProxy((Lane) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_LaneProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy extends Namespace implements BindableProxy {
      private BindableProxyAgent<Namespace> agent;
      private Namespace target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy() {
        this(new Namespace());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy(Namespace targetVal) {
        agent = new BindableProxyAgent<Namespace>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Namespace.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Namespace unwrap() {
        return target;
      }

      public Namespace deepUnwrap() {
        final Namespace clone = new Namespace();
        final Namespace t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Namespace", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Namespace) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Namespace", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Namespace.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy((Namespace) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_NamespaceProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy extends TextBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<TextBoxFieldDefinition> agent;
      private TextBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy() {
        this(new TextBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy(TextBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<TextBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(TextBoxFieldType.class, false, false));
        p.put("maxLength", new PropertyType(Integer.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TextBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TextBoxFieldDefinition unwrap() {
        return target;
      }

      public TextBoxFieldDefinition deepUnwrap() {
        final TextBoxFieldDefinition clone = new TextBoxFieldDefinition();
        final TextBoxFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setMaxLength(t.getMaxLength());
        clone.setPlaceHolder(t.getPlaceHolder());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public TextBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Integer getMaxLength() {
        return target.getMaxLength();
      }

      public void setMaxLength(Integer maxLength) {
        changeAndFire("maxLength", maxLength);
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "maxLength": return getMaxLength();
          case "placeHolder": return getPlaceHolder();
          case "this": return target;
          default: throw new NonExistingPropertyException("TextBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "maxLength": target.setMaxLength((Integer) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "this": target = (TextBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TextBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(TextBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy((TextBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_TextBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_IdProxy extends Id implements BindableProxy {
      private BindableProxyAgent<Id> agent;
      private Id target;
      public org_kie_workbench_common_dmn_api_property_dmn_IdProxy() {
        this(new Id());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_IdProxy(Id targetVal) {
        agent = new BindableProxyAgent<Id>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Id.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Id unwrap() {
        return target;
      }

      public Id deepUnwrap() {
        final Id clone = new Id();
        final Id t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_IdProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_IdProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public boolean isReadOnly() {
        return target.isReadOnly();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "readOnly": return isReadOnly();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Id", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Id) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Id", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Id.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_IdProxy((Id) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_IdProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy extends DecimalBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DecimalBoxFieldDefinition> agent;
      private DecimalBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy() {
        this(new DecimalBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy(DecimalBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DecimalBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(DecimalBoxFieldType.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("maxLength", new PropertyType(Integer.class, false, false));
        p.put("this", new PropertyType(DecimalBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecimalBoxFieldDefinition unwrap() {
        return target;
      }

      public DecimalBoxFieldDefinition deepUnwrap() {
        final DecimalBoxFieldDefinition clone = new DecimalBoxFieldDefinition();
        final DecimalBoxFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setPlaceHolder(t.getPlaceHolder());
        clone.setMaxLength(t.getMaxLength());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public DecimalBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Integer getMaxLength() {
        return target.getMaxLength();
      }

      public void setMaxLength(Integer maxLength) {
        changeAndFire("maxLength", maxLength);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "placeHolder": return getPlaceHolder();
          case "maxLength": return getMaxLength();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecimalBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "maxLength": target.setMaxLength((Integer) value);
          break;
          case "this": target = (DecimalBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecimalBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DecimalBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy((DecimalBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_decimalBox_definition_DecimalBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy extends ProcessReusableSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<ProcessReusableSubprocessTaskExecutionSet> agent;
      private ProcessReusableSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy() {
        this(new ProcessReusableSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy(ProcessReusableSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<ProcessReusableSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("abortParent", new PropertyType(AbortParent.class, true, false));
        p.put("independent", new PropertyType(Independent.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("waitForCompletion", new PropertyType(WaitForCompletion.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("isCase", new PropertyType(IsCase.class, true, false));
        p.put("calledElement", new PropertyType(CalledElement.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("this", new PropertyType(ProcessReusableSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessReusableSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public ProcessReusableSubprocessTaskExecutionSet deepUnwrap() {
        final ProcessReusableSubprocessTaskExecutionSet clone = new ProcessReusableSubprocessTaskExecutionSet();
        final ProcessReusableSubprocessTaskExecutionSet t = unwrap();
        if (t.getAbortParent() instanceof BindableProxy) {
          clone.setAbortParent((AbortParent) ((BindableProxy) getAbortParent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAbortParent())) {
          clone.setAbortParent((AbortParent) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAbortParent())).deepUnwrap());
        } else {
          clone.setAbortParent(t.getAbortParent());
        }
        if (t.getIndependent() instanceof BindableProxy) {
          clone.setIndependent((Independent) ((BindableProxy) getIndependent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIndependent())) {
          clone.setIndependent((Independent) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIndependent())).deepUnwrap());
        } else {
          clone.setIndependent(t.getIndependent());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getWaitForCompletion() instanceof BindableProxy) {
          clone.setWaitForCompletion((WaitForCompletion) ((BindableProxy) getWaitForCompletion()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWaitForCompletion())) {
          clone.setWaitForCompletion((WaitForCompletion) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWaitForCompletion())).deepUnwrap());
        } else {
          clone.setWaitForCompletion(t.getWaitForCompletion());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getIsCase() instanceof BindableProxy) {
          clone.setIsCase((IsCase) ((BindableProxy) getIsCase()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsCase())) {
          clone.setIsCase((IsCase) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsCase())).deepUnwrap());
        } else {
          clone.setIsCase(t.getIsCase());
        }
        if (t.getCalledElement() instanceof BindableProxy) {
          clone.setCalledElement((CalledElement) ((BindableProxy) getCalledElement()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCalledElement())) {
          clone.setCalledElement((CalledElement) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCalledElement())).deepUnwrap());
        } else {
          clone.setCalledElement(t.getCalledElement());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AbortParent getAbortParent() {
        return target.getAbortParent();
      }

      public void setAbortParent(AbortParent abortParent) {
        if (agent.binders.containsKey("abortParent")) {
          abortParent = (AbortParent) agent.binders.get("abortParent").setModel(abortParent, StateSync.FROM_MODEL, true);
        }
        changeAndFire("abortParent", abortParent);
      }

      public Independent getIndependent() {
        return target.getIndependent();
      }

      public void setIndependent(Independent independent) {
        if (agent.binders.containsKey("independent")) {
          independent = (Independent) agent.binders.get("independent").setModel(independent, StateSync.FROM_MODEL, true);
        }
        changeAndFire("independent", independent);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public WaitForCompletion getWaitForCompletion() {
        return target.getWaitForCompletion();
      }

      public void setWaitForCompletion(WaitForCompletion waitForCompletion) {
        if (agent.binders.containsKey("waitForCompletion")) {
          waitForCompletion = (WaitForCompletion) agent.binders.get("waitForCompletion").setModel(waitForCompletion, StateSync.FROM_MODEL, true);
        }
        changeAndFire("waitForCompletion", waitForCompletion);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public IsCase getIsCase() {
        return target.getIsCase();
      }

      public void setIsCase(IsCase isCase) {
        if (agent.binders.containsKey("isCase")) {
          isCase = (IsCase) agent.binders.get("isCase").setModel(isCase, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isCase", isCase);
      }

      public CalledElement getCalledElement() {
        return target.getCalledElement();
      }

      public void setCalledElement(CalledElement calledElement) {
        if (agent.binders.containsKey("calledElement")) {
          calledElement = (CalledElement) agent.binders.get("calledElement").setModel(calledElement, StateSync.FROM_MODEL, true);
        }
        changeAndFire("calledElement", calledElement);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public Object get(String property) {
        switch (property) {
          case "abortParent": return getAbortParent();
          case "independent": return getIndependent();
          case "isAsync": return getIsAsync();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "waitForCompletion": return getWaitForCompletion();
          case "onEntryAction": return getOnEntryAction();
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "adHocAutostart": return getAdHocAutostart();
          case "slaDueDate": return getSlaDueDate();
          case "isCase": return getIsCase();
          case "calledElement": return getCalledElement();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "onExitAction": return getOnExitAction();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessReusableSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "abortParent": target.setAbortParent((AbortParent) value);
          break;
          case "independent": target.setIndependent((Independent) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "waitForCompletion": target.setWaitForCompletion((WaitForCompletion) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "isCase": target.setIsCase((IsCase) value);
          break;
          case "calledElement": target.setCalledElement((CalledElement) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "this": target = (ProcessReusableSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessReusableSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessReusableSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy((ProcessReusableSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_ProcessReusableSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy extends ActivityRef implements BindableProxy {
      private BindableProxyAgent<ActivityRef> agent;
      private ActivityRef target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy() {
        this(new ActivityRef());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy(ActivityRef targetVal) {
        agent = new BindableProxyAgent<ActivityRef>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ActivityRef.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ActivityRef unwrap() {
        return target;
      }

      public ActivityRef deepUnwrap() {
        final ActivityRef clone = new ActivityRef();
        final ActivityRef t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ActivityRef", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (ActivityRef) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ActivityRef", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ActivityRef.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy((ActivityRef) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_ActivityRefProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy extends IntermediateSignalEventThrowing implements BindableProxy {
      private BindableProxyAgent<IntermediateSignalEventThrowing> agent;
      private IntermediateSignalEventThrowing target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy() {
        this(new IntermediateSignalEventThrowing());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy(IntermediateSignalEventThrowing targetVal) {
        agent = new BindableProxyAgent<IntermediateSignalEventThrowing>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(ScopedSignalEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateSignalEventThrowing.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateSignalEventThrowing unwrap() {
        return target;
      }

      public IntermediateSignalEventThrowing deepUnwrap() {
        final IntermediateSignalEventThrowing clone = new IntermediateSignalEventThrowing();
        final IntermediateSignalEventThrowing t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ScopedSignalEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ScopedSignalEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public ScopedSignalEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ScopedSignalEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ScopedSignalEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateSignalEventThrowing", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((ScopedSignalEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateSignalEventThrowing) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateSignalEventThrowing", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateSignalEventThrowing.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy((IntermediateSignalEventThrowing) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventThrowingProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy extends BusinessKnowledgeModel implements BindableProxy {
      private BindableProxyAgent<BusinessKnowledgeModel> agent;
      private BusinessKnowledgeModel target;
      public org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy() {
        this(new BusinessKnowledgeModel());
      }

      public org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy(BusinessKnowledgeModel targetVal) {
        agent = new BindableProxyAgent<BusinessKnowledgeModel>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("encapsulatedLogic", new PropertyType(FunctionDefinition.class, false, false));
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("allowOnlyVisualChange", new PropertyType(Boolean.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("backgroundSet", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        p.put("variable", new PropertyType(InformationItemPrimary.class, true, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("fontSet", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(GeneralRectangleDimensionsSet.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("linksHolder", new PropertyType(DocumentationLinksHolder.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(BusinessKnowledgeModel.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BusinessKnowledgeModel unwrap() {
        return target;
      }

      public BusinessKnowledgeModel deepUnwrap() {
        final BusinessKnowledgeModel clone = new BusinessKnowledgeModel();
        final BusinessKnowledgeModel t = unwrap();
        clone.setEncapsulatedLogic(t.getEncapsulatedLogic());
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        clone.setAllowOnlyVisualChange(t.isAllowOnlyVisualChange());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getVariable() instanceof BindableProxy) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) getVariable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getVariable())) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getVariable())).deepUnwrap());
        } else {
          clone.setVariable(t.getVariable());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getLinksHolder() instanceof BindableProxy) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) getLinksHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLinksHolder())) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLinksHolder())).deepUnwrap());
        } else {
          clone.setLinksHolder(t.getLinksHolder());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public FunctionDefinition getEncapsulatedLogic() {
        return target.getEncapsulatedLogic();
      }

      public void setEncapsulatedLogic(FunctionDefinition encapsulatedLogic) {
        changeAndFire("encapsulatedLogic", encapsulatedLogic);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public boolean isAllowOnlyVisualChange() {
        return target.isAllowOnlyVisualChange();
      }

      public void setAllowOnlyVisualChange(boolean allowOnlyVisualChange) {
        changeAndFire("allowOnlyVisualChange", allowOnlyVisualChange);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(org.kie.workbench.common.dmn.api.property.background.BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InformationItemPrimary getVariable() {
        return target.getVariable();
      }

      public void setVariable(InformationItemPrimary variable) {
        if (agent.binders.containsKey("variable")) {
          variable = (InformationItemPrimary) agent.binders.get("variable").setModel(variable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("variable", variable);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(org.kie.workbench.common.dmn.api.property.font.FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (org.kie.workbench.common.dmn.api.property.font.FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public GeneralRectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(GeneralRectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (GeneralRectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public DocumentationLinksHolder getLinksHolder() {
        return target.getLinksHolder();
      }

      public void setLinksHolder(DocumentationLinksHolder linksHolder) {
        if (agent.binders.containsKey("linksHolder")) {
          linksHolder = (DocumentationLinksHolder) agent.binders.get("linksHolder").setModel(linksHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("linksHolder", linksHolder);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "encapsulatedLogic": return getEncapsulatedLogic();
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "allowOnlyVisualChange": return isAllowOnlyVisualChange();
          case "description": return getDescription();
          case "nsContext": return getNsContext();
          case "backgroundSet": return getBackgroundSet();
          case "variable": return getVariable();
          case "name": return getName();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "id": return getId();
          case "linksHolder": return getLinksHolder();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("BusinessKnowledgeModel", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "encapsulatedLogic": target.setEncapsulatedLogic((FunctionDefinition) value);
          break;
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "allowOnlyVisualChange": target.setAllowOnlyVisualChange((Boolean) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "backgroundSet": target.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value);
          break;
          case "variable": target.setVariable((InformationItemPrimary) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "fontSet": target.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((GeneralRectangleDimensionsSet) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "linksHolder": target.setLinksHolder((DocumentationLinksHolder) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (BusinessKnowledgeModel) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BusinessKnowledgeModel", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public HasExpression asHasExpression() {
        final HasExpression returnValue = target.asHasExpression();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public ReadOnly getReadOnly(String a0) {
        final ReadOnly returnValue = target.getReadOnly(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(BusinessKnowledgeModel.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy((BusinessKnowledgeModel) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_BusinessKnowledgeModelProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy extends IntermediateCompensationEventThrowing implements BindableProxy {
      private BindableProxyAgent<IntermediateCompensationEventThrowing> agent;
      private IntermediateCompensationEventThrowing target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy() {
        this(new IntermediateCompensationEventThrowing());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy(IntermediateCompensationEventThrowing targetVal) {
        agent = new BindableProxyAgent<IntermediateCompensationEventThrowing>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CompensationEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateCompensationEventThrowing.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateCompensationEventThrowing unwrap() {
        return target;
      }

      public IntermediateCompensationEventThrowing deepUnwrap() {
        final IntermediateCompensationEventThrowing clone = new IntermediateCompensationEventThrowing();
        final IntermediateCompensationEventThrowing t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CompensationEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CompensationEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CompensationEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CompensationEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CompensationEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateCompensationEventThrowing", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CompensationEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateCompensationEventThrowing) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateCompensationEventThrowing", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateCompensationEventThrowing.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy((IntermediateCompensationEventThrowing) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventThrowingProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy extends StartSignalEvent implements BindableProxy {
      private BindableProxyAgent<StartSignalEvent> agent;
      private StartSignalEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy() {
        this(new StartSignalEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy(StartSignalEvent targetVal) {
        agent = new BindableProxyAgent<StartSignalEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(InterruptingSignalEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartSignalEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartSignalEvent unwrap() {
        return target;
      }

      public StartSignalEvent deepUnwrap() {
        final StartSignalEvent clone = new StartSignalEvent();
        final StartSignalEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((InterruptingSignalEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((InterruptingSignalEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InterruptingSignalEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(InterruptingSignalEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (InterruptingSignalEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartSignalEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((InterruptingSignalEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartSignalEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartSignalEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartSignalEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy((StartSignalEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartSignalEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy extends WaitForCompletion implements BindableProxy {
      private BindableProxyAgent<WaitForCompletion> agent;
      private WaitForCompletion target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy() {
        this(new WaitForCompletion());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy(WaitForCompletion targetVal) {
        agent = new BindableProxyAgent<WaitForCompletion>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(WaitForCompletion.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public WaitForCompletion unwrap() {
        return target;
      }

      public WaitForCompletion deepUnwrap() {
        final WaitForCompletion clone = new WaitForCompletion();
        final WaitForCompletion t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("WaitForCompletion", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (WaitForCompletion) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("WaitForCompletion", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(WaitForCompletion.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy((WaitForCompletion) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_WaitForCompletionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy extends DocumentationLinksHolder implements BindableProxy {
      private BindableProxyAgent<DocumentationLinksHolder> agent;
      private DocumentationLinksHolder target;
      public org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy() {
        this(new DocumentationLinksHolder());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy(DocumentationLinksHolder targetVal) {
        agent = new BindableProxyAgent<DocumentationLinksHolder>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(DocumentationLinks.class, false, false));
        p.put("this", new PropertyType(DocumentationLinksHolder.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DocumentationLinksHolder unwrap() {
        return target;
      }

      public DocumentationLinksHolder deepUnwrap() {
        final DocumentationLinksHolder clone = new DocumentationLinksHolder();
        final DocumentationLinksHolder t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DocumentationLinks getValue() {
        return target.getValue();
      }

      public void setValue(DocumentationLinks value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DocumentationLinksHolder", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((DocumentationLinks) value);
          break;
          case "this": target = (DocumentationLinksHolder) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DocumentationLinksHolder", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DocumentationLinksHolder.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy((DocumentationLinksHolder) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_DocumentationLinksHolderProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy extends org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet> agent;
      private org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet target;
      public org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy() {
        this(new org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("globalVariables", new PropertyType(GlobalVariables.class, true, false));
        p.put("processInstanceDescription", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription.class, true, false));
        p.put("imports", new PropertyType(Imports.class, true, false));
        p.put("packageProperty", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.Package.class, true, false));
        p.put("documentation", new PropertyType(Documentation.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("name", new PropertyType(Name.class, true, false));
        p.put("id", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id.class, true, false));
        p.put("adHoc", new PropertyType(AdHoc.class, true, false));
        p.put("version", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.Version.class, true, false));
        p.put("executable", new PropertyType(Executable.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet deepUnwrap() {
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet clone = new org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet();
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet t = unwrap();
        if (t.getGlobalVariables() instanceof BindableProxy) {
          clone.setGlobalVariables((GlobalVariables) ((BindableProxy) getGlobalVariables()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGlobalVariables())) {
          clone.setGlobalVariables((GlobalVariables) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGlobalVariables())).deepUnwrap());
        } else {
          clone.setGlobalVariables(t.getGlobalVariables());
        }
        if (t.getProcessInstanceDescription() instanceof BindableProxy) {
          clone.setProcessInstanceDescription((org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription) ((BindableProxy) getProcessInstanceDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessInstanceDescription())) {
          clone.setProcessInstanceDescription((org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessInstanceDescription())).deepUnwrap());
        } else {
          clone.setProcessInstanceDescription(t.getProcessInstanceDescription());
        }
        if (t.getImports() instanceof BindableProxy) {
          clone.setImports((Imports) ((BindableProxy) getImports()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImports())) {
          clone.setImports((Imports) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImports())).deepUnwrap());
        } else {
          clone.setImports(t.getImports());
        }
        if (t.getPackageProperty() instanceof BindableProxy) {
          clone.setPackageProperty((org.kie.workbench.common.stunner.cm.definition.property.diagram.Package) ((BindableProxy) getPackageProperty()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getPackageProperty())) {
          clone.setPackageProperty((org.kie.workbench.common.stunner.cm.definition.property.diagram.Package) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getPackageProperty())).deepUnwrap());
        } else {
          clone.setPackageProperty(t.getPackageProperty());
        }
        if (t.getDocumentation() instanceof BindableProxy) {
          clone.setDocumentation((Documentation) ((BindableProxy) getDocumentation()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDocumentation())) {
          clone.setDocumentation((Documentation) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDocumentation())).deepUnwrap());
        } else {
          clone.setDocumentation(t.getDocumentation());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getAdHoc() instanceof BindableProxy) {
          clone.setAdHoc((AdHoc) ((BindableProxy) getAdHoc()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHoc())) {
          clone.setAdHoc((AdHoc) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHoc())).deepUnwrap());
        } else {
          clone.setAdHoc(t.getAdHoc());
        }
        if (t.getVersion() instanceof BindableProxy) {
          clone.setVersion((org.kie.workbench.common.stunner.cm.definition.property.diagram.Version) ((BindableProxy) getVersion()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getVersion())) {
          clone.setVersion((org.kie.workbench.common.stunner.cm.definition.property.diagram.Version) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getVersion())).deepUnwrap());
        } else {
          clone.setVersion(t.getVersion());
        }
        if (t.getExecutable() instanceof BindableProxy) {
          clone.setExecutable((Executable) ((BindableProxy) getExecutable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutable())) {
          clone.setExecutable((Executable) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutable())).deepUnwrap());
        } else {
          clone.setExecutable(t.getExecutable());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public GlobalVariables getGlobalVariables() {
        return target.getGlobalVariables();
      }

      public void setGlobalVariables(GlobalVariables globalVariables) {
        if (agent.binders.containsKey("globalVariables")) {
          globalVariables = (GlobalVariables) agent.binders.get("globalVariables").setModel(globalVariables, StateSync.FROM_MODEL, true);
        }
        changeAndFire("globalVariables", globalVariables);
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription getProcessInstanceDescription() {
        return target.getProcessInstanceDescription();
      }

      public void setProcessInstanceDescription(org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription processInstanceDescription) {
        if (agent.binders.containsKey("processInstanceDescription")) {
          processInstanceDescription = (org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription) agent.binders.get("processInstanceDescription").setModel(processInstanceDescription, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processInstanceDescription", processInstanceDescription);
      }

      public Imports getImports() {
        return target.getImports();
      }

      public void setImports(Imports imports) {
        if (agent.binders.containsKey("imports")) {
          imports = (Imports) agent.binders.get("imports").setModel(imports, StateSync.FROM_MODEL, true);
        }
        changeAndFire("imports", imports);
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.Package getPackageProperty() {
        return target.getPackageProperty();
      }

      public void setPackageProperty(org.kie.workbench.common.stunner.cm.definition.property.diagram.Package packageProperty) {
        if (agent.binders.containsKey("packageProperty")) {
          packageProperty = (org.kie.workbench.common.stunner.cm.definition.property.diagram.Package) agent.binders.get("packageProperty").setModel(packageProperty, StateSync.FROM_MODEL, true);
        }
        changeAndFire("packageProperty", packageProperty);
      }

      public Documentation getDocumentation() {
        return target.getDocumentation();
      }

      public void setDocumentation(Documentation documentation) {
        if (agent.binders.containsKey("documentation")) {
          documentation = (Documentation) agent.binders.get("documentation").setModel(documentation, StateSync.FROM_MODEL, true);
        }
        changeAndFire("documentation", documentation);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Name getName() {
        return target.getName();
      }

      public void setName(Name name) {
        if (agent.binders.containsKey("name")) {
          name = (Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id getId() {
        return target.getId();
      }

      public void setId(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id id) {
        if (agent.binders.containsKey("id")) {
          id = (org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public AdHoc getAdHoc() {
        return target.getAdHoc();
      }

      public void setAdHoc(AdHoc adHoc) {
        if (agent.binders.containsKey("adHoc")) {
          adHoc = (AdHoc) agent.binders.get("adHoc").setModel(adHoc, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHoc", adHoc);
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.Version getVersion() {
        return target.getVersion();
      }

      public void setVersion(org.kie.workbench.common.stunner.cm.definition.property.diagram.Version version) {
        if (agent.binders.containsKey("version")) {
          version = (org.kie.workbench.common.stunner.cm.definition.property.diagram.Version) agent.binders.get("version").setModel(version, StateSync.FROM_MODEL, true);
        }
        changeAndFire("version", version);
      }

      public Executable getExecutable() {
        return target.getExecutable();
      }

      public void setExecutable(Executable executable) {
        if (agent.binders.containsKey("executable")) {
          executable = (Executable) agent.binders.get("executable").setModel(executable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executable", executable);
      }

      public Object get(String property) {
        switch (property) {
          case "globalVariables": return getGlobalVariables();
          case "processInstanceDescription": return getProcessInstanceDescription();
          case "imports": return getImports();
          case "packageProperty": return getPackageProperty();
          case "documentation": return getDocumentation();
          case "slaDueDate": return getSlaDueDate();
          case "name": return getName();
          case "id": return getId();
          case "adHoc": return getAdHoc();
          case "version": return getVersion();
          case "executable": return getExecutable();
          case "this": return target;
          default: throw new NonExistingPropertyException("DiagramSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "globalVariables": target.setGlobalVariables((GlobalVariables) value);
          break;
          case "processInstanceDescription": target.setProcessInstanceDescription((org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription) value);
          break;
          case "imports": target.setImports((Imports) value);
          break;
          case "packageProperty": target.setPackageProperty((org.kie.workbench.common.stunner.cm.definition.property.diagram.Package) value);
          break;
          case "documentation": target.setDocumentation((Documentation) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "name": target.setName((Name) value);
          break;
          case "id": target.setId((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) value);
          break;
          case "adHoc": target.setAdHoc((AdHoc) value);
          break;
          case "version": target.setVersion((org.kie.workbench.common.stunner.cm.definition.property.diagram.Version) value);
          break;
          case "executable": target.setExecutable((Executable) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DiagramSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy((org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_DiagramSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy extends TextFormat implements BindableProxy {
      private BindableProxyAgent<TextFormat> agent;
      private TextFormat target;
      public org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy() {
        this(new TextFormat());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy(TextFormat targetVal) {
        agent = new BindableProxyAgent<TextFormat>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TextFormat.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TextFormat unwrap() {
        return target;
      }

      public TextFormat deepUnwrap() {
        final TextFormat clone = new TextFormat();
        final TextFormat t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("TextFormat", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (TextFormat) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TextFormat", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TextFormat.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy((TextFormat) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_TextFormatProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy extends MultipleInstanceCollectionInput implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceCollectionInput> agent;
      private MultipleInstanceCollectionInput target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy() {
        this(new MultipleInstanceCollectionInput());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy(MultipleInstanceCollectionInput targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceCollectionInput>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceCollectionInput unwrap() {
        return target;
      }

      public MultipleInstanceCollectionInput deepUnwrap() {
        final MultipleInstanceCollectionInput clone = new MultipleInstanceCollectionInput();
        final MultipleInstanceCollectionInput t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceCollectionInput", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (MultipleInstanceCollectionInput) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceCollectionInput", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceCollectionInput.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy((MultipleInstanceCollectionInput) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionInputProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy extends Definitions implements BindableProxy {
      private BindableProxyAgent<Definitions> agent;
      private Definitions target;
      public org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy() {
        this(new Definitions());
      }

      public org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy(Definitions targetVal) {
        agent = new BindableProxyAgent<Definitions>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("import", new PropertyType(List.class, false, true));
        p.put("exporterVersion", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("elementCollection", new PropertyType(List.class, false, true));
        p.put("expressionLanguage", new PropertyType(ExpressionLanguage.class, true, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("itemDefinition", new PropertyType(List.class, false, true));
        p.put("artifact", new PropertyType(List.class, false, true));
        p.put("businessContextElement", new PropertyType(List.class, false, true));
        p.put("exporter", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("typeLanguage", new PropertyType(String.class, false, false));
        p.put("namespace", new PropertyType(Text.class, true, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("drgElement", new PropertyType(List.class, false, true));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(Definitions.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Definitions unwrap() {
        return target;
      }

      public Definitions deepUnwrap() {
        final Definitions clone = new Definitions();
        final Definitions t = unwrap();
        clone.setParent(t.getParent());
        clone.setExporterVersion(t.getExporterVersion());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getExpressionLanguage() instanceof BindableProxy) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) getExpressionLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExpressionLanguage())) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExpressionLanguage())).deepUnwrap());
        } else {
          clone.setExpressionLanguage(t.getExpressionLanguage());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        clone.setExporter(t.getExporter());
        clone.setTypeLanguage(t.getTypeLanguage());
        if (t.getNamespace() instanceof BindableProxy) {
          clone.setNamespace((Text) ((BindableProxy) getNamespace()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getNamespace())) {
          clone.setNamespace((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getNamespace())).deepUnwrap());
        } else {
          clone.setNamespace(t.getNamespace());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public List getImport() {
        return target.getImport();
      }

      public String getExporterVersion() {
        return target.getExporterVersion();
      }

      public void setExporterVersion(String exporterVersion) {
        changeAndFire("exporterVersion", exporterVersion);
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public List getElementCollection() {
        return target.getElementCollection();
      }

      public ExpressionLanguage getExpressionLanguage() {
        return target.getExpressionLanguage();
      }

      public void setExpressionLanguage(ExpressionLanguage expressionLanguage) {
        if (agent.binders.containsKey("expressionLanguage")) {
          expressionLanguage = (ExpressionLanguage) agent.binders.get("expressionLanguage").setModel(expressionLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("expressionLanguage", expressionLanguage);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public List getItemDefinition() {
        return target.getItemDefinition();
      }

      public List getArtifact() {
        return target.getArtifact();
      }

      public List getBusinessContextElement() {
        return target.getBusinessContextElement();
      }

      public String getExporter() {
        return target.getExporter();
      }

      public void setExporter(String exporter) {
        changeAndFire("exporter", exporter);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public String getTypeLanguage() {
        return target.getTypeLanguage();
      }

      public void setTypeLanguage(String typeLanguage) {
        changeAndFire("typeLanguage", typeLanguage);
      }

      public Text getNamespace() {
        return target.getNamespace();
      }

      public void setNamespace(Text namespace) {
        if (agent.binders.containsKey("namespace")) {
          namespace = (Text) agent.binders.get("namespace").setModel(namespace, StateSync.FROM_MODEL, true);
        }
        changeAndFire("namespace", namespace);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public List getDrgElement() {
        return target.getDrgElement();
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "import": return getImport();
          case "exporterVersion": return getExporterVersion();
          case "extensionElements": return getExtensionElements();
          case "elementCollection": return getElementCollection();
          case "expressionLanguage": return getExpressionLanguage();
          case "description": return getDescription();
          case "itemDefinition": return getItemDefinition();
          case "artifact": return getArtifact();
          case "businessContextElement": return getBusinessContextElement();
          case "exporter": return getExporter();
          case "nsContext": return getNsContext();
          case "typeLanguage": return getTypeLanguage();
          case "namespace": return getNamespace();
          case "name": return getName();
          case "id": return getId();
          case "drgElement": return getDrgElement();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("Definitions", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "exporterVersion": target.setExporterVersion((String) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "expressionLanguage": target.setExpressionLanguage((ExpressionLanguage) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "exporter": target.setExporter((String) value);
          break;
          case "typeLanguage": target.setTypeLanguage((String) value);
          break;
          case "namespace": target.setNamespace((Text) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (Definitions) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Definitions", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(Definitions.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy((Definitions) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_DefinitionsProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy extends RuleFlowGroup implements BindableProxy {
      private BindableProxyAgent<RuleFlowGroup> agent;
      private RuleFlowGroup target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy() {
        this(new RuleFlowGroup());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy(RuleFlowGroup targetVal) {
        agent = new BindableProxyAgent<RuleFlowGroup>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(RuleFlowGroup.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public RuleFlowGroup unwrap() {
        return target;
      }

      public RuleFlowGroup deepUnwrap() {
        final RuleFlowGroup clone = new RuleFlowGroup();
        final RuleFlowGroup t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("RuleFlowGroup", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (RuleFlowGroup) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("RuleFlowGroup", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(RuleFlowGroup.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy((RuleFlowGroup) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_RuleFlowGroupProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy extends Priority implements BindableProxy {
      private BindableProxyAgent<Priority> agent;
      private Priority target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy() {
        this(new Priority());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy(Priority targetVal) {
        agent = new BindableProxyAgent<Priority>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Priority.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Priority unwrap() {
        return target;
      }

      public Priority deepUnwrap() {
        final Priority clone = new Priority();
        final Priority t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Priority", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Priority) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Priority", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Priority.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy((Priority) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_connectors_PriorityProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy extends Currency implements BindableProxy {
      private BindableProxyAgent<Currency> agent;
      private Currency target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy() {
        this(new Currency());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy(Currency targetVal) {
        agent = new BindableProxyAgent<Currency>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Currency.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Currency unwrap() {
        return target;
      }

      public Currency deepUnwrap() {
        final Currency clone = new Currency();
        final Currency t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Currency", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Currency) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Currency", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Currency.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy((Currency) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_CurrencyProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy extends InformationRequirement implements BindableProxy {
      private BindableProxyAgent<InformationRequirement> agent;
      private InformationRequirement target;
      public org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy() {
        this(new InformationRequirement());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy(InformationRequirement targetVal) {
        agent = new BindableProxyAgent<InformationRequirement>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InformationRequirement.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InformationRequirement unwrap() {
        return target;
      }

      public InformationRequirement deepUnwrap() {
        final InformationRequirement clone = new InformationRequirement();
        final InformationRequirement t = unwrap();
        clone.setParent(t.getParent());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "nsContext": return getNsContext();
          case "stunnerLabels": return getStunnerLabels();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InformationRequirement", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InformationRequirement) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InformationRequirement", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InformationRequirement.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy((InformationRequirement) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InformationRequirementProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy extends EnumListBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<EnumListBoxFieldDefinition> agent;
      private EnumListBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy() {
        this(new EnumListBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy(EnumListBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<EnumListBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("addEmptyOption", new PropertyType(Boolean.class, false, false));
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Enum.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ListBoxFieldType.class, false, false));
        p.put("this", new PropertyType(EnumListBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EnumListBoxFieldDefinition unwrap() {
        return target;
      }

      public EnumListBoxFieldDefinition deepUnwrap() {
        final EnumListBoxFieldDefinition clone = new EnumListBoxFieldDefinition();
        final EnumListBoxFieldDefinition t = unwrap();
        clone.setAddEmptyOption(t.getAddEmptyOption());
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getAddEmptyOption() {
        return target.getAddEmptyOption();
      }

      public void setAddEmptyOption(Boolean addEmptyOption) {
        changeAndFire("addEmptyOption", addEmptyOption);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Enum getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Enum defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<EnumSelectorOption> options) {
        List<EnumSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ListBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "addEmptyOption": return getAddEmptyOption();
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("EnumListBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "addEmptyOption": target.setAddEmptyOption((Boolean) value);
          break;
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Enum) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<EnumSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (EnumListBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EnumListBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(EnumListBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy((EnumListBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_EnumListBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy extends LocationURI implements BindableProxy {
      private BindableProxyAgent<LocationURI> agent;
      private LocationURI target;
      public org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy() {
        this(new LocationURI());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy(LocationURI targetVal) {
        agent = new BindableProxyAgent<LocationURI>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(LocationURI.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public LocationURI unwrap() {
        return target;
      }

      public LocationURI deepUnwrap() {
        final LocationURI clone = new LocationURI();
        final LocationURI t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("LocationURI", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (LocationURI) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("LocationURI", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(LocationURI.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy((LocationURI) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_LocationURIProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy extends AdHocSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<AdHocSubprocessTaskExecutionSet> agent;
      private AdHocSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy() {
        this(new AdHocSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy(AdHocSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<AdHocSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("adHocOrdering", new PropertyType(AdHocOrdering.class, true, false));
        p.put("adHocActivationCondition", new PropertyType(AdHocActivationCondition.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("adHocCompletionCondition", new PropertyType(AdHocCompletionCondition.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("this", new PropertyType(AdHocSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHocSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public AdHocSubprocessTaskExecutionSet deepUnwrap() {
        final AdHocSubprocessTaskExecutionSet clone = new AdHocSubprocessTaskExecutionSet();
        final AdHocSubprocessTaskExecutionSet t = unwrap();
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getAdHocOrdering() instanceof BindableProxy) {
          clone.setAdHocOrdering((AdHocOrdering) ((BindableProxy) getAdHocOrdering()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocOrdering())) {
          clone.setAdHocOrdering((AdHocOrdering) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocOrdering())).deepUnwrap());
        } else {
          clone.setAdHocOrdering(t.getAdHocOrdering());
        }
        if (t.getAdHocActivationCondition() instanceof BindableProxy) {
          clone.setAdHocActivationCondition((AdHocActivationCondition) ((BindableProxy) getAdHocActivationCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocActivationCondition())) {
          clone.setAdHocActivationCondition((AdHocActivationCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocActivationCondition())).deepUnwrap());
        } else {
          clone.setAdHocActivationCondition(t.getAdHocActivationCondition());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getAdHocCompletionCondition() instanceof BindableProxy) {
          clone.setAdHocCompletionCondition((AdHocCompletionCondition) ((BindableProxy) getAdHocCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocCompletionCondition())) {
          clone.setAdHocCompletionCondition((AdHocCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocCompletionCondition())).deepUnwrap());
        } else {
          clone.setAdHocCompletionCondition(t.getAdHocCompletionCondition());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public AdHocOrdering getAdHocOrdering() {
        return target.getAdHocOrdering();
      }

      public void setAdHocOrdering(AdHocOrdering adHocOrdering) {
        if (agent.binders.containsKey("adHocOrdering")) {
          adHocOrdering = (AdHocOrdering) agent.binders.get("adHocOrdering").setModel(adHocOrdering, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocOrdering", adHocOrdering);
      }

      public AdHocActivationCondition getAdHocActivationCondition() {
        return target.getAdHocActivationCondition();
      }

      public void setAdHocActivationCondition(AdHocActivationCondition adHocActivationCondition) {
        if (agent.binders.containsKey("adHocActivationCondition")) {
          adHocActivationCondition = (AdHocActivationCondition) agent.binders.get("adHocActivationCondition").setModel(adHocActivationCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocActivationCondition", adHocActivationCondition);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public AdHocCompletionCondition getAdHocCompletionCondition() {
        return target.getAdHocCompletionCondition();
      }

      public void setAdHocCompletionCondition(AdHocCompletionCondition adHocCompletionCondition) {
        if (agent.binders.containsKey("adHocCompletionCondition")) {
          adHocCompletionCondition = (AdHocCompletionCondition) agent.binders.get("adHocCompletionCondition").setModel(adHocCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocCompletionCondition", adHocCompletionCondition);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public Object get(String property) {
        switch (property) {
          case "adHocAutostart": return getAdHocAutostart();
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "adHocOrdering": return getAdHocOrdering();
          case "adHocActivationCondition": return getAdHocActivationCondition();
          case "onExitAction": return getOnExitAction();
          case "adHocCompletionCondition": return getAdHocCompletionCondition();
          case "onEntryAction": return getOnEntryAction();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "adHocOrdering": target.setAdHocOrdering((AdHocOrdering) value);
          break;
          case "adHocActivationCondition": target.setAdHocActivationCondition((AdHocActivationCondition) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "adHocCompletionCondition": target.setAdHocCompletionCondition((AdHocCompletionCondition) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "this": target = (AdHocSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHocSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy((AdHocSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_AdHocSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy extends GatewayExecutionSet implements BindableProxy {
      private BindableProxyAgent<GatewayExecutionSet> agent;
      private GatewayExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy() {
        this(new GatewayExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy(GatewayExecutionSet targetVal) {
        agent = new BindableProxyAgent<GatewayExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("defaultRoute", new PropertyType(DefaultRoute.class, true, false));
        p.put("this", new PropertyType(GatewayExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GatewayExecutionSet unwrap() {
        return target;
      }

      public GatewayExecutionSet deepUnwrap() {
        final GatewayExecutionSet clone = new GatewayExecutionSet();
        final GatewayExecutionSet t = unwrap();
        if (t.getDefaultRoute() instanceof BindableProxy) {
          clone.setDefaultRoute((DefaultRoute) ((BindableProxy) getDefaultRoute()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDefaultRoute())) {
          clone.setDefaultRoute((DefaultRoute) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDefaultRoute())).deepUnwrap());
        } else {
          clone.setDefaultRoute(t.getDefaultRoute());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DefaultRoute getDefaultRoute() {
        return target.getDefaultRoute();
      }

      public void setDefaultRoute(DefaultRoute defaultRoute) {
        if (agent.binders.containsKey("defaultRoute")) {
          defaultRoute = (DefaultRoute) agent.binders.get("defaultRoute").setModel(defaultRoute, StateSync.FROM_MODEL, true);
        }
        changeAndFire("defaultRoute", defaultRoute);
      }

      public Object get(String property) {
        switch (property) {
          case "defaultRoute": return getDefaultRoute();
          case "this": return target;
          default: throw new NonExistingPropertyException("GatewayExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "defaultRoute": target.setDefaultRoute((DefaultRoute) value);
          break;
          case "this": target = (GatewayExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GatewayExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(GatewayExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy((GatewayExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_gateway_GatewayExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy extends ScopedSignalEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<ScopedSignalEventExecutionSet> agent;
      private ScopedSignalEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy() {
        this(new ScopedSignalEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy(ScopedSignalEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<ScopedSignalEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("signalScope", new PropertyType(SignalScope.class, true, false));
        p.put("signalRef", new PropertyType(SignalRef.class, true, false));
        p.put("this", new PropertyType(ScopedSignalEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScopedSignalEventExecutionSet unwrap() {
        return target;
      }

      public ScopedSignalEventExecutionSet deepUnwrap() {
        final ScopedSignalEventExecutionSet clone = new ScopedSignalEventExecutionSet();
        final ScopedSignalEventExecutionSet t = unwrap();
        if (t.getSignalScope() instanceof BindableProxy) {
          clone.setSignalScope((SignalScope) ((BindableProxy) getSignalScope()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSignalScope())) {
          clone.setSignalScope((SignalScope) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSignalScope())).deepUnwrap());
        } else {
          clone.setSignalScope(t.getSignalScope());
        }
        if (t.getSignalRef() instanceof BindableProxy) {
          clone.setSignalRef((SignalRef) ((BindableProxy) getSignalRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSignalRef())) {
          clone.setSignalRef((SignalRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSignalRef())).deepUnwrap());
        } else {
          clone.setSignalRef(t.getSignalRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public SignalScope getSignalScope() {
        return target.getSignalScope();
      }

      public void setSignalScope(SignalScope signalScope) {
        if (agent.binders.containsKey("signalScope")) {
          signalScope = (SignalScope) agent.binders.get("signalScope").setModel(signalScope, StateSync.FROM_MODEL, true);
        }
        changeAndFire("signalScope", signalScope);
      }

      public SignalRef getSignalRef() {
        return target.getSignalRef();
      }

      public void setSignalRef(SignalRef signalRef) {
        if (agent.binders.containsKey("signalRef")) {
          signalRef = (SignalRef) agent.binders.get("signalRef").setModel(signalRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("signalRef", signalRef);
      }

      public Object get(String property) {
        switch (property) {
          case "signalScope": return getSignalScope();
          case "signalRef": return getSignalRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScopedSignalEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "signalScope": target.setSignalScope((SignalScope) value);
          break;
          case "signalRef": target.setSignalRef((SignalRef) value);
          break;
          case "this": target = (ScopedSignalEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScopedSignalEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ScopedSignalEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy((ScopedSignalEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_ScopedSignalEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy extends DateMultipleSelectorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DateMultipleSelectorFieldDefinition> agent;
      private DateMultipleSelectorFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy() {
        this(new DateMultipleSelectorFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy(DateMultipleSelectorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DateMultipleSelectorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDropdownElements", new PropertyType(Integer.class, false, false));
        p.put("listOfValues", new PropertyType(List.class, false, true));
        p.put("maxElementsOnTitle", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("allowFilter", new PropertyType(Boolean.class, false, false));
        p.put("allowClearSelection", new PropertyType(Boolean.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(DateMultipleSelectorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DateMultipleSelectorFieldDefinition unwrap() {
        return target;
      }

      public DateMultipleSelectorFieldDefinition deepUnwrap() {
        final DateMultipleSelectorFieldDefinition clone = new DateMultipleSelectorFieldDefinition();
        final DateMultipleSelectorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDropdownElements(t.getMaxDropdownElements());
        if (t.getListOfValues() != null) {
          final List listOfValuesClone = new ArrayList();
          for (Object listOfValuesElem : t.getListOfValues()) {
            if (listOfValuesElem instanceof BindableProxy) {
              listOfValuesClone.add(((BindableProxy) listOfValuesElem).deepUnwrap());
            } else {
              listOfValuesClone.add(listOfValuesElem);
            }
          }
          clone.setListOfValues(listOfValuesClone);
        }
        clone.setMaxElementsOnTitle(t.getMaxElementsOnTitle());
        clone.setName(t.getName());
        clone.setAllowFilter(t.getAllowFilter());
        clone.setAllowClearSelection(t.getAllowClearSelection());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDropdownElements() {
        return target.getMaxDropdownElements();
      }

      public void setMaxDropdownElements(Integer maxDropdownElements) {
        changeAndFire("maxDropdownElements", maxDropdownElements);
      }

      public List getListOfValues() {
        return target.getListOfValues();
      }

      public void setListOfValues(List<Date> listOfValues) {
        List<Date> oldValue = target.getListOfValues();
        listOfValues = agent.ensureBoundListIsProxied("listOfValues", listOfValues);
        target.setListOfValues(listOfValues);
        agent.updateWidgetsAndFireEvent(true, "listOfValues", oldValue, listOfValues);
      }

      public Integer getMaxElementsOnTitle() {
        return target.getMaxElementsOnTitle();
      }

      public void setMaxElementsOnTitle(Integer maxElementsOnTitle) {
        changeAndFire("maxElementsOnTitle", maxElementsOnTitle);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Boolean getAllowFilter() {
        return target.getAllowFilter();
      }

      public void setAllowFilter(Boolean allowFilter) {
        changeAndFire("allowFilter", allowFilter);
      }

      public Boolean getAllowClearSelection() {
        return target.getAllowClearSelection();
      }

      public void setAllowClearSelection(Boolean allowClearSelection) {
        changeAndFire("allowClearSelection", allowClearSelection);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDropdownElements": return getMaxDropdownElements();
          case "listOfValues": return getListOfValues();
          case "maxElementsOnTitle": return getMaxElementsOnTitle();
          case "name": return getName();
          case "allowFilter": return getAllowFilter();
          case "allowClearSelection": return getAllowClearSelection();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DateMultipleSelectorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDropdownElements": target.setMaxDropdownElements((Integer) value);
          break;
          case "listOfValues": target.setListOfValues((List<Date>) value);
          break;
          case "maxElementsOnTitle": target.setMaxElementsOnTitle((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "allowFilter": target.setAllowFilter((Boolean) value);
          break;
          case "allowClearSelection": target.setAllowClearSelection((Boolean) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DateMultipleSelectorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DateMultipleSelectorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DateMultipleSelectorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy((DateMultipleSelectorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DateMultipleSelectorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy extends Question implements BindableProxy {
      private BindableProxyAgent<Question> agent;
      private Question target;
      public org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy() {
        this(new Question());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy(Question targetVal) {
        agent = new BindableProxyAgent<Question>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Question.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Question unwrap() {
        return target;
      }

      public Question deepUnwrap() {
        final Question clone = new Question();
        final Question t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Question", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Question) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Question", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Question.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy((Question) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_QuestionProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy extends CaseManagementDiagram implements BindableProxy {
      private BindableProxyAgent<CaseManagementDiagram> agent;
      private CaseManagementDiagram target;
      public org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy() {
        this(new CaseManagementDiagram());
      }

      public org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy(CaseManagementDiagram targetVal) {
        agent = new BindableProxyAgent<CaseManagementDiagram>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNBaseInfo.class, false, false));
        p.put("caseManagementSet", new PropertyType(CaseManagementSet.class, true, false));
        p.put("processData", new PropertyType(ProcessData.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("diagramSet", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(CaseManagementDiagram.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseManagementDiagram unwrap() {
        return target;
      }

      public CaseManagementDiagram deepUnwrap() {
        final CaseManagementDiagram clone = new CaseManagementDiagram();
        final CaseManagementDiagram t = unwrap();
        if (t.getCaseManagementSet() instanceof BindableProxy) {
          clone.setCaseManagementSet((CaseManagementSet) ((BindableProxy) getCaseManagementSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCaseManagementSet())) {
          clone.setCaseManagementSet((CaseManagementSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCaseManagementSet())).deepUnwrap());
        } else {
          clone.setCaseManagementSet(t.getCaseManagementSet());
        }
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getDiagramSet() instanceof BindableProxy) {
          clone.setDiagramSet((org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet) ((BindableProxy) getDiagramSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDiagramSet())) {
          clone.setDiagramSet((org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDiagramSet())).deepUnwrap());
        } else {
          clone.setDiagramSet(t.getDiagramSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNBaseInfo getGeneral() {
        return target.getGeneral();
      }

      public CaseManagementSet getCaseManagementSet() {
        return target.getCaseManagementSet();
      }

      public void setCaseManagementSet(CaseManagementSet caseManagementSet) {
        if (agent.binders.containsKey("caseManagementSet")) {
          caseManagementSet = (CaseManagementSet) agent.binders.get("caseManagementSet").setModel(caseManagementSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("caseManagementSet", caseManagementSet);
      }

      public ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet getDiagramSet() {
        return target.getDiagramSet();
      }

      public void setDiagramSet(org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet diagramSet) {
        if (agent.binders.containsKey("diagramSet")) {
          diagramSet = (org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet) agent.binders.get("diagramSet").setModel(diagramSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("diagramSet", diagramSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "caseManagementSet": return getCaseManagementSet();
          case "processData": return getProcessData();
          case "backgroundSet": return getBackgroundSet();
          case "diagramSet": return getDiagramSet();
          case "dimensionsSet": return getDimensionsSet();
          case "fontSet": return getFontSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseManagementDiagram", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "caseManagementSet": target.setCaseManagementSet((CaseManagementSet) value);
          break;
          case "processData": target.setProcessData((ProcessData) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "diagramSet": target.setDiagramSet((org.kie.workbench.common.stunner.cm.definition.property.diagram.DiagramSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "this": target = (CaseManagementDiagram) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseManagementDiagram", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseManagementDiagram.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy((CaseManagementDiagram) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_CaseManagementDiagramProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy extends IntermediateConditionalEvent implements BindableProxy {
      private BindableProxyAgent<IntermediateConditionalEvent> agent;
      private IntermediateConditionalEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy() {
        this(new IntermediateConditionalEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy(IntermediateConditionalEvent targetVal) {
        agent = new BindableProxyAgent<IntermediateConditionalEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CancellingConditionalEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateConditionalEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateConditionalEvent unwrap() {
        return target;
      }

      public IntermediateConditionalEvent deepUnwrap() {
        final IntermediateConditionalEvent clone = new IntermediateConditionalEvent();
        final IntermediateConditionalEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CancellingConditionalEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CancellingConditionalEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CancellingConditionalEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CancellingConditionalEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CancellingConditionalEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateConditionalEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CancellingConditionalEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateConditionalEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateConditionalEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateConditionalEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy((IntermediateConditionalEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateConditionalEventProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy extends IntegerListBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<IntegerListBoxFieldDefinition> agent;
      private IntegerListBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy() {
        this(new IntegerListBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy(IntegerListBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<IntegerListBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("addEmptyOption", new PropertyType(Boolean.class, false, false));
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Long.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ListBoxFieldType.class, false, false));
        p.put("this", new PropertyType(IntegerListBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerListBoxFieldDefinition unwrap() {
        return target;
      }

      public IntegerListBoxFieldDefinition deepUnwrap() {
        final IntegerListBoxFieldDefinition clone = new IntegerListBoxFieldDefinition();
        final IntegerListBoxFieldDefinition t = unwrap();
        clone.setAddEmptyOption(t.getAddEmptyOption());
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getAddEmptyOption() {
        return target.getAddEmptyOption();
      }

      public void setAddEmptyOption(Boolean addEmptyOption) {
        changeAndFire("addEmptyOption", addEmptyOption);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Long getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Long defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<IntegerSelectorOption> options) {
        List<IntegerSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ListBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "addEmptyOption": return getAddEmptyOption();
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerListBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "addEmptyOption": target.setAddEmptyOption((Boolean) value);
          break;
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Long) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<IntegerSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (IntegerListBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerListBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerListBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy((IntegerListBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_IntegerListBoxFieldDefinitionProxy();
      }
    });
    class org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy extends ActiveFilterItem implements BindableProxy {
      private BindableProxyAgent<ActiveFilterItem> agent;
      private ActiveFilterItem target;
      public org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy() {
        this(new ActiveFilterItem());
      }

      public org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy(ActiveFilterItem targetVal) {
        agent = new BindableProxyAgent<ActiveFilterItem>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("hint", new PropertyType(String.class, false, false));
        p.put("callback", new PropertyType(Consumer.class, false, false));
        p.put("labelValue", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(Object.class, false, false));
        p.put("key", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ActiveFilterItem.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ActiveFilterItem unwrap() {
        return target;
      }

      public ActiveFilterItem deepUnwrap() {
        final ActiveFilterItem clone = new ActiveFilterItem();
        final ActiveFilterItem t = unwrap();
        clone.setHint(t.getHint());
        clone.setCallback(t.getCallback());
        clone.setLabelValue(t.getLabelValue());
        clone.setValue(t.getValue());
        clone.setKey(t.getKey());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy) {
          obj = ((org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getHint() {
        return target.getHint();
      }

      public void setHint(String hint) {
        changeAndFire("hint", hint);
      }

      public Consumer getCallback() {
        return target.getCallback();
      }

      public void setCallback(Consumer callback) {
        changeAndFire("callback", callback);
      }

      public String getLabelValue() {
        return target.getLabelValue();
      }

      public void setLabelValue(String labelValue) {
        changeAndFire("labelValue", labelValue);
      }

      public Object getValue() {
        return target.getValue();
      }

      public void setValue(Object value) {
        changeAndFire("value", value);
      }

      public String getKey() {
        return target.getKey();
      }

      public void setKey(String key) {
        changeAndFire("key", key);
      }

      public Object get(String property) {
        switch (property) {
          case "hint": return getHint();
          case "callback": return getCallback();
          case "labelValue": return getLabelValue();
          case "value": return getValue();
          case "key": return getKey();
          case "this": return target;
          default: throw new NonExistingPropertyException("ActiveFilterItem", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "hint": target.setHint((String) value);
          break;
          case "callback": target.setCallback((Consumer) value);
          break;
          case "labelValue": target.setLabelValue((String) value);
          break;
          case "value": target.setValue(value);
          break;
          case "key": target.setKey((String) value);
          break;
          case "this": target = (ActiveFilterItem) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ActiveFilterItem", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ActiveFilterItem.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy((ActiveFilterItem) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_common_client_filters_active_ActiveFilterItemProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy extends GeneralRectangleDimensionsSet implements BindableProxy {
      private BindableProxyAgent<GeneralRectangleDimensionsSet> agent;
      private GeneralRectangleDimensionsSet target;
      public org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy() {
        this(new GeneralRectangleDimensionsSet());
      }

      public org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy(GeneralRectangleDimensionsSet targetVal) {
        agent = new BindableProxyAgent<GeneralRectangleDimensionsSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("width", new PropertyType(Width.class, true, false));
        p.put("maximumWidth", new PropertyType(Double.class, false, false));
        p.put("minimumHeight", new PropertyType(Double.class, false, false));
        p.put("maximumHeight", new PropertyType(Double.class, false, false));
        p.put("minimumWidth", new PropertyType(Double.class, false, false));
        p.put("height", new PropertyType(org.kie.workbench.common.dmn.api.property.dimensions.Height.class, true, false));
        p.put("this", new PropertyType(GeneralRectangleDimensionsSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GeneralRectangleDimensionsSet unwrap() {
        return target;
      }

      public GeneralRectangleDimensionsSet deepUnwrap() {
        final GeneralRectangleDimensionsSet clone = new GeneralRectangleDimensionsSet();
        final GeneralRectangleDimensionsSet t = unwrap();
        if (t.getWidth() instanceof BindableProxy) {
          clone.setWidth((Width) ((BindableProxy) getWidth()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWidth())) {
          clone.setWidth((Width) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWidth())).deepUnwrap());
        } else {
          clone.setWidth(t.getWidth());
        }
        if (t.getHeight() instanceof BindableProxy) {
          clone.setHeight((org.kie.workbench.common.dmn.api.property.dimensions.Height) ((BindableProxy) getHeight()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getHeight())) {
          clone.setHeight((org.kie.workbench.common.dmn.api.property.dimensions.Height) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getHeight())).deepUnwrap());
        } else {
          clone.setHeight(t.getHeight());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Width getWidth() {
        return target.getWidth();
      }

      public void setWidth(Width width) {
        if (agent.binders.containsKey("width")) {
          width = (Width) agent.binders.get("width").setModel(width, StateSync.FROM_MODEL, true);
        }
        changeAndFire("width", width);
      }

      public double getMaximumWidth() {
        return target.getMaximumWidth();
      }

      public double getMinimumHeight() {
        return target.getMinimumHeight();
      }

      public double getMaximumHeight() {
        return target.getMaximumHeight();
      }

      public double getMinimumWidth() {
        return target.getMinimumWidth();
      }

      public org.kie.workbench.common.dmn.api.property.dimensions.Height getHeight() {
        return target.getHeight();
      }

      public void setHeight(org.kie.workbench.common.dmn.api.property.dimensions.Height height) {
        if (agent.binders.containsKey("height")) {
          height = (org.kie.workbench.common.dmn.api.property.dimensions.Height) agent.binders.get("height").setModel(height, StateSync.FROM_MODEL, true);
        }
        changeAndFire("height", height);
      }

      public Object get(String property) {
        switch (property) {
          case "width": return getWidth();
          case "maximumWidth": return getMaximumWidth();
          case "minimumHeight": return getMinimumHeight();
          case "maximumHeight": return getMaximumHeight();
          case "minimumWidth": return getMinimumWidth();
          case "height": return getHeight();
          case "this": return target;
          default: throw new NonExistingPropertyException("GeneralRectangleDimensionsSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "width": target.setWidth((Width) value);
          break;
          case "height": target.setHeight((org.kie.workbench.common.dmn.api.property.dimensions.Height) value);
          break;
          case "this": target = (GeneralRectangleDimensionsSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GeneralRectangleDimensionsSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(GeneralRectangleDimensionsSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy((GeneralRectangleDimensionsSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dimensions_GeneralRectangleDimensionsSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy extends Min implements BindableProxy {
      private BindableProxyAgent<Min> agent;
      private Min target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy() {
        this(new Min());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy(Min targetVal) {
        agent = new BindableProxyAgent<Min>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Min.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Min unwrap() {
        return target;
      }

      public Min deepUnwrap() {
        final Min clone = new Min();
        final Min t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Min", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Min) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Min", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Min.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy((Min) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MinProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InputDataProxy extends InputData implements BindableProxy {
      private BindableProxyAgent<InputData> agent;
      private InputData target;
      public org_kie_workbench_common_dmn_api_definition_model_InputDataProxy() {
        this(new InputData());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InputDataProxy(InputData targetVal) {
        agent = new BindableProxyAgent<InputData>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("allowOnlyVisualChange", new PropertyType(Boolean.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("backgroundSet", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        p.put("variable", new PropertyType(InformationItemPrimary.class, true, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("fontSet", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(GeneralRectangleDimensionsSet.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("linksHolder", new PropertyType(DocumentationLinksHolder.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InputData.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InputData unwrap() {
        return target;
      }

      public InputData deepUnwrap() {
        final InputData clone = new InputData();
        final InputData t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        clone.setAllowOnlyVisualChange(t.isAllowOnlyVisualChange());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getVariable() instanceof BindableProxy) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) getVariable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getVariable())) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getVariable())).deepUnwrap());
        } else {
          clone.setVariable(t.getVariable());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getLinksHolder() instanceof BindableProxy) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) getLinksHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLinksHolder())) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLinksHolder())).deepUnwrap());
        } else {
          clone.setLinksHolder(t.getLinksHolder());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InputDataProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InputDataProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public boolean isAllowOnlyVisualChange() {
        return target.isAllowOnlyVisualChange();
      }

      public void setAllowOnlyVisualChange(boolean allowOnlyVisualChange) {
        changeAndFire("allowOnlyVisualChange", allowOnlyVisualChange);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(org.kie.workbench.common.dmn.api.property.background.BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InformationItemPrimary getVariable() {
        return target.getVariable();
      }

      public void setVariable(InformationItemPrimary variable) {
        if (agent.binders.containsKey("variable")) {
          variable = (InformationItemPrimary) agent.binders.get("variable").setModel(variable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("variable", variable);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(org.kie.workbench.common.dmn.api.property.font.FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (org.kie.workbench.common.dmn.api.property.font.FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public GeneralRectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(GeneralRectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (GeneralRectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public DocumentationLinksHolder getLinksHolder() {
        return target.getLinksHolder();
      }

      public void setLinksHolder(DocumentationLinksHolder linksHolder) {
        if (agent.binders.containsKey("linksHolder")) {
          linksHolder = (DocumentationLinksHolder) agent.binders.get("linksHolder").setModel(linksHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("linksHolder", linksHolder);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "stunnerLabels": return getStunnerLabels();
          case "allowOnlyVisualChange": return isAllowOnlyVisualChange();
          case "description": return getDescription();
          case "nsContext": return getNsContext();
          case "backgroundSet": return getBackgroundSet();
          case "variable": return getVariable();
          case "name": return getName();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "id": return getId();
          case "linksHolder": return getLinksHolder();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InputData", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "allowOnlyVisualChange": target.setAllowOnlyVisualChange((Boolean) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "backgroundSet": target.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value);
          break;
          case "variable": target.setVariable((InformationItemPrimary) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "fontSet": target.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((GeneralRectangleDimensionsSet) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "linksHolder": target.setLinksHolder((DocumentationLinksHolder) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InputData) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InputData", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public ReadOnly getReadOnly(String a0) {
        final ReadOnly returnValue = target.getReadOnly(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InputData.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InputDataProxy((InputData) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InputDataProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy extends StringRadioGroupFieldDefinition implements BindableProxy {
      private BindableProxyAgent<StringRadioGroupFieldDefinition> agent;
      private StringRadioGroupFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy() {
        this(new StringRadioGroupFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy(StringRadioGroupFieldDefinition targetVal) {
        agent = new BindableProxyAgent<StringRadioGroupFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("inline", new PropertyType(Boolean.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(RadioGroupFieldType.class, false, false));
        p.put("this", new PropertyType(StringRadioGroupFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StringRadioGroupFieldDefinition unwrap() {
        return target;
      }

      public StringRadioGroupFieldDefinition deepUnwrap() {
        final StringRadioGroupFieldDefinition clone = new StringRadioGroupFieldDefinition();
        final StringRadioGroupFieldDefinition t = unwrap();
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setInline(t.getInline());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Boolean getInline() {
        return target.getInline();
      }

      public void setInline(Boolean inline) {
        changeAndFire("inline", inline);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<StringSelectorOption> options) {
        List<StringSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public RadioGroupFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "inline": return getInline();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("StringRadioGroupFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "inline": target.setInline((Boolean) value);
          break;
          case "options": target.setOptions((List<StringSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (StringRadioGroupFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StringRadioGroupFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(StringRadioGroupFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy((StringRadioGroupFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_radioGroup_definition_StringRadioGroupFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy extends DecisionServiceDividerLineY implements BindableProxy {
      private BindableProxyAgent<DecisionServiceDividerLineY> agent;
      private DecisionServiceDividerLineY target;
      public org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy() {
        this(new DecisionServiceDividerLineY());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy(DecisionServiceDividerLineY targetVal) {
        agent = new BindableProxyAgent<DecisionServiceDividerLineY>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(DecisionServiceDividerLineY.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecisionServiceDividerLineY unwrap() {
        return target;
      }

      public DecisionServiceDividerLineY deepUnwrap() {
        final DecisionServiceDividerLineY clone = new DecisionServiceDividerLineY();
        final DecisionServiceDividerLineY t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecisionServiceDividerLineY", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (DecisionServiceDividerLineY) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecisionServiceDividerLineY", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DecisionServiceDividerLineY.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy((DecisionServiceDividerLineY) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_DecisionServiceDividerLineYProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy extends BooleanMultipleSelectorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<BooleanMultipleSelectorFieldDefinition> agent;
      private BooleanMultipleSelectorFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy() {
        this(new BooleanMultipleSelectorFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy(BooleanMultipleSelectorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<BooleanMultipleSelectorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDropdownElements", new PropertyType(Integer.class, false, false));
        p.put("listOfValues", new PropertyType(List.class, false, true));
        p.put("maxElementsOnTitle", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("allowFilter", new PropertyType(Boolean.class, false, false));
        p.put("allowClearSelection", new PropertyType(Boolean.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(BooleanMultipleSelectorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BooleanMultipleSelectorFieldDefinition unwrap() {
        return target;
      }

      public BooleanMultipleSelectorFieldDefinition deepUnwrap() {
        final BooleanMultipleSelectorFieldDefinition clone = new BooleanMultipleSelectorFieldDefinition();
        final BooleanMultipleSelectorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDropdownElements(t.getMaxDropdownElements());
        if (t.getListOfValues() != null) {
          final List listOfValuesClone = new ArrayList();
          for (Object listOfValuesElem : t.getListOfValues()) {
            if (listOfValuesElem instanceof BindableProxy) {
              listOfValuesClone.add(((BindableProxy) listOfValuesElem).deepUnwrap());
            } else {
              listOfValuesClone.add(listOfValuesElem);
            }
          }
          clone.setListOfValues(listOfValuesClone);
        }
        clone.setMaxElementsOnTitle(t.getMaxElementsOnTitle());
        clone.setName(t.getName());
        clone.setAllowFilter(t.getAllowFilter());
        clone.setAllowClearSelection(t.getAllowClearSelection());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDropdownElements() {
        return target.getMaxDropdownElements();
      }

      public void setMaxDropdownElements(Integer maxDropdownElements) {
        changeAndFire("maxDropdownElements", maxDropdownElements);
      }

      public List getListOfValues() {
        return target.getListOfValues();
      }

      public void setListOfValues(List<Boolean> listOfValues) {
        List<Boolean> oldValue = target.getListOfValues();
        listOfValues = agent.ensureBoundListIsProxied("listOfValues", listOfValues);
        target.setListOfValues(listOfValues);
        agent.updateWidgetsAndFireEvent(true, "listOfValues", oldValue, listOfValues);
      }

      public Integer getMaxElementsOnTitle() {
        return target.getMaxElementsOnTitle();
      }

      public void setMaxElementsOnTitle(Integer maxElementsOnTitle) {
        changeAndFire("maxElementsOnTitle", maxElementsOnTitle);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Boolean getAllowFilter() {
        return target.getAllowFilter();
      }

      public void setAllowFilter(Boolean allowFilter) {
        changeAndFire("allowFilter", allowFilter);
      }

      public Boolean getAllowClearSelection() {
        return target.getAllowClearSelection();
      }

      public void setAllowClearSelection(Boolean allowClearSelection) {
        changeAndFire("allowClearSelection", allowClearSelection);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDropdownElements": return getMaxDropdownElements();
          case "listOfValues": return getListOfValues();
          case "maxElementsOnTitle": return getMaxElementsOnTitle();
          case "name": return getName();
          case "allowFilter": return getAllowFilter();
          case "allowClearSelection": return getAllowClearSelection();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("BooleanMultipleSelectorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDropdownElements": target.setMaxDropdownElements((Integer) value);
          break;
          case "listOfValues": target.setListOfValues((List<Boolean>) value);
          break;
          case "maxElementsOnTitle": target.setMaxElementsOnTitle((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "allowFilter": target.setAllowFilter((Boolean) value);
          break;
          case "allowClearSelection": target.setAllowClearSelection((Boolean) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (BooleanMultipleSelectorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BooleanMultipleSelectorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(BooleanMultipleSelectorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy((BooleanMultipleSelectorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_BooleanMultipleSelectorFieldDefinitionProxy();
      }
    });
    class org_jbpm_workbench_pr_model_TimerSummaryProxy extends TimerSummary implements BindableProxy {
      private BindableProxyAgent<TimerSummary> agent;
      private TimerSummary target;
      public org_jbpm_workbench_pr_model_TimerSummaryProxy() {
        this(new TimerSummary());
      }

      public org_jbpm_workbench_pr_model_TimerSummaryProxy(TimerSummary targetVal) {
        agent = new BindableProxyAgent<TimerSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("name", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("nodeId", new PropertyType(Long.class, false, false));
        p.put("uniqueId", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TimerSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TimerSummary unwrap() {
        return target;
      }

      public TimerSummary deepUnwrap() {
        final TimerSummary clone = new TimerSummary();
        final TimerSummary t = unwrap();
        clone.setName(t.getName());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setId(t.getId());
        clone.setNodeId(t.getNodeId());
        clone.setUniqueId(t.getUniqueId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_pr_model_TimerSummaryProxy) {
          obj = ((org_jbpm_workbench_pr_model_TimerSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public Long getNodeId() {
        return target.getNodeId();
      }

      public void setNodeId(Long nodeId) {
        changeAndFire("nodeId", nodeId);
      }

      public String getUniqueId() {
        return target.getUniqueId();
      }

      public void setUniqueId(String uniqueId) {
        changeAndFire("uniqueId", uniqueId);
      }

      public Object get(String property) {
        switch (property) {
          case "name": return getName();
          case "callbacks": return getCallbacks();
          case "id": return getId();
          case "nodeId": return getNodeId();
          case "uniqueId": return getUniqueId();
          case "this": return target;
          default: throw new NonExistingPropertyException("TimerSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "name": target.setName((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "nodeId": target.setNodeId((Long) value);
          break;
          case "uniqueId": target.setUniqueId((String) value);
          break;
          case "this": target = (TimerSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TimerSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(TimerSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_pr_model_TimerSummaryProxy((TimerSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_pr_model_TimerSummaryProxy();
      }
    });
    class org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy extends DocumentData implements BindableProxy {
      private BindableProxyAgent<DocumentData> agent;
      private DocumentData target;
      public org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy() {
        this(new DocumentData());
      }

      public org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy(DocumentData targetVal) {
        agent = new BindableProxyAgent<DocumentData>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("fileName", new PropertyType(String.class, false, false));
        p.put("size", new PropertyType(Long.class, false, false));
        p.put("link", new PropertyType(String.class, false, false));
        p.put("contentId", new PropertyType(String.class, false, false));
        p.put("lastModified", new PropertyType(Long.class, false, false));
        p.put("status", new PropertyType(DocumentStatus.class, false, false));
        p.put("this", new PropertyType(DocumentData.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DocumentData unwrap() {
        return target;
      }

      public DocumentData deepUnwrap() {
        final DocumentData clone = new DocumentData();
        final DocumentData t = unwrap();
        clone.setFileName(t.getFileName());
        clone.setSize(t.getSize());
        clone.setLink(t.getLink());
        clone.setContentId(t.getContentId());
        clone.setLastModified(t.getLastModified());
        clone.setStatus(t.getStatus());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy) {
          obj = ((org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getFileName() {
        return target.getFileName();
      }

      public void setFileName(String fileName) {
        changeAndFire("fileName", fileName);
      }

      public long getSize() {
        return target.getSize();
      }

      public void setSize(long size) {
        changeAndFire("size", size);
      }

      public String getLink() {
        return target.getLink();
      }

      public void setLink(String link) {
        changeAndFire("link", link);
      }

      public String getContentId() {
        return target.getContentId();
      }

      public void setContentId(String contentId) {
        changeAndFire("contentId", contentId);
      }

      public long getLastModified() {
        return target.getLastModified();
      }

      public void setLastModified(long lastModified) {
        changeAndFire("lastModified", lastModified);
      }

      public DocumentStatus getStatus() {
        return target.getStatus();
      }

      public void setStatus(DocumentStatus status) {
        changeAndFire("status", status);
      }

      public Object get(String property) {
        switch (property) {
          case "fileName": return getFileName();
          case "size": return getSize();
          case "link": return getLink();
          case "contentId": return getContentId();
          case "lastModified": return getLastModified();
          case "status": return getStatus();
          case "this": return target;
          default: throw new NonExistingPropertyException("DocumentData", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "fileName": target.setFileName((String) value);
          break;
          case "size": target.setSize((Long) value);
          break;
          case "link": target.setLink((String) value);
          break;
          case "contentId": target.setContentId((String) value);
          break;
          case "lastModified": target.setLastModified((Long) value);
          break;
          case "status": target.setStatus((DocumentStatus) value);
          break;
          case "this": target = (DocumentData) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DocumentData", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DocumentData.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy((DocumentData) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_jbpm_model_document_DocumentDataProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy extends MultipleInstanceVariableFieldDefinition implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceVariableFieldDefinition> agent;
      private MultipleInstanceVariableFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy() {
        this(new MultipleInstanceVariableFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy(MultipleInstanceVariableFieldDefinition targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceVariableFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceVariableFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceVariableFieldDefinition unwrap() {
        return target;
      }

      public MultipleInstanceVariableFieldDefinition deepUnwrap() {
        final MultipleInstanceVariableFieldDefinition clone = new MultipleInstanceVariableFieldDefinition();
        final MultipleInstanceVariableFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceVariableFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (MultipleInstanceVariableFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceVariableFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceVariableFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy((MultipleInstanceVariableFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_MultipleInstanceVariableFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy extends ImportedValues implements BindableProxy {
      private BindableProxyAgent<ImportedValues> agent;
      private ImportedValues target;
      public org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy() {
        this(new ImportedValues());
      }

      public org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy(ImportedValues targetVal) {
        agent = new BindableProxyAgent<ImportedValues>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("expressionLanguage", new PropertyType(ExpressionLanguage.class, true, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("importedElement", new PropertyType(String.class, false, false));
        p.put("importType", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("namespace", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("locationURI", new PropertyType(LocationURI.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(ImportedValues.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ImportedValues unwrap() {
        return target;
      }

      public ImportedValues deepUnwrap() {
        final ImportedValues clone = new ImportedValues();
        final ImportedValues t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getExpressionLanguage() instanceof BindableProxy) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) getExpressionLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExpressionLanguage())) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExpressionLanguage())).deepUnwrap());
        } else {
          clone.setExpressionLanguage(t.getExpressionLanguage());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        clone.setImportedElement(t.getImportedElement());
        clone.setImportType(t.getImportType());
        clone.setNamespace(t.getNamespace());
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getLocationURI() instanceof BindableProxy) {
          clone.setLocationURI((LocationURI) ((BindableProxy) getLocationURI()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLocationURI())) {
          clone.setLocationURI((LocationURI) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLocationURI())).deepUnwrap());
        } else {
          clone.setLocationURI(t.getLocationURI());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public ExpressionLanguage getExpressionLanguage() {
        return target.getExpressionLanguage();
      }

      public void setExpressionLanguage(ExpressionLanguage expressionLanguage) {
        if (agent.binders.containsKey("expressionLanguage")) {
          expressionLanguage = (ExpressionLanguage) agent.binders.get("expressionLanguage").setModel(expressionLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("expressionLanguage", expressionLanguage);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public String getImportedElement() {
        return target.getImportedElement();
      }

      public void setImportedElement(String importedElement) {
        changeAndFire("importedElement", importedElement);
      }

      public String getImportType() {
        return target.getImportType();
      }

      public void setImportType(String importType) {
        changeAndFire("importType", importType);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public String getNamespace() {
        return target.getNamespace();
      }

      public void setNamespace(String namespace) {
        changeAndFire("namespace", namespace);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public LocationURI getLocationURI() {
        return target.getLocationURI();
      }

      public void setLocationURI(LocationURI locationURI) {
        if (agent.binders.containsKey("locationURI")) {
          locationURI = (LocationURI) agent.binders.get("locationURI").setModel(locationURI, StateSync.FROM_MODEL, true);
        }
        changeAndFire("locationURI", locationURI);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "expressionLanguage": return getExpressionLanguage();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "importedElement": return getImportedElement();
          case "importType": return getImportType();
          case "nsContext": return getNsContext();
          case "namespace": return getNamespace();
          case "name": return getName();
          case "id": return getId();
          case "locationURI": return getLocationURI();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("ImportedValues", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "expressionLanguage": target.setExpressionLanguage((ExpressionLanguage) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "importedElement": target.setImportedElement((String) value);
          break;
          case "importType": target.setImportType((String) value);
          break;
          case "namespace": target.setNamespace((String) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "locationURI": target.setLocationURI((LocationURI) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (ImportedValues) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ImportedValues", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ImportedValues.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy((ImportedValues) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_ImportedValuesProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy extends StartEscalationEvent implements BindableProxy {
      private BindableProxyAgent<StartEscalationEvent> agent;
      private StartEscalationEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy() {
        this(new StartEscalationEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy(StartEscalationEvent targetVal) {
        agent = new BindableProxyAgent<StartEscalationEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(InterruptingEscalationEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartEscalationEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartEscalationEvent unwrap() {
        return target;
      }

      public StartEscalationEvent deepUnwrap() {
        final StartEscalationEvent clone = new StartEscalationEvent();
        final StartEscalationEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((InterruptingEscalationEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((InterruptingEscalationEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InterruptingEscalationEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(InterruptingEscalationEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (InterruptingEscalationEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartEscalationEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((InterruptingEscalationEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartEscalationEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartEscalationEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartEscalationEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy((StartEscalationEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartEscalationEventProxy();
      }
    });
    class org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy extends WorkItemParameterSummary implements BindableProxy {
      private BindableProxyAgent<WorkItemParameterSummary> agent;
      private WorkItemParameterSummary target;
      public org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy() {
        this(new WorkItemParameterSummary());
      }

      public org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy(WorkItemParameterSummary targetVal) {
        agent = new BindableProxyAgent<WorkItemParameterSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("name", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(WorkItemParameterSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public WorkItemParameterSummary unwrap() {
        return target;
      }

      public WorkItemParameterSummary deepUnwrap() {
        final WorkItemParameterSummary clone = new WorkItemParameterSummary();
        final WorkItemParameterSummary t = unwrap();
        clone.setName(t.getName());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy) {
          obj = ((org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public Object get(String property) {
        switch (property) {
          case "name": return getName();
          case "callbacks": return getCallbacks();
          case "id": return getId();
          case "this": return target;
          default: throw new NonExistingPropertyException("WorkItemParameterSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "name": target.setName((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (WorkItemParameterSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("WorkItemParameterSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(WorkItemParameterSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy((WorkItemParameterSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_pr_model_WorkItemParameterSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy extends CaseReusableSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<CaseReusableSubprocessTaskExecutionSet> agent;
      private CaseReusableSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy() {
        this(new CaseReusableSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy(CaseReusableSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<CaseReusableSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("abortParent", new PropertyType(AbortParent.class, true, false));
        p.put("independent", new PropertyType(Independent.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("waitForCompletion", new PropertyType(WaitForCompletion.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("isCase", new PropertyType(IsCase.class, true, false));
        p.put("calledElement", new PropertyType(CalledElement.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("this", new PropertyType(CaseReusableSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseReusableSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public CaseReusableSubprocessTaskExecutionSet deepUnwrap() {
        final CaseReusableSubprocessTaskExecutionSet clone = new CaseReusableSubprocessTaskExecutionSet();
        final CaseReusableSubprocessTaskExecutionSet t = unwrap();
        if (t.getAbortParent() instanceof BindableProxy) {
          clone.setAbortParent((AbortParent) ((BindableProxy) getAbortParent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAbortParent())) {
          clone.setAbortParent((AbortParent) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAbortParent())).deepUnwrap());
        } else {
          clone.setAbortParent(t.getAbortParent());
        }
        if (t.getIndependent() instanceof BindableProxy) {
          clone.setIndependent((Independent) ((BindableProxy) getIndependent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIndependent())) {
          clone.setIndependent((Independent) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIndependent())).deepUnwrap());
        } else {
          clone.setIndependent(t.getIndependent());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getWaitForCompletion() instanceof BindableProxy) {
          clone.setWaitForCompletion((WaitForCompletion) ((BindableProxy) getWaitForCompletion()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWaitForCompletion())) {
          clone.setWaitForCompletion((WaitForCompletion) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWaitForCompletion())).deepUnwrap());
        } else {
          clone.setWaitForCompletion(t.getWaitForCompletion());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getIsCase() instanceof BindableProxy) {
          clone.setIsCase((IsCase) ((BindableProxy) getIsCase()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsCase())) {
          clone.setIsCase((IsCase) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsCase())).deepUnwrap());
        } else {
          clone.setIsCase(t.getIsCase());
        }
        if (t.getCalledElement() instanceof BindableProxy) {
          clone.setCalledElement((CalledElement) ((BindableProxy) getCalledElement()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCalledElement())) {
          clone.setCalledElement((CalledElement) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCalledElement())).deepUnwrap());
        } else {
          clone.setCalledElement(t.getCalledElement());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AbortParent getAbortParent() {
        return target.getAbortParent();
      }

      public void setAbortParent(AbortParent abortParent) {
        if (agent.binders.containsKey("abortParent")) {
          abortParent = (AbortParent) agent.binders.get("abortParent").setModel(abortParent, StateSync.FROM_MODEL, true);
        }
        changeAndFire("abortParent", abortParent);
      }

      public Independent getIndependent() {
        return target.getIndependent();
      }

      public void setIndependent(Independent independent) {
        if (agent.binders.containsKey("independent")) {
          independent = (Independent) agent.binders.get("independent").setModel(independent, StateSync.FROM_MODEL, true);
        }
        changeAndFire("independent", independent);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public WaitForCompletion getWaitForCompletion() {
        return target.getWaitForCompletion();
      }

      public void setWaitForCompletion(WaitForCompletion waitForCompletion) {
        if (agent.binders.containsKey("waitForCompletion")) {
          waitForCompletion = (WaitForCompletion) agent.binders.get("waitForCompletion").setModel(waitForCompletion, StateSync.FROM_MODEL, true);
        }
        changeAndFire("waitForCompletion", waitForCompletion);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public IsCase getIsCase() {
        return target.getIsCase();
      }

      public void setIsCase(IsCase isCase) {
        if (agent.binders.containsKey("isCase")) {
          isCase = (IsCase) agent.binders.get("isCase").setModel(isCase, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isCase", isCase);
      }

      public CalledElement getCalledElement() {
        return target.getCalledElement();
      }

      public void setCalledElement(CalledElement calledElement) {
        if (agent.binders.containsKey("calledElement")) {
          calledElement = (CalledElement) agent.binders.get("calledElement").setModel(calledElement, StateSync.FROM_MODEL, true);
        }
        changeAndFire("calledElement", calledElement);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public Object get(String property) {
        switch (property) {
          case "abortParent": return getAbortParent();
          case "independent": return getIndependent();
          case "isAsync": return getIsAsync();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "waitForCompletion": return getWaitForCompletion();
          case "onEntryAction": return getOnEntryAction();
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "adHocAutostart": return getAdHocAutostart();
          case "slaDueDate": return getSlaDueDate();
          case "isCase": return getIsCase();
          case "calledElement": return getCalledElement();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "onExitAction": return getOnExitAction();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseReusableSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "abortParent": target.setAbortParent((AbortParent) value);
          break;
          case "independent": target.setIndependent((Independent) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "waitForCompletion": target.setWaitForCompletion((WaitForCompletion) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "isCase": target.setIsCase((IsCase) value);
          break;
          case "calledElement": target.setCalledElement((CalledElement) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "this": target = (CaseReusableSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseReusableSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseReusableSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy((CaseReusableSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_CaseReusableSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy extends IntermediateEscalationEventThrowing implements BindableProxy {
      private BindableProxyAgent<IntermediateEscalationEventThrowing> agent;
      private IntermediateEscalationEventThrowing target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy() {
        this(new IntermediateEscalationEventThrowing());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy(IntermediateEscalationEventThrowing targetVal) {
        agent = new BindableProxyAgent<IntermediateEscalationEventThrowing>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(EscalationEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateEscalationEventThrowing.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateEscalationEventThrowing unwrap() {
        return target;
      }

      public IntermediateEscalationEventThrowing deepUnwrap() {
        final IntermediateEscalationEventThrowing clone = new IntermediateEscalationEventThrowing();
        final IntermediateEscalationEventThrowing t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((EscalationEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((EscalationEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public EscalationEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(EscalationEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (EscalationEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateEscalationEventThrowing", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((EscalationEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateEscalationEventThrowing) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateEscalationEventThrowing", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateEscalationEventThrowing.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy((IntermediateEscalationEventThrowing) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateEscalationEventThrowingProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy extends GenericServiceTaskEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<GenericServiceTaskEditorFieldDefinition> agent;
      private GenericServiceTaskEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy() {
        this(new GenericServiceTaskEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy(GenericServiceTaskEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<GenericServiceTaskEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(GenericServiceTaskEditorFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(GenericServiceTaskEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GenericServiceTaskEditorFieldDefinition unwrap() {
        return target;
      }

      public GenericServiceTaskEditorFieldDefinition deepUnwrap() {
        final GenericServiceTaskEditorFieldDefinition clone = new GenericServiceTaskEditorFieldDefinition();
        final GenericServiceTaskEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public GenericServiceTaskEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("GenericServiceTaskEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (GenericServiceTaskEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GenericServiceTaskEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(GenericServiceTaskEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy((GenericServiceTaskEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_GenericServiceTaskEditorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("adHocOrdering", new PropertyType(AdHocOrdering.class, true, false));
        p.put("adHocActivationCondition", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("adHocCompletionCondition", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet clone = new org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet();
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet t = unwrap();
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getAdHocOrdering() instanceof BindableProxy) {
          clone.setAdHocOrdering((AdHocOrdering) ((BindableProxy) getAdHocOrdering()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocOrdering())) {
          clone.setAdHocOrdering((AdHocOrdering) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocOrdering())).deepUnwrap());
        } else {
          clone.setAdHocOrdering(t.getAdHocOrdering());
        }
        if (t.getAdHocActivationCondition() instanceof BindableProxy) {
          clone.setAdHocActivationCondition((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition) ((BindableProxy) getAdHocActivationCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocActivationCondition())) {
          clone.setAdHocActivationCondition((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocActivationCondition())).deepUnwrap());
        } else {
          clone.setAdHocActivationCondition(t.getAdHocActivationCondition());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getAdHocCompletionCondition() instanceof BindableProxy) {
          clone.setAdHocCompletionCondition((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition) ((BindableProxy) getAdHocCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocCompletionCondition())) {
          clone.setAdHocCompletionCondition((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocCompletionCondition())).deepUnwrap());
        } else {
          clone.setAdHocCompletionCondition(t.getAdHocCompletionCondition());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public AdHocOrdering getAdHocOrdering() {
        return target.getAdHocOrdering();
      }

      public void setAdHocOrdering(AdHocOrdering adHocOrdering) {
        if (agent.binders.containsKey("adHocOrdering")) {
          adHocOrdering = (AdHocOrdering) agent.binders.get("adHocOrdering").setModel(adHocOrdering, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocOrdering", adHocOrdering);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition getAdHocActivationCondition() {
        return target.getAdHocActivationCondition();
      }

      public void setAdHocActivationCondition(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition adHocActivationCondition) {
        if (agent.binders.containsKey("adHocActivationCondition")) {
          adHocActivationCondition = (org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition) agent.binders.get("adHocActivationCondition").setModel(adHocActivationCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocActivationCondition", adHocActivationCondition);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition getAdHocCompletionCondition() {
        return target.getAdHocCompletionCondition();
      }

      public void setAdHocCompletionCondition(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition adHocCompletionCondition) {
        if (agent.binders.containsKey("adHocCompletionCondition")) {
          adHocCompletionCondition = (org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition) agent.binders.get("adHocCompletionCondition").setModel(adHocCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocCompletionCondition", adHocCompletionCondition);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public Object get(String property) {
        switch (property) {
          case "adHocAutostart": return getAdHocAutostart();
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "adHocOrdering": return getAdHocOrdering();
          case "adHocActivationCondition": return getAdHocActivationCondition();
          case "onExitAction": return getOnExitAction();
          case "adHocCompletionCondition": return getAdHocCompletionCondition();
          case "onEntryAction": return getOnEntryAction();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "adHocOrdering": target.setAdHocOrdering((AdHocOrdering) value);
          break;
          case "adHocActivationCondition": target.setAdHocActivationCondition((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "adHocCompletionCondition": target.setAdHocCompletionCondition((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy extends IntermediateTimerEvent implements BindableProxy {
      private BindableProxyAgent<IntermediateTimerEvent> agent;
      private IntermediateTimerEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy() {
        this(new IntermediateTimerEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy(IntermediateTimerEvent targetVal) {
        agent = new BindableProxyAgent<IntermediateTimerEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CancellingTimerEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateTimerEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateTimerEvent unwrap() {
        return target;
      }

      public IntermediateTimerEvent deepUnwrap() {
        final IntermediateTimerEvent clone = new IntermediateTimerEvent();
        final IntermediateTimerEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CancellingTimerEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CancellingTimerEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CancellingTimerEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CancellingTimerEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CancellingTimerEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateTimerEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CancellingTimerEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateTimerEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateTimerEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateTimerEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy((IntermediateTimerEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateTimerEventProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy extends LiteralExpressionPMMLDocument implements BindableProxy {
      private BindableProxyAgent<LiteralExpressionPMMLDocument> agent;
      private LiteralExpressionPMMLDocument target;
      public org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy() {
        this(new LiteralExpressionPMMLDocument());
      }

      public org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy(LiteralExpressionPMMLDocument targetVal) {
        agent = new BindableProxyAgent<LiteralExpressionPMMLDocument>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("expressionLanguage", new PropertyType(ExpressionLanguage.class, true, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("importedValues", new PropertyType(ImportedValues.class, true, false));
        p.put("requiredComponentWidthCount", new PropertyType(Integer.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("componentWidths", new PropertyType(List.class, false, true));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(LiteralExpressionPMMLDocument.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public LiteralExpressionPMMLDocument unwrap() {
        return target;
      }

      public LiteralExpressionPMMLDocument deepUnwrap() {
        final LiteralExpressionPMMLDocument clone = new LiteralExpressionPMMLDocument();
        final LiteralExpressionPMMLDocument t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getExpressionLanguage() instanceof BindableProxy) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) getExpressionLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExpressionLanguage())) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExpressionLanguage())).deepUnwrap());
        } else {
          clone.setExpressionLanguage(t.getExpressionLanguage());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getImportedValues() instanceof BindableProxy) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) getImportedValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImportedValues())) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImportedValues())).deepUnwrap());
        } else {
          clone.setImportedValues(t.getImportedValues());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public ExpressionLanguage getExpressionLanguage() {
        return target.getExpressionLanguage();
      }

      public void setExpressionLanguage(ExpressionLanguage expressionLanguage) {
        if (agent.binders.containsKey("expressionLanguage")) {
          expressionLanguage = (ExpressionLanguage) agent.binders.get("expressionLanguage").setModel(expressionLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("expressionLanguage", expressionLanguage);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public ImportedValues getImportedValues() {
        return target.getImportedValues();
      }

      public void setImportedValues(ImportedValues importedValues) {
        if (agent.binders.containsKey("importedValues")) {
          importedValues = (ImportedValues) agent.binders.get("importedValues").setModel(importedValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("importedValues", importedValues);
      }

      public int getRequiredComponentWidthCount() {
        return target.getRequiredComponentWidthCount();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getComponentWidths() {
        return target.getComponentWidths();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "expressionLanguage": return getExpressionLanguage();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "importedValues": return getImportedValues();
          case "requiredComponentWidthCount": return getRequiredComponentWidthCount();
          case "nsContext": return getNsContext();
          case "componentWidths": return getComponentWidths();
          case "hasTypeRefs": return getHasTypeRefs();
          case "text": return getText();
          case "id": return getId();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("LiteralExpressionPMMLDocument", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "expressionLanguage": target.setExpressionLanguage((ExpressionLanguage) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "importedValues": target.setImportedValues((ImportedValues) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (LiteralExpressionPMMLDocument) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("LiteralExpressionPMMLDocument", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(LiteralExpressionPMMLDocument.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy((LiteralExpressionPMMLDocument) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_LiteralExpressionPMMLDocumentProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy extends DefaultRoute implements BindableProxy {
      private BindableProxyAgent<DefaultRoute> agent;
      private DefaultRoute target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy() {
        this(new DefaultRoute());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy(DefaultRoute targetVal) {
        agent = new BindableProxyAgent<DefaultRoute>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DefaultRoute.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DefaultRoute unwrap() {
        return target;
      }

      public DefaultRoute deepUnwrap() {
        final DefaultRoute clone = new DefaultRoute();
        final DefaultRoute t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DefaultRoute", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (DefaultRoute) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DefaultRoute", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DefaultRoute.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy((DefaultRoute) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_gateway_DefaultRouteProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy extends BPMNDiagramImpl implements BindableProxy {
      private BindableProxyAgent<BPMNDiagramImpl> agent;
      private BPMNDiagramImpl target;
      public org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy() {
        this(new BPMNDiagramImpl());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy(BPMNDiagramImpl targetVal) {
        agent = new BindableProxyAgent<BPMNDiagramImpl>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNBaseInfo.class, false, false));
        p.put("processData", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, true, false));
        p.put("caseManagementSet", new PropertyType(CaseManagementSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("diagramSet", new PropertyType(DiagramSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(BPMNDiagramImpl.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BPMNDiagramImpl unwrap() {
        return target;
      }

      public BPMNDiagramImpl deepUnwrap() {
        final BPMNDiagramImpl clone = new BPMNDiagramImpl();
        final BPMNDiagramImpl t = unwrap();
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getCaseManagementSet() instanceof BindableProxy) {
          clone.setCaseManagementSet((CaseManagementSet) ((BindableProxy) getCaseManagementSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCaseManagementSet())) {
          clone.setCaseManagementSet((CaseManagementSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCaseManagementSet())).deepUnwrap());
        } else {
          clone.setCaseManagementSet(t.getCaseManagementSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getDiagramSet() instanceof BindableProxy) {
          clone.setDiagramSet((DiagramSet) ((BindableProxy) getDiagramSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDiagramSet())) {
          clone.setDiagramSet((DiagramSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDiagramSet())).deepUnwrap());
        } else {
          clone.setDiagramSet(t.getDiagramSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNBaseInfo getGeneral() {
        return target.getGeneral();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public CaseManagementSet getCaseManagementSet() {
        return target.getCaseManagementSet();
      }

      public void setCaseManagementSet(CaseManagementSet caseManagementSet) {
        if (agent.binders.containsKey("caseManagementSet")) {
          caseManagementSet = (CaseManagementSet) agent.binders.get("caseManagementSet").setModel(caseManagementSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("caseManagementSet", caseManagementSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public DiagramSet getDiagramSet() {
        return target.getDiagramSet();
      }

      public void setDiagramSet(DiagramSet diagramSet) {
        if (agent.binders.containsKey("diagramSet")) {
          diagramSet = (DiagramSet) agent.binders.get("diagramSet").setModel(diagramSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("diagramSet", diagramSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "processData": return getProcessData();
          case "caseManagementSet": return getCaseManagementSet();
          case "backgroundSet": return getBackgroundSet();
          case "diagramSet": return getDiagramSet();
          case "dimensionsSet": return getDimensionsSet();
          case "fontSet": return getFontSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("BPMNDiagramImpl", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "processData": target.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) value);
          break;
          case "caseManagementSet": target.setCaseManagementSet((CaseManagementSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "diagramSet": target.setDiagramSet((DiagramSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "this": target = (BPMNDiagramImpl) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BPMNDiagramImpl", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BPMNDiagramImpl.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy((BPMNDiagramImpl) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_BPMNDiagramImplProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy extends AdHocActivationCondition implements BindableProxy {
      private BindableProxyAgent<AdHocActivationCondition> agent;
      private AdHocActivationCondition target;
      public org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy() {
        this(new AdHocActivationCondition());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy(AdHocActivationCondition targetVal) {
        agent = new BindableProxyAgent<AdHocActivationCondition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(AdHocActivationCondition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHocActivationCondition unwrap() {
        return target;
      }

      public AdHocActivationCondition deepUnwrap() {
        final AdHocActivationCondition clone = new AdHocActivationCondition();
        final AdHocActivationCondition t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocActivationCondition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (AdHocActivationCondition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocActivationCondition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHocActivationCondition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy((AdHocActivationCondition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_AdHocActivationConditionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy extends StartConditionalEvent implements BindableProxy {
      private BindableProxyAgent<StartConditionalEvent> agent;
      private StartConditionalEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy() {
        this(new StartConditionalEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy(StartConditionalEvent targetVal) {
        agent = new BindableProxyAgent<StartConditionalEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(InterruptingConditionalEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartConditionalEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartConditionalEvent unwrap() {
        return target;
      }

      public StartConditionalEvent deepUnwrap() {
        final StartConditionalEvent clone = new StartConditionalEvent();
        final StartConditionalEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((InterruptingConditionalEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((InterruptingConditionalEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InterruptingConditionalEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(InterruptingConditionalEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (InterruptingConditionalEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartConditionalEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((InterruptingConditionalEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartConditionalEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartConditionalEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartConditionalEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy((StartConditionalEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartConditionalEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy extends StartTimerEvent implements BindableProxy {
      private BindableProxyAgent<StartTimerEvent> agent;
      private StartTimerEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy() {
        this(new StartTimerEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy(StartTimerEvent targetVal) {
        agent = new BindableProxyAgent<StartTimerEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(InterruptingTimerEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartTimerEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartTimerEvent unwrap() {
        return target;
      }

      public StartTimerEvent deepUnwrap() {
        final StartTimerEvent clone = new StartTimerEvent();
        final StartTimerEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((InterruptingTimerEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((InterruptingTimerEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InterruptingTimerEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(InterruptingTimerEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (InterruptingTimerEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartTimerEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((InterruptingTimerEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartTimerEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartTimerEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartTimerEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy((StartTimerEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartTimerEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy extends CancelActivity implements BindableProxy {
      private BindableProxyAgent<CancelActivity> agent;
      private CancelActivity target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy() {
        this(new CancelActivity());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy(CancelActivity targetVal) {
        agent = new BindableProxyAgent<CancelActivity>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(CancelActivity.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancelActivity unwrap() {
        return target;
      }

      public CancelActivity deepUnwrap() {
        final CancelActivity clone = new CancelActivity();
        final CancelActivity t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancelActivity", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (CancelActivity) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancelActivity", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancelActivity.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy((CancelActivity) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_CancelActivityProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy extends DmnModelName implements BindableProxy {
      private BindableProxyAgent<DmnModelName> agent;
      private DmnModelName target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy() {
        this(new DmnModelName());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy(DmnModelName targetVal) {
        agent = new BindableProxyAgent<DmnModelName>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DmnModelName.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DmnModelName unwrap() {
        return target;
      }

      public DmnModelName deepUnwrap() {
        final DmnModelName clone = new DmnModelName();
        final DmnModelName t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DmnModelName", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (DmnModelName) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DmnModelName", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DmnModelName.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy((DmnModelName) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_DmnModelNameProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy extends Description implements BindableProxy {
      private BindableProxyAgent<Description> agent;
      private Description target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy() {
        this(new Description());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy(Description targetVal) {
        agent = new BindableProxyAgent<Description>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Description.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Description unwrap() {
        return target;
      }

      public Description deepUnwrap() {
        final Description clone = new Description();
        final Description t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Description", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Description) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Description", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Description.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy((Description) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_DescriptionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy extends BorderSize implements BindableProxy {
      private BindableProxyAgent<BorderSize> agent;
      private BorderSize target;
      public org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy() {
        this(new BorderSize());
      }

      public org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy(BorderSize targetVal) {
        agent = new BindableProxyAgent<BorderSize>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(BorderSize.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BorderSize unwrap() {
        return target;
      }

      public BorderSize deepUnwrap() {
        final BorderSize clone = new BorderSize();
        final BorderSize t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("BorderSize", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (BorderSize) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BorderSize", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BorderSize.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy((BorderSize) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_background_BorderSizeProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ScriptTypeValue.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition clone = new org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition();
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ScriptTypeValue getValue() {
        return target.getValue();
      }

      public void setValue(ScriptTypeValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ScriptTypeValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocCompletionCondition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ScriptTypeValue) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocCompletionCondition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocCompletionCondition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocCompletionConditionProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_UserTaskProxy extends UserTask implements BindableProxy {
      private BindableProxyAgent<UserTask> agent;
      private UserTask target;
      public org_kie_workbench_common_stunner_cm_definition_UserTaskProxy() {
        this(new UserTask());
      }

      public org_kie_workbench_common_stunner_cm_definition_UserTaskProxy(UserTask targetVal) {
        agent = new BindableProxyAgent<UserTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(UserTaskExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(UserTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public UserTask unwrap() {
        return target;
      }

      public UserTask deepUnwrap() {
        final UserTask clone = new UserTask();
        final UserTask t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((UserTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((UserTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_UserTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_UserTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public UserTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(UserTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (UserTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("UserTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((UserTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (UserTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("UserTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(UserTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_UserTaskProxy((UserTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_UserTaskProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy extends IsCase implements BindableProxy {
      private BindableProxyAgent<IsCase> agent;
      private IsCase target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy() {
        this(new IsCase());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy(IsCase targetVal) {
        agent = new BindableProxyAgent<IsCase>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(IsCase.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IsCase unwrap() {
        return target;
      }

      public IsCase deepUnwrap() {
        final IsCase clone = new IsCase();
        final IsCase t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("IsCase", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (IsCase) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IsCase", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(IsCase.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy((IsCase) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_IsCaseProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy extends DateMultipleInputFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DateMultipleInputFieldDefinition> agent;
      private DateMultipleInputFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy() {
        this(new DateMultipleInputFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy(DateMultipleInputFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DateMultipleInputFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("pageSize", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(DateMultipleInputFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DateMultipleInputFieldDefinition unwrap() {
        return target;
      }

      public DateMultipleInputFieldDefinition deepUnwrap() {
        final DateMultipleInputFieldDefinition clone = new DateMultipleInputFieldDefinition();
        final DateMultipleInputFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setPageSize(t.getPageSize());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getPageSize() {
        return target.getPageSize();
      }

      public void setPageSize(Integer pageSize) {
        changeAndFire("pageSize", pageSize);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "pageSize": return getPageSize();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DateMultipleInputFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "pageSize": target.setPageSize((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DateMultipleInputFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DateMultipleInputFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DateMultipleInputFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy((DateMultipleInputFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_DateMultipleInputFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy extends UnaryTests implements BindableProxy {
      private BindableProxyAgent<UnaryTests> agent;
      private UnaryTests target;
      public org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy() {
        this(new UnaryTests());
      }

      public org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy(UnaryTests targetVal) {
        agent = new BindableProxyAgent<UnaryTests>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("expressionLanguage", new PropertyType(ExpressionLanguage.class, true, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("constraintType", new PropertyType(ConstraintType.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(UnaryTests.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public UnaryTests unwrap() {
        return target;
      }

      public UnaryTests deepUnwrap() {
        final UnaryTests clone = new UnaryTests();
        final UnaryTests t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getExpressionLanguage() instanceof BindableProxy) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) getExpressionLanguage()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExpressionLanguage())) {
          clone.setExpressionLanguage((ExpressionLanguage) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExpressionLanguage())).deepUnwrap());
        } else {
          clone.setExpressionLanguage(t.getExpressionLanguage());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        clone.setConstraintType(t.getConstraintType());
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public ExpressionLanguage getExpressionLanguage() {
        return target.getExpressionLanguage();
      }

      public void setExpressionLanguage(ExpressionLanguage expressionLanguage) {
        if (agent.binders.containsKey("expressionLanguage")) {
          expressionLanguage = (ExpressionLanguage) agent.binders.get("expressionLanguage").setModel(expressionLanguage, StateSync.FROM_MODEL, true);
        }
        changeAndFire("expressionLanguage", expressionLanguage);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public ConstraintType getConstraintType() {
        return target.getConstraintType();
      }

      public void setConstraintType(ConstraintType constraintType) {
        changeAndFire("constraintType", constraintType);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "expressionLanguage": return getExpressionLanguage();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "constraintType": return getConstraintType();
          case "nsContext": return getNsContext();
          case "text": return getText();
          case "id": return getId();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("UnaryTests", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "expressionLanguage": target.setExpressionLanguage((ExpressionLanguage) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "constraintType": target.setConstraintType((ConstraintType) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (UnaryTests) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("UnaryTests", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(UnaryTests.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy((UnaryTests) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_UnaryTestsProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy extends OutputClauseLiteralExpression implements BindableProxy {
      private BindableProxyAgent<OutputClauseLiteralExpression> agent;
      private OutputClauseLiteralExpression target;
      public org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy() {
        this(new OutputClauseLiteralExpression());
      }

      public org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy(OutputClauseLiteralExpression targetVal) {
        agent = new BindableProxyAgent<OutputClauseLiteralExpression>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("importedValues", new PropertyType(ImportedValues.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(OutputClauseLiteralExpression.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public OutputClauseLiteralExpression unwrap() {
        return target;
      }

      public OutputClauseLiteralExpression deepUnwrap() {
        final OutputClauseLiteralExpression clone = new OutputClauseLiteralExpression();
        final OutputClauseLiteralExpression t = unwrap();
        clone.setParent(t.getParent());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getImportedValues() instanceof BindableProxy) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) getImportedValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getImportedValues())) {
          clone.setImportedValues((ImportedValues) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getImportedValues())).deepUnwrap());
        } else {
          clone.setImportedValues(t.getImportedValues());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public ImportedValues getImportedValues() {
        return target.getImportedValues();
      }

      public void setImportedValues(ImportedValues importedValues) {
        if (agent.binders.containsKey("importedValues")) {
          importedValues = (ImportedValues) agent.binders.get("importedValues").setModel(importedValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("importedValues", importedValues);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public Id getId() {
        return target.getId();
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "importedValues": return getImportedValues();
          case "nsContext": return getNsContext();
          case "hasTypeRefs": return getHasTypeRefs();
          case "id": return getId();
          case "text": return getText();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("OutputClauseLiteralExpression", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "importedValues": target.setImportedValues((ImportedValues) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (OutputClauseLiteralExpression) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("OutputClauseLiteralExpression", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(OutputClauseLiteralExpression.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy((OutputClauseLiteralExpression) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_OutputClauseLiteralExpressionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy extends QNameHolder implements BindableProxy {
      private BindableProxyAgent<QNameHolder> agent;
      private QNameHolder target;
      public org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy() {
        this(new QNameHolder());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy(QNameHolder targetVal) {
        agent = new BindableProxyAgent<QNameHolder>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(QName.class, false, false));
        p.put("this", new PropertyType(QNameHolder.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public QNameHolder unwrap() {
        return target;
      }

      public QNameHolder deepUnwrap() {
        final QNameHolder clone = new QNameHolder();
        final QNameHolder t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public QName getValue() {
        return target.getValue();
      }

      public void setValue(QName value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("QNameHolder", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((QName) value);
          break;
          case "this": target = (QNameHolder) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("QNameHolder", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(QNameHolder.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy((QNameHolder) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_QNameHolderProxy();
      }
    });
    class org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy extends ExecutionErrorSummary implements BindableProxy {
      private BindableProxyAgent<ExecutionErrorSummary> agent;
      private ExecutionErrorSummary target;
      public org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy() {
        this(new ExecutionErrorSummary());
      }

      public org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy(ExecutionErrorSummary targetVal) {
        agent = new BindableProxyAgent<ExecutionErrorSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("processInstanceId", new PropertyType(Long.class, false, false));
        p.put("acknowledged", new PropertyType(Boolean.class, false, false));
        p.put("activityName", new PropertyType(String.class, false, false));
        p.put("errorMessage", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("acknowledgedBy", new PropertyType(String.class, false, false));
        p.put("errorDate", new PropertyType(Date.class, false, false));
        p.put("type", new PropertyType(ExecutionErrorType.class, false, false));
        p.put("error", new PropertyType(String.class, false, false));
        p.put("acknowledgedAt", new PropertyType(Date.class, false, false));
        p.put("activityId", new PropertyType(Long.class, false, false));
        p.put("jobId", new PropertyType(Long.class, false, false));
        p.put("processId", new PropertyType(String.class, false, false));
        p.put("deploymentId", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("errorId", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ExecutionErrorSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ExecutionErrorSummary unwrap() {
        return target;
      }

      public ExecutionErrorSummary deepUnwrap() {
        final ExecutionErrorSummary clone = new ExecutionErrorSummary();
        final ExecutionErrorSummary t = unwrap();
        clone.setProcessInstanceId(t.getProcessInstanceId());
        clone.setAcknowledged(t.isAcknowledged());
        clone.setActivityName(t.getActivityName());
        clone.setErrorMessage(t.getErrorMessage());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setAcknowledgedBy(t.getAcknowledgedBy());
        clone.setErrorDate(t.getErrorDate());
        clone.setType(t.getType());
        clone.setError(t.getError());
        clone.setAcknowledgedAt(t.getAcknowledgedAt());
        clone.setActivityId(t.getActivityId());
        clone.setJobId(t.getJobId());
        clone.setProcessId(t.getProcessId());
        clone.setDeploymentId(t.getDeploymentId());
        clone.setName(t.getName());
        clone.setErrorId(t.getErrorId());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy) {
          obj = ((org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Long getProcessInstanceId() {
        return target.getProcessInstanceId();
      }

      public void setProcessInstanceId(Long processInstanceId) {
        changeAndFire("processInstanceId", processInstanceId);
      }

      public boolean isAcknowledged() {
        return target.isAcknowledged();
      }

      public void setAcknowledged(Boolean acknowledged) {
        changeAndFire("acknowledged", acknowledged);
      }

      public String getActivityName() {
        return target.getActivityName();
      }

      public void setActivityName(String activityName) {
        changeAndFire("activityName", activityName);
      }

      public String getErrorMessage() {
        return target.getErrorMessage();
      }

      public void setErrorMessage(String errorMessage) {
        changeAndFire("errorMessage", errorMessage);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public String getAcknowledgedBy() {
        return target.getAcknowledgedBy();
      }

      public void setAcknowledgedBy(String acknowledgedBy) {
        changeAndFire("acknowledgedBy", acknowledgedBy);
      }

      public Date getErrorDate() {
        return target.getErrorDate();
      }

      public void setErrorDate(Date errorDate) {
        changeAndFire("errorDate", errorDate);
      }

      public ExecutionErrorType getType() {
        return target.getType();
      }

      public void setType(ExecutionErrorType type) {
        changeAndFire("type", type);
      }

      public String getError() {
        return target.getError();
      }

      public void setError(String error) {
        changeAndFire("error", error);
      }

      public Date getAcknowledgedAt() {
        return target.getAcknowledgedAt();
      }

      public void setAcknowledgedAt(Date acknowledgedAt) {
        changeAndFire("acknowledgedAt", acknowledgedAt);
      }

      public Long getActivityId() {
        return target.getActivityId();
      }

      public void setActivityId(Long activityId) {
        changeAndFire("activityId", activityId);
      }

      public Long getJobId() {
        return target.getJobId();
      }

      public void setJobId(Long jobId) {
        changeAndFire("jobId", jobId);
      }

      public String getProcessId() {
        return target.getProcessId();
      }

      public void setProcessId(String processId) {
        changeAndFire("processId", processId);
      }

      public String getDeploymentId() {
        return target.getDeploymentId();
      }

      public void setDeploymentId(String deploymentId) {
        changeAndFire("deploymentId", deploymentId);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getErrorId() {
        return target.getErrorId();
      }

      public void setErrorId(String errorId) {
        changeAndFire("errorId", errorId);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public Object get(String property) {
        switch (property) {
          case "processInstanceId": return getProcessInstanceId();
          case "acknowledged": return isAcknowledged();
          case "activityName": return getActivityName();
          case "errorMessage": return getErrorMessage();
          case "callbacks": return getCallbacks();
          case "acknowledgedBy": return getAcknowledgedBy();
          case "errorDate": return getErrorDate();
          case "type": return getType();
          case "error": return getError();
          case "acknowledgedAt": return getAcknowledgedAt();
          case "activityId": return getActivityId();
          case "jobId": return getJobId();
          case "processId": return getProcessId();
          case "deploymentId": return getDeploymentId();
          case "name": return getName();
          case "errorId": return getErrorId();
          case "id": return getId();
          case "this": return target;
          default: throw new NonExistingPropertyException("ExecutionErrorSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "processInstanceId": target.setProcessInstanceId((Long) value);
          break;
          case "acknowledged": target.setAcknowledged((Boolean) value);
          break;
          case "activityName": target.setActivityName((String) value);
          break;
          case "errorMessage": target.setErrorMessage((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "acknowledgedBy": target.setAcknowledgedBy((String) value);
          break;
          case "errorDate": target.setErrorDate((Date) value);
          break;
          case "type": target.setType((ExecutionErrorType) value);
          break;
          case "error": target.setError((String) value);
          break;
          case "acknowledgedAt": target.setAcknowledgedAt((Date) value);
          break;
          case "activityId": target.setActivityId((Long) value);
          break;
          case "jobId": target.setJobId((Long) value);
          break;
          case "processId": target.setProcessId((String) value);
          break;
          case "deploymentId": target.setDeploymentId((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "errorId": target.setErrorId((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (ExecutionErrorSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ExecutionErrorSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ExecutionErrorSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy((ExecutionErrorSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_es_model_ExecutionErrorSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy extends UnitCost implements BindableProxy {
      private BindableProxyAgent<UnitCost> agent;
      private UnitCost target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy() {
        this(new UnitCost());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy(UnitCost targetVal) {
        agent = new BindableProxyAgent<UnitCost>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(UnitCost.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public UnitCost unwrap() {
        return target;
      }

      public UnitCost deepUnwrap() {
        final UnitCost clone = new UnitCost();
        final UnitCost t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("UnitCost", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (UnitCost) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("UnitCost", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(UnitCost.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy((UnitCost) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_UnitCostProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy extends BorderColor implements BindableProxy {
      private BindableProxyAgent<BorderColor> agent;
      private BorderColor target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy() {
        this(new BorderColor());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy(BorderColor targetVal) {
        agent = new BindableProxyAgent<BorderColor>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(BorderColor.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BorderColor unwrap() {
        return target;
      }

      public BorderColor deepUnwrap() {
        final BorderColor clone = new BorderColor();
        final BorderColor t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("BorderColor", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (BorderColor) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BorderColor", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BorderColor.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy((BorderColor) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderColorProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_font_FontSizeProxy extends FontSize implements BindableProxy {
      private BindableProxyAgent<FontSize> agent;
      private FontSize target;
      public org_kie_workbench_common_dmn_api_property_font_FontSizeProxy() {
        this(new FontSize());
      }

      public org_kie_workbench_common_dmn_api_property_font_FontSizeProxy(FontSize targetVal) {
        agent = new BindableProxyAgent<FontSize>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(FontSize.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontSize unwrap() {
        return target;
      }

      public FontSize deepUnwrap() {
        final FontSize clone = new FontSize();
        final FontSize t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_font_FontSizeProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_font_FontSizeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontSize", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (FontSize) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontSize", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontSize.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_font_FontSizeProxy((FontSize) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_font_FontSizeProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy extends AdHocCompletionCondition implements BindableProxy {
      private BindableProxyAgent<AdHocCompletionCondition> agent;
      private AdHocCompletionCondition target;
      public org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy() {
        this(new AdHocCompletionCondition());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy(AdHocCompletionCondition targetVal) {
        agent = new BindableProxyAgent<AdHocCompletionCondition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ScriptTypeValue.class, true, false));
        p.put("this", new PropertyType(AdHocCompletionCondition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHocCompletionCondition unwrap() {
        return target;
      }

      public AdHocCompletionCondition deepUnwrap() {
        final AdHocCompletionCondition clone = new AdHocCompletionCondition();
        final AdHocCompletionCondition t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ScriptTypeValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ScriptTypeValue getValue() {
        return target.getValue();
      }

      public void setValue(ScriptTypeValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ScriptTypeValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocCompletionCondition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ScriptTypeValue) value);
          break;
          case "this": target = (AdHocCompletionCondition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocCompletionCondition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHocCompletionCondition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy((AdHocCompletionCondition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_task_AdHocCompletionConditionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy extends MultipleInstanceSubprocessTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceSubprocessTaskExecutionSet> agent;
      private MultipleInstanceSubprocessTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy() {
        this(new MultipleInstanceSubprocessTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy(MultipleInstanceSubprocessTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceSubprocessTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("this", new PropertyType(MultipleInstanceSubprocessTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceSubprocessTaskExecutionSet unwrap() {
        return target;
      }

      public MultipleInstanceSubprocessTaskExecutionSet deepUnwrap() {
        final MultipleInstanceSubprocessTaskExecutionSet clone = new MultipleInstanceSubprocessTaskExecutionSet();
        final MultipleInstanceSubprocessTaskExecutionSet t = unwrap();
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public Object get(String property) {
        switch (property) {
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "onExitAction": return getOnExitAction();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "onEntryAction": return getOnEntryAction();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceSubprocessTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "this": target = (MultipleInstanceSubprocessTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceSubprocessTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceSubprocessTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy((MultipleInstanceSubprocessTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceSubprocessTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy extends OnEntryAction implements BindableProxy {
      private BindableProxyAgent<OnEntryAction> agent;
      private OnEntryAction target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy() {
        this(new OnEntryAction());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy(OnEntryAction targetVal) {
        agent = new BindableProxyAgent<OnEntryAction>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ScriptTypeListValue.class, true, false));
        p.put("this", new PropertyType(OnEntryAction.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public OnEntryAction unwrap() {
        return target;
      }

      public OnEntryAction deepUnwrap() {
        final OnEntryAction clone = new OnEntryAction();
        final OnEntryAction t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ScriptTypeListValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ScriptTypeListValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ScriptTypeListValue getValue() {
        return target.getValue();
      }

      public void setValue(ScriptTypeListValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ScriptTypeListValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("OnEntryAction", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ScriptTypeListValue) value);
          break;
          case "this": target = (OnEntryAction) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("OnEntryAction", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(OnEntryAction.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy((OnEntryAction) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_OnEntryActionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy extends RolesEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<RolesEditorFieldDefinition> agent;
      private RolesEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy() {
        this(new RolesEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy(RolesEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<RolesEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(RolesEditorFieldType.class, false, false));
        p.put("this", new PropertyType(RolesEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public RolesEditorFieldDefinition unwrap() {
        return target;
      }

      public RolesEditorFieldDefinition deepUnwrap() {
        final RolesEditorFieldDefinition clone = new RolesEditorFieldDefinition();
        final RolesEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public RolesEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("RolesEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (RolesEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("RolesEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(RolesEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy((RolesEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_cm_RolesEditorFieldDefinitionProxy();
      }
    });
    class org_jbpm_workbench_es_model_RequestSummaryProxy extends RequestSummary implements BindableProxy {
      private BindableProxyAgent<RequestSummary> agent;
      private RequestSummary target;
      public org_jbpm_workbench_es_model_RequestSummaryProxy() {
        this(new RequestSummary());
      }

      public org_jbpm_workbench_es_model_RequestSummaryProxy(RequestSummary targetVal) {
        agent = new BindableProxyAgent<RequestSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("processInstanceId", new PropertyType(Long.class, false, false));
        p.put("processInstanceDescription", new PropertyType(String.class, false, false));
        p.put("callbacks", new PropertyType(List.class, false, true));
        p.put("message", new PropertyType(String.class, false, false));
        p.put("jobId", new PropertyType(Long.class, false, false));
        p.put("retries", new PropertyType(Integer.class, false, false));
        p.put("commandName", new PropertyType(String.class, false, false));
        p.put("executions", new PropertyType(Integer.class, false, false));
        p.put("processName", new PropertyType(String.class, false, false));
        p.put("deploymentId", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("time", new PropertyType(Date.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("key", new PropertyType(String.class, false, false));
        p.put("status", new PropertyType(RequestStatus.class, false, false));
        p.put("this", new PropertyType(RequestSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public RequestSummary unwrap() {
        return target;
      }

      public RequestSummary deepUnwrap() {
        final RequestSummary clone = new RequestSummary();
        final RequestSummary t = unwrap();
        clone.setProcessInstanceId(t.getProcessInstanceId());
        clone.setProcessInstanceDescription(t.getProcessInstanceDescription());
        if (t.getCallbacks() != null) {
          final List callbacksClone = new ArrayList();
          for (Object callbacksElem : t.getCallbacks()) {
            if (callbacksElem instanceof BindableProxy) {
              callbacksClone.add(((BindableProxy) callbacksElem).deepUnwrap());
            } else {
              callbacksClone.add(callbacksElem);
            }
          }
          clone.setCallbacks(callbacksClone);
        }
        clone.setMessage(t.getMessage());
        clone.setJobId(t.getJobId());
        clone.setRetries(t.getRetries());
        clone.setCommandName(t.getCommandName());
        clone.setExecutions(t.getExecutions());
        clone.setProcessName(t.getProcessName());
        clone.setDeploymentId(t.getDeploymentId());
        clone.setName(t.getName());
        clone.setTime(t.getTime());
        clone.setId(t.getId());
        clone.setKey(t.getKey());
        clone.setStatus(t.getStatus());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_es_model_RequestSummaryProxy) {
          obj = ((org_jbpm_workbench_es_model_RequestSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Long getProcessInstanceId() {
        return target.getProcessInstanceId();
      }

      public void setProcessInstanceId(Long processInstanceId) {
        changeAndFire("processInstanceId", processInstanceId);
      }

      public String getProcessInstanceDescription() {
        return target.getProcessInstanceDescription();
      }

      public void setProcessInstanceDescription(String processInstanceDescription) {
        changeAndFire("processInstanceDescription", processInstanceDescription);
      }

      public List getCallbacks() {
        return target.getCallbacks();
      }

      public void setCallbacks(List<LabeledCommand> callbacks) {
        List<LabeledCommand> oldValue = target.getCallbacks();
        callbacks = agent.ensureBoundListIsProxied("callbacks", callbacks);
        target.setCallbacks(callbacks);
        agent.updateWidgetsAndFireEvent(true, "callbacks", oldValue, callbacks);
      }

      public String getMessage() {
        return target.getMessage();
      }

      public void setMessage(String message) {
        changeAndFire("message", message);
      }

      public Long getJobId() {
        return target.getJobId();
      }

      public void setJobId(Long jobId) {
        changeAndFire("jobId", jobId);
      }

      public Integer getRetries() {
        return target.getRetries();
      }

      public void setRetries(Integer retries) {
        changeAndFire("retries", retries);
      }

      public String getCommandName() {
        return target.getCommandName();
      }

      public void setCommandName(String commandName) {
        changeAndFire("commandName", commandName);
      }

      public Integer getExecutions() {
        return target.getExecutions();
      }

      public void setExecutions(Integer executions) {
        changeAndFire("executions", executions);
      }

      public String getProcessName() {
        return target.getProcessName();
      }

      public void setProcessName(String processName) {
        changeAndFire("processName", processName);
      }

      public String getDeploymentId() {
        return target.getDeploymentId();
      }

      public void setDeploymentId(String deploymentId) {
        changeAndFire("deploymentId", deploymentId);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Date getTime() {
        return target.getTime();
      }

      public void setTime(Date time) {
        changeAndFire("time", time);
      }

      public Long getId() {
        return target.getId();
      }

      public void setId(Long id) {
        changeAndFire("id", id);
      }

      public String getKey() {
        return target.getKey();
      }

      public void setKey(String key) {
        changeAndFire("key", key);
      }

      public RequestStatus getStatus() {
        return target.getStatus();
      }

      public void setStatus(RequestStatus status) {
        changeAndFire("status", status);
      }

      public Object get(String property) {
        switch (property) {
          case "processInstanceId": return getProcessInstanceId();
          case "processInstanceDescription": return getProcessInstanceDescription();
          case "callbacks": return getCallbacks();
          case "message": return getMessage();
          case "jobId": return getJobId();
          case "retries": return getRetries();
          case "commandName": return getCommandName();
          case "executions": return getExecutions();
          case "processName": return getProcessName();
          case "deploymentId": return getDeploymentId();
          case "name": return getName();
          case "time": return getTime();
          case "id": return getId();
          case "key": return getKey();
          case "status": return getStatus();
          case "this": return target;
          default: throw new NonExistingPropertyException("RequestSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "processInstanceId": target.setProcessInstanceId((Long) value);
          break;
          case "processInstanceDescription": target.setProcessInstanceDescription((String) value);
          break;
          case "callbacks": target.setCallbacks((List<LabeledCommand>) value);
          break;
          case "message": target.setMessage((String) value);
          break;
          case "jobId": target.setJobId((Long) value);
          break;
          case "retries": target.setRetries((Integer) value);
          break;
          case "commandName": target.setCommandName((String) value);
          break;
          case "executions": target.setExecutions((Integer) value);
          break;
          case "processName": target.setProcessName((String) value);
          break;
          case "deploymentId": target.setDeploymentId((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "time": target.setTime((Date) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "key": target.setKey((String) value);
          break;
          case "status": target.setStatus((RequestStatus) value);
          break;
          case "this": target = (RequestSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("RequestSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasCallbacks() {
        final boolean returnValue = target.hasCallbacks();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public void addCallback(String a0, Command a1) {
        target.addCallback(a0, a1);
        agent.updateWidgetsAndFireEvents();
      }

      public int compareTo(AbstractPageRow a0) {
        final int returnValue = target.compareTo(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(RequestSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_es_model_RequestSummaryProxy((RequestSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_es_model_RequestSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy extends EndMessageEvent implements BindableProxy {
      private BindableProxyAgent<EndMessageEvent> agent;
      private EndMessageEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy() {
        this(new EndMessageEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy(EndMessageEvent targetVal) {
        agent = new BindableProxyAgent<EndMessageEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(MessageEventExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndMessageEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndMessageEvent unwrap() {
        return target;
      }

      public EndMessageEvent deepUnwrap() {
        final EndMessageEvent clone = new EndMessageEvent();
        final EndMessageEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((MessageEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((MessageEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public MessageEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(MessageEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (MessageEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndMessageEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((MessageEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndMessageEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndMessageEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndMessageEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy((EndMessageEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndMessageEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy extends EmbeddedSubprocess implements BindableProxy {
      private BindableProxyAgent<EmbeddedSubprocess> agent;
      private EmbeddedSubprocess target;
      public org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy() {
        this(new EmbeddedSubprocess());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy(EmbeddedSubprocess targetVal) {
        agent = new BindableProxyAgent<EmbeddedSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("processData", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(EmbeddedSubprocessExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EmbeddedSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EmbeddedSubprocess unwrap() {
        return target;
      }

      public EmbeddedSubprocess deepUnwrap() {
        final EmbeddedSubprocess clone = new EmbeddedSubprocess();
        final EmbeddedSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getProcessData() instanceof BindableProxy) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) getProcessData()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessData())) {
          clone.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessData())).deepUnwrap());
        } else {
          clone.setProcessData(t.getProcessData());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((EmbeddedSubprocessExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((EmbeddedSubprocessExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData getProcessData() {
        return target.getProcessData();
      }

      public void setProcessData(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData processData) {
        if (agent.binders.containsKey("processData")) {
          processData = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) agent.binders.get("processData").setModel(processData, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processData", processData);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public EmbeddedSubprocessExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(EmbeddedSubprocessExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (EmbeddedSubprocessExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "simulationSet": return getSimulationSet();
          case "processData": return getProcessData();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EmbeddedSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "processData": target.setProcessData((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((EmbeddedSubprocessExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (EmbeddedSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EmbeddedSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EmbeddedSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy((EmbeddedSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EmbeddedSubprocessProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy extends Actors implements BindableProxy {
      private BindableProxyAgent<Actors> agent;
      private Actors target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy() {
        this(new Actors());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy(Actors targetVal) {
        agent = new BindableProxyAgent<Actors>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Actors.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Actors unwrap() {
        return target;
      }

      public Actors deepUnwrap() {
        final Actors clone = new Actors();
        final Actors t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Actors", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Actors) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Actors", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Actors.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy((Actors) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_assignee_ActorsProxy();
      }
    });
    class org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy extends ServiceTaskSummary implements BindableProxy {
      private BindableProxyAgent<ServiceTaskSummary> agent;
      private ServiceTaskSummary target;
      public org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy() {
        this(new ServiceTaskSummary());
      }

      public org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy(ServiceTaskSummary targetVal) {
        agent = new BindableProxyAgent<ServiceTaskSummary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("installedOn", new PropertyType(Set.class, false, false));
        p.put("installedOnBranch", new PropertyType(Set.class, false, false));
        p.put("icon", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("additionalInfo", new PropertyType(String.class, false, false));
        p.put("description", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("parameters", new PropertyType(List.class, false, true));
        p.put("referenceLink", new PropertyType(String.class, false, false));
        p.put("enabled", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(ServiceTaskSummary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ServiceTaskSummary unwrap() {
        return target;
      }

      public ServiceTaskSummary deepUnwrap() {
        final ServiceTaskSummary clone = new ServiceTaskSummary();
        final ServiceTaskSummary t = unwrap();
        if (t.getInstalledOn() != null) {
          final Set installedOnClone = new HashSet();
          for (Object installedOnElem : t.getInstalledOn()) {
            if (installedOnElem instanceof BindableProxy) {
              installedOnClone.add(((BindableProxy) installedOnElem).deepUnwrap());
            } else {
              installedOnClone.add(installedOnElem);
            }
          }
          clone.setInstalledOn(installedOnClone);
        }
        if (t.getInstalledOnBranch() != null) {
          final Set installedOnBranchClone = new HashSet();
          for (Object installedOnBranchElem : t.getInstalledOnBranch()) {
            if (installedOnBranchElem instanceof BindableProxy) {
              installedOnBranchClone.add(((BindableProxy) installedOnBranchElem).deepUnwrap());
            } else {
              installedOnBranchClone.add(installedOnBranchElem);
            }
          }
          clone.setInstalledOnBranch(installedOnBranchClone);
        }
        clone.setIcon(t.getIcon());
        clone.setName(t.getName());
        clone.setAdditionalInfo(t.getAdditionalInfo());
        clone.setDescription(t.getDescription());
        clone.setId(t.getId());
        if (t.getParameters() != null) {
          final List parametersClone = new ArrayList();
          for (Object parametersElem : t.getParameters()) {
            if (parametersElem instanceof BindableProxy) {
              parametersClone.add(((BindableProxy) parametersElem).deepUnwrap());
            } else {
              parametersClone.add(parametersElem);
            }
          }
          clone.setParameters(parametersClone);
        }
        clone.setReferenceLink(t.getReferenceLink());
        clone.setEnabled(t.getEnabled());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy) {
          obj = ((org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Set getInstalledOn() {
        return target.getInstalledOn();
      }

      public void setInstalledOn(Set<String> installedOn) {
        changeAndFire("installedOn", installedOn);
      }

      public Set getInstalledOnBranch() {
        return target.getInstalledOnBranch();
      }

      public void setInstalledOnBranch(Set<String> installedOnBranch) {
        changeAndFire("installedOnBranch", installedOnBranch);
      }

      public String getIcon() {
        return target.getIcon();
      }

      public void setIcon(String icon) {
        changeAndFire("icon", icon);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getAdditionalInfo() {
        return target.getAdditionalInfo();
      }

      public void setAdditionalInfo(String additionalInfo) {
        changeAndFire("additionalInfo", additionalInfo);
      }

      public String getDescription() {
        return target.getDescription();
      }

      public void setDescription(String description) {
        changeAndFire("description", description);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public List getParameters() {
        return target.getParameters();
      }

      public void setParameters(List<String> parameters) {
        List<String> oldValue = target.getParameters();
        parameters = agent.ensureBoundListIsProxied("parameters", parameters);
        target.setParameters(parameters);
        agent.updateWidgetsAndFireEvent(true, "parameters", oldValue, parameters);
      }

      public String getReferenceLink() {
        return target.getReferenceLink();
      }

      public void setReferenceLink(String referenceLink) {
        changeAndFire("referenceLink", referenceLink);
      }

      public Boolean getEnabled() {
        return target.getEnabled();
      }

      public void setEnabled(Boolean enabled) {
        changeAndFire("enabled", enabled);
      }

      public Object get(String property) {
        switch (property) {
          case "installedOn": return getInstalledOn();
          case "installedOnBranch": return getInstalledOnBranch();
          case "icon": return getIcon();
          case "name": return getName();
          case "additionalInfo": return getAdditionalInfo();
          case "description": return getDescription();
          case "id": return getId();
          case "parameters": return getParameters();
          case "referenceLink": return getReferenceLink();
          case "enabled": return getEnabled();
          case "this": return target;
          default: throw new NonExistingPropertyException("ServiceTaskSummary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "installedOn": target.setInstalledOn((Set<String>) value);
          break;
          case "installedOnBranch": target.setInstalledOnBranch((Set<String>) value);
          break;
          case "icon": target.setIcon((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "additionalInfo": target.setAdditionalInfo((String) value);
          break;
          case "description": target.setDescription((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "parameters": target.setParameters((List<String>) value);
          break;
          case "referenceLink": target.setReferenceLink((String) value);
          break;
          case "enabled": target.setEnabled((Boolean) value);
          break;
          case "this": target = (ServiceTaskSummary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ServiceTaskSummary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ServiceTaskSummary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy((ServiceTaskSummary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_workbench_wi_workitems_model_ServiceTaskSummaryProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy extends CompensationEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CompensationEventExecutionSet> agent;
      private CompensationEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy() {
        this(new CompensationEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy(CompensationEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CompensationEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("activityRef", new PropertyType(ActivityRef.class, true, false));
        p.put("this", new PropertyType(CompensationEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CompensationEventExecutionSet unwrap() {
        return target;
      }

      public CompensationEventExecutionSet deepUnwrap() {
        final CompensationEventExecutionSet clone = new CompensationEventExecutionSet();
        final CompensationEventExecutionSet t = unwrap();
        if (t.getActivityRef() instanceof BindableProxy) {
          clone.setActivityRef((ActivityRef) ((BindableProxy) getActivityRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getActivityRef())) {
          clone.setActivityRef((ActivityRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getActivityRef())).deepUnwrap());
        } else {
          clone.setActivityRef(t.getActivityRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ActivityRef getActivityRef() {
        return target.getActivityRef();
      }

      public void setActivityRef(ActivityRef activityRef) {
        if (agent.binders.containsKey("activityRef")) {
          activityRef = (ActivityRef) agent.binders.get("activityRef").setModel(activityRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("activityRef", activityRef);
      }

      public Object get(String property) {
        switch (property) {
          case "activityRef": return getActivityRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("CompensationEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "activityRef": target.setActivityRef((ActivityRef) value);
          break;
          case "this": target = (CompensationEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CompensationEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CompensationEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy((CompensationEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_compensation_CompensationEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy extends DMNDefinitionSet implements BindableProxy {
      private BindableProxyAgent<DMNDefinitionSet> agent;
      private DMNDefinitionSet target;
      public org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy() {
        this(new DMNDefinitionSet());
      }

      public org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy(DMNDefinitionSet targetVal) {
        agent = new BindableProxyAgent<DMNDefinitionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("description", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DMNDefinitionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DMNDefinitionSet unwrap() {
        return target;
      }

      public DMNDefinitionSet deepUnwrap() {
        final DMNDefinitionSet clone = new DMNDefinitionSet();
        final DMNDefinitionSet t = unwrap();
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy) {
          obj = ((org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getDescription() {
        return target.getDescription();
      }

      public Object get(String property) {
        switch (property) {
          case "description": return getDescription();
          case "this": return target;
          default: throw new NonExistingPropertyException("DMNDefinitionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "this": target = (DMNDefinitionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DMNDefinitionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DMNDefinitionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy((DMNDefinitionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_DMNDefinitionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy extends StartMessageEvent implements BindableProxy {
      private BindableProxyAgent<StartMessageEvent> agent;
      private StartMessageEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy() {
        this(new StartMessageEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy(StartMessageEvent targetVal) {
        agent = new BindableProxyAgent<StartMessageEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationAttributeSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(InterruptingMessageEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(StartMessageEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StartMessageEvent unwrap() {
        return target;
      }

      public StartMessageEvent deepUnwrap() {
        final StartMessageEvent clone = new StartMessageEvent();
        final StartMessageEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationAttributeSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((InterruptingMessageEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((InterruptingMessageEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationAttributeSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationAttributeSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationAttributeSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InterruptingMessageEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(InterruptingMessageEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (InterruptingMessageEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("StartMessageEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationAttributeSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((InterruptingMessageEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (StartMessageEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StartMessageEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(StartMessageEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy((StartMessageEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_StartMessageEventProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy extends CharacterBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<CharacterBoxFieldDefinition> agent;
      private CharacterBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy() {
        this(new CharacterBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy(CharacterBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<CharacterBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(TextBoxFieldType.class, false, false));
        p.put("maxLength", new PropertyType(Integer.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CharacterBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CharacterBoxFieldDefinition unwrap() {
        return target;
      }

      public CharacterBoxFieldDefinition deepUnwrap() {
        final CharacterBoxFieldDefinition clone = new CharacterBoxFieldDefinition();
        final CharacterBoxFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setMaxLength(t.getMaxLength());
        clone.setPlaceHolder(t.getPlaceHolder());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public TextBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Integer getMaxLength() {
        return target.getMaxLength();
      }

      public void setMaxLength(Integer maxLength) {
        changeAndFire("maxLength", maxLength);
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "maxLength": return getMaxLength();
          case "placeHolder": return getPlaceHolder();
          case "this": return target;
          default: throw new NonExistingPropertyException("CharacterBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "maxLength": target.setMaxLength((Integer) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "this": target = (CharacterBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CharacterBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(CharacterBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy((CharacterBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textBox_definition_CharacterBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy extends DecisionService implements BindableProxy {
      private BindableProxyAgent<DecisionService> agent;
      private DecisionService target;
      public org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy() {
        this(new DecisionService());
      }

      public org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy(DecisionService targetVal) {
        agent = new BindableProxyAgent<DecisionService>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("inputDecision", new PropertyType(List.class, false, true));
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("outputDecision", new PropertyType(List.class, false, true));
        p.put("inputData", new PropertyType(List.class, false, true));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("allowOnlyVisualChange", new PropertyType(Boolean.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("backgroundSet", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        p.put("variable", new PropertyType(InformationItemPrimary.class, true, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("fontSet", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(DecisionServiceRectangleDimensionsSet.class, true, false));
        p.put("encapsulatedDecision", new PropertyType(List.class, false, true));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("dividerLineY", new PropertyType(DecisionServiceDividerLineY.class, true, false));
        p.put("linksHolder", new PropertyType(DocumentationLinksHolder.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(DecisionService.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecisionService unwrap() {
        return target;
      }

      public DecisionService deepUnwrap() {
        final DecisionService clone = new DecisionService();
        final DecisionService t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        clone.setAllowOnlyVisualChange(t.isAllowOnlyVisualChange());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getVariable() instanceof BindableProxy) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) getVariable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getVariable())) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getVariable())).deepUnwrap());
        } else {
          clone.setVariable(t.getVariable());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((DecisionServiceRectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((DecisionServiceRectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getDividerLineY() instanceof BindableProxy) {
          clone.setDividerLineY((DecisionServiceDividerLineY) ((BindableProxy) getDividerLineY()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDividerLineY())) {
          clone.setDividerLineY((DecisionServiceDividerLineY) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDividerLineY())).deepUnwrap());
        } else {
          clone.setDividerLineY(t.getDividerLineY());
        }
        if (t.getLinksHolder() instanceof BindableProxy) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) getLinksHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLinksHolder())) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLinksHolder())).deepUnwrap());
        } else {
          clone.setLinksHolder(t.getLinksHolder());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public List getInputDecision() {
        return target.getInputDecision();
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public List getOutputDecision() {
        return target.getOutputDecision();
      }

      public List getInputData() {
        return target.getInputData();
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public boolean isAllowOnlyVisualChange() {
        return target.isAllowOnlyVisualChange();
      }

      public void setAllowOnlyVisualChange(boolean allowOnlyVisualChange) {
        changeAndFire("allowOnlyVisualChange", allowOnlyVisualChange);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(org.kie.workbench.common.dmn.api.property.background.BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public InformationItemPrimary getVariable() {
        return target.getVariable();
      }

      public void setVariable(InformationItemPrimary variable) {
        if (agent.binders.containsKey("variable")) {
          variable = (InformationItemPrimary) agent.binders.get("variable").setModel(variable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("variable", variable);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(org.kie.workbench.common.dmn.api.property.font.FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (org.kie.workbench.common.dmn.api.property.font.FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public DecisionServiceRectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(DecisionServiceRectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (DecisionServiceRectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public List getEncapsulatedDecision() {
        return target.getEncapsulatedDecision();
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public DecisionServiceDividerLineY getDividerLineY() {
        return target.getDividerLineY();
      }

      public void setDividerLineY(DecisionServiceDividerLineY dividerLineY) {
        if (agent.binders.containsKey("dividerLineY")) {
          dividerLineY = (DecisionServiceDividerLineY) agent.binders.get("dividerLineY").setModel(dividerLineY, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dividerLineY", dividerLineY);
      }

      public DocumentationLinksHolder getLinksHolder() {
        return target.getLinksHolder();
      }

      public void setLinksHolder(DocumentationLinksHolder linksHolder) {
        if (agent.binders.containsKey("linksHolder")) {
          linksHolder = (DocumentationLinksHolder) agent.binders.get("linksHolder").setModel(linksHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("linksHolder", linksHolder);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "inputDecision": return getInputDecision();
          case "parent": return getParent();
          case "outputDecision": return getOutputDecision();
          case "inputData": return getInputData();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "allowOnlyVisualChange": return isAllowOnlyVisualChange();
          case "description": return getDescription();
          case "nsContext": return getNsContext();
          case "backgroundSet": return getBackgroundSet();
          case "variable": return getVariable();
          case "name": return getName();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "encapsulatedDecision": return getEncapsulatedDecision();
          case "id": return getId();
          case "dividerLineY": return getDividerLineY();
          case "linksHolder": return getLinksHolder();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecisionService", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "allowOnlyVisualChange": target.setAllowOnlyVisualChange((Boolean) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "backgroundSet": target.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value);
          break;
          case "variable": target.setVariable((InformationItemPrimary) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "fontSet": target.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((DecisionServiceRectangleDimensionsSet) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "dividerLineY": target.setDividerLineY((DecisionServiceDividerLineY) value);
          break;
          case "linksHolder": target.setLinksHolder((DocumentationLinksHolder) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (DecisionService) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecisionService", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public ReadOnly getReadOnly(String a0) {
        final ReadOnly returnValue = target.getReadOnly(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(DecisionService.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy((DecisionService) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_DecisionServiceProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy extends AbortParent implements BindableProxy {
      private BindableProxyAgent<AbortParent> agent;
      private AbortParent target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy() {
        this(new AbortParent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy(AbortParent targetVal) {
        agent = new BindableProxyAgent<AbortParent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(AbortParent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AbortParent unwrap() {
        return target;
      }

      public AbortParent deepUnwrap() {
        final AbortParent clone = new AbortParent();
        final AbortParent t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AbortParent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (AbortParent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AbortParent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AbortParent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy((AbortParent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AbortParentProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy extends AdHocOrdering implements BindableProxy {
      private BindableProxyAgent<AdHocOrdering> agent;
      private AdHocOrdering target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy() {
        this(new AdHocOrdering());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy(AdHocOrdering targetVal) {
        agent = new BindableProxyAgent<AdHocOrdering>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(AdHocOrdering.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHocOrdering unwrap() {
        return target;
      }

      public AdHocOrdering deepUnwrap() {
        final AdHocOrdering clone = new AdHocOrdering();
        final AdHocOrdering t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocOrdering", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (AdHocOrdering) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocOrdering", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHocOrdering.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy((AdHocOrdering) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocOrderingProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy extends ComboBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ComboBoxFieldDefinition> agent;
      private ComboBoxFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy() {
        this(new ComboBoxFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy(ComboBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ComboBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("allowCustomValue", new PropertyType(Boolean.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(ComboBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ComboBoxFieldDefinition unwrap() {
        return target;
      }

      public ComboBoxFieldDefinition deepUnwrap() {
        final ComboBoxFieldDefinition clone = new ComboBoxFieldDefinition();
        final ComboBoxFieldDefinition t = unwrap();
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setAllowCustomValue(t.isAllowCustomValue());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean isAllowCustomValue() {
        return target.isAllowCustomValue();
      }

      public void setAllowCustomValue(Boolean allowCustomValue) {
        changeAndFire("allowCustomValue", allowCustomValue);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<StringSelectorOption> options) {
        List<StringSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "allowCustomValue": return isAllowCustomValue();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("ComboBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "allowCustomValue": target.setAllowCustomValue((Boolean) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<StringSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (ComboBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ComboBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ComboBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy((ComboBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ComboBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy extends KnowledgeSourceType implements BindableProxy {
      private BindableProxyAgent<KnowledgeSourceType> agent;
      private KnowledgeSourceType target;
      public org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy() {
        this(new KnowledgeSourceType());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy(KnowledgeSourceType targetVal) {
        agent = new BindableProxyAgent<KnowledgeSourceType>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(KnowledgeSourceType.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public KnowledgeSourceType unwrap() {
        return target;
      }

      public KnowledgeSourceType deepUnwrap() {
        final KnowledgeSourceType clone = new KnowledgeSourceType();
        final KnowledgeSourceType t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("KnowledgeSourceType", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (KnowledgeSourceType) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("KnowledgeSourceType", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(KnowledgeSourceType.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy((KnowledgeSourceType) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_KnowledgeSourceTypeProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy extends SignalScope implements BindableProxy {
      private BindableProxyAgent<SignalScope> agent;
      private SignalScope target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy() {
        this(new SignalScope());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy(SignalScope targetVal) {
        agent = new BindableProxyAgent<SignalScope>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(SignalScope.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SignalScope unwrap() {
        return target;
      }

      public SignalScope deepUnwrap() {
        final SignalScope clone = new SignalScope();
        final SignalScope t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("SignalScope", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (SignalScope) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SignalScope", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SignalScope.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy((SignalScope) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalScopeProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy extends ConditionalComboBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ConditionalComboBoxFieldDefinition> agent;
      private ConditionalComboBoxFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy() {
        this(new ConditionalComboBoxFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy(ConditionalComboBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ConditionalComboBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("allowCustomValue", new PropertyType(Boolean.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ConditionalComboBoxFieldType.class, false, false));
        p.put("this", new PropertyType(ConditionalComboBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ConditionalComboBoxFieldDefinition unwrap() {
        return target;
      }

      public ConditionalComboBoxFieldDefinition deepUnwrap() {
        final ConditionalComboBoxFieldDefinition clone = new ConditionalComboBoxFieldDefinition();
        final ConditionalComboBoxFieldDefinition t = unwrap();
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setAllowCustomValue(t.isAllowCustomValue());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean isAllowCustomValue() {
        return target.isAllowCustomValue();
      }

      public void setAllowCustomValue(Boolean allowCustomValue) {
        changeAndFire("allowCustomValue", allowCustomValue);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<StringSelectorOption> options) {
        List<StringSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ConditionalComboBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "allowCustomValue": return isAllowCustomValue();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("ConditionalComboBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "allowCustomValue": target.setAllowCustomValue((Boolean) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<StringSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (ConditionalComboBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ConditionalComboBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ConditionalComboBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy((ConditionalComboBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ConditionalComboBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy extends TimerSettingsFieldDefinition implements BindableProxy {
      private BindableProxyAgent<TimerSettingsFieldDefinition> agent;
      private TimerSettingsFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy() {
        this(new TimerSettingsFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy(TimerSettingsFieldDefinition targetVal) {
        agent = new BindableProxyAgent<TimerSettingsFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(TimerSettingsFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TimerSettingsFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TimerSettingsFieldDefinition unwrap() {
        return target;
      }

      public TimerSettingsFieldDefinition deepUnwrap() {
        final TimerSettingsFieldDefinition clone = new TimerSettingsFieldDefinition();
        final TimerSettingsFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public TimerSettingsFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("TimerSettingsFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (TimerSettingsFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TimerSettingsFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(TimerSettingsFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy((TimerSettingsFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_TimerSettingsFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("processVariables", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData clone = new org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData();
        final org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData t = unwrap();
        if (t.getProcessVariables() instanceof BindableProxy) {
          clone.setProcessVariables((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables) ((BindableProxy) getProcessVariables()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getProcessVariables())) {
          clone.setProcessVariables((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getProcessVariables())).deepUnwrap());
        } else {
          clone.setProcessVariables(t.getProcessVariables());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables getProcessVariables() {
        return target.getProcessVariables();
      }

      public void setProcessVariables(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables processVariables) {
        if (agent.binders.containsKey("processVariables")) {
          processVariables = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables) agent.binders.get("processVariables").setModel(processVariables, StateSync.FROM_MODEL, true);
        }
        changeAndFire("processVariables", processVariables);
      }

      public Object get(String property) {
        switch (property) {
          case "processVariables": return getProcessVariables();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessData", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "processVariables": target.setProcessVariables((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessData", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessDataProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy extends InterruptingTimerEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<InterruptingTimerEventExecutionSet> agent;
      private InterruptingTimerEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy() {
        this(new InterruptingTimerEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy(InterruptingTimerEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<InterruptingTimerEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("timerSettings", new PropertyType(TimerSettings.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(InterruptingTimerEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InterruptingTimerEventExecutionSet unwrap() {
        return target;
      }

      public InterruptingTimerEventExecutionSet deepUnwrap() {
        final InterruptingTimerEventExecutionSet clone = new InterruptingTimerEventExecutionSet();
        final InterruptingTimerEventExecutionSet t = unwrap();
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getTimerSettings() instanceof BindableProxy) {
          clone.setTimerSettings((TimerSettings) ((BindableProxy) getTimerSettings()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTimerSettings())) {
          clone.setTimerSettings((TimerSettings) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTimerSettings())).deepUnwrap());
        } else {
          clone.setTimerSettings(t.getTimerSettings());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public TimerSettings getTimerSettings() {
        return target.getTimerSettings();
      }

      public void setTimerSettings(TimerSettings timerSettings) {
        if (agent.binders.containsKey("timerSettings")) {
          timerSettings = (TimerSettings) agent.binders.get("timerSettings").setModel(timerSettings, StateSync.FROM_MODEL, true);
        }
        changeAndFire("timerSettings", timerSettings);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "isInterrupting": return getIsInterrupting();
          case "timerSettings": return getTimerSettings();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("InterruptingTimerEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "timerSettings": target.setTimerSettings((TimerSettings) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (InterruptingTimerEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InterruptingTimerEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InterruptingTimerEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy((InterruptingTimerEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_InterruptingTimerEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy extends org.kie.workbench.common.stunner.cm.definition.property.diagram.Version implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.Version> agent;
      private org.kie.workbench.common.stunner.cm.definition.property.diagram.Version target;
      public org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy() {
        this(new org.kie.workbench.common.stunner.cm.definition.property.diagram.Version());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.Version targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.Version>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.Version.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.Version unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.Version deepUnwrap() {
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.Version clone = new org.kie.workbench.common.stunner.cm.definition.property.diagram.Version();
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.Version t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Version", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.cm.definition.property.diagram.Version) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Version", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.Version.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy((org.kie.workbench.common.stunner.cm.definition.property.diagram.Version) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_VersionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy extends EndErrorEvent implements BindableProxy {
      private BindableProxyAgent<EndErrorEvent> agent;
      private EndErrorEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy() {
        this(new EndErrorEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy(EndErrorEvent targetVal) {
        agent = new BindableProxyAgent<EndErrorEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(ErrorEventExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndErrorEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndErrorEvent unwrap() {
        return target;
      }

      public EndErrorEvent deepUnwrap() {
        final EndErrorEvent clone = new EndErrorEvent();
        final EndErrorEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ErrorEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ErrorEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public ErrorEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ErrorEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ErrorEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndErrorEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((ErrorEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndErrorEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndErrorEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndErrorEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy((EndErrorEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndErrorEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy extends EndNoneEvent implements BindableProxy {
      private BindableProxyAgent<EndNoneEvent> agent;
      private EndNoneEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy() {
        this(new EndNoneEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy(EndNoneEvent targetVal) {
        agent = new BindableProxyAgent<EndNoneEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndNoneEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndNoneEvent unwrap() {
        return target;
      }

      public EndNoneEvent deepUnwrap() {
        final EndNoneEvent clone = new EndNoneEvent();
        final EndNoneEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndNoneEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndNoneEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndNoneEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndNoneEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy((EndNoneEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndNoneEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy extends BaseCancellingEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<BaseCancellingEventExecutionSet> agent;
      private BaseCancellingEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy() {
        this(new BaseCancellingEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy(BaseCancellingEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<BaseCancellingEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(BaseCancellingEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BaseCancellingEventExecutionSet unwrap() {
        return target;
      }

      public BaseCancellingEventExecutionSet deepUnwrap() {
        final BaseCancellingEventExecutionSet clone = new BaseCancellingEventExecutionSet();
        final BaseCancellingEventExecutionSet t = unwrap();
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("BaseCancellingEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (BaseCancellingEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BaseCancellingEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BaseCancellingEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy((BaseCancellingEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseCancellingEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy extends InterruptingEscalationEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<InterruptingEscalationEventExecutionSet> agent;
      private InterruptingEscalationEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy() {
        this(new InterruptingEscalationEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy(InterruptingEscalationEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<InterruptingEscalationEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("escalationRef", new PropertyType(EscalationRef.class, true, false));
        p.put("this", new PropertyType(InterruptingEscalationEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InterruptingEscalationEventExecutionSet unwrap() {
        return target;
      }

      public InterruptingEscalationEventExecutionSet deepUnwrap() {
        final InterruptingEscalationEventExecutionSet clone = new InterruptingEscalationEventExecutionSet();
        final InterruptingEscalationEventExecutionSet t = unwrap();
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getEscalationRef() instanceof BindableProxy) {
          clone.setEscalationRef((EscalationRef) ((BindableProxy) getEscalationRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getEscalationRef())) {
          clone.setEscalationRef((EscalationRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getEscalationRef())).deepUnwrap());
        } else {
          clone.setEscalationRef(t.getEscalationRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public EscalationRef getEscalationRef() {
        return target.getEscalationRef();
      }

      public void setEscalationRef(EscalationRef escalationRef) {
        if (agent.binders.containsKey("escalationRef")) {
          escalationRef = (EscalationRef) agent.binders.get("escalationRef").setModel(escalationRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("escalationRef", escalationRef);
      }

      public Object get(String property) {
        switch (property) {
          case "isInterrupting": return getIsInterrupting();
          case "slaDueDate": return getSlaDueDate();
          case "escalationRef": return getEscalationRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("InterruptingEscalationEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "escalationRef": target.setEscalationRef((EscalationRef) value);
          break;
          case "this": target = (InterruptingEscalationEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InterruptingEscalationEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InterruptingEscalationEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy((InterruptingEscalationEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_InterruptingEscalationEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy extends OutputClause implements BindableProxy {
      private BindableProxyAgent<OutputClause> agent;
      private OutputClause target;
      public org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy() {
        this(new OutputClause());
      }

      public org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy(OutputClause targetVal) {
        agent = new BindableProxyAgent<OutputClause>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("outputValues", new PropertyType(OutputClauseUnaryTests.class, true, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("defaultOutputEntry", new PropertyType(OutputClauseLiteralExpression.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(OutputClause.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public OutputClause unwrap() {
        return target;
      }

      public OutputClause deepUnwrap() {
        final OutputClause clone = new OutputClause();
        final OutputClause t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getOutputValues() instanceof BindableProxy) {
          clone.setOutputValues((OutputClauseUnaryTests) ((BindableProxy) getOutputValues()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOutputValues())) {
          clone.setOutputValues((OutputClauseUnaryTests) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOutputValues())).deepUnwrap());
        } else {
          clone.setOutputValues(t.getOutputValues());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getDefaultOutputEntry() instanceof BindableProxy) {
          clone.setDefaultOutputEntry((OutputClauseLiteralExpression) ((BindableProxy) getDefaultOutputEntry()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDefaultOutputEntry())) {
          clone.setDefaultOutputEntry((OutputClauseLiteralExpression) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDefaultOutputEntry())).deepUnwrap());
        } else {
          clone.setDefaultOutputEntry(t.getDefaultOutputEntry());
        }
        clone.setName(t.getName());
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public OutputClauseUnaryTests getOutputValues() {
        return target.getOutputValues();
      }

      public void setOutputValues(OutputClauseUnaryTests outputValues) {
        if (agent.binders.containsKey("outputValues")) {
          outputValues = (OutputClauseUnaryTests) agent.binders.get("outputValues").setModel(outputValues, StateSync.FROM_MODEL, true);
        }
        changeAndFire("outputValues", outputValues);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public OutputClauseLiteralExpression getDefaultOutputEntry() {
        return target.getDefaultOutputEntry();
      }

      public void setDefaultOutputEntry(OutputClauseLiteralExpression defaultOutputEntry) {
        if (agent.binders.containsKey("defaultOutputEntry")) {
          defaultOutputEntry = (OutputClauseLiteralExpression) agent.binders.get("defaultOutputEntry").setModel(defaultOutputEntry, StateSync.FROM_MODEL, true);
        }
        changeAndFire("defaultOutputEntry", defaultOutputEntry);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "outputValues": return getOutputValues();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "defaultOutputEntry": return getDefaultOutputEntry();
          case "nsContext": return getNsContext();
          case "hasTypeRefs": return getHasTypeRefs();
          case "name": return getName();
          case "id": return getId();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("OutputClause", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "outputValues": target.setOutputValues((OutputClauseUnaryTests) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "defaultOutputEntry": target.setDefaultOutputEntry((OutputClauseLiteralExpression) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (OutputClause) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("OutputClause", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(OutputClause.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy((OutputClause) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_OutputClauseProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy extends IntermediateSignalEventCatching implements BindableProxy {
      private BindableProxyAgent<IntermediateSignalEventCatching> agent;
      private IntermediateSignalEventCatching target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy() {
        this(new IntermediateSignalEventCatching());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy(IntermediateSignalEventCatching targetVal) {
        agent = new BindableProxyAgent<IntermediateSignalEventCatching>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CancellingSignalEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateSignalEventCatching.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateSignalEventCatching unwrap() {
        return target;
      }

      public IntermediateSignalEventCatching deepUnwrap() {
        final IntermediateSignalEventCatching clone = new IntermediateSignalEventCatching();
        final IntermediateSignalEventCatching t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CancellingSignalEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CancellingSignalEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CancellingSignalEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CancellingSignalEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CancellingSignalEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateSignalEventCatching", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CancellingSignalEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateSignalEventCatching) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateSignalEventCatching", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateSignalEventCatching.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy((IntermediateSignalEventCatching) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateSignalEventCatchingProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy extends BaseStartEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<BaseStartEventExecutionSet> agent;
      private BaseStartEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy() {
        this(new BaseStartEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy(BaseStartEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<BaseStartEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(BaseStartEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BaseStartEventExecutionSet unwrap() {
        return target;
      }

      public BaseStartEventExecutionSet deepUnwrap() {
        final BaseStartEventExecutionSet clone = new BaseStartEventExecutionSet();
        final BaseStartEventExecutionSet t = unwrap();
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "isInterrupting": return getIsInterrupting();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("BaseStartEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (BaseStartEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BaseStartEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BaseStartEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy((BaseStartEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_BaseStartEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy extends Name implements BindableProxy {
      private BindableProxyAgent<Name> agent;
      private Name target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy() {
        this(new Name());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy(Name targetVal) {
        agent = new BindableProxyAgent<Name>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Name.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Name unwrap() {
        return target;
      }

      public Name deepUnwrap() {
        final Name clone = new Name();
        final Name t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Name", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Name) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Name", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Name.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy((Name) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_NameProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy extends ReassignmentValue implements BindableProxy {
      private BindableProxyAgent<ReassignmentValue> agent;
      private ReassignmentValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy() {
        this(new ReassignmentValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy(ReassignmentValue targetVal) {
        agent = new BindableProxyAgent<ReassignmentValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("duration", new PropertyType(String.class, false, false));
        p.put("groups", new PropertyType(List.class, false, true));
        p.put("type", new PropertyType(String.class, false, false));
        p.put("users", new PropertyType(List.class, false, true));
        p.put("this", new PropertyType(ReassignmentValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReassignmentValue unwrap() {
        return target;
      }

      public ReassignmentValue deepUnwrap() {
        final ReassignmentValue clone = new ReassignmentValue();
        final ReassignmentValue t = unwrap();
        clone.setDuration(t.getDuration());
        if (t.getGroups() != null) {
          final List groupsClone = new ArrayList();
          for (Object groupsElem : t.getGroups()) {
            if (groupsElem instanceof BindableProxy) {
              groupsClone.add(((BindableProxy) groupsElem).deepUnwrap());
            } else {
              groupsClone.add(groupsElem);
            }
          }
          clone.setGroups(groupsClone);
        }
        clone.setType(t.getType());
        if (t.getUsers() != null) {
          final List usersClone = new ArrayList();
          for (Object usersElem : t.getUsers()) {
            if (usersElem instanceof BindableProxy) {
              usersClone.add(((BindableProxy) usersElem).deepUnwrap());
            } else {
              usersClone.add(usersElem);
            }
          }
          clone.setUsers(usersClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getDuration() {
        return target.getDuration();
      }

      public void setDuration(String duration) {
        changeAndFire("duration", duration);
      }

      public List getGroups() {
        return target.getGroups();
      }

      public void setGroups(List<String> groups) {
        List<String> oldValue = target.getGroups();
        groups = agent.ensureBoundListIsProxied("groups", groups);
        target.setGroups(groups);
        agent.updateWidgetsAndFireEvent(true, "groups", oldValue, groups);
      }

      public String getType() {
        return target.getType();
      }

      public void setType(String type) {
        changeAndFire("type", type);
      }

      public List getUsers() {
        return target.getUsers();
      }

      public void setUsers(List<String> users) {
        List<String> oldValue = target.getUsers();
        users = agent.ensureBoundListIsProxied("users", users);
        target.setUsers(users);
        agent.updateWidgetsAndFireEvent(true, "users", oldValue, users);
      }

      public Object get(String property) {
        switch (property) {
          case "duration": return getDuration();
          case "groups": return getGroups();
          case "type": return getType();
          case "users": return getUsers();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReassignmentValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "duration": target.setDuration((String) value);
          break;
          case "groups": target.setGroups((List<String>) value);
          break;
          case "type": target.setType((String) value);
          break;
          case "users": target.setUsers((List<String>) value);
          break;
          case "this": target = (ReassignmentValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReassignmentValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public String toCDATAFormat() {
        final String returnValue = target.toCDATAFormat();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ReassignmentValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy((ReassignmentValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentValueProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy extends AdHoc implements BindableProxy {
      private BindableProxyAgent<AdHoc> agent;
      private AdHoc target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy() {
        this(new AdHoc());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy(AdHoc targetVal) {
        agent = new BindableProxyAgent<AdHoc>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(AdHoc.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AdHoc unwrap() {
        return target;
      }

      public AdHoc deepUnwrap() {
        final AdHoc clone = new AdHoc();
        final AdHoc t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHoc", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (AdHoc) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHoc", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AdHoc.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy((AdHoc) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_AdHocProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy extends IntegerMultipleSelectorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<IntegerMultipleSelectorFieldDefinition> agent;
      private IntegerMultipleSelectorFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy() {
        this(new IntegerMultipleSelectorFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy(IntegerMultipleSelectorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<IntegerMultipleSelectorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDropdownElements", new PropertyType(Integer.class, false, false));
        p.put("listOfValues", new PropertyType(List.class, false, true));
        p.put("maxElementsOnTitle", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("allowFilter", new PropertyType(Boolean.class, false, false));
        p.put("allowClearSelection", new PropertyType(Boolean.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(IntegerMultipleSelectorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerMultipleSelectorFieldDefinition unwrap() {
        return target;
      }

      public IntegerMultipleSelectorFieldDefinition deepUnwrap() {
        final IntegerMultipleSelectorFieldDefinition clone = new IntegerMultipleSelectorFieldDefinition();
        final IntegerMultipleSelectorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDropdownElements(t.getMaxDropdownElements());
        if (t.getListOfValues() != null) {
          final List listOfValuesClone = new ArrayList();
          for (Object listOfValuesElem : t.getListOfValues()) {
            if (listOfValuesElem instanceof BindableProxy) {
              listOfValuesClone.add(((BindableProxy) listOfValuesElem).deepUnwrap());
            } else {
              listOfValuesClone.add(listOfValuesElem);
            }
          }
          clone.setListOfValues(listOfValuesClone);
        }
        clone.setMaxElementsOnTitle(t.getMaxElementsOnTitle());
        clone.setName(t.getName());
        clone.setAllowFilter(t.getAllowFilter());
        clone.setAllowClearSelection(t.getAllowClearSelection());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDropdownElements() {
        return target.getMaxDropdownElements();
      }

      public void setMaxDropdownElements(Integer maxDropdownElements) {
        changeAndFire("maxDropdownElements", maxDropdownElements);
      }

      public List getListOfValues() {
        return target.getListOfValues();
      }

      public void setListOfValues(List<Long> listOfValues) {
        List<Long> oldValue = target.getListOfValues();
        listOfValues = agent.ensureBoundListIsProxied("listOfValues", listOfValues);
        target.setListOfValues(listOfValues);
        agent.updateWidgetsAndFireEvent(true, "listOfValues", oldValue, listOfValues);
      }

      public Integer getMaxElementsOnTitle() {
        return target.getMaxElementsOnTitle();
      }

      public void setMaxElementsOnTitle(Integer maxElementsOnTitle) {
        changeAndFire("maxElementsOnTitle", maxElementsOnTitle);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Boolean getAllowFilter() {
        return target.getAllowFilter();
      }

      public void setAllowFilter(Boolean allowFilter) {
        changeAndFire("allowFilter", allowFilter);
      }

      public Boolean getAllowClearSelection() {
        return target.getAllowClearSelection();
      }

      public void setAllowClearSelection(Boolean allowClearSelection) {
        changeAndFire("allowClearSelection", allowClearSelection);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDropdownElements": return getMaxDropdownElements();
          case "listOfValues": return getListOfValues();
          case "maxElementsOnTitle": return getMaxElementsOnTitle();
          case "name": return getName();
          case "allowFilter": return getAllowFilter();
          case "allowClearSelection": return getAllowClearSelection();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerMultipleSelectorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDropdownElements": target.setMaxDropdownElements((Integer) value);
          break;
          case "listOfValues": target.setListOfValues((List<Long>) value);
          break;
          case "maxElementsOnTitle": target.setMaxElementsOnTitle((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "allowFilter": target.setAllowFilter((Boolean) value);
          break;
          case "allowClearSelection": target.setAllowClearSelection((Boolean) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (IntegerMultipleSelectorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerMultipleSelectorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerMultipleSelectorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy((IntegerMultipleSelectorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_IntegerMultipleSelectorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy extends Groupid implements BindableProxy {
      private BindableProxyAgent<Groupid> agent;
      private Groupid target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy() {
        this(new Groupid());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy(Groupid targetVal) {
        agent = new BindableProxyAgent<Groupid>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Groupid.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Groupid unwrap() {
        return target;
      }

      public Groupid deepUnwrap() {
        final Groupid clone = new Groupid();
        final Groupid t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Groupid", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Groupid) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Groupid", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Groupid.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy((Groupid) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_assignee_GroupidProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy extends DirectionalAssociation implements BindableProxy {
      private BindableProxyAgent<DirectionalAssociation> agent;
      private DirectionalAssociation target;
      public org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy() {
        this(new DirectionalAssociation());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy(DirectionalAssociation targetVal) {
        agent = new BindableProxyAgent<DirectionalAssociation>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(DirectionalAssociation.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DirectionalAssociation unwrap() {
        return target;
      }

      public DirectionalAssociation deepUnwrap() {
        final DirectionalAssociation clone = new DirectionalAssociation();
        final DirectionalAssociation t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("DirectionalAssociation", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "this": target = (DirectionalAssociation) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DirectionalAssociation", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DirectionalAssociation.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy((DirectionalAssociation) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_DirectionalAssociationProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy extends IntermediateErrorEventCatching implements BindableProxy {
      private BindableProxyAgent<IntermediateErrorEventCatching> agent;
      private IntermediateErrorEventCatching target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy() {
        this(new IntermediateErrorEventCatching());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy(IntermediateErrorEventCatching targetVal) {
        agent = new BindableProxyAgent<IntermediateErrorEventCatching>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CancellingErrorEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateErrorEventCatching.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateErrorEventCatching unwrap() {
        return target;
      }

      public IntermediateErrorEventCatching deepUnwrap() {
        final IntermediateErrorEventCatching clone = new IntermediateErrorEventCatching();
        final IntermediateErrorEventCatching t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CancellingErrorEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CancellingErrorEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CancellingErrorEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CancellingErrorEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CancellingErrorEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateErrorEventCatching", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CancellingErrorEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateErrorEventCatching) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateErrorEventCatching", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateErrorEventCatching.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy((IntermediateErrorEventCatching) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateErrorEventCatchingProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy extends TextAnnotation implements BindableProxy {
      private BindableProxyAgent<TextAnnotation> agent;
      private TextAnnotation target;
      public org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy() {
        this(new TextAnnotation());
      }

      public org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy(TextAnnotation targetVal) {
        agent = new BindableProxyAgent<TextAnnotation>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("allowOnlyVisualChange", new PropertyType(Boolean.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("textFormat", new PropertyType(TextFormat.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("backgroundSet", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(GeneralRectangleDimensionsSet.class, true, false));
        p.put("text", new PropertyType(Text.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(TextAnnotation.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TextAnnotation unwrap() {
        return target;
      }

      public TextAnnotation deepUnwrap() {
        final TextAnnotation clone = new TextAnnotation();
        final TextAnnotation t = unwrap();
        clone.setParent(t.getParent());
        clone.setExtensionElements(t.getExtensionElements());
        clone.setAllowOnlyVisualChange(t.isAllowOnlyVisualChange());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getTextFormat() instanceof BindableProxy) {
          clone.setTextFormat((TextFormat) ((BindableProxy) getTextFormat()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTextFormat())) {
          clone.setTextFormat((TextFormat) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTextFormat())).deepUnwrap());
        } else {
          clone.setTextFormat(t.getTextFormat());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getText() instanceof BindableProxy) {
          clone.setText((Text) ((BindableProxy) getText()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getText())) {
          clone.setText((Text) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getText())).deepUnwrap());
        } else {
          clone.setText(t.getText());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public boolean isAllowOnlyVisualChange() {
        return target.isAllowOnlyVisualChange();
      }

      public void setAllowOnlyVisualChange(boolean allowOnlyVisualChange) {
        changeAndFire("allowOnlyVisualChange", allowOnlyVisualChange);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public TextFormat getTextFormat() {
        return target.getTextFormat();
      }

      public void setTextFormat(TextFormat textFormat) {
        if (agent.binders.containsKey("textFormat")) {
          textFormat = (TextFormat) agent.binders.get("textFormat").setModel(textFormat, StateSync.FROM_MODEL, true);
        }
        changeAndFire("textFormat", textFormat);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(org.kie.workbench.common.dmn.api.property.background.BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(org.kie.workbench.common.dmn.api.property.font.FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (org.kie.workbench.common.dmn.api.property.font.FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public GeneralRectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(GeneralRectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (GeneralRectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public Text getText() {
        return target.getText();
      }

      public void setText(Text text) {
        if (agent.binders.containsKey("text")) {
          text = (Text) agent.binders.get("text").setModel(text, StateSync.FROM_MODEL, true);
        }
        changeAndFire("text", text);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "stunnerLabels": return getStunnerLabels();
          case "allowOnlyVisualChange": return isAllowOnlyVisualChange();
          case "description": return getDescription();
          case "textFormat": return getTextFormat();
          case "nsContext": return getNsContext();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "text": return getText();
          case "id": return getId();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("TextAnnotation", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "allowOnlyVisualChange": target.setAllowOnlyVisualChange((Boolean) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "textFormat": target.setTextFormat((TextFormat) value);
          break;
          case "backgroundSet": target.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((GeneralRectangleDimensionsSet) value);
          break;
          case "text": target.setText((Text) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (TextAnnotation) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TextAnnotation", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public ReadOnly getReadOnly(String a0) {
        final ReadOnly returnValue = target.getReadOnly(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(TextAnnotation.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy((TextAnnotation) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_TextAnnotationProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy extends TaskType implements BindableProxy {
      private BindableProxyAgent<TaskType> agent;
      private TaskType target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy() {
        this(new TaskType());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy(TaskType targetVal) {
        agent = new BindableProxyAgent<TaskType>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("allowedValues", new PropertyType(Iterable.class, false, false));
        p.put("rawType", new PropertyType(String.class, false, false));
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(TaskTypes.class, false, false));
        p.put("this", new PropertyType(TaskType.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TaskType unwrap() {
        return target;
      }

      public TaskType deepUnwrap() {
        final TaskType clone = new TaskType();
        final TaskType t = unwrap();
        clone.setRawType(t.getRawType());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Iterable getAllowedValues() {
        return target.getAllowedValues();
      }

      public String getRawType() {
        return target.getRawType();
      }

      public void setRawType(String rawType) {
        changeAndFire("rawType", rawType);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public TaskTypes getValue() {
        return target.getValue();
      }

      public void setValue(TaskTypes value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "allowedValues": return getAllowedValues();
          case "rawType": return getRawType();
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("TaskType", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "rawType": target.setRawType((String) value);
          break;
          case "value": target.setValue((TaskTypes) value);
          break;
          case "this": target = (TaskType) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TaskType", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TaskType.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy((TaskType) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskTypeProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables clone = new org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables();
        final org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessVariables", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessVariables", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy((org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_variables_ProcessVariablesProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy extends org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription> agent;
      private org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription target;
      public org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy() {
        this(new org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription deepUnwrap() {
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription clone = new org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription();
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessInstanceDescription", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessInstanceDescription", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy((org.kie.workbench.common.stunner.cm.definition.property.diagram.ProcessInstanceDescription) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_ProcessInstanceDescriptionProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy extends StringMultipleInputFieldDefinition implements BindableProxy {
      private BindableProxyAgent<StringMultipleInputFieldDefinition> agent;
      private StringMultipleInputFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy() {
        this(new StringMultipleInputFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy(StringMultipleInputFieldDefinition targetVal) {
        agent = new BindableProxyAgent<StringMultipleInputFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("pageSize", new PropertyType(Integer.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(StringMultipleInputFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StringMultipleInputFieldDefinition unwrap() {
        return target;
      }

      public StringMultipleInputFieldDefinition deepUnwrap() {
        final StringMultipleInputFieldDefinition clone = new StringMultipleInputFieldDefinition();
        final StringMultipleInputFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setPageSize(t.getPageSize());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Integer getPageSize() {
        return target.getPageSize();
      }

      public void setPageSize(Integer pageSize) {
        changeAndFire("pageSize", pageSize);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "pageSize": return getPageSize();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("StringMultipleInputFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "pageSize": target.setPageSize((Integer) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (StringMultipleInputFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StringMultipleInputFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(StringMultipleInputFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy((StringMultipleInputFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_input_impl_StringMultipleInputFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy extends SLADueDate implements BindableProxy {
      private BindableProxyAgent<SLADueDate> agent;
      private SLADueDate target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy() {
        this(new SLADueDate());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy(SLADueDate targetVal) {
        agent = new BindableProxyAgent<SLADueDate>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(SLADueDate.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SLADueDate unwrap() {
        return target;
      }

      public SLADueDate deepUnwrap() {
        final SLADueDate clone = new SLADueDate();
        final SLADueDate t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("SLADueDate", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (SLADueDate) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SLADueDate", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SLADueDate.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy((SLADueDate) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_SLADueDateProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy extends IntermediateCompensationEvent implements BindableProxy {
      private BindableProxyAgent<IntermediateCompensationEvent> agent;
      private IntermediateCompensationEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy() {
        this(new IntermediateCompensationEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy(IntermediateCompensationEvent targetVal) {
        agent = new BindableProxyAgent<IntermediateCompensationEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(BaseCancellingEventExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateCompensationEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateCompensationEvent unwrap() {
        return target;
      }

      public IntermediateCompensationEvent deepUnwrap() {
        final IntermediateCompensationEvent clone = new IntermediateCompensationEvent();
        final IntermediateCompensationEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((BaseCancellingEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((BaseCancellingEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public BaseCancellingEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(BaseCancellingEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (BaseCancellingEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateCompensationEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((BaseCancellingEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateCompensationEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateCompensationEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateCompensationEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy((IntermediateCompensationEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateCompensationEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy extends Quantity implements BindableProxy {
      private BindableProxyAgent<Quantity> agent;
      private Quantity target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy() {
        this(new Quantity());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy(Quantity targetVal) {
        agent = new BindableProxyAgent<Quantity>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Quantity.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Quantity unwrap() {
        return target;
      }

      public Quantity deepUnwrap() {
        final Quantity clone = new Quantity();
        final Quantity t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Quantity", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Quantity) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Quantity", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Quantity.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy((Quantity) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_QuantityProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy extends ErrorEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<ErrorEventExecutionSet> agent;
      private ErrorEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy() {
        this(new ErrorEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy(ErrorEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<ErrorEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("errorRef", new PropertyType(ErrorRef.class, true, false));
        p.put("this", new PropertyType(ErrorEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ErrorEventExecutionSet unwrap() {
        return target;
      }

      public ErrorEventExecutionSet deepUnwrap() {
        final ErrorEventExecutionSet clone = new ErrorEventExecutionSet();
        final ErrorEventExecutionSet t = unwrap();
        if (t.getErrorRef() instanceof BindableProxy) {
          clone.setErrorRef((ErrorRef) ((BindableProxy) getErrorRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getErrorRef())) {
          clone.setErrorRef((ErrorRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getErrorRef())).deepUnwrap());
        } else {
          clone.setErrorRef(t.getErrorRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ErrorRef getErrorRef() {
        return target.getErrorRef();
      }

      public void setErrorRef(ErrorRef errorRef) {
        if (agent.binders.containsKey("errorRef")) {
          errorRef = (ErrorRef) agent.binders.get("errorRef").setModel(errorRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("errorRef", errorRef);
      }

      public Object get(String property) {
        switch (property) {
          case "errorRef": return getErrorRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("ErrorEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "errorRef": target.setErrorRef((ErrorRef) value);
          break;
          case "this": target = (ErrorEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ErrorEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ErrorEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy((ErrorEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_ErrorEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy extends CaseReusableSubprocess implements BindableProxy {
      private BindableProxyAgent<CaseReusableSubprocess> agent;
      private CaseReusableSubprocess target;
      public org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy() {
        this(new CaseReusableSubprocess());
      }

      public org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy(CaseReusableSubprocess targetVal) {
        agent = new BindableProxyAgent<CaseReusableSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(CaseReusableSubprocessTaskExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(CaseReusableSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseReusableSubprocess unwrap() {
        return target;
      }

      public CaseReusableSubprocess deepUnwrap() {
        final CaseReusableSubprocess clone = new CaseReusableSubprocess();
        final CaseReusableSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((CaseReusableSubprocessTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((CaseReusableSubprocessTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public CaseReusableSubprocessTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(CaseReusableSubprocessTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (CaseReusableSubprocessTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseReusableSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((CaseReusableSubprocessTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (CaseReusableSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseReusableSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(CaseReusableSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy((CaseReusableSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_CaseReusableSubprocessProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy extends BPMNGeneralSet implements BindableProxy {
      private BindableProxyAgent<BPMNGeneralSet> agent;
      private BPMNGeneralSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy() {
        this(new BPMNGeneralSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy(BPMNGeneralSet targetVal) {
        agent = new BindableProxyAgent<BPMNGeneralSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("documentation", new PropertyType(Documentation.class, true, false));
        p.put("name", new PropertyType(Name.class, true, false));
        p.put("this", new PropertyType(BPMNGeneralSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BPMNGeneralSet unwrap() {
        return target;
      }

      public BPMNGeneralSet deepUnwrap() {
        final BPMNGeneralSet clone = new BPMNGeneralSet();
        final BPMNGeneralSet t = unwrap();
        if (t.getDocumentation() instanceof BindableProxy) {
          clone.setDocumentation((Documentation) ((BindableProxy) getDocumentation()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDocumentation())) {
          clone.setDocumentation((Documentation) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDocumentation())).deepUnwrap());
        } else {
          clone.setDocumentation(t.getDocumentation());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Documentation getDocumentation() {
        return target.getDocumentation();
      }

      public void setDocumentation(Documentation documentation) {
        if (agent.binders.containsKey("documentation")) {
          documentation = (Documentation) agent.binders.get("documentation").setModel(documentation, StateSync.FROM_MODEL, true);
        }
        changeAndFire("documentation", documentation);
      }

      public Name getName() {
        return target.getName();
      }

      public void setName(Name name) {
        if (agent.binders.containsKey("name")) {
          name = (Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public Object get(String property) {
        switch (property) {
          case "documentation": return getDocumentation();
          case "name": return getName();
          case "this": return target;
          default: throw new NonExistingPropertyException("BPMNGeneralSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "documentation": target.setDocumentation((Documentation) value);
          break;
          case "name": target.setName((Name) value);
          break;
          case "this": target = (BPMNGeneralSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BPMNGeneralSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BPMNGeneralSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy((BPMNGeneralSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_BPMNGeneralSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy extends OnExitAction implements BindableProxy {
      private BindableProxyAgent<OnExitAction> agent;
      private OnExitAction target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy() {
        this(new OnExitAction());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy(OnExitAction targetVal) {
        agent = new BindableProxyAgent<OnExitAction>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ScriptTypeListValue.class, true, false));
        p.put("this", new PropertyType(OnExitAction.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public OnExitAction unwrap() {
        return target;
      }

      public OnExitAction deepUnwrap() {
        final OnExitAction clone = new OnExitAction();
        final OnExitAction t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ScriptTypeListValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ScriptTypeListValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ScriptTypeListValue getValue() {
        return target.getValue();
      }

      public void setValue(ScriptTypeListValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ScriptTypeListValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("OnExitAction", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ScriptTypeListValue) value);
          break;
          case "this": target = (OnExitAction) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("OnExitAction", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(OnExitAction.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy((OnExitAction) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_OnExitActionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy extends org.kie.workbench.common.dmn.api.property.font.FontFamily implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.dmn.api.property.font.FontFamily> agent;
      private org.kie.workbench.common.dmn.api.property.font.FontFamily target;
      public org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy() {
        this(new org.kie.workbench.common.dmn.api.property.font.FontFamily());
      }

      public org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy(org.kie.workbench.common.dmn.api.property.font.FontFamily targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.dmn.api.property.font.FontFamily>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontFamily.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.dmn.api.property.font.FontFamily unwrap() {
        return target;
      }

      public org.kie.workbench.common.dmn.api.property.font.FontFamily deepUnwrap() {
        final org.kie.workbench.common.dmn.api.property.font.FontFamily clone = new org.kie.workbench.common.dmn.api.property.font.FontFamily();
        final org.kie.workbench.common.dmn.api.property.font.FontFamily t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontFamily", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.dmn.api.property.font.FontFamily) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontFamily", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.dmn.api.property.font.FontFamily.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy((org.kie.workbench.common.dmn.api.property.font.FontFamily) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_font_FontFamilyProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy(org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width clone = new org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width();
        final org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Width", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Width", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy((org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_WidthProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy extends MultipleInstanceDataOutput implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceDataOutput> agent;
      private MultipleInstanceDataOutput target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy() {
        this(new MultipleInstanceDataOutput());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy(MultipleInstanceDataOutput targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceDataOutput>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceDataOutput unwrap() {
        return target;
      }

      public MultipleInstanceDataOutput deepUnwrap() {
        final MultipleInstanceDataOutput clone = new MultipleInstanceDataOutput();
        final MultipleInstanceDataOutput t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceDataOutput", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (MultipleInstanceDataOutput) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceDataOutput", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceDataOutput.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy((MultipleInstanceDataOutput) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataOutputProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy extends NotificationTypeListValue implements BindableProxy {
      private BindableProxyAgent<NotificationTypeListValue> agent;
      private NotificationTypeListValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy() {
        this(new NotificationTypeListValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy(NotificationTypeListValue targetVal) {
        agent = new BindableProxyAgent<NotificationTypeListValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("values", new PropertyType(List.class, false, true));
        p.put("empty", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(NotificationTypeListValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NotificationTypeListValue unwrap() {
        return target;
      }

      public NotificationTypeListValue deepUnwrap() {
        final NotificationTypeListValue clone = new NotificationTypeListValue();
        final NotificationTypeListValue t = unwrap();
        if (t.getValues() != null) {
          final List valuesClone = new ArrayList();
          for (Object valuesElem : t.getValues()) {
            if (valuesElem instanceof BindableProxy) {
              valuesClone.add(((BindableProxy) valuesElem).deepUnwrap());
            } else {
              valuesClone.add(valuesElem);
            }
          }
          clone.setValues(valuesClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public List getValues() {
        return target.getValues();
      }

      public void setValues(List<NotificationValue> values) {
        List<NotificationValue> oldValue = target.getValues();
        values = agent.ensureBoundListIsProxied("values", values);
        target.setValues(values);
        agent.updateWidgetsAndFireEvent(true, "values", oldValue, values);
      }

      public boolean isEmpty() {
        return target.isEmpty();
      }

      public Object get(String property) {
        switch (property) {
          case "values": return getValues();
          case "empty": return isEmpty();
          case "this": return target;
          default: throw new NonExistingPropertyException("NotificationTypeListValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "values": target.setValues((List<NotificationValue>) value);
          break;
          case "this": target = (NotificationTypeListValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NotificationTypeListValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public NotificationTypeListValue addValue(NotificationValue a0) {
        final NotificationTypeListValue returnValue = target.addValue(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(NotificationTypeListValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy((NotificationTypeListValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationTypeListValueProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy extends EnumSelectorOption implements BindableProxy {
      private BindableProxyAgent<EnumSelectorOption> agent;
      private EnumSelectorOption target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy() {
        this(new EnumSelectorOption());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy(EnumSelectorOption targetVal) {
        agent = new BindableProxyAgent<EnumSelectorOption>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("text", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(Enum.class, false, false));
        p.put("this", new PropertyType(EnumSelectorOption.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EnumSelectorOption unwrap() {
        return target;
      }

      public EnumSelectorOption deepUnwrap() {
        final EnumSelectorOption clone = new EnumSelectorOption();
        final EnumSelectorOption t = unwrap();
        clone.setText(t.getText());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public Enum getValue() {
        return target.getValue();
      }

      public void setValue(Enum value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "text": return getText();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("EnumSelectorOption", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "text": target.setText((String) value);
          break;
          case "value": target.setValue((Enum) value);
          break;
          case "this": target = (EnumSelectorOption) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EnumSelectorOption", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EnumSelectorOption.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy((EnumSelectorOption) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_EnumSelectorOptionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy extends InterruptingConditionalEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<InterruptingConditionalEventExecutionSet> agent;
      private InterruptingConditionalEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy() {
        this(new InterruptingConditionalEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy(InterruptingConditionalEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<InterruptingConditionalEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("conditionExpression", new PropertyType(ConditionExpression.class, true, false));
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(InterruptingConditionalEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InterruptingConditionalEventExecutionSet unwrap() {
        return target;
      }

      public InterruptingConditionalEventExecutionSet deepUnwrap() {
        final InterruptingConditionalEventExecutionSet clone = new InterruptingConditionalEventExecutionSet();
        final InterruptingConditionalEventExecutionSet t = unwrap();
        if (t.getConditionExpression() instanceof BindableProxy) {
          clone.setConditionExpression((ConditionExpression) ((BindableProxy) getConditionExpression()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getConditionExpression())) {
          clone.setConditionExpression((ConditionExpression) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getConditionExpression())).deepUnwrap());
        } else {
          clone.setConditionExpression(t.getConditionExpression());
        }
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ConditionExpression getConditionExpression() {
        return target.getConditionExpression();
      }

      public void setConditionExpression(ConditionExpression conditionExpression) {
        if (agent.binders.containsKey("conditionExpression")) {
          conditionExpression = (ConditionExpression) agent.binders.get("conditionExpression").setModel(conditionExpression, StateSync.FROM_MODEL, true);
        }
        changeAndFire("conditionExpression", conditionExpression);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "conditionExpression": return getConditionExpression();
          case "isInterrupting": return getIsInterrupting();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("InterruptingConditionalEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "conditionExpression": target.setConditionExpression((ConditionExpression) value);
          break;
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (InterruptingConditionalEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InterruptingConditionalEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InterruptingConditionalEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy((InterruptingConditionalEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_InterruptingConditionalEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy extends ConstraintTypeProperty implements BindableProxy {
      private BindableProxyAgent<ConstraintTypeProperty> agent;
      private ConstraintTypeProperty target;
      public org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy() {
        this(new ConstraintTypeProperty());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy(ConstraintTypeProperty targetVal) {
        agent = new BindableProxyAgent<ConstraintTypeProperty>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ConstraintTypeProperty.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ConstraintTypeProperty unwrap() {
        return target;
      }

      public ConstraintTypeProperty deepUnwrap() {
        final ConstraintTypeProperty clone = new ConstraintTypeProperty();
        final ConstraintTypeProperty t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ConstraintTypeProperty", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (ConstraintTypeProperty) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ConstraintTypeProperty", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ConstraintTypeProperty.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy((ConstraintTypeProperty) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_ConstraintTypePropertyProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy extends Documentation implements BindableProxy {
      private BindableProxyAgent<Documentation> agent;
      private Documentation target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy() {
        this(new Documentation());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy(Documentation targetVal) {
        agent = new BindableProxyAgent<Documentation>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Documentation.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Documentation unwrap() {
        return target;
      }

      public Documentation deepUnwrap() {
        final Documentation clone = new Documentation();
        final Documentation t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Documentation", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Documentation) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Documentation", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Documentation.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy((Documentation) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_general_DocumentationProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy extends WSDLImport implements BindableProxy {
      private BindableProxyAgent<WSDLImport> agent;
      private WSDLImport target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy() {
        this(new WSDLImport());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy(WSDLImport targetVal) {
        agent = new BindableProxyAgent<WSDLImport>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("namespace", new PropertyType(String.class, false, false));
        p.put("location", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(WSDLImport.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public WSDLImport unwrap() {
        return target;
      }

      public WSDLImport deepUnwrap() {
        final WSDLImport clone = new WSDLImport();
        final WSDLImport t = unwrap();
        clone.setNamespace(t.getNamespace());
        clone.setLocation(t.getLocation());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getNamespace() {
        return target.getNamespace();
      }

      public void setNamespace(String namespace) {
        changeAndFire("namespace", namespace);
      }

      public String getLocation() {
        return target.getLocation();
      }

      public void setLocation(String location) {
        changeAndFire("location", location);
      }

      public Object get(String property) {
        switch (property) {
          case "namespace": return getNamespace();
          case "location": return getLocation();
          case "this": return target;
          default: throw new NonExistingPropertyException("WSDLImport", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "namespace": target.setNamespace((String) value);
          break;
          case "location": target.setLocation((String) value);
          break;
          case "this": target = (WSDLImport) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("WSDLImport", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(WSDLImport.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy((WSDLImport) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_WSDLImportProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy extends TimerSettingsValue implements BindableProxy {
      private BindableProxyAgent<TimerSettingsValue> agent;
      private TimerSettingsValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy() {
        this(new TimerSettingsValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy(TimerSettingsValue targetVal) {
        agent = new BindableProxyAgent<TimerSettingsValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("timeCycleLanguage", new PropertyType(String.class, false, false));
        p.put("timeDate", new PropertyType(String.class, false, false));
        p.put("timeDuration", new PropertyType(String.class, false, false));
        p.put("timeCycle", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TimerSettingsValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TimerSettingsValue unwrap() {
        return target;
      }

      public TimerSettingsValue deepUnwrap() {
        final TimerSettingsValue clone = new TimerSettingsValue();
        final TimerSettingsValue t = unwrap();
        clone.setTimeCycleLanguage(t.getTimeCycleLanguage());
        clone.setTimeDate(t.getTimeDate());
        clone.setTimeDuration(t.getTimeDuration());
        clone.setTimeCycle(t.getTimeCycle());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getTimeCycleLanguage() {
        return target.getTimeCycleLanguage();
      }

      public void setTimeCycleLanguage(String timeCycleLanguage) {
        changeAndFire("timeCycleLanguage", timeCycleLanguage);
      }

      public String getTimeDate() {
        return target.getTimeDate();
      }

      public void setTimeDate(String timeDate) {
        changeAndFire("timeDate", timeDate);
      }

      public String getTimeDuration() {
        return target.getTimeDuration();
      }

      public void setTimeDuration(String timeDuration) {
        changeAndFire("timeDuration", timeDuration);
      }

      public String getTimeCycle() {
        return target.getTimeCycle();
      }

      public void setTimeCycle(String timeCycle) {
        changeAndFire("timeCycle", timeCycle);
      }

      public Object get(String property) {
        switch (property) {
          case "timeCycleLanguage": return getTimeCycleLanguage();
          case "timeDate": return getTimeDate();
          case "timeDuration": return getTimeDuration();
          case "timeCycle": return getTimeCycle();
          case "this": return target;
          default: throw new NonExistingPropertyException("TimerSettingsValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "timeCycleLanguage": target.setTimeCycleLanguage((String) value);
          break;
          case "timeDate": target.setTimeDate((String) value);
          break;
          case "timeDuration": target.setTimeDuration((String) value);
          break;
          case "timeCycle": target.setTimeCycle((String) value);
          break;
          case "this": target = (TimerSettingsValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TimerSettingsValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TimerSettingsValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy((TimerSettingsValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_TimerSettingsValueProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy extends CancellingConditionalEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CancellingConditionalEventExecutionSet> agent;
      private CancellingConditionalEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy() {
        this(new CancellingConditionalEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy(CancellingConditionalEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CancellingConditionalEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("conditionExpression", new PropertyType(ConditionExpression.class, true, false));
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(CancellingConditionalEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancellingConditionalEventExecutionSet unwrap() {
        return target;
      }

      public CancellingConditionalEventExecutionSet deepUnwrap() {
        final CancellingConditionalEventExecutionSet clone = new CancellingConditionalEventExecutionSet();
        final CancellingConditionalEventExecutionSet t = unwrap();
        if (t.getConditionExpression() instanceof BindableProxy) {
          clone.setConditionExpression((ConditionExpression) ((BindableProxy) getConditionExpression()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getConditionExpression())) {
          clone.setConditionExpression((ConditionExpression) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getConditionExpression())).deepUnwrap());
        } else {
          clone.setConditionExpression(t.getConditionExpression());
        }
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ConditionExpression getConditionExpression() {
        return target.getConditionExpression();
      }

      public void setConditionExpression(ConditionExpression conditionExpression) {
        if (agent.binders.containsKey("conditionExpression")) {
          conditionExpression = (ConditionExpression) agent.binders.get("conditionExpression").setModel(conditionExpression, StateSync.FROM_MODEL, true);
        }
        changeAndFire("conditionExpression", conditionExpression);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "conditionExpression": return getConditionExpression();
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancellingConditionalEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "conditionExpression": target.setConditionExpression((ConditionExpression) value);
          break;
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (CancellingConditionalEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancellingConditionalEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancellingConditionalEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy((CancellingConditionalEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_conditional_CancellingConditionalEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy extends DecimalSelectorOption implements BindableProxy {
      private BindableProxyAgent<DecimalSelectorOption> agent;
      private DecimalSelectorOption target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy() {
        this(new DecimalSelectorOption());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy(DecimalSelectorOption targetVal) {
        agent = new BindableProxyAgent<DecimalSelectorOption>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("text", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(DecimalSelectorOption.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecimalSelectorOption unwrap() {
        return target;
      }

      public DecimalSelectorOption deepUnwrap() {
        final DecimalSelectorOption clone = new DecimalSelectorOption();
        final DecimalSelectorOption t = unwrap();
        clone.setText(t.getText());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "text": return getText();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecimalSelectorOption", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "text": target.setText((String) value);
          break;
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (DecimalSelectorOption) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecimalSelectorOption", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DecimalSelectorOption.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy((DecimalSelectorOption) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DecimalSelectorOptionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_TextProxy extends Text implements BindableProxy {
      private BindableProxyAgent<Text> agent;
      private Text target;
      public org_kie_workbench_common_dmn_api_property_dmn_TextProxy() {
        this(new Text());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_TextProxy(Text targetVal) {
        agent = new BindableProxyAgent<Text>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Text.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Text unwrap() {
        return target;
      }

      public Text deepUnwrap() {
        final Text clone = new Text();
        final Text t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_TextProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_TextProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Text", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Text) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Text", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Text.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_TextProxy((Text) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_TextProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy extends CalledElement implements BindableProxy {
      private BindableProxyAgent<CalledElement> agent;
      private CalledElement target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy() {
        this(new CalledElement());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy(CalledElement targetVal) {
        agent = new BindableProxyAgent<CalledElement>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CalledElement.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CalledElement unwrap() {
        return target;
      }

      public CalledElement deepUnwrap() {
        final CalledElement clone = new CalledElement();
        final CalledElement t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CalledElement", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (CalledElement) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CalledElement", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CalledElement.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy((CalledElement) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_CalledElementProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy extends InterruptingErrorEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<InterruptingErrorEventExecutionSet> agent;
      private InterruptingErrorEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy() {
        this(new InterruptingErrorEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy(InterruptingErrorEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<InterruptingErrorEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isInterrupting", new PropertyType(IsInterrupting.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("errorRef", new PropertyType(ErrorRef.class, true, false));
        p.put("this", new PropertyType(InterruptingErrorEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InterruptingErrorEventExecutionSet unwrap() {
        return target;
      }

      public InterruptingErrorEventExecutionSet deepUnwrap() {
        final InterruptingErrorEventExecutionSet clone = new InterruptingErrorEventExecutionSet();
        final InterruptingErrorEventExecutionSet t = unwrap();
        if (t.getIsInterrupting() instanceof BindableProxy) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) getIsInterrupting()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsInterrupting())) {
          clone.setIsInterrupting((IsInterrupting) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsInterrupting())).deepUnwrap());
        } else {
          clone.setIsInterrupting(t.getIsInterrupting());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getErrorRef() instanceof BindableProxy) {
          clone.setErrorRef((ErrorRef) ((BindableProxy) getErrorRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getErrorRef())) {
          clone.setErrorRef((ErrorRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getErrorRef())).deepUnwrap());
        } else {
          clone.setErrorRef(t.getErrorRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsInterrupting getIsInterrupting() {
        return target.getIsInterrupting();
      }

      public void setIsInterrupting(IsInterrupting isInterrupting) {
        if (agent.binders.containsKey("isInterrupting")) {
          isInterrupting = (IsInterrupting) agent.binders.get("isInterrupting").setModel(isInterrupting, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isInterrupting", isInterrupting);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public ErrorRef getErrorRef() {
        return target.getErrorRef();
      }

      public void setErrorRef(ErrorRef errorRef) {
        if (agent.binders.containsKey("errorRef")) {
          errorRef = (ErrorRef) agent.binders.get("errorRef").setModel(errorRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("errorRef", errorRef);
      }

      public Object get(String property) {
        switch (property) {
          case "isInterrupting": return getIsInterrupting();
          case "slaDueDate": return getSlaDueDate();
          case "errorRef": return getErrorRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("InterruptingErrorEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isInterrupting": target.setIsInterrupting((IsInterrupting) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "errorRef": target.setErrorRef((ErrorRef) value);
          break;
          case "this": target = (InterruptingErrorEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InterruptingErrorEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(InterruptingErrorEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy((InterruptingErrorEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_InterruptingErrorEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy extends ExclusiveGateway implements BindableProxy {
      private BindableProxyAgent<ExclusiveGateway> agent;
      private ExclusiveGateway target;
      public org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy() {
        this(new ExclusiveGateway());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy(ExclusiveGateway targetVal) {
        agent = new BindableProxyAgent<ExclusiveGateway>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(GatewayExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(ExclusiveGateway.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ExclusiveGateway unwrap() {
        return target;
      }

      public ExclusiveGateway deepUnwrap() {
        final ExclusiveGateway clone = new ExclusiveGateway();
        final ExclusiveGateway t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((GatewayExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((GatewayExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public GatewayExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(GatewayExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (GatewayExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("ExclusiveGateway", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((GatewayExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (ExclusiveGateway) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ExclusiveGateway", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ExclusiveGateway.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy((ExclusiveGateway) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_ExclusiveGatewayProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy extends ServiceTask implements BindableProxy {
      private BindableProxyAgent<ServiceTask> agent;
      private ServiceTask target;
      public org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy() {
        this(new ServiceTask());
      }

      public org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy(ServiceTask targetVal) {
        agent = new BindableProxyAgent<ServiceTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("description", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("defaultHandler", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(ServiceTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(ServiceTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ServiceTask unwrap() {
        return target;
      }

      public ServiceTask deepUnwrap() {
        final ServiceTask clone = new ServiceTask();
        final ServiceTask t = unwrap();
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        clone.setDescription(t.getDescription());
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        clone.setDefaultHandler(t.getDefaultHandler());
        clone.setName(t.getName());
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ServiceTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ServiceTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        clone.setCategory(t.getCategory());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public String getDescription() {
        return target.getDescription();
      }

      public void setDescription(String description) {
        changeAndFire("description", description);
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public String getDefaultHandler() {
        return target.getDefaultHandler();
      }

      public void setDefaultHandler(String defaultHandler) {
        changeAndFire("defaultHandler", defaultHandler);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public ServiceTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ServiceTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ServiceTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public void setCategory(String category) {
        changeAndFire("category", category);
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Object get(String property) {
        switch (property) {
          case "dataIOSet": return getDataIOSet();
          case "description": return getDescription();
          case "labels": return getLabels();
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "defaultHandler": return getDefaultHandler();
          case "name": return getName();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "this": return target;
          default: throw new NonExistingPropertyException("ServiceTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "description": target.setDescription((String) value);
          break;
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "defaultHandler": target.setDefaultHandler((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "executionSet": target.setExecutionSet((ServiceTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "category": target.setCategory((String) value);
          break;
          case "this": target = (ServiceTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ServiceTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ServiceTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy((ServiceTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy extends ScriptTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<ScriptTaskExecutionSet> agent;
      private ScriptTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy() {
        this(new ScriptTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy(ScriptTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<ScriptTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("script", new PropertyType(Script.class, true, false));
        p.put("this", new PropertyType(ScriptTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScriptTaskExecutionSet unwrap() {
        return target;
      }

      public ScriptTaskExecutionSet deepUnwrap() {
        final ScriptTaskExecutionSet clone = new ScriptTaskExecutionSet();
        final ScriptTaskExecutionSet t = unwrap();
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getScript() instanceof BindableProxy) {
          clone.setScript((Script) ((BindableProxy) getScript()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getScript())) {
          clone.setScript((Script) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getScript())).deepUnwrap());
        } else {
          clone.setScript(t.getScript());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public Script getScript() {
        return target.getScript();
      }

      public void setScript(Script script) {
        if (agent.binders.containsKey("script")) {
          script = (Script) agent.binders.get("script").setModel(script, StateSync.FROM_MODEL, true);
        }
        changeAndFire("script", script);
      }

      public Object get(String property) {
        switch (property) {
          case "adHocAutostart": return getAdHocAutostart();
          case "isAsync": return getIsAsync();
          case "script": return getScript();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScriptTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "script": target.setScript((Script) value);
          break;
          case "this": target = (ScriptTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScriptTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ScriptTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy((ScriptTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy extends MultipleInstanceCollectionOutput implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceCollectionOutput> agent;
      private MultipleInstanceCollectionOutput target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy() {
        this(new MultipleInstanceCollectionOutput());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy(MultipleInstanceCollectionOutput targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceCollectionOutput>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceCollectionOutput unwrap() {
        return target;
      }

      public MultipleInstanceCollectionOutput deepUnwrap() {
        final MultipleInstanceCollectionOutput clone = new MultipleInstanceCollectionOutput();
        final MultipleInstanceCollectionOutput t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceCollectionOutput", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (MultipleInstanceCollectionOutput) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceCollectionOutput", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceCollectionOutput.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy((MultipleInstanceCollectionOutput) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceCollectionOutputProxy();
      }
    });
    class org_jbpm_designer_client_shared_AssignmentRowProxy extends AssignmentRow implements BindableProxy {
      private BindableProxyAgent<AssignmentRow> agent;
      private AssignmentRow target;
      public org_jbpm_designer_client_shared_AssignmentRowProxy() {
        this(new AssignmentRow());
      }

      public org_jbpm_designer_client_shared_AssignmentRowProxy(AssignmentRow targetVal) {
        agent = new BindableProxyAgent<AssignmentRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("variableType", new PropertyType(org.jbpm.designer.client.shared.Variable.VariableType.class, false, false));
        p.put("processVar", new PropertyType(String.class, false, false));
        p.put("constant", new PropertyType(String.class, false, false));
        p.put("dataType", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("customDataType", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("complete", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(AssignmentRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AssignmentRow unwrap() {
        return target;
      }

      public AssignmentRow deepUnwrap() {
        final AssignmentRow clone = new AssignmentRow();
        final AssignmentRow t = unwrap();
        clone.setVariableType(t.getVariableType());
        clone.setProcessVar(t.getProcessVar());
        clone.setConstant(t.getConstant());
        clone.setDataType(t.getDataType());
        clone.setName(t.getName());
        clone.setCustomDataType(t.getCustomDataType());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jbpm_designer_client_shared_AssignmentRowProxy) {
          obj = ((org_jbpm_designer_client_shared_AssignmentRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.jbpm.designer.client.shared.Variable.VariableType getVariableType() {
        return target.getVariableType();
      }

      public void setVariableType(org.jbpm.designer.client.shared.Variable.VariableType variableType) {
        changeAndFire("variableType", variableType);
      }

      public String getProcessVar() {
        return target.getProcessVar();
      }

      public void setProcessVar(String processVar) {
        changeAndFire("processVar", processVar);
      }

      public String getConstant() {
        return target.getConstant();
      }

      public void setConstant(String constant) {
        changeAndFire("constant", constant);
      }

      public String getDataType() {
        return target.getDataType();
      }

      public void setDataType(String dataType) {
        changeAndFire("dataType", dataType);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getCustomDataType() {
        return target.getCustomDataType();
      }

      public void setCustomDataType(String customDataType) {
        changeAndFire("customDataType", customDataType);
      }

      public long getId() {
        return target.getId();
      }

      public void setId(long id) {
        changeAndFire("id", id);
      }

      public boolean isComplete() {
        return target.isComplete();
      }

      public Object get(String property) {
        switch (property) {
          case "variableType": return getVariableType();
          case "processVar": return getProcessVar();
          case "constant": return getConstant();
          case "dataType": return getDataType();
          case "name": return getName();
          case "customDataType": return getCustomDataType();
          case "id": return getId();
          case "complete": return isComplete();
          case "this": return target;
          default: throw new NonExistingPropertyException("AssignmentRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "variableType": target.setVariableType((org.jbpm.designer.client.shared.Variable.VariableType) value);
          break;
          case "processVar": target.setProcessVar((String) value);
          break;
          case "constant": target.setConstant((String) value);
          break;
          case "dataType": target.setDataType((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "customDataType": target.setCustomDataType((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "this": target = (AssignmentRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AssignmentRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(AssignmentRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jbpm_designer_client_shared_AssignmentRowProxy((AssignmentRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jbpm_designer_client_shared_AssignmentRowProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy extends Executable implements BindableProxy {
      private BindableProxyAgent<Executable> agent;
      private Executable target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy() {
        this(new Executable());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy(Executable targetVal) {
        agent = new BindableProxyAgent<Executable>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(Executable.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Executable unwrap() {
        return target;
      }

      public Executable deepUnwrap() {
        final Executable clone = new Executable();
        final Executable t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Executable", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (Executable) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Executable", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Executable.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy((Executable) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ExecutableProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy extends Skippable implements BindableProxy {
      private BindableProxyAgent<Skippable> agent;
      private Skippable target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy() {
        this(new Skippable());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy(Skippable targetVal) {
        agent = new BindableProxyAgent<Skippable>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(Skippable.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Skippable unwrap() {
        return target;
      }

      public Skippable deepUnwrap() {
        final Skippable clone = new Skippable();
        final Skippable t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Skippable", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (Skippable) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Skippable", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Skippable.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy((Skippable) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_SkippableProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy extends StringSelectorOption implements BindableProxy {
      private BindableProxyAgent<StringSelectorOption> agent;
      private StringSelectorOption target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy() {
        this(new StringSelectorOption());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy(StringSelectorOption targetVal) {
        agent = new BindableProxyAgent<StringSelectorOption>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("text", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(StringSelectorOption.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public StringSelectorOption unwrap() {
        return target;
      }

      public StringSelectorOption deepUnwrap() {
        final StringSelectorOption clone = new StringSelectorOption();
        final StringSelectorOption t = unwrap();
        clone.setText(t.getText());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "text": return getText();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("StringSelectorOption", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "text": target.setText((String) value);
          break;
          case "value": target.setValue((String) value);
          break;
          case "this": target = (StringSelectorOption) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("StringSelectorOption", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(StringSelectorOption.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy((StringSelectorOption) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_StringSelectorOptionProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy extends PictureFieldDefinition implements BindableProxy {
      private BindableProxyAgent<PictureFieldDefinition> agent;
      private PictureFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy() {
        this(new PictureFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy(PictureFieldDefinition targetVal) {
        agent = new BindableProxyAgent<PictureFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("size", new PropertyType(PictureSize.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(PictureFieldType.class, false, false));
        p.put("this", new PropertyType(PictureFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public PictureFieldDefinition unwrap() {
        return target;
      }

      public PictureFieldDefinition deepUnwrap() {
        final PictureFieldDefinition clone = new PictureFieldDefinition();
        final PictureFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setSize(t.getSize());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public PictureSize getSize() {
        return target.getSize();
      }

      public void setSize(PictureSize size) {
        changeAndFire("size", size);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public PictureFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "size": return getSize();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("PictureFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "size": target.setSize((PictureSize) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (PictureFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("PictureFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(PictureFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy((PictureFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_image_definition_PictureFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy extends ScriptTypeListValue implements BindableProxy {
      private BindableProxyAgent<ScriptTypeListValue> agent;
      private ScriptTypeListValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy() {
        this(new ScriptTypeListValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy(ScriptTypeListValue targetVal) {
        agent = new BindableProxyAgent<ScriptTypeListValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("values", new PropertyType(List.class, false, true));
        p.put("empty", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(ScriptTypeListValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScriptTypeListValue unwrap() {
        return target;
      }

      public ScriptTypeListValue deepUnwrap() {
        final ScriptTypeListValue clone = new ScriptTypeListValue();
        final ScriptTypeListValue t = unwrap();
        if (t.getValues() != null) {
          final List valuesClone = new ArrayList();
          for (Object valuesElem : t.getValues()) {
            if (valuesElem instanceof BindableProxy) {
              valuesClone.add(((BindableProxy) valuesElem).deepUnwrap());
            } else {
              valuesClone.add(valuesElem);
            }
          }
          clone.setValues(valuesClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public List getValues() {
        return target.getValues();
      }

      public void setValues(List<ScriptTypeValue> values) {
        List<ScriptTypeValue> oldValue = target.getValues();
        values = agent.ensureBoundListIsProxied("values", values);
        target.setValues(values);
        agent.updateWidgetsAndFireEvent(true, "values", oldValue, values);
      }

      public boolean isEmpty() {
        return target.isEmpty();
      }

      public Object get(String property) {
        switch (property) {
          case "values": return getValues();
          case "empty": return isEmpty();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScriptTypeListValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "values": target.setValues((List<ScriptTypeValue>) value);
          break;
          case "this": target = (ScriptTypeListValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScriptTypeListValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public ScriptTypeListValue addValue(ScriptTypeValue a0) {
        final ScriptTypeListValue returnValue = target.addValue(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ScriptTypeListValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy((ScriptTypeListValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_ScriptTypeListValueProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy extends Independent implements BindableProxy {
      private BindableProxyAgent<Independent> agent;
      private Independent target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy() {
        this(new Independent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy(Independent targetVal) {
        agent = new BindableProxyAgent<Independent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(Independent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Independent unwrap() {
        return target;
      }

      public Independent deepUnwrap() {
        final Independent clone = new Independent();
        final Independent t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Independent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (Independent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Independent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Independent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy((Independent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_IndependentProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy extends GenericServiceTaskInfo implements BindableProxy {
      private BindableProxyAgent<GenericServiceTaskInfo> agent;
      private GenericServiceTaskInfo target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy() {
        this(new GenericServiceTaskInfo());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy(GenericServiceTaskInfo targetVal) {
        agent = new BindableProxyAgent<GenericServiceTaskInfo>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(GenericServiceTaskValue.class, true, false));
        p.put("this", new PropertyType(GenericServiceTaskInfo.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GenericServiceTaskInfo unwrap() {
        return target;
      }

      public GenericServiceTaskInfo deepUnwrap() {
        final GenericServiceTaskInfo clone = new GenericServiceTaskInfo();
        final GenericServiceTaskInfo t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((GenericServiceTaskValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((GenericServiceTaskValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public GenericServiceTaskValue getValue() {
        return target.getValue();
      }

      public void setValue(GenericServiceTaskValue value) {
        if (agent.binders.containsKey("value")) {
          value = (GenericServiceTaskValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("GenericServiceTaskInfo", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((GenericServiceTaskValue) value);
          break;
          case "this": target = (GenericServiceTaskInfo) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GenericServiceTaskInfo", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(GenericServiceTaskInfo.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy((GenericServiceTaskInfo) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_service_GenericServiceTaskInfoProxy();
      }
    });
    class org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy extends DocumentFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DocumentFieldDefinition> agent;
      private DocumentFieldDefinition target;
      public org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy() {
        this(new DocumentFieldDefinition());
      }

      public org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy(DocumentFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DocumentFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(DocumentFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DocumentFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DocumentFieldDefinition unwrap() {
        return target;
      }

      public DocumentFieldDefinition deepUnwrap() {
        final DocumentFieldDefinition clone = new DocumentFieldDefinition();
        final DocumentFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public DocumentFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("DocumentFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (DocumentFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DocumentFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DocumentFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy((DocumentFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_jbpm_model_authoring_document_definition_DocumentFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy extends GlobalVariables implements BindableProxy {
      private BindableProxyAgent<GlobalVariables> agent;
      private GlobalVariables target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy() {
        this(new GlobalVariables());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy(GlobalVariables targetVal) {
        agent = new BindableProxyAgent<GlobalVariables>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(GlobalVariables.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public GlobalVariables unwrap() {
        return target;
      }

      public GlobalVariables deepUnwrap() {
        final GlobalVariables clone = new GlobalVariables();
        final GlobalVariables t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("GlobalVariables", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (GlobalVariables) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("GlobalVariables", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(GlobalVariables.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy((GlobalVariables) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_GlobalVariablesProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition clone = new org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition();
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("AdHocActivationCondition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AdHocActivationCondition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy((org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocActivationCondition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_AdHocActivationConditionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy extends Max implements BindableProxy {
      private BindableProxyAgent<Max> agent;
      private Max target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy() {
        this(new Max());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy(Max targetVal) {
        agent = new BindableProxyAgent<Max>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Max.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Max unwrap() {
        return target;
      }

      public Max deepUnwrap() {
        final Max clone = new Max();
        final Max t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Max", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Max) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Max", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Max.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy((Max) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_MaxProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("subject", new PropertyType(Subject.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("description", new PropertyType(Description.class, true, false));
        p.put("multipleInstanceDataOutput", new PropertyType(MultipleInstanceDataOutput.class, true, false));
        p.put("content", new PropertyType(Content.class, true, false));
        p.put("multipleInstanceDataInput", new PropertyType(MultipleInstanceDataInput.class, true, false));
        p.put("reassignmentsInfo", new PropertyType(ReassignmentsInfo.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("assignmentsinfo", new PropertyType(AssignmentsInfo.class, true, false));
        p.put("isMultipleInstance", new PropertyType(IsMultipleInstance.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("notificationsInfo", new PropertyType(NotificationsInfo.class, true, false));
        p.put("groupid", new PropertyType(Groupid.class, true, false));
        p.put("skippable", new PropertyType(Skippable.class, true, false));
        p.put("priority", new PropertyType(Priority.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("multipleInstanceCollectionInput", new PropertyType(MultipleInstanceCollectionInput.class, true, false));
        p.put("multipleInstanceCollectionOutput", new PropertyType(MultipleInstanceCollectionOutput.class, true, false));
        p.put("actors", new PropertyType(Actors.class, true, false));
        p.put("createdBy", new PropertyType(CreatedBy.class, true, false));
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("taskName", new PropertyType(TaskName.class, true, false));
        p.put("multipleInstanceCompletionCondition", new PropertyType(MultipleInstanceCompletionCondition.class, true, false));
        p.put("multipleInstanceExecutionMode", new PropertyType(MultipleInstanceExecutionMode.class, true, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet clone = new org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet();
        final org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet t = unwrap();
        if (t.getSubject() instanceof BindableProxy) {
          clone.setSubject((Subject) ((BindableProxy) getSubject()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSubject())) {
          clone.setSubject((Subject) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSubject())).deepUnwrap());
        } else {
          clone.setSubject(t.getSubject());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getMultipleInstanceDataOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) getMultipleInstanceDataOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataOutput())) {
          clone.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataOutput(t.getMultipleInstanceDataOutput());
        }
        if (t.getContent() instanceof BindableProxy) {
          clone.setContent((Content) ((BindableProxy) getContent()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getContent())) {
          clone.setContent((Content) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getContent())).deepUnwrap());
        } else {
          clone.setContent(t.getContent());
        }
        if (t.getMultipleInstanceDataInput() instanceof BindableProxy) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) getMultipleInstanceDataInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceDataInput())) {
          clone.setMultipleInstanceDataInput((MultipleInstanceDataInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceDataInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceDataInput(t.getMultipleInstanceDataInput());
        }
        if (t.getReassignmentsInfo() instanceof BindableProxy) {
          clone.setReassignmentsInfo((ReassignmentsInfo) ((BindableProxy) getReassignmentsInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getReassignmentsInfo())) {
          clone.setReassignmentsInfo((ReassignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getReassignmentsInfo())).deepUnwrap());
        } else {
          clone.setReassignmentsInfo(t.getReassignmentsInfo());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getAssignmentsinfo() instanceof BindableProxy) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) getAssignmentsinfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAssignmentsinfo())) {
          clone.setAssignmentsinfo((AssignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAssignmentsinfo())).deepUnwrap());
        } else {
          clone.setAssignmentsinfo(t.getAssignmentsinfo());
        }
        if (t.getIsMultipleInstance() instanceof BindableProxy) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) getIsMultipleInstance()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsMultipleInstance())) {
          clone.setIsMultipleInstance((IsMultipleInstance) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsMultipleInstance())).deepUnwrap());
        } else {
          clone.setIsMultipleInstance(t.getIsMultipleInstance());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getNotificationsInfo() instanceof BindableProxy) {
          clone.setNotificationsInfo((NotificationsInfo) ((BindableProxy) getNotificationsInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getNotificationsInfo())) {
          clone.setNotificationsInfo((NotificationsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getNotificationsInfo())).deepUnwrap());
        } else {
          clone.setNotificationsInfo(t.getNotificationsInfo());
        }
        if (t.getGroupid() instanceof BindableProxy) {
          clone.setGroupid((Groupid) ((BindableProxy) getGroupid()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGroupid())) {
          clone.setGroupid((Groupid) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGroupid())).deepUnwrap());
        } else {
          clone.setGroupid(t.getGroupid());
        }
        if (t.getSkippable() instanceof BindableProxy) {
          clone.setSkippable((Skippable) ((BindableProxy) getSkippable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSkippable())) {
          clone.setSkippable((Skippable) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSkippable())).deepUnwrap());
        } else {
          clone.setSkippable(t.getSkippable());
        }
        if (t.getPriority() instanceof BindableProxy) {
          clone.setPriority((Priority) ((BindableProxy) getPriority()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getPriority())) {
          clone.setPriority((Priority) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getPriority())).deepUnwrap());
        } else {
          clone.setPriority(t.getPriority());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        if (t.getMultipleInstanceCollectionInput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) getMultipleInstanceCollectionInput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionInput())) {
          clone.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionInput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionInput(t.getMultipleInstanceCollectionInput());
        }
        if (t.getMultipleInstanceCollectionOutput() instanceof BindableProxy) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) getMultipleInstanceCollectionOutput()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCollectionOutput())) {
          clone.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCollectionOutput())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCollectionOutput(t.getMultipleInstanceCollectionOutput());
        }
        if (t.getActors() instanceof BindableProxy) {
          clone.setActors((Actors) ((BindableProxy) getActors()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getActors())) {
          clone.setActors((Actors) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getActors())).deepUnwrap());
        } else {
          clone.setActors(t.getActors());
        }
        if (t.getCreatedBy() instanceof BindableProxy) {
          clone.setCreatedBy((CreatedBy) ((BindableProxy) getCreatedBy()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCreatedBy())) {
          clone.setCreatedBy((CreatedBy) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCreatedBy())).deepUnwrap());
        } else {
          clone.setCreatedBy(t.getCreatedBy());
        }
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getTaskName() instanceof BindableProxy) {
          clone.setTaskName((TaskName) ((BindableProxy) getTaskName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskName())) {
          clone.setTaskName((TaskName) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskName())).deepUnwrap());
        } else {
          clone.setTaskName(t.getTaskName());
        }
        if (t.getMultipleInstanceCompletionCondition() instanceof BindableProxy) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) getMultipleInstanceCompletionCondition()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceCompletionCondition())) {
          clone.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceCompletionCondition())).deepUnwrap());
        } else {
          clone.setMultipleInstanceCompletionCondition(t.getMultipleInstanceCompletionCondition());
        }
        if (t.getMultipleInstanceExecutionMode() instanceof BindableProxy) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) getMultipleInstanceExecutionMode()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMultipleInstanceExecutionMode())) {
          clone.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMultipleInstanceExecutionMode())).deepUnwrap());
        } else {
          clone.setMultipleInstanceExecutionMode(t.getMultipleInstanceExecutionMode());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Subject getSubject() {
        return target.getSubject();
      }

      public void setSubject(Subject subject) {
        if (agent.binders.containsKey("subject")) {
          subject = (Subject) agent.binders.get("subject").setModel(subject, StateSync.FROM_MODEL, true);
        }
        changeAndFire("subject", subject);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(Description description) {
        if (agent.binders.containsKey("description")) {
          description = (Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public MultipleInstanceDataOutput getMultipleInstanceDataOutput() {
        return target.getMultipleInstanceDataOutput();
      }

      public void setMultipleInstanceDataOutput(MultipleInstanceDataOutput multipleInstanceDataOutput) {
        if (agent.binders.containsKey("multipleInstanceDataOutput")) {
          multipleInstanceDataOutput = (MultipleInstanceDataOutput) agent.binders.get("multipleInstanceDataOutput").setModel(multipleInstanceDataOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataOutput", multipleInstanceDataOutput);
      }

      public Content getContent() {
        return target.getContent();
      }

      public void setContent(Content content) {
        if (agent.binders.containsKey("content")) {
          content = (Content) agent.binders.get("content").setModel(content, StateSync.FROM_MODEL, true);
        }
        changeAndFire("content", content);
      }

      public MultipleInstanceDataInput getMultipleInstanceDataInput() {
        return target.getMultipleInstanceDataInput();
      }

      public void setMultipleInstanceDataInput(MultipleInstanceDataInput multipleInstanceDataInput) {
        if (agent.binders.containsKey("multipleInstanceDataInput")) {
          multipleInstanceDataInput = (MultipleInstanceDataInput) agent.binders.get("multipleInstanceDataInput").setModel(multipleInstanceDataInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceDataInput", multipleInstanceDataInput);
      }

      public ReassignmentsInfo getReassignmentsInfo() {
        return target.getReassignmentsInfo();
      }

      public void setReassignmentsInfo(ReassignmentsInfo reassignmentsInfo) {
        if (agent.binders.containsKey("reassignmentsInfo")) {
          reassignmentsInfo = (ReassignmentsInfo) agent.binders.get("reassignmentsInfo").setModel(reassignmentsInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("reassignmentsInfo", reassignmentsInfo);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public AssignmentsInfo getAssignmentsinfo() {
        return target.getAssignmentsinfo();
      }

      public void setAssignmentsinfo(AssignmentsInfo assignmentsinfo) {
        if (agent.binders.containsKey("assignmentsinfo")) {
          assignmentsinfo = (AssignmentsInfo) agent.binders.get("assignmentsinfo").setModel(assignmentsinfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("assignmentsinfo", assignmentsinfo);
      }

      public IsMultipleInstance getIsMultipleInstance() {
        return target.getIsMultipleInstance();
      }

      public void setIsMultipleInstance(IsMultipleInstance isMultipleInstance) {
        if (agent.binders.containsKey("isMultipleInstance")) {
          isMultipleInstance = (IsMultipleInstance) agent.binders.get("isMultipleInstance").setModel(isMultipleInstance, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isMultipleInstance", isMultipleInstance);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public NotificationsInfo getNotificationsInfo() {
        return target.getNotificationsInfo();
      }

      public void setNotificationsInfo(NotificationsInfo notificationsInfo) {
        if (agent.binders.containsKey("notificationsInfo")) {
          notificationsInfo = (NotificationsInfo) agent.binders.get("notificationsInfo").setModel(notificationsInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("notificationsInfo", notificationsInfo);
      }

      public Groupid getGroupid() {
        return target.getGroupid();
      }

      public void setGroupid(Groupid groupid) {
        if (agent.binders.containsKey("groupid")) {
          groupid = (Groupid) agent.binders.get("groupid").setModel(groupid, StateSync.FROM_MODEL, true);
        }
        changeAndFire("groupid", groupid);
      }

      public Skippable getSkippable() {
        return target.getSkippable();
      }

      public void setSkippable(Skippable skippable) {
        if (agent.binders.containsKey("skippable")) {
          skippable = (Skippable) agent.binders.get("skippable").setModel(skippable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("skippable", skippable);
      }

      public Priority getPriority() {
        return target.getPriority();
      }

      public void setPriority(Priority priority) {
        if (agent.binders.containsKey("priority")) {
          priority = (Priority) agent.binders.get("priority").setModel(priority, StateSync.FROM_MODEL, true);
        }
        changeAndFire("priority", priority);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public MultipleInstanceCollectionInput getMultipleInstanceCollectionInput() {
        return target.getMultipleInstanceCollectionInput();
      }

      public void setMultipleInstanceCollectionInput(MultipleInstanceCollectionInput multipleInstanceCollectionInput) {
        if (agent.binders.containsKey("multipleInstanceCollectionInput")) {
          multipleInstanceCollectionInput = (MultipleInstanceCollectionInput) agent.binders.get("multipleInstanceCollectionInput").setModel(multipleInstanceCollectionInput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionInput", multipleInstanceCollectionInput);
      }

      public MultipleInstanceCollectionOutput getMultipleInstanceCollectionOutput() {
        return target.getMultipleInstanceCollectionOutput();
      }

      public void setMultipleInstanceCollectionOutput(MultipleInstanceCollectionOutput multipleInstanceCollectionOutput) {
        if (agent.binders.containsKey("multipleInstanceCollectionOutput")) {
          multipleInstanceCollectionOutput = (MultipleInstanceCollectionOutput) agent.binders.get("multipleInstanceCollectionOutput").setModel(multipleInstanceCollectionOutput, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCollectionOutput", multipleInstanceCollectionOutput);
      }

      public Actors getActors() {
        return target.getActors();
      }

      public void setActors(Actors actors) {
        if (agent.binders.containsKey("actors")) {
          actors = (Actors) agent.binders.get("actors").setModel(actors, StateSync.FROM_MODEL, true);
        }
        changeAndFire("actors", actors);
      }

      public CreatedBy getCreatedBy() {
        return target.getCreatedBy();
      }

      public void setCreatedBy(CreatedBy createdBy) {
        if (agent.binders.containsKey("createdBy")) {
          createdBy = (CreatedBy) agent.binders.get("createdBy").setModel(createdBy, StateSync.FROM_MODEL, true);
        }
        changeAndFire("createdBy", createdBy);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public TaskName getTaskName() {
        return target.getTaskName();
      }

      public void setTaskName(TaskName taskName) {
        if (agent.binders.containsKey("taskName")) {
          taskName = (TaskName) agent.binders.get("taskName").setModel(taskName, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskName", taskName);
      }

      public MultipleInstanceCompletionCondition getMultipleInstanceCompletionCondition() {
        return target.getMultipleInstanceCompletionCondition();
      }

      public void setMultipleInstanceCompletionCondition(MultipleInstanceCompletionCondition multipleInstanceCompletionCondition) {
        if (agent.binders.containsKey("multipleInstanceCompletionCondition")) {
          multipleInstanceCompletionCondition = (MultipleInstanceCompletionCondition) agent.binders.get("multipleInstanceCompletionCondition").setModel(multipleInstanceCompletionCondition, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceCompletionCondition", multipleInstanceCompletionCondition);
      }

      public MultipleInstanceExecutionMode getMultipleInstanceExecutionMode() {
        return target.getMultipleInstanceExecutionMode();
      }

      public void setMultipleInstanceExecutionMode(MultipleInstanceExecutionMode multipleInstanceExecutionMode) {
        if (agent.binders.containsKey("multipleInstanceExecutionMode")) {
          multipleInstanceExecutionMode = (MultipleInstanceExecutionMode) agent.binders.get("multipleInstanceExecutionMode").setModel(multipleInstanceExecutionMode, StateSync.FROM_MODEL, true);
        }
        changeAndFire("multipleInstanceExecutionMode", multipleInstanceExecutionMode);
      }

      public Object get(String property) {
        switch (property) {
          case "subject": return getSubject();
          case "isAsync": return getIsAsync();
          case "description": return getDescription();
          case "multipleInstanceDataOutput": return getMultipleInstanceDataOutput();
          case "content": return getContent();
          case "multipleInstanceDataInput": return getMultipleInstanceDataInput();
          case "reassignmentsInfo": return getReassignmentsInfo();
          case "slaDueDate": return getSlaDueDate();
          case "assignmentsinfo": return getAssignmentsinfo();
          case "isMultipleInstance": return getIsMultipleInstance();
          case "onExitAction": return getOnExitAction();
          case "notificationsInfo": return getNotificationsInfo();
          case "groupid": return getGroupid();
          case "skippable": return getSkippable();
          case "priority": return getPriority();
          case "onEntryAction": return getOnEntryAction();
          case "multipleInstanceCollectionInput": return getMultipleInstanceCollectionInput();
          case "multipleInstanceCollectionOutput": return getMultipleInstanceCollectionOutput();
          case "actors": return getActors();
          case "createdBy": return getCreatedBy();
          case "adHocAutostart": return getAdHocAutostart();
          case "taskName": return getTaskName();
          case "multipleInstanceCompletionCondition": return getMultipleInstanceCompletionCondition();
          case "multipleInstanceExecutionMode": return getMultipleInstanceExecutionMode();
          case "this": return target;
          default: throw new NonExistingPropertyException("UserTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "subject": target.setSubject((Subject) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "description": target.setDescription((Description) value);
          break;
          case "multipleInstanceDataOutput": target.setMultipleInstanceDataOutput((MultipleInstanceDataOutput) value);
          break;
          case "content": target.setContent((Content) value);
          break;
          case "multipleInstanceDataInput": target.setMultipleInstanceDataInput((MultipleInstanceDataInput) value);
          break;
          case "reassignmentsInfo": target.setReassignmentsInfo((ReassignmentsInfo) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "assignmentsinfo": target.setAssignmentsinfo((AssignmentsInfo) value);
          break;
          case "isMultipleInstance": target.setIsMultipleInstance((IsMultipleInstance) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "notificationsInfo": target.setNotificationsInfo((NotificationsInfo) value);
          break;
          case "groupid": target.setGroupid((Groupid) value);
          break;
          case "skippable": target.setSkippable((Skippable) value);
          break;
          case "priority": target.setPriority((Priority) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "multipleInstanceCollectionInput": target.setMultipleInstanceCollectionInput((MultipleInstanceCollectionInput) value);
          break;
          case "multipleInstanceCollectionOutput": target.setMultipleInstanceCollectionOutput((MultipleInstanceCollectionOutput) value);
          break;
          case "actors": target.setActors((Actors) value);
          break;
          case "createdBy": target.setCreatedBy((CreatedBy) value);
          break;
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "taskName": target.setTaskName((TaskName) value);
          break;
          case "multipleInstanceCompletionCondition": target.setMultipleInstanceCompletionCondition((MultipleInstanceCompletionCondition) value);
          break;
          case "multipleInstanceExecutionMode": target.setMultipleInstanceExecutionMode((MultipleInstanceExecutionMode) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("UserTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy((org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_UserTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy extends DecisionServiceRectangleDimensionsSet implements BindableProxy {
      private BindableProxyAgent<DecisionServiceRectangleDimensionsSet> agent;
      private DecisionServiceRectangleDimensionsSet target;
      public org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy() {
        this(new DecisionServiceRectangleDimensionsSet());
      }

      public org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy(DecisionServiceRectangleDimensionsSet targetVal) {
        agent = new BindableProxyAgent<DecisionServiceRectangleDimensionsSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("width", new PropertyType(Width.class, true, false));
        p.put("maximumWidth", new PropertyType(Double.class, false, false));
        p.put("minimumHeight", new PropertyType(Double.class, false, false));
        p.put("maximumHeight", new PropertyType(Double.class, false, false));
        p.put("minimumWidth", new PropertyType(Double.class, false, false));
        p.put("height", new PropertyType(org.kie.workbench.common.dmn.api.property.dimensions.Height.class, true, false));
        p.put("this", new PropertyType(DecisionServiceRectangleDimensionsSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecisionServiceRectangleDimensionsSet unwrap() {
        return target;
      }

      public DecisionServiceRectangleDimensionsSet deepUnwrap() {
        final DecisionServiceRectangleDimensionsSet clone = new DecisionServiceRectangleDimensionsSet();
        final DecisionServiceRectangleDimensionsSet t = unwrap();
        if (t.getWidth() instanceof BindableProxy) {
          clone.setWidth((Width) ((BindableProxy) getWidth()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWidth())) {
          clone.setWidth((Width) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWidth())).deepUnwrap());
        } else {
          clone.setWidth(t.getWidth());
        }
        if (t.getHeight() instanceof BindableProxy) {
          clone.setHeight((org.kie.workbench.common.dmn.api.property.dimensions.Height) ((BindableProxy) getHeight()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getHeight())) {
          clone.setHeight((org.kie.workbench.common.dmn.api.property.dimensions.Height) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getHeight())).deepUnwrap());
        } else {
          clone.setHeight(t.getHeight());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Width getWidth() {
        return target.getWidth();
      }

      public void setWidth(Width width) {
        if (agent.binders.containsKey("width")) {
          width = (Width) agent.binders.get("width").setModel(width, StateSync.FROM_MODEL, true);
        }
        changeAndFire("width", width);
      }

      public double getMaximumWidth() {
        return target.getMaximumWidth();
      }

      public double getMinimumHeight() {
        return target.getMinimumHeight();
      }

      public double getMaximumHeight() {
        return target.getMaximumHeight();
      }

      public double getMinimumWidth() {
        return target.getMinimumWidth();
      }

      public org.kie.workbench.common.dmn.api.property.dimensions.Height getHeight() {
        return target.getHeight();
      }

      public void setHeight(org.kie.workbench.common.dmn.api.property.dimensions.Height height) {
        if (agent.binders.containsKey("height")) {
          height = (org.kie.workbench.common.dmn.api.property.dimensions.Height) agent.binders.get("height").setModel(height, StateSync.FROM_MODEL, true);
        }
        changeAndFire("height", height);
      }

      public Object get(String property) {
        switch (property) {
          case "width": return getWidth();
          case "maximumWidth": return getMaximumWidth();
          case "minimumHeight": return getMinimumHeight();
          case "maximumHeight": return getMaximumHeight();
          case "minimumWidth": return getMinimumWidth();
          case "height": return getHeight();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecisionServiceRectangleDimensionsSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "width": target.setWidth((Width) value);
          break;
          case "height": target.setHeight((org.kie.workbench.common.dmn.api.property.dimensions.Height) value);
          break;
          case "this": target = (DecisionServiceRectangleDimensionsSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecisionServiceRectangleDimensionsSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DecisionServiceRectangleDimensionsSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy((DecisionServiceRectangleDimensionsSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dimensions_DecisionServiceRectangleDimensionsSetProxy();
      }
    });
    class org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy extends DocumentCollectionFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DocumentCollectionFieldDefinition> agent;
      private DocumentCollectionFieldDefinition target;
      public org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy() {
        this(new DocumentCollectionFieldDefinition());
      }

      public org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy(DocumentCollectionFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DocumentCollectionFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDocuments", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(DocumentCollectionFieldType.class, false, false));
        p.put("this", new PropertyType(DocumentCollectionFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DocumentCollectionFieldDefinition unwrap() {
        return target;
      }

      public DocumentCollectionFieldDefinition deepUnwrap() {
        final DocumentCollectionFieldDefinition clone = new DocumentCollectionFieldDefinition();
        final DocumentCollectionFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDocuments(t.getMaxDocuments());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDocuments() {
        return target.getMaxDocuments();
      }

      public void setMaxDocuments(Integer maxDocuments) {
        changeAndFire("maxDocuments", maxDocuments);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public DocumentCollectionFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDocuments": return getMaxDocuments();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DocumentCollectionFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDocuments": target.setMaxDocuments((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DocumentCollectionFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DocumentCollectionFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DocumentCollectionFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy((DocumentCollectionFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_jbpm_model_authoring_documents_definition_DocumentCollectionFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy extends IntermediateMessageEventThrowing implements BindableProxy {
      private BindableProxyAgent<IntermediateMessageEventThrowing> agent;
      private IntermediateMessageEventThrowing target;
      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy() {
        this(new IntermediateMessageEventThrowing());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy(IntermediateMessageEventThrowing targetVal) {
        agent = new BindableProxyAgent<IntermediateMessageEventThrowing>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(MessageEventExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(IntermediateMessageEventThrowing.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntermediateMessageEventThrowing unwrap() {
        return target;
      }

      public IntermediateMessageEventThrowing deepUnwrap() {
        final IntermediateMessageEventThrowing clone = new IntermediateMessageEventThrowing();
        final IntermediateMessageEventThrowing t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((MessageEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((MessageEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public MessageEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(MessageEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (MessageEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntermediateMessageEventThrowing", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((MessageEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (IntermediateMessageEventThrowing) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntermediateMessageEventThrowing", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(IntermediateMessageEventThrowing.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy((IntermediateMessageEventThrowing) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_IntermediateMessageEventThrowingProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy extends EventSubprocessExecutionSet implements BindableProxy {
      private BindableProxyAgent<EventSubprocessExecutionSet> agent;
      private EventSubprocessExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy() {
        this(new EventSubprocessExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy(EventSubprocessExecutionSet targetVal) {
        agent = new BindableProxyAgent<EventSubprocessExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(EventSubprocessExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EventSubprocessExecutionSet unwrap() {
        return target;
      }

      public EventSubprocessExecutionSet deepUnwrap() {
        final EventSubprocessExecutionSet clone = new EventSubprocessExecutionSet();
        final EventSubprocessExecutionSet t = unwrap();
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("EventSubprocessExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (EventSubprocessExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EventSubprocessExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EventSubprocessExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy((EventSubprocessExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_subProcess_execution_EventSubprocessExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy extends CancellingMessageEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CancellingMessageEventExecutionSet> agent;
      private CancellingMessageEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy() {
        this(new CancellingMessageEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy(CancellingMessageEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CancellingMessageEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("messageRef", new PropertyType(MessageRef.class, true, false));
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(CancellingMessageEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancellingMessageEventExecutionSet unwrap() {
        return target;
      }

      public CancellingMessageEventExecutionSet deepUnwrap() {
        final CancellingMessageEventExecutionSet clone = new CancellingMessageEventExecutionSet();
        final CancellingMessageEventExecutionSet t = unwrap();
        if (t.getMessageRef() instanceof BindableProxy) {
          clone.setMessageRef((MessageRef) ((BindableProxy) getMessageRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMessageRef())) {
          clone.setMessageRef((MessageRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMessageRef())).deepUnwrap());
        } else {
          clone.setMessageRef(t.getMessageRef());
        }
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public MessageRef getMessageRef() {
        return target.getMessageRef();
      }

      public void setMessageRef(MessageRef messageRef) {
        if (agent.binders.containsKey("messageRef")) {
          messageRef = (MessageRef) agent.binders.get("messageRef").setModel(messageRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("messageRef", messageRef);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "messageRef": return getMessageRef();
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancellingMessageEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "messageRef": target.setMessageRef((MessageRef) value);
          break;
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (CancellingMessageEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancellingMessageEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancellingMessageEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy((CancellingMessageEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_CancellingMessageEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy extends org.kie.workbench.common.stunner.cm.definition.property.diagram.Package implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.Package> agent;
      private org.kie.workbench.common.stunner.cm.definition.property.diagram.Package target;
      public org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy() {
        this(new org.kie.workbench.common.stunner.cm.definition.property.diagram.Package());
      }

      public org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.Package targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.cm.definition.property.diagram.Package>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.cm.definition.property.diagram.Package.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.Package unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.cm.definition.property.diagram.Package deepUnwrap() {
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.Package clone = new org.kie.workbench.common.stunner.cm.definition.property.diagram.Package();
        final org.kie.workbench.common.stunner.cm.definition.property.diagram.Package t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Package", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.cm.definition.property.diagram.Package) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Package", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.cm.definition.property.diagram.Package.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy((org.kie.workbench.common.stunner.cm.definition.property.diagram.Package) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_property_diagram_PackageProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy extends MessageEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<MessageEventExecutionSet> agent;
      private MessageEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy() {
        this(new MessageEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy(MessageEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<MessageEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("messageRef", new PropertyType(MessageRef.class, true, false));
        p.put("this", new PropertyType(MessageEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MessageEventExecutionSet unwrap() {
        return target;
      }

      public MessageEventExecutionSet deepUnwrap() {
        final MessageEventExecutionSet clone = new MessageEventExecutionSet();
        final MessageEventExecutionSet t = unwrap();
        if (t.getMessageRef() instanceof BindableProxy) {
          clone.setMessageRef((MessageRef) ((BindableProxy) getMessageRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMessageRef())) {
          clone.setMessageRef((MessageRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMessageRef())).deepUnwrap());
        } else {
          clone.setMessageRef(t.getMessageRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public MessageRef getMessageRef() {
        return target.getMessageRef();
      }

      public void setMessageRef(MessageRef messageRef) {
        if (agent.binders.containsKey("messageRef")) {
          messageRef = (MessageRef) agent.binders.get("messageRef").setModel(messageRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("messageRef", messageRef);
      }

      public Object get(String property) {
        switch (property) {
          case "messageRef": return getMessageRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("MessageEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "messageRef": target.setMessageRef((MessageRef) value);
          break;
          case "this": target = (MessageEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MessageEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MessageEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy((MessageEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_message_MessageEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy extends TaskName implements BindableProxy {
      private BindableProxyAgent<TaskName> agent;
      private TaskName target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy() {
        this(new TaskName());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy(TaskName targetVal) {
        agent = new BindableProxyAgent<TaskName>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TaskName.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TaskName unwrap() {
        return target;
      }

      public TaskName deepUnwrap() {
        final TaskName clone = new TaskName();
        final TaskName t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("TaskName", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (TaskName) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TaskName", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TaskName.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy((TaskName) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_TaskNameProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy extends org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow> agent;
      private org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow target;
      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow());
      }

      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy(org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("variableType", new PropertyType(VariableType.class, false, false));
        p.put("processVar", new PropertyType(String.class, false, false));
        p.put("constant", new PropertyType(String.class, false, false));
        p.put("dataType", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("customDataType", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("complete", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow clone = new org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow();
        final org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow t = unwrap();
        clone.setVariableType(t.getVariableType());
        clone.setProcessVar(t.getProcessVar());
        clone.setConstant(t.getConstant());
        clone.setDataType(t.getDataType());
        clone.setName(t.getName());
        clone.setCustomDataType(t.getCustomDataType());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public VariableType getVariableType() {
        return target.getVariableType();
      }

      public void setVariableType(VariableType variableType) {
        changeAndFire("variableType", variableType);
      }

      public String getProcessVar() {
        return target.getProcessVar();
      }

      public void setProcessVar(String processVar) {
        changeAndFire("processVar", processVar);
      }

      public String getConstant() {
        return target.getConstant();
      }

      public void setConstant(String constant) {
        changeAndFire("constant", constant);
      }

      public String getDataType() {
        return target.getDataType();
      }

      public void setDataType(String dataType) {
        changeAndFire("dataType", dataType);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getCustomDataType() {
        return target.getCustomDataType();
      }

      public void setCustomDataType(String customDataType) {
        changeAndFire("customDataType", customDataType);
      }

      public long getId() {
        return target.getId();
      }

      public void setId(long id) {
        changeAndFire("id", id);
      }

      public boolean isComplete() {
        return target.isComplete();
      }

      public Object get(String property) {
        switch (property) {
          case "variableType": return getVariableType();
          case "processVar": return getProcessVar();
          case "constant": return getConstant();
          case "dataType": return getDataType();
          case "name": return getName();
          case "customDataType": return getCustomDataType();
          case "id": return getId();
          case "complete": return isComplete();
          case "this": return target;
          default: throw new NonExistingPropertyException("AssignmentRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "variableType": target.setVariableType((VariableType) value);
          break;
          case "processVar": target.setProcessVar((String) value);
          break;
          case "constant": target.setConstant((String) value);
          break;
          case "dataType": target.setDataType((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "customDataType": target.setCustomDataType((String) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AssignmentRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy((org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_AssignmentRowProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy extends Subject implements BindableProxy {
      private BindableProxyAgent<Subject> agent;
      private Subject target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy() {
        this(new Subject());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy(Subject targetVal) {
        agent = new BindableProxyAgent<Subject>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Subject.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Subject unwrap() {
        return target;
      }

      public Subject deepUnwrap() {
        final Subject clone = new Subject();
        final Subject t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Subject", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Subject) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Subject", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Subject.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy((Subject) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_SubjectProxy();
      }
    });
    class org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy extends DocumentationLinksFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DocumentationLinksFieldDefinition> agent;
      private DocumentationLinksFieldDefinition target;
      public org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy() {
        this(new DocumentationLinksFieldDefinition());
      }

      public org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy(DocumentationLinksFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DocumentationLinksFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(DocumentationLinksFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DocumentationLinksFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DocumentationLinksFieldDefinition unwrap() {
        return target;
      }

      public DocumentationLinksFieldDefinition deepUnwrap() {
        final DocumentationLinksFieldDefinition clone = new DocumentationLinksFieldDefinition();
        final DocumentationLinksFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public DocumentationLinksFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("DocumentationLinksFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (DocumentationLinksFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DocumentationLinksFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DocumentationLinksFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy((DocumentationLinksFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_client_property_dmn_DocumentationLinksFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy extends DecisionName implements BindableProxy {
      private BindableProxyAgent<DecisionName> agent;
      private DecisionName target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy() {
        this(new DecisionName());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy(DecisionName targetVal) {
        agent = new BindableProxyAgent<DecisionName>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(DecisionName.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecisionName unwrap() {
        return target;
      }

      public DecisionName deepUnwrap() {
        final DecisionName clone = new DecisionName();
        final DecisionName t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecisionName", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (DecisionName) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecisionName", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DecisionName.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy((DecisionName) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_DecisionNameProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy extends TableColumnMeta implements BindableProxy {
      private BindableProxyAgent<TableColumnMeta> agent;
      private TableColumnMeta target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy() {
        this(new TableColumnMeta());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy(TableColumnMeta targetVal) {
        agent = new BindableProxyAgent<TableColumnMeta>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("property", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TableColumnMeta.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TableColumnMeta unwrap() {
        return target;
      }

      public TableColumnMeta deepUnwrap() {
        final TableColumnMeta clone = new TableColumnMeta();
        final TableColumnMeta t = unwrap();
        clone.setProperty(t.getProperty());
        clone.setLabel(t.getLabel());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getProperty() {
        return target.getProperty();
      }

      public void setProperty(String property) {
        changeAndFire("property", property);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Object get(String property) {
        switch (property) {
          case "property": return getProperty();
          case "label": return getLabel();
          case "this": return target;
          default: throw new NonExistingPropertyException("TableColumnMeta", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "property": target.setProperty((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "this": target = (TableColumnMeta) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TableColumnMeta", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(TableColumnMeta.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy((TableColumnMeta) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_relations_TableColumnMetaProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_background_BgColourProxy extends BgColour implements BindableProxy {
      private BindableProxyAgent<BgColour> agent;
      private BgColour target;
      public org_kie_workbench_common_dmn_api_property_background_BgColourProxy() {
        this(new BgColour());
      }

      public org_kie_workbench_common_dmn_api_property_background_BgColourProxy(BgColour targetVal) {
        agent = new BindableProxyAgent<BgColour>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(BgColour.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public BgColour unwrap() {
        return target;
      }

      public BgColour deepUnwrap() {
        final BgColour clone = new BgColour();
        final BgColour t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_background_BgColourProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_background_BgColourProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("BgColour", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (BgColour) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BgColour", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(BgColour.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_background_BgColourProxy((BgColour) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_background_BgColourProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy extends org.kie.workbench.common.stunner.bpmn.definition.UserTask implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.UserTask> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.UserTask target;
      public org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.UserTask());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy(org.kie.workbench.common.stunner.bpmn.definition.UserTask targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.UserTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.UserTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.UserTask unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.UserTask deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.UserTask clone = new org.kie.workbench.common.stunner.bpmn.definition.UserTask();
        final org.kie.workbench.common.stunner.bpmn.definition.UserTask t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("UserTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.UserTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("UserTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.UserTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy((org.kie.workbench.common.stunner.bpmn.definition.UserTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_UserTaskProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy(org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize clone = new org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize();
        final org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontSize", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontSize", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy((org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSize) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontSizeProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy extends CancellingErrorEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CancellingErrorEventExecutionSet> agent;
      private CancellingErrorEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy() {
        this(new CancellingErrorEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy(CancellingErrorEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CancellingErrorEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("errorRef", new PropertyType(ErrorRef.class, true, false));
        p.put("this", new PropertyType(CancellingErrorEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancellingErrorEventExecutionSet unwrap() {
        return target;
      }

      public CancellingErrorEventExecutionSet deepUnwrap() {
        final CancellingErrorEventExecutionSet clone = new CancellingErrorEventExecutionSet();
        final CancellingErrorEventExecutionSet t = unwrap();
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getErrorRef() instanceof BindableProxy) {
          clone.setErrorRef((ErrorRef) ((BindableProxy) getErrorRef()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getErrorRef())) {
          clone.setErrorRef((ErrorRef) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getErrorRef())).deepUnwrap());
        } else {
          clone.setErrorRef(t.getErrorRef());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public ErrorRef getErrorRef() {
        return target.getErrorRef();
      }

      public void setErrorRef(ErrorRef errorRef) {
        if (agent.binders.containsKey("errorRef")) {
          errorRef = (ErrorRef) agent.binders.get("errorRef").setModel(errorRef, StateSync.FROM_MODEL, true);
        }
        changeAndFire("errorRef", errorRef);
      }

      public Object get(String property) {
        switch (property) {
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "errorRef": return getErrorRef();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancellingErrorEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "errorRef": target.setErrorRef((ErrorRef) value);
          break;
          case "this": target = (CancellingErrorEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancellingErrorEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancellingErrorEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy((CancellingErrorEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_error_CancellingErrorEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy extends EscalationRef implements BindableProxy {
      private BindableProxyAgent<EscalationRef> agent;
      private EscalationRef target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy() {
        this(new EscalationRef());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy(EscalationRef targetVal) {
        agent = new BindableProxyAgent<EscalationRef>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(EscalationRef.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EscalationRef unwrap() {
        return target;
      }

      public EscalationRef deepUnwrap() {
        final EscalationRef clone = new EscalationRef();
        final EscalationRef t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("EscalationRef", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (EscalationRef) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EscalationRef", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(EscalationRef.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy((EscalationRef) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_escalation_EscalationRefProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy extends NotificationRow implements BindableProxy {
      private BindableProxyAgent<NotificationRow> agent;
      private NotificationRow target;
      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy() {
        this(new NotificationRow());
      }

      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy(NotificationRow targetVal) {
        agent = new BindableProxyAgent<NotificationRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("subject", new PropertyType(String.class, false, false));
        p.put("replyTo", new PropertyType(String.class, false, false));
        p.put("groups", new PropertyType(List.class, false, true));
        p.put("from", new PropertyType(String.class, false, false));
        p.put("expiration", new PropertyType(Expiration.class, false, false));
        p.put("id", new PropertyType(Long.class, false, false));
        p.put("body", new PropertyType(String.class, false, false));
        p.put("type", new PropertyType(NotificationType.class, false, false));
        p.put("expiresAt", new PropertyType(String.class, false, false));
        p.put("users", new PropertyType(List.class, false, true));
        p.put("this", new PropertyType(NotificationRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NotificationRow unwrap() {
        return target;
      }

      public NotificationRow deepUnwrap() {
        final NotificationRow clone = new NotificationRow();
        final NotificationRow t = unwrap();
        clone.setSubject(t.getSubject());
        clone.setReplyTo(t.getReplyTo());
        if (t.getGroups() != null) {
          final List groupsClone = new ArrayList();
          for (Object groupsElem : t.getGroups()) {
            if (groupsElem instanceof BindableProxy) {
              groupsClone.add(((BindableProxy) groupsElem).deepUnwrap());
            } else {
              groupsClone.add(groupsElem);
            }
          }
          clone.setGroups(groupsClone);
        }
        clone.setFrom(t.getFrom());
        clone.setExpiration(t.getExpiration());
        clone.setId(t.getId());
        clone.setBody(t.getBody());
        clone.setType(t.getType());
        clone.setExpiresAt(t.getExpiresAt());
        if (t.getUsers() != null) {
          final List usersClone = new ArrayList();
          for (Object usersElem : t.getUsers()) {
            if (usersElem instanceof BindableProxy) {
              usersClone.add(((BindableProxy) usersElem).deepUnwrap());
            } else {
              usersClone.add(usersElem);
            }
          }
          clone.setUsers(usersClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getSubject() {
        return target.getSubject();
      }

      public void setSubject(String subject) {
        changeAndFire("subject", subject);
      }

      public String getReplyTo() {
        return target.getReplyTo();
      }

      public void setReplyTo(String replyTo) {
        changeAndFire("replyTo", replyTo);
      }

      public List getGroups() {
        return target.getGroups();
      }

      public void setGroups(List<String> groups) {
        List<String> oldValue = target.getGroups();
        groups = agent.ensureBoundListIsProxied("groups", groups);
        target.setGroups(groups);
        agent.updateWidgetsAndFireEvent(true, "groups", oldValue, groups);
      }

      public String getFrom() {
        return target.getFrom();
      }

      public void setFrom(String from) {
        changeAndFire("from", from);
      }

      public Expiration getExpiration() {
        return target.getExpiration();
      }

      public void setExpiration(Expiration expiration) {
        changeAndFire("expiration", expiration);
      }

      public long getId() {
        return target.getId();
      }

      public void setId(long id) {
        changeAndFire("id", id);
      }

      public String getBody() {
        return target.getBody();
      }

      public void setBody(String body) {
        changeAndFire("body", body);
      }

      public NotificationType getType() {
        return target.getType();
      }

      public void setType(NotificationType type) {
        changeAndFire("type", type);
      }

      public String getExpiresAt() {
        return target.getExpiresAt();
      }

      public void setExpiresAt(String expiresAt) {
        changeAndFire("expiresAt", expiresAt);
      }

      public List getUsers() {
        return target.getUsers();
      }

      public void setUsers(List<String> users) {
        List<String> oldValue = target.getUsers();
        users = agent.ensureBoundListIsProxied("users", users);
        target.setUsers(users);
        agent.updateWidgetsAndFireEvent(true, "users", oldValue, users);
      }

      public Object get(String property) {
        switch (property) {
          case "subject": return getSubject();
          case "replyTo": return getReplyTo();
          case "groups": return getGroups();
          case "from": return getFrom();
          case "expiration": return getExpiration();
          case "id": return getId();
          case "body": return getBody();
          case "type": return getType();
          case "expiresAt": return getExpiresAt();
          case "users": return getUsers();
          case "this": return target;
          default: throw new NonExistingPropertyException("NotificationRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "subject": target.setSubject((String) value);
          break;
          case "replyTo": target.setReplyTo((String) value);
          break;
          case "groups": target.setGroups((List<String>) value);
          break;
          case "from": target.setFrom((String) value);
          break;
          case "expiration": target.setExpiration((Expiration) value);
          break;
          case "id": target.setId((Long) value);
          break;
          case "body": target.setBody((String) value);
          break;
          case "type": target.setType((NotificationType) value);
          break;
          case "expiresAt": target.setExpiresAt((String) value);
          break;
          case "users": target.setUsers((List<String>) value);
          break;
          case "this": target = (NotificationRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NotificationRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public NotificationValue toNotificationValue() {
        final NotificationValue returnValue = target.toNotificationValue();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public NotificationRow clone() {
        final NotificationRow returnValue = target.clone();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(NotificationRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy((NotificationRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_NotificationRowProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy extends ReassignmentSet implements BindableProxy {
      private BindableProxyAgent<ReassignmentSet> agent;
      private ReassignmentSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy() {
        this(new ReassignmentSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy(ReassignmentSet targetVal) {
        agent = new BindableProxyAgent<ReassignmentSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("reassignmentsInfo", new PropertyType(ReassignmentsInfo.class, true, false));
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("this", new PropertyType(ReassignmentSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReassignmentSet unwrap() {
        return target;
      }

      public ReassignmentSet deepUnwrap() {
        final ReassignmentSet clone = new ReassignmentSet();
        final ReassignmentSet t = unwrap();
        if (t.getReassignmentsInfo() instanceof BindableProxy) {
          clone.setReassignmentsInfo((ReassignmentsInfo) ((BindableProxy) getReassignmentsInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getReassignmentsInfo())) {
          clone.setReassignmentsInfo((ReassignmentsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getReassignmentsInfo())).deepUnwrap());
        } else {
          clone.setReassignmentsInfo(t.getReassignmentsInfo());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public ReassignmentsInfo getReassignmentsInfo() {
        return target.getReassignmentsInfo();
      }

      public void setReassignmentsInfo(ReassignmentsInfo reassignmentsInfo) {
        if (agent.binders.containsKey("reassignmentsInfo")) {
          reassignmentsInfo = (ReassignmentsInfo) agent.binders.get("reassignmentsInfo").setModel(reassignmentsInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("reassignmentsInfo", reassignmentsInfo);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public Object get(String property) {
        switch (property) {
          case "reassignmentsInfo": return getReassignmentsInfo();
          case "type": return getType();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReassignmentSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "reassignmentsInfo": target.setReassignmentsInfo((ReassignmentsInfo) value);
          break;
          case "this": target = (ReassignmentSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReassignmentSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ReassignmentSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy((ReassignmentSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy extends ServiceTaskExecutionSet implements BindableProxy {
      private BindableProxyAgent<ServiceTaskExecutionSet> agent;
      private ServiceTaskExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy() {
        this(new ServiceTaskExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy(ServiceTaskExecutionSet targetVal) {
        agent = new BindableProxyAgent<ServiceTaskExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("adHocAutostart", new PropertyType(AdHocAutostart.class, true, false));
        p.put("isAsync", new PropertyType(IsAsync.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("taskName", new PropertyType(TaskName.class, true, false));
        p.put("onExitAction", new PropertyType(OnExitAction.class, true, false));
        p.put("onEntryAction", new PropertyType(OnEntryAction.class, true, false));
        p.put("this", new PropertyType(ServiceTaskExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ServiceTaskExecutionSet unwrap() {
        return target;
      }

      public ServiceTaskExecutionSet deepUnwrap() {
        final ServiceTaskExecutionSet clone = new ServiceTaskExecutionSet();
        final ServiceTaskExecutionSet t = unwrap();
        if (t.getAdHocAutostart() instanceof BindableProxy) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) getAdHocAutostart()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAdHocAutostart())) {
          clone.setAdHocAutostart((AdHocAutostart) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAdHocAutostart())).deepUnwrap());
        } else {
          clone.setAdHocAutostart(t.getAdHocAutostart());
        }
        if (t.getIsAsync() instanceof BindableProxy) {
          clone.setIsAsync((IsAsync) ((BindableProxy) getIsAsync()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getIsAsync())) {
          clone.setIsAsync((IsAsync) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getIsAsync())).deepUnwrap());
        } else {
          clone.setIsAsync(t.getIsAsync());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        if (t.getTaskName() instanceof BindableProxy) {
          clone.setTaskName((TaskName) ((BindableProxy) getTaskName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskName())) {
          clone.setTaskName((TaskName) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskName())).deepUnwrap());
        } else {
          clone.setTaskName(t.getTaskName());
        }
        if (t.getOnExitAction() instanceof BindableProxy) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) getOnExitAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnExitAction())) {
          clone.setOnExitAction((OnExitAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnExitAction())).deepUnwrap());
        } else {
          clone.setOnExitAction(t.getOnExitAction());
        }
        if (t.getOnEntryAction() instanceof BindableProxy) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) getOnEntryAction()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getOnEntryAction())) {
          clone.setOnEntryAction((OnEntryAction) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getOnEntryAction())).deepUnwrap());
        } else {
          clone.setOnEntryAction(t.getOnEntryAction());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public AdHocAutostart getAdHocAutostart() {
        return target.getAdHocAutostart();
      }

      public void setAdHocAutostart(AdHocAutostart adHocAutostart) {
        if (agent.binders.containsKey("adHocAutostart")) {
          adHocAutostart = (AdHocAutostart) agent.binders.get("adHocAutostart").setModel(adHocAutostart, StateSync.FROM_MODEL, true);
        }
        changeAndFire("adHocAutostart", adHocAutostart);
      }

      public IsAsync getIsAsync() {
        return target.getIsAsync();
      }

      public void setIsAsync(IsAsync isAsync) {
        if (agent.binders.containsKey("isAsync")) {
          isAsync = (IsAsync) agent.binders.get("isAsync").setModel(isAsync, StateSync.FROM_MODEL, true);
        }
        changeAndFire("isAsync", isAsync);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public TaskName getTaskName() {
        return target.getTaskName();
      }

      public void setTaskName(TaskName taskName) {
        if (agent.binders.containsKey("taskName")) {
          taskName = (TaskName) agent.binders.get("taskName").setModel(taskName, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskName", taskName);
      }

      public OnExitAction getOnExitAction() {
        return target.getOnExitAction();
      }

      public void setOnExitAction(OnExitAction onExitAction) {
        if (agent.binders.containsKey("onExitAction")) {
          onExitAction = (OnExitAction) agent.binders.get("onExitAction").setModel(onExitAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onExitAction", onExitAction);
      }

      public OnEntryAction getOnEntryAction() {
        return target.getOnEntryAction();
      }

      public void setOnEntryAction(OnEntryAction onEntryAction) {
        if (agent.binders.containsKey("onEntryAction")) {
          onEntryAction = (OnEntryAction) agent.binders.get("onEntryAction").setModel(onEntryAction, StateSync.FROM_MODEL, true);
        }
        changeAndFire("onEntryAction", onEntryAction);
      }

      public Object get(String property) {
        switch (property) {
          case "adHocAutostart": return getAdHocAutostart();
          case "isAsync": return getIsAsync();
          case "slaDueDate": return getSlaDueDate();
          case "taskName": return getTaskName();
          case "onExitAction": return getOnExitAction();
          case "onEntryAction": return getOnEntryAction();
          case "this": return target;
          default: throw new NonExistingPropertyException("ServiceTaskExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "adHocAutostart": target.setAdHocAutostart((AdHocAutostart) value);
          break;
          case "isAsync": target.setIsAsync((IsAsync) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "taskName": target.setTaskName((TaskName) value);
          break;
          case "onExitAction": target.setOnExitAction((OnExitAction) value);
          break;
          case "onEntryAction": target.setOnEntryAction((OnEntryAction) value);
          break;
          case "this": target = (ServiceTaskExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ServiceTaskExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ServiceTaskExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy((ServiceTaskExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_workitem_ServiceTaskExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy extends Package implements BindableProxy {
      private BindableProxyAgent<Package> agent;
      private Package target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy() {
        this(new Package());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy(Package targetVal) {
        agent = new BindableProxyAgent<Package>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Package.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Package unwrap() {
        return target;
      }

      public Package deepUnwrap() {
        final Package clone = new Package();
        final Package t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Package", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (Package) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Package", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Package.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy((Package) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_PackageProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy extends ScriptTask implements BindableProxy {
      private BindableProxyAgent<ScriptTask> agent;
      private ScriptTask target;
      public org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy() {
        this(new ScriptTask());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy(ScriptTask targetVal) {
        agent = new BindableProxyAgent<ScriptTask>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(TaskGeneralSet.class, true, false));
        p.put("taskType", new PropertyType(TaskType.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(ScriptTaskExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(ScriptTask.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ScriptTask unwrap() {
        return target;
      }

      public ScriptTask deepUnwrap() {
        final ScriptTask clone = new ScriptTask();
        final ScriptTask t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((TaskGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getTaskType() instanceof BindableProxy) {
          clone.setTaskType((TaskType) ((BindableProxy) getTaskType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTaskType())) {
          clone.setTaskType((TaskType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTaskType())).deepUnwrap());
        } else {
          clone.setTaskType(t.getTaskType());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ScriptTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ScriptTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public TaskGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(TaskGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (TaskGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public TaskType getTaskType() {
        return target.getTaskType();
      }

      public void setTaskType(TaskType taskType) {
        if (agent.binders.containsKey("taskType")) {
          taskType = (TaskType) agent.binders.get("taskType").setModel(taskType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("taskType", taskType);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public ScriptTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ScriptTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ScriptTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "taskType": return getTaskType();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("ScriptTask", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((TaskGeneralSet) value);
          break;
          case "taskType": target.setTaskType((TaskType) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((ScriptTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (ScriptTask) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ScriptTask", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ScriptTask.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy((ScriptTask) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_ScriptTaskProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy extends IntegerSelectorOption implements BindableProxy {
      private BindableProxyAgent<IntegerSelectorOption> agent;
      private IntegerSelectorOption target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy() {
        this(new IntegerSelectorOption());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy(IntegerSelectorOption targetVal) {
        agent = new BindableProxyAgent<IntegerSelectorOption>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("text", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(Long.class, false, false));
        p.put("this", new PropertyType(IntegerSelectorOption.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IntegerSelectorOption unwrap() {
        return target;
      }

      public IntegerSelectorOption deepUnwrap() {
        final IntegerSelectorOption clone = new IntegerSelectorOption();
        final IntegerSelectorOption t = unwrap();
        clone.setText(t.getText());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public Long getValue() {
        return target.getValue();
      }

      public void setValue(Long value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "text": return getText();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("IntegerSelectorOption", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "text": target.setText((String) value);
          break;
          case "value": target.setValue((Long) value);
          break;
          case "this": target = (IntegerSelectorOption) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IntegerSelectorOption", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(IntegerSelectorOption.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy((IntegerSelectorOption) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_IntegerSelectorOptionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy extends ReassignmentTypeListValue implements BindableProxy {
      private BindableProxyAgent<ReassignmentTypeListValue> agent;
      private ReassignmentTypeListValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy() {
        this(new ReassignmentTypeListValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy(ReassignmentTypeListValue targetVal) {
        agent = new BindableProxyAgent<ReassignmentTypeListValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("values", new PropertyType(List.class, false, true));
        p.put("empty", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(ReassignmentTypeListValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReassignmentTypeListValue unwrap() {
        return target;
      }

      public ReassignmentTypeListValue deepUnwrap() {
        final ReassignmentTypeListValue clone = new ReassignmentTypeListValue();
        final ReassignmentTypeListValue t = unwrap();
        if (t.getValues() != null) {
          final List valuesClone = new ArrayList();
          for (Object valuesElem : t.getValues()) {
            if (valuesElem instanceof BindableProxy) {
              valuesClone.add(((BindableProxy) valuesElem).deepUnwrap());
            } else {
              valuesClone.add(valuesElem);
            }
          }
          clone.setValues(valuesClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public List getValues() {
        return target.getValues();
      }

      public void setValues(List<ReassignmentValue> values) {
        List<ReassignmentValue> oldValue = target.getValues();
        values = agent.ensureBoundListIsProxied("values", values);
        target.setValues(values);
        agent.updateWidgetsAndFireEvent(true, "values", oldValue, values);
      }

      public boolean isEmpty() {
        return target.isEmpty();
      }

      public Object get(String property) {
        switch (property) {
          case "values": return getValues();
          case "empty": return isEmpty();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReassignmentTypeListValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "values": target.setValues((List<ReassignmentValue>) value);
          break;
          case "this": target = (ReassignmentTypeListValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReassignmentTypeListValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public ReassignmentTypeListValue addValue(ReassignmentValue a0) {
        final ReassignmentTypeListValue returnValue = target.addValue(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ReassignmentTypeListValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy((ReassignmentTypeListValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_reassignment_ReassignmentTypeListValueProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy extends CreatedBy implements BindableProxy {
      private BindableProxyAgent<CreatedBy> agent;
      private CreatedBy target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy() {
        this(new CreatedBy());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy(CreatedBy targetVal) {
        agent = new BindableProxyAgent<CreatedBy>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CreatedBy.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CreatedBy unwrap() {
        return target;
      }

      public CreatedBy deepUnwrap() {
        final CreatedBy clone = new CreatedBy();
        final CreatedBy t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("CreatedBy", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (CreatedBy) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CreatedBy", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CreatedBy.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy((CreatedBy) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_CreatedByProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy(org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize clone = new org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize();
        final org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("BorderSize", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("BorderSize", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy((org.kie.workbench.common.stunner.bpmn.definition.property.background.BorderSize) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_background_BorderSizeProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy extends AuthorityRequirement implements BindableProxy {
      private BindableProxyAgent<AuthorityRequirement> agent;
      private AuthorityRequirement target;
      public org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy() {
        this(new AuthorityRequirement());
      }

      public org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy(AuthorityRequirement targetVal) {
        agent = new BindableProxyAgent<AuthorityRequirement>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(AuthorityRequirement.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public AuthorityRequirement unwrap() {
        return target;
      }

      public AuthorityRequirement deepUnwrap() {
        final AuthorityRequirement clone = new AuthorityRequirement();
        final AuthorityRequirement t = unwrap();
        clone.setParent(t.getParent());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "nsContext": return getNsContext();
          case "stunnerLabels": return getStunnerLabels();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("AuthorityRequirement", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (AuthorityRequirement) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("AuthorityRequirement", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(AuthorityRequirement.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy((AuthorityRequirement) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_AuthorityRequirementProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy extends DefaultSelectorOption implements BindableProxy {
      private BindableProxyAgent<DefaultSelectorOption> agent;
      private DefaultSelectorOption target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy() {
        this(new DefaultSelectorOption());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy(DefaultSelectorOption targetVal) {
        agent = new BindableProxyAgent<DefaultSelectorOption>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("text", new PropertyType(String.class, false, false));
        p.put("value", new PropertyType(Object.class, false, false));
        p.put("this", new PropertyType(DefaultSelectorOption.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DefaultSelectorOption unwrap() {
        return target;
      }

      public DefaultSelectorOption deepUnwrap() {
        final DefaultSelectorOption clone = new DefaultSelectorOption();
        final DefaultSelectorOption t = unwrap();
        clone.setText(t.getText());
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getText() {
        return target.getText();
      }

      public void setText(String text) {
        changeAndFire("text", text);
      }

      public Object getValue() {
        return target.getValue();
      }

      public void setValue(Object value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "text": return getText();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("DefaultSelectorOption", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "text": target.setText((String) value);
          break;
          case "value": target.setValue(value);
          break;
          case "this": target = (DefaultSelectorOption) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DefaultSelectorOption", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(DefaultSelectorOption.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy((DefaultSelectorOption) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_DefaultSelectorOptionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy extends EndTerminateEvent implements BindableProxy {
      private BindableProxyAgent<EndTerminateEvent> agent;
      private EndTerminateEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy() {
        this(new EndTerminateEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy(EndTerminateEvent targetVal) {
        agent = new BindableProxyAgent<EndTerminateEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndTerminateEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndTerminateEvent unwrap() {
        return target;
      }

      public EndTerminateEvent deepUnwrap() {
        final EndTerminateEvent clone = new EndTerminateEvent();
        final EndTerminateEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndTerminateEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndTerminateEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndTerminateEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndTerminateEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy((EndTerminateEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndTerminateEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy extends SimulationSet implements BindableProxy {
      private BindableProxyAgent<SimulationSet> agent;
      private SimulationSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy() {
        this(new SimulationSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy(SimulationSet targetVal) {
        agent = new BindableProxyAgent<SimulationSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("min", new PropertyType(Min.class, true, false));
        p.put("distributionType", new PropertyType(DistributionType.class, true, false));
        p.put("quantity", new PropertyType(Quantity.class, true, false));
        p.put("max", new PropertyType(Max.class, true, false));
        p.put("mean", new PropertyType(Mean.class, true, false));
        p.put("unitCost", new PropertyType(UnitCost.class, true, false));
        p.put("currency", new PropertyType(Currency.class, true, false));
        p.put("workingHours", new PropertyType(WorkingHours.class, true, false));
        p.put("standardDeviation", new PropertyType(StandardDeviation.class, true, false));
        p.put("timeUnit", new PropertyType(TimeUnit.class, true, false));
        p.put("this", new PropertyType(SimulationSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SimulationSet unwrap() {
        return target;
      }

      public SimulationSet deepUnwrap() {
        final SimulationSet clone = new SimulationSet();
        final SimulationSet t = unwrap();
        if (t.getMin() instanceof BindableProxy) {
          clone.setMin((Min) ((BindableProxy) getMin()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMin())) {
          clone.setMin((Min) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMin())).deepUnwrap());
        } else {
          clone.setMin(t.getMin());
        }
        if (t.getDistributionType() instanceof BindableProxy) {
          clone.setDistributionType((DistributionType) ((BindableProxy) getDistributionType()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDistributionType())) {
          clone.setDistributionType((DistributionType) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDistributionType())).deepUnwrap());
        } else {
          clone.setDistributionType(t.getDistributionType());
        }
        if (t.getQuantity() instanceof BindableProxy) {
          clone.setQuantity((Quantity) ((BindableProxy) getQuantity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getQuantity())) {
          clone.setQuantity((Quantity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getQuantity())).deepUnwrap());
        } else {
          clone.setQuantity(t.getQuantity());
        }
        if (t.getMax() instanceof BindableProxy) {
          clone.setMax((Max) ((BindableProxy) getMax()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMax())) {
          clone.setMax((Max) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMax())).deepUnwrap());
        } else {
          clone.setMax(t.getMax());
        }
        if (t.getMean() instanceof BindableProxy) {
          clone.setMean((Mean) ((BindableProxy) getMean()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getMean())) {
          clone.setMean((Mean) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getMean())).deepUnwrap());
        } else {
          clone.setMean(t.getMean());
        }
        if (t.getUnitCost() instanceof BindableProxy) {
          clone.setUnitCost((UnitCost) ((BindableProxy) getUnitCost()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getUnitCost())) {
          clone.setUnitCost((UnitCost) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getUnitCost())).deepUnwrap());
        } else {
          clone.setUnitCost(t.getUnitCost());
        }
        if (t.getCurrency() instanceof BindableProxy) {
          clone.setCurrency((Currency) ((BindableProxy) getCurrency()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCurrency())) {
          clone.setCurrency((Currency) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCurrency())).deepUnwrap());
        } else {
          clone.setCurrency(t.getCurrency());
        }
        if (t.getWorkingHours() instanceof BindableProxy) {
          clone.setWorkingHours((WorkingHours) ((BindableProxy) getWorkingHours()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getWorkingHours())) {
          clone.setWorkingHours((WorkingHours) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getWorkingHours())).deepUnwrap());
        } else {
          clone.setWorkingHours(t.getWorkingHours());
        }
        if (t.getStandardDeviation() instanceof BindableProxy) {
          clone.setStandardDeviation((StandardDeviation) ((BindableProxy) getStandardDeviation()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getStandardDeviation())) {
          clone.setStandardDeviation((StandardDeviation) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getStandardDeviation())).deepUnwrap());
        } else {
          clone.setStandardDeviation(t.getStandardDeviation());
        }
        if (t.getTimeUnit() instanceof BindableProxy) {
          clone.setTimeUnit((TimeUnit) ((BindableProxy) getTimeUnit()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTimeUnit())) {
          clone.setTimeUnit((TimeUnit) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTimeUnit())).deepUnwrap());
        } else {
          clone.setTimeUnit(t.getTimeUnit());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Min getMin() {
        return target.getMin();
      }

      public void setMin(Min min) {
        if (agent.binders.containsKey("min")) {
          min = (Min) agent.binders.get("min").setModel(min, StateSync.FROM_MODEL, true);
        }
        changeAndFire("min", min);
      }

      public DistributionType getDistributionType() {
        return target.getDistributionType();
      }

      public void setDistributionType(DistributionType distributionType) {
        if (agent.binders.containsKey("distributionType")) {
          distributionType = (DistributionType) agent.binders.get("distributionType").setModel(distributionType, StateSync.FROM_MODEL, true);
        }
        changeAndFire("distributionType", distributionType);
      }

      public Quantity getQuantity() {
        return target.getQuantity();
      }

      public void setQuantity(Quantity quantity) {
        if (agent.binders.containsKey("quantity")) {
          quantity = (Quantity) agent.binders.get("quantity").setModel(quantity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("quantity", quantity);
      }

      public Max getMax() {
        return target.getMax();
      }

      public void setMax(Max max) {
        if (agent.binders.containsKey("max")) {
          max = (Max) agent.binders.get("max").setModel(max, StateSync.FROM_MODEL, true);
        }
        changeAndFire("max", max);
      }

      public Mean getMean() {
        return target.getMean();
      }

      public void setMean(Mean mean) {
        if (agent.binders.containsKey("mean")) {
          mean = (Mean) agent.binders.get("mean").setModel(mean, StateSync.FROM_MODEL, true);
        }
        changeAndFire("mean", mean);
      }

      public UnitCost getUnitCost() {
        return target.getUnitCost();
      }

      public void setUnitCost(UnitCost unitCost) {
        if (agent.binders.containsKey("unitCost")) {
          unitCost = (UnitCost) agent.binders.get("unitCost").setModel(unitCost, StateSync.FROM_MODEL, true);
        }
        changeAndFire("unitCost", unitCost);
      }

      public Currency getCurrency() {
        return target.getCurrency();
      }

      public void setCurrency(Currency currency) {
        if (agent.binders.containsKey("currency")) {
          currency = (Currency) agent.binders.get("currency").setModel(currency, StateSync.FROM_MODEL, true);
        }
        changeAndFire("currency", currency);
      }

      public WorkingHours getWorkingHours() {
        return target.getWorkingHours();
      }

      public void setWorkingHours(WorkingHours workingHours) {
        if (agent.binders.containsKey("workingHours")) {
          workingHours = (WorkingHours) agent.binders.get("workingHours").setModel(workingHours, StateSync.FROM_MODEL, true);
        }
        changeAndFire("workingHours", workingHours);
      }

      public StandardDeviation getStandardDeviation() {
        return target.getStandardDeviation();
      }

      public void setStandardDeviation(StandardDeviation standardDeviation) {
        if (agent.binders.containsKey("standardDeviation")) {
          standardDeviation = (StandardDeviation) agent.binders.get("standardDeviation").setModel(standardDeviation, StateSync.FROM_MODEL, true);
        }
        changeAndFire("standardDeviation", standardDeviation);
      }

      public TimeUnit getTimeUnit() {
        return target.getTimeUnit();
      }

      public void setTimeUnit(TimeUnit timeUnit) {
        if (agent.binders.containsKey("timeUnit")) {
          timeUnit = (TimeUnit) agent.binders.get("timeUnit").setModel(timeUnit, StateSync.FROM_MODEL, true);
        }
        changeAndFire("timeUnit", timeUnit);
      }

      public Object get(String property) {
        switch (property) {
          case "min": return getMin();
          case "distributionType": return getDistributionType();
          case "quantity": return getQuantity();
          case "max": return getMax();
          case "mean": return getMean();
          case "unitCost": return getUnitCost();
          case "currency": return getCurrency();
          case "workingHours": return getWorkingHours();
          case "standardDeviation": return getStandardDeviation();
          case "timeUnit": return getTimeUnit();
          case "this": return target;
          default: throw new NonExistingPropertyException("SimulationSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "min": target.setMin((Min) value);
          break;
          case "distributionType": target.setDistributionType((DistributionType) value);
          break;
          case "quantity": target.setQuantity((Quantity) value);
          break;
          case "max": target.setMax((Max) value);
          break;
          case "mean": target.setMean((Mean) value);
          break;
          case "unitCost": target.setUnitCost((UnitCost) value);
          break;
          case "currency": target.setCurrency((Currency) value);
          break;
          case "workingHours": target.setWorkingHours((WorkingHours) value);
          break;
          case "standardDeviation": target.setStandardDeviation((StandardDeviation) value);
          break;
          case "timeUnit": target.setTimeUnit((TimeUnit) value);
          break;
          case "this": target = (SimulationSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SimulationSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SimulationSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy((SimulationSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_simulation_SimulationSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy extends EndSignalEvent implements BindableProxy {
      private BindableProxyAgent<EndSignalEvent> agent;
      private EndSignalEvent target;
      public org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy() {
        this(new EndSignalEvent());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy(EndSignalEvent targetVal) {
        agent = new BindableProxyAgent<EndSignalEvent>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("executionSet", new PropertyType(ScopedSignalEventExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(CircleDimensionSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(EndSignalEvent.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public EndSignalEvent unwrap() {
        return target;
      }

      public EndSignalEvent deepUnwrap() {
        final EndSignalEvent clone = new EndSignalEvent();
        final EndSignalEvent t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ScopedSignalEventExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ScopedSignalEventExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((CircleDimensionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public ScopedSignalEventExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ScopedSignalEventExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ScopedSignalEventExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public CircleDimensionSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(CircleDimensionSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (CircleDimensionSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "backgroundSet": return getBackgroundSet();
          case "singleInputVar": return isSingleInputVar();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("EndSignalEvent", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((ScopedSignalEventExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((CircleDimensionSet) value);
          break;
          case "this": target = (EndSignalEvent) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("EndSignalEvent", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(EndSignalEvent.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy((EndSignalEvent) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_EndSignalEventProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy extends ProcessInstanceDescription implements BindableProxy {
      private BindableProxyAgent<ProcessInstanceDescription> agent;
      private ProcessInstanceDescription target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy() {
        this(new ProcessInstanceDescription());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy(ProcessInstanceDescription targetVal) {
        agent = new BindableProxyAgent<ProcessInstanceDescription>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ProcessInstanceDescription.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessInstanceDescription unwrap() {
        return target;
      }

      public ProcessInstanceDescription deepUnwrap() {
        final ProcessInstanceDescription clone = new ProcessInstanceDescription();
        final ProcessInstanceDescription t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessInstanceDescription", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (ProcessInstanceDescription) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessInstanceDescription", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessInstanceDescription.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy((ProcessInstanceDescription) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_ProcessInstanceDescriptionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy extends CancellingTimerEventExecutionSet implements BindableProxy {
      private BindableProxyAgent<CancellingTimerEventExecutionSet> agent;
      private CancellingTimerEventExecutionSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy() {
        this(new CancellingTimerEventExecutionSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy(CancellingTimerEventExecutionSet targetVal) {
        agent = new BindableProxyAgent<CancellingTimerEventExecutionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("timerSettings", new PropertyType(TimerSettings.class, true, false));
        p.put("cancelActivity", new PropertyType(CancelActivity.class, true, false));
        p.put("slaDueDate", new PropertyType(SLADueDate.class, true, false));
        p.put("this", new PropertyType(CancellingTimerEventExecutionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CancellingTimerEventExecutionSet unwrap() {
        return target;
      }

      public CancellingTimerEventExecutionSet deepUnwrap() {
        final CancellingTimerEventExecutionSet clone = new CancellingTimerEventExecutionSet();
        final CancellingTimerEventExecutionSet t = unwrap();
        if (t.getTimerSettings() instanceof BindableProxy) {
          clone.setTimerSettings((TimerSettings) ((BindableProxy) getTimerSettings()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTimerSettings())) {
          clone.setTimerSettings((TimerSettings) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTimerSettings())).deepUnwrap());
        } else {
          clone.setTimerSettings(t.getTimerSettings());
        }
        if (t.getCancelActivity() instanceof BindableProxy) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) getCancelActivity()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getCancelActivity())) {
          clone.setCancelActivity((CancelActivity) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getCancelActivity())).deepUnwrap());
        } else {
          clone.setCancelActivity(t.getCancelActivity());
        }
        if (t.getSlaDueDate() instanceof BindableProxy) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) getSlaDueDate()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSlaDueDate())) {
          clone.setSlaDueDate((SLADueDate) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSlaDueDate())).deepUnwrap());
        } else {
          clone.setSlaDueDate(t.getSlaDueDate());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public TimerSettings getTimerSettings() {
        return target.getTimerSettings();
      }

      public void setTimerSettings(TimerSettings timerSettings) {
        if (agent.binders.containsKey("timerSettings")) {
          timerSettings = (TimerSettings) agent.binders.get("timerSettings").setModel(timerSettings, StateSync.FROM_MODEL, true);
        }
        changeAndFire("timerSettings", timerSettings);
      }

      public CancelActivity getCancelActivity() {
        return target.getCancelActivity();
      }

      public void setCancelActivity(CancelActivity cancelActivity) {
        if (agent.binders.containsKey("cancelActivity")) {
          cancelActivity = (CancelActivity) agent.binders.get("cancelActivity").setModel(cancelActivity, StateSync.FROM_MODEL, true);
        }
        changeAndFire("cancelActivity", cancelActivity);
      }

      public SLADueDate getSlaDueDate() {
        return target.getSlaDueDate();
      }

      public void setSlaDueDate(SLADueDate slaDueDate) {
        if (agent.binders.containsKey("slaDueDate")) {
          slaDueDate = (SLADueDate) agent.binders.get("slaDueDate").setModel(slaDueDate, StateSync.FROM_MODEL, true);
        }
        changeAndFire("slaDueDate", slaDueDate);
      }

      public Object get(String property) {
        switch (property) {
          case "timerSettings": return getTimerSettings();
          case "cancelActivity": return getCancelActivity();
          case "slaDueDate": return getSlaDueDate();
          case "this": return target;
          default: throw new NonExistingPropertyException("CancellingTimerEventExecutionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "timerSettings": target.setTimerSettings((TimerSettings) value);
          break;
          case "cancelActivity": target.setCancelActivity((CancelActivity) value);
          break;
          case "slaDueDate": target.setSlaDueDate((SLADueDate) value);
          break;
          case "this": target = (CancellingTimerEventExecutionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CancellingTimerEventExecutionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CancellingTimerEventExecutionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy((CancellingTimerEventExecutionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_timer_CancellingTimerEventExecutionSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy extends ProcessReusableSubprocess implements BindableProxy {
      private BindableProxyAgent<ProcessReusableSubprocess> agent;
      private ProcessReusableSubprocess target;
      public org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy() {
        this(new ProcessReusableSubprocess());
      }

      public org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy(ProcessReusableSubprocess targetVal) {
        agent = new BindableProxyAgent<ProcessReusableSubprocess>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("dataIOSet", new PropertyType(DataIOSet.class, true, false));
        p.put("simulationSet", new PropertyType(SimulationSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(ProcessReusableSubprocessTaskExecutionSet.class, true, false));
        p.put("singleInputVar", new PropertyType(Boolean.class, false, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("singleOutputVar", new PropertyType(Boolean.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(ProcessReusableSubprocess.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ProcessReusableSubprocess unwrap() {
        return target;
      }

      public ProcessReusableSubprocess deepUnwrap() {
        final ProcessReusableSubprocess clone = new ProcessReusableSubprocess();
        final ProcessReusableSubprocess t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getDataIOSet() instanceof BindableProxy) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) getDataIOSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDataIOSet())) {
          clone.setDataIOSet((DataIOSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDataIOSet())).deepUnwrap());
        } else {
          clone.setDataIOSet(t.getDataIOSet());
        }
        if (t.getSimulationSet() instanceof BindableProxy) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) getSimulationSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getSimulationSet())) {
          clone.setSimulationSet((SimulationSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getSimulationSet())).deepUnwrap());
        } else {
          clone.setSimulationSet(t.getSimulationSet());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((ProcessReusableSubprocessTaskExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((ProcessReusableSubprocessTaskExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public DataIOSet getDataIOSet() {
        return target.getDataIOSet();
      }

      public void setDataIOSet(DataIOSet dataIOSet) {
        if (agent.binders.containsKey("dataIOSet")) {
          dataIOSet = (DataIOSet) agent.binders.get("dataIOSet").setModel(dataIOSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dataIOSet", dataIOSet);
      }

      public SimulationSet getSimulationSet() {
        return target.getSimulationSet();
      }

      public void setSimulationSet(SimulationSet simulationSet) {
        if (agent.binders.containsKey("simulationSet")) {
          simulationSet = (SimulationSet) agent.binders.get("simulationSet").setModel(simulationSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("simulationSet", simulationSet);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public ProcessReusableSubprocessTaskExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(ProcessReusableSubprocessTaskExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (ProcessReusableSubprocessTaskExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public boolean isSingleInputVar() {
        return target.isSingleInputVar();
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public boolean isSingleOutputVar() {
        return target.isSingleOutputVar();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "dataIOSet": return getDataIOSet();
          case "simulationSet": return getSimulationSet();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "singleInputVar": return isSingleInputVar();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "singleOutputVar": return isSingleOutputVar();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("ProcessReusableSubprocess", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "dataIOSet": target.setDataIOSet((DataIOSet) value);
          break;
          case "simulationSet": target.setSimulationSet((SimulationSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((ProcessReusableSubprocessTaskExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (ProcessReusableSubprocess) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ProcessReusableSubprocess", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public boolean hasInputVars() {
        final boolean returnValue = target.hasInputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public boolean hasOutputVars() {
        final boolean returnValue = target.hasOutputVars();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(ProcessReusableSubprocess.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy((ProcessReusableSubprocess) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_definition_ProcessReusableSubprocessProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy extends SequenceFlow implements BindableProxy {
      private BindableProxyAgent<SequenceFlow> agent;
      private SequenceFlow target;
      public org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy() {
        this(new SequenceFlow());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy(SequenceFlow targetVal) {
        agent = new BindableProxyAgent<SequenceFlow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("executionSet", new PropertyType(SequenceFlowExecutionSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(SequenceFlow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SequenceFlow unwrap() {
        return target;
      }

      public SequenceFlow deepUnwrap() {
        final SequenceFlow clone = new SequenceFlow();
        final SequenceFlow t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getExecutionSet() instanceof BindableProxy) {
          clone.setExecutionSet((SequenceFlowExecutionSet) ((BindableProxy) getExecutionSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getExecutionSet())) {
          clone.setExecutionSet((SequenceFlowExecutionSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getExecutionSet())).deepUnwrap());
        } else {
          clone.setExecutionSet(t.getExecutionSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public SequenceFlowExecutionSet getExecutionSet() {
        return target.getExecutionSet();
      }

      public void setExecutionSet(SequenceFlowExecutionSet executionSet) {
        if (agent.binders.containsKey("executionSet")) {
          executionSet = (SequenceFlowExecutionSet) agent.binders.get("executionSet").setModel(executionSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("executionSet", executionSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "executionSet": return getExecutionSet();
          case "fontSet": return getFontSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("SequenceFlow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "executionSet": target.setExecutionSet((SequenceFlowExecutionSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "this": target = (SequenceFlow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SequenceFlow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SequenceFlow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy((SequenceFlow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_SequenceFlowProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy extends DoubleSliderDefinition implements BindableProxy {
      private BindableProxyAgent<DoubleSliderDefinition> agent;
      private DoubleSliderDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy() {
        this(new DoubleSliderDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy(DoubleSliderDefinition targetVal) {
        agent = new BindableProxyAgent<DoubleSliderDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("max", new PropertyType(Double.class, false, false));
        p.put("precision", new PropertyType(Double.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("min", new PropertyType(Double.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("step", new PropertyType(Double.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(SliderFieldType.class, false, false));
        p.put("this", new PropertyType(DoubleSliderDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DoubleSliderDefinition unwrap() {
        return target;
      }

      public DoubleSliderDefinition deepUnwrap() {
        final DoubleSliderDefinition clone = new DoubleSliderDefinition();
        final DoubleSliderDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setMax(t.getMax());
        clone.setPrecision(t.getPrecision());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMin(t.getMin());
        clone.setName(t.getName());
        clone.setStep(t.getStep());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Double getMax() {
        return target.getMax();
      }

      public void setMax(Double max) {
        changeAndFire("max", max);
      }

      public Double getPrecision() {
        return target.getPrecision();
      }

      public void setPrecision(Double precision) {
        changeAndFire("precision", precision);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Double getMin() {
        return target.getMin();
      }

      public void setMin(Double min) {
        changeAndFire("min", min);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Double getStep() {
        return target.getStep();
      }

      public void setStep(Double step) {
        changeAndFire("step", step);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public SliderFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "max": return getMax();
          case "precision": return getPrecision();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "min": return getMin();
          case "name": return getName();
          case "step": return getStep();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DoubleSliderDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "max": target.setMax((Double) value);
          break;
          case "precision": target.setPrecision((Double) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "min": target.setMin((Double) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "step": target.setStep((Double) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DoubleSliderDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DoubleSliderDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DoubleSliderDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy((DoubleSliderDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_slider_definition_DoubleSliderDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy extends NotificationSet implements BindableProxy {
      private BindableProxyAgent<NotificationSet> agent;
      private NotificationSet target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy() {
        this(new NotificationSet());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy(NotificationSet targetVal) {
        agent = new BindableProxyAgent<NotificationSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("notificationsInfo", new PropertyType(NotificationsInfo.class, true, false));
        p.put("this", new PropertyType(NotificationSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NotificationSet unwrap() {
        return target;
      }

      public NotificationSet deepUnwrap() {
        final NotificationSet clone = new NotificationSet();
        final NotificationSet t = unwrap();
        if (t.getNotificationsInfo() instanceof BindableProxy) {
          clone.setNotificationsInfo((NotificationsInfo) ((BindableProxy) getNotificationsInfo()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getNotificationsInfo())) {
          clone.setNotificationsInfo((NotificationsInfo) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getNotificationsInfo())).deepUnwrap());
        } else {
          clone.setNotificationsInfo(t.getNotificationsInfo());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public NotificationsInfo getNotificationsInfo() {
        return target.getNotificationsInfo();
      }

      public void setNotificationsInfo(NotificationsInfo notificationsInfo) {
        if (agent.binders.containsKey("notificationsInfo")) {
          notificationsInfo = (NotificationsInfo) agent.binders.get("notificationsInfo").setModel(notificationsInfo, StateSync.FROM_MODEL, true);
        }
        changeAndFire("notificationsInfo", notificationsInfo);
      }

      public Object get(String property) {
        switch (property) {
          case "notificationsInfo": return getNotificationsInfo();
          case "this": return target;
          default: throw new NonExistingPropertyException("NotificationSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "notificationsInfo": target.setNotificationsInfo((NotificationsInfo) value);
          break;
          case "this": target = (NotificationSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NotificationSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(NotificationSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy((NotificationSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationSetProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy extends FontBorderColor implements BindableProxy {
      private BindableProxyAgent<FontBorderColor> agent;
      private FontBorderColor target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy() {
        this(new FontBorderColor());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy(FontBorderColor targetVal) {
        agent = new BindableProxyAgent<FontBorderColor>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(FontBorderColor.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public FontBorderColor unwrap() {
        return target;
      }

      public FontBorderColor deepUnwrap() {
        final FontBorderColor clone = new FontBorderColor();
        final FontBorderColor t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("FontBorderColor", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (FontBorderColor) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("FontBorderColor", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(FontBorderColor.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy((FontBorderColor) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_font_FontBorderColorProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy extends IsInterrupting implements BindableProxy {
      private BindableProxyAgent<IsInterrupting> agent;
      private IsInterrupting target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy() {
        this(new IsInterrupting());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy(IsInterrupting targetVal) {
        agent = new BindableProxyAgent<IsInterrupting>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(IsInterrupting.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IsInterrupting unwrap() {
        return target;
      }

      public IsInterrupting deepUnwrap() {
        final IsInterrupting clone = new IsInterrupting();
        final IsInterrupting t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("IsInterrupting", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (IsInterrupting) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IsInterrupting", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(IsInterrupting.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy((IsInterrupting) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_IsInterruptingProxy();
      }
    });
    class org_jboss_errai_ui_shared_api_LocaleProxy extends Locale implements BindableProxy {
      private BindableProxyAgent<Locale> agent;
      private Locale target;
      public org_jboss_errai_ui_shared_api_LocaleProxy() {
        this(new Locale());
      }

      public org_jboss_errai_ui_shared_api_LocaleProxy(Locale targetVal) {
        agent = new BindableProxyAgent<Locale>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("label", new PropertyType(String.class, false, false));
        p.put("locale", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(Locale.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Locale unwrap() {
        return target;
      }

      public Locale deepUnwrap() {
        final Locale clone = new Locale();
        final Locale t = unwrap();
        clone.setLabel(t.getLabel());
        clone.setLocale(t.getLocale());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_jboss_errai_ui_shared_api_LocaleProxy) {
          obj = ((org_jboss_errai_ui_shared_api_LocaleProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public String getLocale() {
        return target.getLocale();
      }

      public void setLocale(String locale) {
        changeAndFire("locale", locale);
      }

      public Object get(String property) {
        switch (property) {
          case "label": return getLabel();
          case "locale": return getLocale();
          case "this": return target;
          default: throw new NonExistingPropertyException("Locale", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "label": target.setLabel((String) value);
          break;
          case "locale": target.setLocale((String) value);
          break;
          case "this": target = (Locale) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Locale", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Locale.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_jboss_errai_ui_shared_api_LocaleProxy((Locale) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_jboss_errai_ui_shared_api_LocaleProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy extends org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id clone = new org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id();
        final org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Id", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Id", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy((org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_IdProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy extends SignalRef implements BindableProxy {
      private BindableProxyAgent<SignalRef> agent;
      private SignalRef target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy() {
        this(new SignalRef());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy(SignalRef targetVal) {
        agent = new BindableProxyAgent<SignalRef>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(SignalRef.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public SignalRef unwrap() {
        return target;
      }

      public SignalRef deepUnwrap() {
        final SignalRef clone = new SignalRef();
        final SignalRef t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("SignalRef", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (SignalRef) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("SignalRef", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(SignalRef.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy((SignalRef) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_event_signal_SignalRefProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy extends IsAsync implements BindableProxy {
      private BindableProxyAgent<IsAsync> agent;
      private IsAsync target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy() {
        this(new IsAsync());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy(IsAsync targetVal) {
        agent = new BindableProxyAgent<IsAsync>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Boolean.class, false, false));
        p.put("this", new PropertyType(IsAsync.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public IsAsync unwrap() {
        return target;
      }

      public IsAsync deepUnwrap() {
        final IsAsync clone = new IsAsync();
        final IsAsync t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValue() {
        return target.getValue();
      }

      public void setValue(Boolean value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("IsAsync", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Boolean) value);
          break;
          case "this": target = (IsAsync) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("IsAsync", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(IsAsync.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy((IsAsync) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_IsAsyncProxy();
      }
    });
    class org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy extends CaseManagementDefinitionSet implements BindableProxy {
      private BindableProxyAgent<CaseManagementDefinitionSet> agent;
      private CaseManagementDefinitionSet target;
      public org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy() {
        this(new CaseManagementDefinitionSet());
      }

      public org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy(CaseManagementDefinitionSet targetVal) {
        agent = new BindableProxyAgent<CaseManagementDefinitionSet>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("description", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(CaseManagementDefinitionSet.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public CaseManagementDefinitionSet unwrap() {
        return target;
      }

      public CaseManagementDefinitionSet deepUnwrap() {
        final CaseManagementDefinitionSet clone = new CaseManagementDefinitionSet();
        final CaseManagementDefinitionSet t = unwrap();
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy) {
          obj = ((org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getDescription() {
        return target.getDescription();
      }

      public Object get(String property) {
        switch (property) {
          case "description": return getDescription();
          case "this": return target;
          default: throw new NonExistingPropertyException("CaseManagementDefinitionSet", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "this": target = (CaseManagementDefinitionSet) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("CaseManagementDefinitionSet", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(CaseManagementDefinitionSet.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy((CaseManagementDefinitionSet) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_cm_CaseManagementDefinitionSetProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy extends TextAreaFieldDefinition implements BindableProxy {
      private BindableProxyAgent<TextAreaFieldDefinition> agent;
      private TextAreaFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy() {
        this(new TextAreaFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy(TextAreaFieldDefinition targetVal) {
        agent = new BindableProxyAgent<TextAreaFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("rows", new PropertyType(Integer.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(TextAreaFieldType.class, false, false));
        p.put("placeHolder", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(TextAreaFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public TextAreaFieldDefinition unwrap() {
        return target;
      }

      public TextAreaFieldDefinition deepUnwrap() {
        final TextAreaFieldDefinition clone = new TextAreaFieldDefinition();
        final TextAreaFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRows(t.getRows());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setName(t.getName());
        clone.setId(t.getId());
        clone.setPlaceHolder(t.getPlaceHolder());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Integer getRows() {
        return target.getRows();
      }

      public void setRows(Integer rows) {
        changeAndFire("rows", rows);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public TextAreaFieldType getFieldType() {
        return target.getFieldType();
      }

      public String getPlaceHolder() {
        return target.getPlaceHolder();
      }

      public void setPlaceHolder(String placeHolder) {
        changeAndFire("placeHolder", placeHolder);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "rows": return getRows();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "placeHolder": return getPlaceHolder();
          case "this": return target;
          default: throw new NonExistingPropertyException("TextAreaFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "rows": target.setRows((Integer) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "placeHolder": target.setPlaceHolder((String) value);
          break;
          case "this": target = (TextAreaFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TextAreaFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(TextAreaFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy((TextAreaFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_textArea_definition_TextAreaFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy extends InformationItemPrimary implements BindableProxy {
      private BindableProxyAgent<InformationItemPrimary> agent;
      private InformationItemPrimary target;
      public org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy() {
        this(new InformationItemPrimary());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy(InformationItemPrimary targetVal) {
        agent = new BindableProxyAgent<InformationItemPrimary>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("typeRefHolder", new PropertyType(QNameHolder.class, true, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InformationItemPrimary.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InformationItemPrimary unwrap() {
        return target;
      }

      public InformationItemPrimary deepUnwrap() {
        final InformationItemPrimary clone = new InformationItemPrimary();
        final InformationItemPrimary t = unwrap();
        clone.setParent(t.getParent());
        if (t.getTypeRefHolder() instanceof BindableProxy) {
          clone.setTypeRefHolder((QNameHolder) ((BindableProxy) getTypeRefHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTypeRefHolder())) {
          clone.setTypeRefHolder((QNameHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTypeRefHolder())).deepUnwrap());
        } else {
          clone.setTypeRefHolder(t.getTypeRefHolder());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public QNameHolder getTypeRefHolder() {
        return target.getTypeRefHolder();
      }

      public void setTypeRefHolder(QNameHolder typeRefHolder) {
        if (agent.binders.containsKey("typeRefHolder")) {
          typeRefHolder = (QNameHolder) agent.binders.get("typeRefHolder").setModel(typeRefHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("typeRefHolder", typeRefHolder);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public Id getId() {
        return target.getId();
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "typeRefHolder": return getTypeRefHolder();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "nsContext": return getNsContext();
          case "hasTypeRefs": return getHasTypeRefs();
          case "name": return getName();
          case "id": return getId();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InformationItemPrimary", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "typeRefHolder": target.setTypeRefHolder((QNameHolder) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InformationItemPrimary) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InformationItemPrimary", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InformationItemPrimary.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy((InformationItemPrimary) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InformationItemPrimaryProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy extends DecimalMultipleSelectorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DecimalMultipleSelectorFieldDefinition> agent;
      private DecimalMultipleSelectorFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy() {
        this(new DecimalMultipleSelectorFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy(DecimalMultipleSelectorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DecimalMultipleSelectorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("maxDropdownElements", new PropertyType(Integer.class, false, false));
        p.put("listOfValues", new PropertyType(List.class, false, true));
        p.put("maxElementsOnTitle", new PropertyType(Integer.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("allowFilter", new PropertyType(Boolean.class, false, false));
        p.put("allowClearSelection", new PropertyType(Boolean.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(FieldType.class, false, false));
        p.put("this", new PropertyType(DecimalMultipleSelectorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecimalMultipleSelectorFieldDefinition unwrap() {
        return target;
      }

      public DecimalMultipleSelectorFieldDefinition deepUnwrap() {
        final DecimalMultipleSelectorFieldDefinition clone = new DecimalMultipleSelectorFieldDefinition();
        final DecimalMultipleSelectorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setMaxDropdownElements(t.getMaxDropdownElements());
        if (t.getListOfValues() != null) {
          final List listOfValuesClone = new ArrayList();
          for (Object listOfValuesElem : t.getListOfValues()) {
            if (listOfValuesElem instanceof BindableProxy) {
              listOfValuesClone.add(((BindableProxy) listOfValuesElem).deepUnwrap());
            } else {
              listOfValuesClone.add(listOfValuesElem);
            }
          }
          clone.setListOfValues(listOfValuesClone);
        }
        clone.setMaxElementsOnTitle(t.getMaxElementsOnTitle());
        clone.setName(t.getName());
        clone.setAllowFilter(t.getAllowFilter());
        clone.setAllowClearSelection(t.getAllowClearSelection());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Integer getMaxDropdownElements() {
        return target.getMaxDropdownElements();
      }

      public void setMaxDropdownElements(Integer maxDropdownElements) {
        changeAndFire("maxDropdownElements", maxDropdownElements);
      }

      public List getListOfValues() {
        return target.getListOfValues();
      }

      public void setListOfValues(List<Double> listOfValues) {
        List<Double> oldValue = target.getListOfValues();
        listOfValues = agent.ensureBoundListIsProxied("listOfValues", listOfValues);
        target.setListOfValues(listOfValues);
        agent.updateWidgetsAndFireEvent(true, "listOfValues", oldValue, listOfValues);
      }

      public Integer getMaxElementsOnTitle() {
        return target.getMaxElementsOnTitle();
      }

      public void setMaxElementsOnTitle(Integer maxElementsOnTitle) {
        changeAndFire("maxElementsOnTitle", maxElementsOnTitle);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public Boolean getAllowFilter() {
        return target.getAllowFilter();
      }

      public void setAllowFilter(Boolean allowFilter) {
        changeAndFire("allowFilter", allowFilter);
      }

      public Boolean getAllowClearSelection() {
        return target.getAllowClearSelection();
      }

      public void setAllowClearSelection(Boolean allowClearSelection) {
        changeAndFire("allowClearSelection", allowClearSelection);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public FieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "binding": return getBinding();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "maxDropdownElements": return getMaxDropdownElements();
          case "listOfValues": return getListOfValues();
          case "maxElementsOnTitle": return getMaxElementsOnTitle();
          case "name": return getName();
          case "allowFilter": return getAllowFilter();
          case "allowClearSelection": return getAllowClearSelection();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecimalMultipleSelectorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "maxDropdownElements": target.setMaxDropdownElements((Integer) value);
          break;
          case "listOfValues": target.setListOfValues((List<Double>) value);
          break;
          case "maxElementsOnTitle": target.setMaxElementsOnTitle((Integer) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "allowFilter": target.setAllowFilter((Boolean) value);
          break;
          case "allowClearSelection": target.setAllowClearSelection((Boolean) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DecimalMultipleSelectorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecimalMultipleSelectorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DecimalMultipleSelectorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy((DecimalMultipleSelectorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_lists_selector_impl_DecimalMultipleSelectorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_DecisionProxy extends Decision implements BindableProxy {
      private BindableProxyAgent<Decision> agent;
      private Decision target;
      public org_kie_workbench_common_dmn_api_definition_model_DecisionProxy() {
        this(new Decision());
      }

      public org_kie_workbench_common_dmn_api_definition_model_DecisionProxy(Decision targetVal) {
        agent = new BindableProxyAgent<Decision>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("expression", new PropertyType(Expression.class, false, false));
        p.put("question", new PropertyType(Question.class, true, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("allowOnlyVisualChange", new PropertyType(Boolean.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("backgroundSet", new PropertyType(org.kie.workbench.common.dmn.api.property.background.BackgroundSet.class, true, false));
        p.put("allowedAnswers", new PropertyType(AllowedAnswers.class, true, false));
        p.put("variable", new PropertyType(InformationItemPrimary.class, true, false));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("fontSet", new PropertyType(org.kie.workbench.common.dmn.api.property.font.FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(GeneralRectangleDimensionsSet.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("linksHolder", new PropertyType(DocumentationLinksHolder.class, true, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(Decision.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Decision unwrap() {
        return target;
      }

      public Decision deepUnwrap() {
        final Decision clone = new Decision();
        final Decision t = unwrap();
        clone.setParent(t.getParent());
        clone.setExpression(t.getExpression());
        if (t.getQuestion() instanceof BindableProxy) {
          clone.setQuestion((Question) ((BindableProxy) getQuestion()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getQuestion())) {
          clone.setQuestion((Question) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getQuestion())).deepUnwrap());
        } else {
          clone.setQuestion(t.getQuestion());
        }
        clone.setExtensionElements(t.getExtensionElements());
        clone.setAllowOnlyVisualChange(t.isAllowOnlyVisualChange());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getAllowedAnswers() instanceof BindableProxy) {
          clone.setAllowedAnswers((AllowedAnswers) ((BindableProxy) getAllowedAnswers()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getAllowedAnswers())) {
          clone.setAllowedAnswers((AllowedAnswers) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getAllowedAnswers())).deepUnwrap());
        } else {
          clone.setAllowedAnswers(t.getAllowedAnswers());
        }
        if (t.getVariable() instanceof BindableProxy) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) getVariable()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getVariable())) {
          clone.setVariable((InformationItemPrimary) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getVariable())).deepUnwrap());
        } else {
          clone.setVariable(t.getVariable());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((GeneralRectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        if (t.getLinksHolder() instanceof BindableProxy) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) getLinksHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getLinksHolder())) {
          clone.setLinksHolder((DocumentationLinksHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getLinksHolder())).deepUnwrap());
        } else {
          clone.setLinksHolder(t.getLinksHolder());
        }
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_DecisionProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_DecisionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public Expression getExpression() {
        return target.getExpression();
      }

      public void setExpression(Expression expression) {
        changeAndFire("expression", expression);
      }

      public Question getQuestion() {
        return target.getQuestion();
      }

      public void setQuestion(Question question) {
        if (agent.binders.containsKey("question")) {
          question = (Question) agent.binders.get("question").setModel(question, StateSync.FROM_MODEL, true);
        }
        changeAndFire("question", question);
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public boolean isAllowOnlyVisualChange() {
        return target.isAllowOnlyVisualChange();
      }

      public void setAllowOnlyVisualChange(boolean allowOnlyVisualChange) {
        changeAndFire("allowOnlyVisualChange", allowOnlyVisualChange);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public org.kie.workbench.common.dmn.api.property.background.BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(org.kie.workbench.common.dmn.api.property.background.BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (org.kie.workbench.common.dmn.api.property.background.BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public AllowedAnswers getAllowedAnswers() {
        return target.getAllowedAnswers();
      }

      public void setAllowedAnswers(AllowedAnswers allowedAnswers) {
        if (agent.binders.containsKey("allowedAnswers")) {
          allowedAnswers = (AllowedAnswers) agent.binders.get("allowedAnswers").setModel(allowedAnswers, StateSync.FROM_MODEL, true);
        }
        changeAndFire("allowedAnswers", allowedAnswers);
      }

      public InformationItemPrimary getVariable() {
        return target.getVariable();
      }

      public void setVariable(InformationItemPrimary variable) {
        if (agent.binders.containsKey("variable")) {
          variable = (InformationItemPrimary) agent.binders.get("variable").setModel(variable, StateSync.FROM_MODEL, true);
        }
        changeAndFire("variable", variable);
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public org.kie.workbench.common.dmn.api.property.font.FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(org.kie.workbench.common.dmn.api.property.font.FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (org.kie.workbench.common.dmn.api.property.font.FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public GeneralRectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(GeneralRectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (GeneralRectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public DocumentationLinksHolder getLinksHolder() {
        return target.getLinksHolder();
      }

      public void setLinksHolder(DocumentationLinksHolder linksHolder) {
        if (agent.binders.containsKey("linksHolder")) {
          linksHolder = (DocumentationLinksHolder) agent.binders.get("linksHolder").setModel(linksHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("linksHolder", linksHolder);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "expression": return getExpression();
          case "question": return getQuestion();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "allowOnlyVisualChange": return isAllowOnlyVisualChange();
          case "description": return getDescription();
          case "nsContext": return getNsContext();
          case "backgroundSet": return getBackgroundSet();
          case "allowedAnswers": return getAllowedAnswers();
          case "variable": return getVariable();
          case "name": return getName();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "id": return getId();
          case "linksHolder": return getLinksHolder();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("Decision", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "expression": target.setExpression((Expression) value);
          break;
          case "question": target.setQuestion((Question) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "allowOnlyVisualChange": target.setAllowOnlyVisualChange((Boolean) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "backgroundSet": target.setBackgroundSet((org.kie.workbench.common.dmn.api.property.background.BackgroundSet) value);
          break;
          case "allowedAnswers": target.setAllowedAnswers((AllowedAnswers) value);
          break;
          case "variable": target.setVariable((InformationItemPrimary) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "fontSet": target.setFontSet((org.kie.workbench.common.dmn.api.property.font.FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((GeneralRectangleDimensionsSet) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "linksHolder": target.setLinksHolder((DocumentationLinksHolder) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (Decision) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Decision", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public ReadOnly getReadOnly(String a0) {
        final ReadOnly returnValue = target.getReadOnly(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(Decision.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_DecisionProxy((Decision) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_DecisionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy extends NotificationValue implements BindableProxy {
      private BindableProxyAgent<NotificationValue> agent;
      private NotificationValue target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy() {
        this(new NotificationValue());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy(NotificationValue targetVal) {
        agent = new BindableProxyAgent<NotificationValue>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("subject", new PropertyType(String.class, false, false));
        p.put("replyTo", new PropertyType(String.class, false, false));
        p.put("groups", new PropertyType(List.class, false, true));
        p.put("from", new PropertyType(String.class, false, false));
        p.put("body", new PropertyType(String.class, false, false));
        p.put("type", new PropertyType(String.class, false, false));
        p.put("expiresAt", new PropertyType(String.class, false, false));
        p.put("users", new PropertyType(List.class, false, true));
        p.put("this", new PropertyType(NotificationValue.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NotificationValue unwrap() {
        return target;
      }

      public NotificationValue deepUnwrap() {
        final NotificationValue clone = new NotificationValue();
        final NotificationValue t = unwrap();
        clone.setSubject(t.getSubject());
        clone.setReplyTo(t.getReplyTo());
        if (t.getGroups() != null) {
          final List groupsClone = new ArrayList();
          for (Object groupsElem : t.getGroups()) {
            if (groupsElem instanceof BindableProxy) {
              groupsClone.add(((BindableProxy) groupsElem).deepUnwrap());
            } else {
              groupsClone.add(groupsElem);
            }
          }
          clone.setGroups(groupsClone);
        }
        clone.setFrom(t.getFrom());
        clone.setBody(t.getBody());
        clone.setType(t.getType());
        clone.setExpiresAt(t.getExpiresAt());
        if (t.getUsers() != null) {
          final List usersClone = new ArrayList();
          for (Object usersElem : t.getUsers()) {
            if (usersElem instanceof BindableProxy) {
              usersClone.add(((BindableProxy) usersElem).deepUnwrap());
            } else {
              usersClone.add(usersElem);
            }
          }
          clone.setUsers(usersClone);
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getSubject() {
        return target.getSubject();
      }

      public void setSubject(String subject) {
        changeAndFire("subject", subject);
      }

      public String getReplyTo() {
        return target.getReplyTo();
      }

      public void setReplyTo(String replyTo) {
        changeAndFire("replyTo", replyTo);
      }

      public List getGroups() {
        return target.getGroups();
      }

      public void setGroups(List<String> groups) {
        List<String> oldValue = target.getGroups();
        groups = agent.ensureBoundListIsProxied("groups", groups);
        target.setGroups(groups);
        agent.updateWidgetsAndFireEvent(true, "groups", oldValue, groups);
      }

      public String getFrom() {
        return target.getFrom();
      }

      public void setFrom(String from) {
        changeAndFire("from", from);
      }

      public String getBody() {
        return target.getBody();
      }

      public void setBody(String body) {
        changeAndFire("body", body);
      }

      public String getType() {
        return target.getType();
      }

      public void setType(String type) {
        changeAndFire("type", type);
      }

      public String getExpiresAt() {
        return target.getExpiresAt();
      }

      public void setExpiresAt(String expiresAt) {
        changeAndFire("expiresAt", expiresAt);
      }

      public List getUsers() {
        return target.getUsers();
      }

      public void setUsers(List<String> users) {
        List<String> oldValue = target.getUsers();
        users = agent.ensureBoundListIsProxied("users", users);
        target.setUsers(users);
        agent.updateWidgetsAndFireEvent(true, "users", oldValue, users);
      }

      public Object get(String property) {
        switch (property) {
          case "subject": return getSubject();
          case "replyTo": return getReplyTo();
          case "groups": return getGroups();
          case "from": return getFrom();
          case "body": return getBody();
          case "type": return getType();
          case "expiresAt": return getExpiresAt();
          case "users": return getUsers();
          case "this": return target;
          default: throw new NonExistingPropertyException("NotificationValue", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "subject": target.setSubject((String) value);
          break;
          case "replyTo": target.setReplyTo((String) value);
          break;
          case "groups": target.setGroups((List<String>) value);
          break;
          case "from": target.setFrom((String) value);
          break;
          case "body": target.setBody((String) value);
          break;
          case "type": target.setType((String) value);
          break;
          case "expiresAt": target.setExpiresAt((String) value);
          break;
          case "users": target.setUsers((List<String>) value);
          break;
          case "this": target = (NotificationValue) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NotificationValue", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public String toCDATAFormat() {
        final String returnValue = target.toCDATAFormat();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(NotificationValue.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy((NotificationValue) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationValueProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy extends KeyValueRow implements BindableProxy {
      private BindableProxyAgent<KeyValueRow> agent;
      private KeyValueRow target;
      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy() {
        this(new KeyValueRow());
      }

      public org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy(KeyValueRow targetVal) {
        agent = new BindableProxyAgent<KeyValueRow>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("key", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(KeyValueRow.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public KeyValueRow unwrap() {
        return target;
      }

      public KeyValueRow deepUnwrap() {
        final KeyValueRow clone = new KeyValueRow();
        final KeyValueRow t = unwrap();
        clone.setValue(t.getValue());
        clone.setKey(t.getKey());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public String getKey() {
        return target.getKey();
      }

      public void setKey(String key) {
        changeAndFire("key", key);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "key": return getKey();
          case "this": return target;
          default: throw new NonExistingPropertyException("KeyValueRow", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "key": target.setKey((String) value);
          break;
          case "this": target = (KeyValueRow) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("KeyValueRow", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(KeyValueRow.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy((KeyValueRow) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_client_forms_fields_model_KeyValueRowProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy extends VariablesEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<VariablesEditorFieldDefinition> agent;
      private VariablesEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy() {
        this(new VariablesEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy(VariablesEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<VariablesEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("caseFileVariable", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(VariablesEditorFieldType.class, false, false));
        p.put("this", new PropertyType(VariablesEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public VariablesEditorFieldDefinition unwrap() {
        return target;
      }

      public VariablesEditorFieldDefinition deepUnwrap() {
        final VariablesEditorFieldDefinition clone = new VariablesEditorFieldDefinition();
        final VariablesEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        clone.setCaseFileVariable(t.isCaseFileVariable());
        clone.setName(t.getName());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(String defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public boolean isCaseFileVariable() {
        return target.isCaseFileVariable();
      }

      public void setCaseFileVariable(boolean caseFileVariable) {
        changeAndFire("caseFileVariable", caseFileVariable);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public VariablesEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "caseFileVariable": return isCaseFileVariable();
          case "name": return getName();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("VariablesEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "caseFileVariable": target.setCaseFileVariable((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (VariablesEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("VariablesEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(VariablesEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy((VariablesEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_VariablesEditorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy extends org.kie.workbench.common.dmn.api.property.dmn.Description implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.dmn.api.property.dmn.Description> agent;
      private org.kie.workbench.common.dmn.api.property.dmn.Description target;
      public org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy() {
        this(new org.kie.workbench.common.dmn.api.property.dmn.Description());
      }

      public org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy(org.kie.workbench.common.dmn.api.property.dmn.Description targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.dmn.api.property.dmn.Description>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description unwrap() {
        return target;
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description deepUnwrap() {
        final org.kie.workbench.common.dmn.api.property.dmn.Description clone = new org.kie.workbench.common.dmn.api.property.dmn.Description();
        final org.kie.workbench.common.dmn.api.property.dmn.Description t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy) {
          obj = ((org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Description", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (org.kie.workbench.common.dmn.api.property.dmn.Description) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Description", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.dmn.api.property.dmn.Description.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy((org.kie.workbench.common.dmn.api.property.dmn.Description) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_property_dmn_DescriptionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy extends Imports implements BindableProxy {
      private BindableProxyAgent<Imports> agent;
      private Imports target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy() {
        this(new Imports());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy(Imports targetVal) {
        agent = new BindableProxyAgent<Imports>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(ImportsValue.class, true, false));
        p.put("this", new PropertyType(Imports.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Imports unwrap() {
        return target;
      }

      public Imports deepUnwrap() {
        final Imports clone = new Imports();
        final Imports t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((ImportsValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((ImportsValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public ImportsValue getValue() {
        return target.getValue();
      }

      public void setValue(ImportsValue value) {
        if (agent.binders.containsKey("value")) {
          value = (ImportsValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Imports", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((ImportsValue) value);
          break;
          case "this": target = (Imports) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Imports", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Imports.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy((Imports) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_diagram_imports_ImportsProxy();
      }
    });
    class org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy extends InformationItem implements BindableProxy {
      private BindableProxyAgent<InformationItem> agent;
      private InformationItem target;
      public org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy() {
        this(new InformationItem());
      }

      public org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy(InformationItem targetVal) {
        agent = new BindableProxyAgent<InformationItem>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("parent", new PropertyType(DMNModelInstrumentedBase.class, false, false));
        p.put("typeRefHolder", new PropertyType(QNameHolder.class, true, false));
        p.put("domainObjectUUID", new PropertyType(String.class, false, false));
        p.put("defaultNamespace", new PropertyType(String.class, false, false));
        p.put("stunnerCategory", new PropertyType(String.class, false, false));
        p.put("extensionElements", new PropertyType(ExtensionElements.class, false, false));
        p.put("domainObjectNameTranslationKey", new PropertyType(String.class, false, false));
        p.put("stunnerLabels", new PropertyType(Set.class, false, false));
        p.put("description", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Description.class, true, false));
        p.put("nsContext", new PropertyType(Map.class, false, false));
        p.put("hasTypeRefs", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(org.kie.workbench.common.dmn.api.property.dmn.Name.class, true, false));
        p.put("id", new PropertyType(Id.class, true, false));
        p.put("typeRef", new PropertyType(QName.class, false, false));
        p.put("additionalAttributes", new PropertyType(Map.class, false, false));
        p.put("this", new PropertyType(InformationItem.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public InformationItem unwrap() {
        return target;
      }

      public InformationItem deepUnwrap() {
        final InformationItem clone = new InformationItem();
        final InformationItem t = unwrap();
        clone.setParent(t.getParent());
        if (t.getTypeRefHolder() instanceof BindableProxy) {
          clone.setTypeRefHolder((QNameHolder) ((BindableProxy) getTypeRefHolder()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getTypeRefHolder())) {
          clone.setTypeRefHolder((QNameHolder) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getTypeRefHolder())).deepUnwrap());
        } else {
          clone.setTypeRefHolder(t.getTypeRefHolder());
        }
        clone.setExtensionElements(t.getExtensionElements());
        if (t.getDescription() instanceof BindableProxy) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) getDescription()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDescription())) {
          clone.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDescription())).deepUnwrap());
        } else {
          clone.setDescription(t.getDescription());
        }
        if (t.getName() instanceof BindableProxy) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) getName()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getName())) {
          clone.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getName())).deepUnwrap());
        } else {
          clone.setName(t.getName());
        }
        if (t.getId() instanceof BindableProxy) {
          clone.setId((Id) ((BindableProxy) getId()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getId())) {
          clone.setId((Id) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getId())).deepUnwrap());
        } else {
          clone.setId(t.getId());
        }
        clone.setTypeRef(t.getTypeRef());
        clone.setAdditionalAttributes(t.getAdditionalAttributes());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy) {
          obj = ((org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public DMNModelInstrumentedBase getParent() {
        return target.getParent();
      }

      public void setParent(DMNModelInstrumentedBase parent) {
        changeAndFire("parent", parent);
      }

      public QNameHolder getTypeRefHolder() {
        return target.getTypeRefHolder();
      }

      public void setTypeRefHolder(QNameHolder typeRefHolder) {
        if (agent.binders.containsKey("typeRefHolder")) {
          typeRefHolder = (QNameHolder) agent.binders.get("typeRefHolder").setModel(typeRefHolder, StateSync.FROM_MODEL, true);
        }
        changeAndFire("typeRefHolder", typeRefHolder);
      }

      public String getDomainObjectUUID() {
        return target.getDomainObjectUUID();
      }

      public String getDefaultNamespace() {
        return target.getDefaultNamespace();
      }

      public String getStunnerCategory() {
        return target.getStunnerCategory();
      }

      public ExtensionElements getExtensionElements() {
        return target.getExtensionElements();
      }

      public void setExtensionElements(ExtensionElements extensionElements) {
        changeAndFire("extensionElements", extensionElements);
      }

      public String getDomainObjectNameTranslationKey() {
        return target.getDomainObjectNameTranslationKey();
      }

      public Set getStunnerLabels() {
        return target.getStunnerLabels();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Description getDescription() {
        return target.getDescription();
      }

      public void setDescription(org.kie.workbench.common.dmn.api.property.dmn.Description description) {
        if (agent.binders.containsKey("description")) {
          description = (org.kie.workbench.common.dmn.api.property.dmn.Description) agent.binders.get("description").setModel(description, StateSync.FROM_MODEL, true);
        }
        changeAndFire("description", description);
      }

      public Map getNsContext() {
        return target.getNsContext();
      }

      public List getHasTypeRefs() {
        return target.getHasTypeRefs();
      }

      public org.kie.workbench.common.dmn.api.property.dmn.Name getName() {
        return target.getName();
      }

      public void setName(org.kie.workbench.common.dmn.api.property.dmn.Name name) {
        if (agent.binders.containsKey("name")) {
          name = (org.kie.workbench.common.dmn.api.property.dmn.Name) agent.binders.get("name").setModel(name, StateSync.FROM_MODEL, true);
        }
        changeAndFire("name", name);
      }

      public Id getId() {
        return target.getId();
      }

      public void setId(Id id) {
        if (agent.binders.containsKey("id")) {
          id = (Id) agent.binders.get("id").setModel(id, StateSync.FROM_MODEL, true);
        }
        changeAndFire("id", id);
      }

      public QName getTypeRef() {
        return target.getTypeRef();
      }

      public void setTypeRef(QName typeRef) {
        changeAndFire("typeRef", typeRef);
      }

      public Map getAdditionalAttributes() {
        return target.getAdditionalAttributes();
      }

      public void setAdditionalAttributes(Map<QName, String> additionalAttributes) {
        changeAndFire("additionalAttributes", additionalAttributes);
      }

      public Object get(String property) {
        switch (property) {
          case "parent": return getParent();
          case "typeRefHolder": return getTypeRefHolder();
          case "domainObjectUUID": return getDomainObjectUUID();
          case "defaultNamespace": return getDefaultNamespace();
          case "stunnerCategory": return getStunnerCategory();
          case "extensionElements": return getExtensionElements();
          case "domainObjectNameTranslationKey": return getDomainObjectNameTranslationKey();
          case "stunnerLabels": return getStunnerLabels();
          case "description": return getDescription();
          case "nsContext": return getNsContext();
          case "hasTypeRefs": return getHasTypeRefs();
          case "name": return getName();
          case "id": return getId();
          case "typeRef": return getTypeRef();
          case "additionalAttributes": return getAdditionalAttributes();
          case "this": return target;
          default: throw new NonExistingPropertyException("InformationItem", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "parent": target.setParent((DMNModelInstrumentedBase) value);
          break;
          case "typeRefHolder": target.setTypeRefHolder((QNameHolder) value);
          break;
          case "extensionElements": target.setExtensionElements((ExtensionElements) value);
          break;
          case "description": target.setDescription((org.kie.workbench.common.dmn.api.property.dmn.Description) value);
          break;
          case "name": target.setName((org.kie.workbench.common.dmn.api.property.dmn.Name) value);
          break;
          case "id": target.setId((Id) value);
          break;
          case "typeRef": target.setTypeRef((QName) value);
          break;
          case "additionalAttributes": target.setAdditionalAttributes((Map<QName, String>) value);
          break;
          case "this": target = (InformationItem) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("InformationItem", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
        final DMNModelInstrumentedBase returnValue = target.asDMNModelInstrumentedBase();
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }

      public Optional getPrefixForNamespaceURI(String a0) {
        final Optional returnValue = target.getPrefixForNamespaceURI(a0);
        agent.updateWidgetsAndFireEvents();
        return returnValue;
      }
    }
    BindableProxyFactory.addBindableProxy(InformationItem.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy((InformationItem) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_dmn_api_definition_model_InformationItemProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy extends Height implements BindableProxy {
      private BindableProxyAgent<Height> agent;
      private Height target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy() {
        this(new Height());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy(Height targetVal) {
        agent = new BindableProxyAgent<Height>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(Double.class, false, false));
        p.put("this", new PropertyType(Height.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public Height unwrap() {
        return target;
      }

      public Height deepUnwrap() {
        final Height clone = new Height();
        final Height t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Double getValue() {
        return target.getValue();
      }

      public void setValue(Double value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("Height", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((Double) value);
          break;
          case "this": target = (Height) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("Height", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(Height.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy((Height) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_dimensions_HeightProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy extends org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation implements BindableProxy {
      private BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation> agent;
      private org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation target;
      public org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy() {
        this(new org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy(org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation targetVal) {
        agent = new BindableProxyAgent<org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("general", new PropertyType(BPMNGeneralSet.class, true, false));
        p.put("backgroundSet", new PropertyType(BackgroundSet.class, true, false));
        p.put("fontSet", new PropertyType(FontSet.class, true, false));
        p.put("dimensionsSet", new PropertyType(RectangleDimensionsSet.class, true, false));
        p.put("category", new PropertyType(String.class, false, false));
        p.put("labels", new PropertyType(Set.class, false, false));
        p.put("this", new PropertyType(org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation unwrap() {
        return target;
      }

      public org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation deepUnwrap() {
        final org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation clone = new org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation();
        final org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation t = unwrap();
        if (t.getGeneral() instanceof BindableProxy) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) getGeneral()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getGeneral())) {
          clone.setGeneral((BPMNGeneralSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getGeneral())).deepUnwrap());
        } else {
          clone.setGeneral(t.getGeneral());
        }
        if (t.getBackgroundSet() instanceof BindableProxy) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) getBackgroundSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getBackgroundSet())) {
          clone.setBackgroundSet((BackgroundSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getBackgroundSet())).deepUnwrap());
        } else {
          clone.setBackgroundSet(t.getBackgroundSet());
        }
        if (t.getFontSet() instanceof BindableProxy) {
          clone.setFontSet((FontSet) ((BindableProxy) getFontSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getFontSet())) {
          clone.setFontSet((FontSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getFontSet())).deepUnwrap());
        } else {
          clone.setFontSet(t.getFontSet());
        }
        if (t.getDimensionsSet() instanceof BindableProxy) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) getDimensionsSet()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getDimensionsSet())) {
          clone.setDimensionsSet((RectangleDimensionsSet) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getDimensionsSet())).deepUnwrap());
        } else {
          clone.setDimensionsSet(t.getDimensionsSet());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public BPMNGeneralSet getGeneral() {
        return target.getGeneral();
      }

      public void setGeneral(BPMNGeneralSet general) {
        if (agent.binders.containsKey("general")) {
          general = (BPMNGeneralSet) agent.binders.get("general").setModel(general, StateSync.FROM_MODEL, true);
        }
        changeAndFire("general", general);
      }

      public BackgroundSet getBackgroundSet() {
        return target.getBackgroundSet();
      }

      public void setBackgroundSet(BackgroundSet backgroundSet) {
        if (agent.binders.containsKey("backgroundSet")) {
          backgroundSet = (BackgroundSet) agent.binders.get("backgroundSet").setModel(backgroundSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("backgroundSet", backgroundSet);
      }

      public FontSet getFontSet() {
        return target.getFontSet();
      }

      public void setFontSet(FontSet fontSet) {
        if (agent.binders.containsKey("fontSet")) {
          fontSet = (FontSet) agent.binders.get("fontSet").setModel(fontSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("fontSet", fontSet);
      }

      public RectangleDimensionsSet getDimensionsSet() {
        return target.getDimensionsSet();
      }

      public void setDimensionsSet(RectangleDimensionsSet dimensionsSet) {
        if (agent.binders.containsKey("dimensionsSet")) {
          dimensionsSet = (RectangleDimensionsSet) agent.binders.get("dimensionsSet").setModel(dimensionsSet, StateSync.FROM_MODEL, true);
        }
        changeAndFire("dimensionsSet", dimensionsSet);
      }

      public String getCategory() {
        return target.getCategory();
      }

      public Set getLabels() {
        return target.getLabels();
      }

      public Object get(String property) {
        switch (property) {
          case "general": return getGeneral();
          case "backgroundSet": return getBackgroundSet();
          case "fontSet": return getFontSet();
          case "dimensionsSet": return getDimensionsSet();
          case "category": return getCategory();
          case "labels": return getLabels();
          case "this": return target;
          default: throw new NonExistingPropertyException("TextAnnotation", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "general": target.setGeneral((BPMNGeneralSet) value);
          break;
          case "backgroundSet": target.setBackgroundSet((BackgroundSet) value);
          break;
          case "fontSet": target.setFontSet((FontSet) value);
          break;
          case "dimensionsSet": target.setDimensionsSet((RectangleDimensionsSet) value);
          break;
          case "this": target = (org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("TextAnnotation", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy((org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_TextAnnotationProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy extends ReassignmentsEditorFieldDefinition implements BindableProxy {
      private BindableProxyAgent<ReassignmentsEditorFieldDefinition> agent;
      private ReassignmentsEditorFieldDefinition target;
      public org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy() {
        this(new ReassignmentsEditorFieldDefinition());
      }

      public org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy(ReassignmentsEditorFieldDefinition targetVal) {
        agent = new BindableProxyAgent<ReassignmentsEditorFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ReassignmentsEditorFieldType.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(ReassignmentsEditorFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public ReassignmentsEditorFieldDefinition unwrap() {
        return target;
      }

      public ReassignmentsEditorFieldDefinition deepUnwrap() {
        final ReassignmentsEditorFieldDefinition clone = new ReassignmentsEditorFieldDefinition();
        final ReassignmentsEditorFieldDefinition t = unwrap();
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setName(t.getName());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setId(t.getId());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public ReassignmentsEditorFieldType getFieldType() {
        return target.getFieldType();
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public Object get(String property) {
        switch (property) {
          case "validateOnChange": return getValidateOnChange();
          case "name": return getName();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "id": return getId();
          case "label": return getLabel();
          case "fieldType": return getFieldType();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "this": return target;
          default: throw new NonExistingPropertyException("ReassignmentsEditorFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "this": target = (ReassignmentsEditorFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("ReassignmentsEditorFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(ReassignmentsEditorFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy((ReassignmentsEditorFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_forms_model_ReassignmentsEditorFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy extends MultipleInstanceDataInput implements BindableProxy {
      private BindableProxyAgent<MultipleInstanceDataInput> agent;
      private MultipleInstanceDataInput target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy() {
        this(new MultipleInstanceDataInput());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy(MultipleInstanceDataInput targetVal) {
        agent = new BindableProxyAgent<MultipleInstanceDataInput>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("value", new PropertyType(String.class, false, false));
        p.put("this", new PropertyType(MultipleInstanceDataInput.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public MultipleInstanceDataInput unwrap() {
        return target;
      }

      public MultipleInstanceDataInput deepUnwrap() {
        final MultipleInstanceDataInput clone = new MultipleInstanceDataInput();
        final MultipleInstanceDataInput t = unwrap();
        clone.setValue(t.getValue());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public String getValue() {
        return target.getValue();
      }

      public void setValue(String value) {
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("MultipleInstanceDataInput", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((String) value);
          break;
          case "this": target = (MultipleInstanceDataInput) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("MultipleInstanceDataInput", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(MultipleInstanceDataInput.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy((MultipleInstanceDataInput) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_task_MultipleInstanceDataInputProxy();
      }
    });
    class org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy extends DecimalListBoxFieldDefinition implements BindableProxy {
      private BindableProxyAgent<DecimalListBoxFieldDefinition> agent;
      private DecimalListBoxFieldDefinition target;
      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy() {
        this(new DecimalListBoxFieldDefinition());
      }

      public org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy(DecimalListBoxFieldDefinition targetVal) {
        agent = new BindableProxyAgent<DecimalListBoxFieldDefinition>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("addEmptyOption", new PropertyType(Boolean.class, false, false));
        p.put("relatedField", new PropertyType(String.class, false, false));
        p.put("validateOnChange", new PropertyType(Boolean.class, false, false));
        p.put("defaultValue", new PropertyType(Double.class, false, false));
        p.put("binding", new PropertyType(String.class, false, false));
        p.put("readOnly", new PropertyType(Boolean.class, false, false));
        p.put("standaloneClassName", new PropertyType(String.class, false, false));
        p.put("fieldTypeInfo", new PropertyType(TypeInfo.class, false, false));
        p.put("label", new PropertyType(String.class, false, false));
        p.put("required", new PropertyType(Boolean.class, false, false));
        p.put("helpMessage", new PropertyType(String.class, false, false));
        p.put("options", new PropertyType(List.class, false, true));
        p.put("name", new PropertyType(String.class, false, false));
        p.put("dataProvider", new PropertyType(String.class, false, false));
        p.put("id", new PropertyType(String.class, false, false));
        p.put("fieldType", new PropertyType(ListBoxFieldType.class, false, false));
        p.put("this", new PropertyType(DecimalListBoxFieldDefinition.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public DecimalListBoxFieldDefinition unwrap() {
        return target;
      }

      public DecimalListBoxFieldDefinition deepUnwrap() {
        final DecimalListBoxFieldDefinition clone = new DecimalListBoxFieldDefinition();
        final DecimalListBoxFieldDefinition t = unwrap();
        clone.setAddEmptyOption(t.getAddEmptyOption());
        clone.setRelatedField(t.getRelatedField());
        clone.setValidateOnChange(t.getValidateOnChange());
        clone.setDefaultValue(t.getDefaultValue());
        clone.setBinding(t.getBinding());
        clone.setReadOnly(t.getReadOnly());
        clone.setStandaloneClassName(t.getStandaloneClassName());
        clone.setLabel(t.getLabel());
        clone.setRequired(t.getRequired());
        clone.setHelpMessage(t.getHelpMessage());
        if (t.getOptions() != null) {
          final List optionsClone = new ArrayList();
          for (Object optionsElem : t.getOptions()) {
            if (optionsElem instanceof BindableProxy) {
              optionsClone.add(((BindableProxy) optionsElem).deepUnwrap());
            } else {
              optionsClone.add(optionsElem);
            }
          }
          clone.setOptions(optionsClone);
        }
        clone.setName(t.getName());
        clone.setDataProvider(t.getDataProvider());
        clone.setId(t.getId());
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy) {
          obj = ((org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public Boolean getAddEmptyOption() {
        return target.getAddEmptyOption();
      }

      public void setAddEmptyOption(Boolean addEmptyOption) {
        changeAndFire("addEmptyOption", addEmptyOption);
      }

      public String getRelatedField() {
        return target.getRelatedField();
      }

      public void setRelatedField(String relatedField) {
        changeAndFire("relatedField", relatedField);
      }

      public Boolean getValidateOnChange() {
        return target.getValidateOnChange();
      }

      public void setValidateOnChange(Boolean validateOnChange) {
        changeAndFire("validateOnChange", validateOnChange);
      }

      public Double getDefaultValue() {
        return target.getDefaultValue();
      }

      public void setDefaultValue(Double defaultValue) {
        changeAndFire("defaultValue", defaultValue);
      }

      public String getBinding() {
        return target.getBinding();
      }

      public void setBinding(String binding) {
        changeAndFire("binding", binding);
      }

      public Boolean getReadOnly() {
        return target.getReadOnly();
      }

      public void setReadOnly(Boolean readOnly) {
        changeAndFire("readOnly", readOnly);
      }

      public String getStandaloneClassName() {
        return target.getStandaloneClassName();
      }

      public void setStandaloneClassName(String standaloneClassName) {
        changeAndFire("standaloneClassName", standaloneClassName);
      }

      public TypeInfo getFieldTypeInfo() {
        return target.getFieldTypeInfo();
      }

      public String getLabel() {
        return target.getLabel();
      }

      public void setLabel(String label) {
        changeAndFire("label", label);
      }

      public Boolean getRequired() {
        return target.getRequired();
      }

      public void setRequired(Boolean required) {
        changeAndFire("required", required);
      }

      public String getHelpMessage() {
        return target.getHelpMessage();
      }

      public void setHelpMessage(String helpMessage) {
        changeAndFire("helpMessage", helpMessage);
      }

      public List getOptions() {
        return target.getOptions();
      }

      public void setOptions(List<DecimalSelectorOption> options) {
        List<DecimalSelectorOption> oldValue = target.getOptions();
        options = agent.ensureBoundListIsProxied("options", options);
        target.setOptions(options);
        agent.updateWidgetsAndFireEvent(true, "options", oldValue, options);
      }

      public String getName() {
        return target.getName();
      }

      public void setName(String name) {
        changeAndFire("name", name);
      }

      public String getDataProvider() {
        return target.getDataProvider();
      }

      public void setDataProvider(String dataProvider) {
        changeAndFire("dataProvider", dataProvider);
      }

      public String getId() {
        return target.getId();
      }

      public void setId(String id) {
        changeAndFire("id", id);
      }

      public ListBoxFieldType getFieldType() {
        return target.getFieldType();
      }

      public Object get(String property) {
        switch (property) {
          case "addEmptyOption": return getAddEmptyOption();
          case "relatedField": return getRelatedField();
          case "validateOnChange": return getValidateOnChange();
          case "defaultValue": return getDefaultValue();
          case "binding": return getBinding();
          case "readOnly": return getReadOnly();
          case "standaloneClassName": return getStandaloneClassName();
          case "fieldTypeInfo": return getFieldTypeInfo();
          case "label": return getLabel();
          case "required": return getRequired();
          case "helpMessage": return getHelpMessage();
          case "options": return getOptions();
          case "name": return getName();
          case "dataProvider": return getDataProvider();
          case "id": return getId();
          case "fieldType": return getFieldType();
          case "this": return target;
          default: throw new NonExistingPropertyException("DecimalListBoxFieldDefinition", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "addEmptyOption": target.setAddEmptyOption((Boolean) value);
          break;
          case "relatedField": target.setRelatedField((String) value);
          break;
          case "validateOnChange": target.setValidateOnChange((Boolean) value);
          break;
          case "defaultValue": target.setDefaultValue((Double) value);
          break;
          case "binding": target.setBinding((String) value);
          break;
          case "readOnly": target.setReadOnly((Boolean) value);
          break;
          case "standaloneClassName": target.setStandaloneClassName((String) value);
          break;
          case "label": target.setLabel((String) value);
          break;
          case "required": target.setRequired((Boolean) value);
          break;
          case "helpMessage": target.setHelpMessage((String) value);
          break;
          case "options": target.setOptions((List<DecimalSelectorOption>) value);
          break;
          case "name": target.setName((String) value);
          break;
          case "dataProvider": target.setDataProvider((String) value);
          break;
          case "id": target.setId((String) value);
          break;
          case "this": target = (DecimalListBoxFieldDefinition) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("DecimalListBoxFieldDefinition", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }

      public void copyFrom(FieldDefinition a0) {
        target.copyFrom(a0);
        agent.updateWidgetsAndFireEvents();
      }
    }
    BindableProxyFactory.addBindableProxy(DecimalListBoxFieldDefinition.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy((DecimalListBoxFieldDefinition) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_forms_fields_shared_fieldTypes_basic_selectors_listBox_definition_DecimalListBoxFieldDefinitionProxy();
      }
    });
    class org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy extends NotificationsInfo implements BindableProxy {
      private BindableProxyAgent<NotificationsInfo> agent;
      private NotificationsInfo target;
      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy() {
        this(new NotificationsInfo());
      }

      public org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy(NotificationsInfo targetVal) {
        agent = new BindableProxyAgent<NotificationsInfo>(this, targetVal);
        target = targetVal;
        final Map<String, PropertyType> p = agent.propertyTypes;
        p.put("type", new PropertyType(org.kie.workbench.common.stunner.core.definition.property.PropertyType.class, false, false));
        p.put("value", new PropertyType(NotificationTypeListValue.class, true, false));
        p.put("this", new PropertyType(NotificationsInfo.class, true, false));
        agent.copyValues();
      }

      public BindableProxyAgent getBindableProxyAgent() {
        return agent;
      }

      public void updateWidgets() {
        agent.updateWidgetsAndFireEvents();
      }

      public NotificationsInfo unwrap() {
        return target;
      }

      public NotificationsInfo deepUnwrap() {
        final NotificationsInfo clone = new NotificationsInfo();
        final NotificationsInfo t = unwrap();
        if (t.getValue() instanceof BindableProxy) {
          clone.setValue((NotificationTypeListValue) ((BindableProxy) getValue()).deepUnwrap());
        } else if (BindableProxyFactory.isBindableType(t.getValue())) {
          clone.setValue((NotificationTypeListValue) ((BindableProxy) BindableProxyFactory.getBindableProxy(t.getValue())).deepUnwrap());
        } else {
          clone.setValue(t.getValue());
        }
        return clone;
      }

      public boolean equals(Object obj) {
        if (obj instanceof org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy) {
          obj = ((org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy) obj).unwrap();
        }
        return target.equals(obj);
      }

      public int hashCode() {
        return target.hashCode();
      }

      public String toString() {
        return target.toString();
      }

      private void changeAndFire(String property, Object value) {
        final Object oldValue = get(property);
        set(property, value);
        agent.updateWidgetsAndFireEvent(false, property, oldValue, value);
      }

      public org.kie.workbench.common.stunner.core.definition.property.PropertyType getType() {
        return target.getType();
      }

      public NotificationTypeListValue getValue() {
        return target.getValue();
      }

      public void setValue(NotificationTypeListValue value) {
        if (agent.binders.containsKey("value")) {
          value = (NotificationTypeListValue) agent.binders.get("value").setModel(value, StateSync.FROM_MODEL, true);
        }
        changeAndFire("value", value);
      }

      public Object get(String property) {
        switch (property) {
          case "type": return getType();
          case "value": return getValue();
          case "this": return target;
          default: throw new NonExistingPropertyException("NotificationsInfo", property);
        }
      }

      public void set(String property, Object value) {
        switch (property) {
          case "value": target.setValue((NotificationTypeListValue) value);
          break;
          case "this": target = (NotificationsInfo) value;
          agent.target = target;
          break;
          default: throw new NonExistingPropertyException("NotificationsInfo", property);
        }
      }

      public Map getBeanProperties() {
        final Map props = new HashMap(agent.propertyTypes);
        props.remove("this");
        return Collections.unmodifiableMap(props);
      }
    }
    BindableProxyFactory.addBindableProxy(NotificationsInfo.class, new BindableProxyProvider() {
      public BindableProxy getBindableProxy(Object model) {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy((NotificationsInfo) model);
      }
      public BindableProxy getBindableProxy() {
        return new org_kie_workbench_common_stunner_bpmn_definition_property_notification_NotificationsInfoProxy();
      }
    });
    Convert.registerDefaultConverter(NotificationType.class, String.class, new NotificationTypeDateConverter());
    Convert.registerDefaultConverter(ReassignmentType.class, String.class, new ReassignmentTypeDateConverter());
  }
}